from dataclasses import dataclass
from os import getenv
from pathlib import Path
from typing import List, Dict, Union

import yaml
from dacite import from_dict

BASE_DIR = Path(__file__).parent.parent.parent

TEST_CONFIG_PATH = Path(getenv('KEYCLOAK_FIXTURES_CONFIG_PATH',
                               (BASE_DIR / 'config/config.yaml').resolve().__str__()))


@dataclass
class OIDCIssuer:
    name: str
    url: str
    default_kid: str
    default: bool = False


@dataclass
class OIDCConfig:
    issuers: List[OIDCIssuer]
    redirect_uris: List[str]
    post_logout_redirect_uris: List[str]
    web_origins: List[str]
    oidc_provider_header_name: str
    access_token_header_name: str
    access_token_prefix: str
    watched_claims: List[str]


@dataclass
class KeycloakClient:
    name: str
    secret: str
    scopes: List[str]
    custom_claim: str
    custom_claim_capabilities: Dict


@dataclass
class KeycloakConfig:
    host: str
    port: int
    master_user: str
    master_password: str
    public_url: str
    client: KeycloakClient


@dataclass
class User:
    username: str
    password: str
    first_name: str
    last_name: str
    email: str
    authorized: bool


@dataclass
class Config:
    debug: bool
    legacy: bool
    keycloak: KeycloakConfig
    oidc: OIDCConfig
    users: List[User]


def _load_config(path: Path) -> Config:
    with open(path, 'r') as fp:
        return from_dict(data_class=Config, data=yaml.safe_load(fp))


CONFIG = _load_config(TEST_CONFIG_PATH)
