from csirtmu.auth_keycloak_test_utils.test_client import KeycloakTestClient
from requests import HTTPError

from csirtmu.auth_keycloak_fixture_loader.config import CONFIG


def _load():
    client = KeycloakTestClient(host=CONFIG.keycloak.host, port=CONFIG.keycloak.port,
                                master_user=CONFIG.keycloak.master_user, master_pass=CONFIG.keycloak.master_password,
                                public_url=CONFIG.keycloak.public_url, legacy=CONFIG.legacy)

    for issuer in CONFIG.oidc.issuers:
        client.create_realm(realm=issuer.name)
        client.create_client(realm=issuer.name, client=CONFIG.keycloak.client.name,
                             client_secret=CONFIG.keycloak.client.secret)
        for user in CONFIG.users:
            client.create_user(username=user.username, password=user.password, realm=issuer.name,
                               first_name=user.first_name, last_name=user.last_name, email=user.email)

        # Scope name is same as mapper name
        client.create_client_scope(realm=issuer.name, name=CONFIG.keycloak.client.custom_claim)
        scopes = client.get_client_scopes(realm=issuer.name)

        # Find scope's ID manually
        mock_scope_id: str = next(
            (scope['id'] for scope in scopes if scope['name'] == CONFIG.keycloak.client.custom_claim),
            None)
        for name, value in CONFIG.keycloak.client.custom_claim_capabilities.items():
            client.add_oidc_claim_to_client_scope(realm=issuer.name, client_scope_id=mock_scope_id,
                                                  mapper_name=name,
                                                  claim_name=name,
                                                  claim_value=value)

        clients = client.get_clients(realm=issuer.name)
        test_client_id: str = next(
            (client['id'] for client in clients if client['clientId'] == CONFIG.keycloak.client.name),
            None)
        client.add_default_client_scope_to_client(realm=issuer.name,
                                                  client_id=test_client_id,
                                                  client_scope_id=mock_scope_id)
        client.set_redirect_uris_for_client(realm=issuer.name, client=test_client_id,
                                            redirect_uris=CONFIG.oidc.redirect_uris)
        client.set_post_logout_redirect_uris_for_client(realm=issuer.name, client=test_client_id,
                                                        redirect_uris=CONFIG.oidc.post_logout_redirect_uris)
        client.set_web_origins_for_client(realm=issuer.name, client=test_client_id,
                                          web_origins=CONFIG.oidc.web_origins)

        for user in CONFIG.users:
            if not user.authorized:
                client.remove_role_mapping_from_user(issuer.name, role_name='default-roles-' + issuer.name.lower(),
                                                     username=user.username)


def load_fixtures():
    try:
        _load()
        print('Fixtures successfully loaded!')
        exit(0)
    except Exception as ex:
        print('Loading Keycloak fixtures failed with following exception:')
        print(ex)
        exit(1)


if __name__ == '__main__':
    load_fixtures()
