from io import BytesIO

from starlette.responses import StreamingResponse, Response

from csirtmu.case_database.models import WorkflowTemplate, TaskTemplate
from csirtmu.case_database.services.file_service import FileHandler


async def file_endpoint(request):
    file_id = request.path_params['file_id']
    file_name = request.path_params['file_name']
    file_handler = FileHandler.get_file_handler()
    file_content = file_handler.get_file(file_name, file_id)
    memory_file = BytesIO(file_content)
    response = StreamingResponse(memory_file)
    return response


class TemplateEndpoint:
    def __init__(self, session_maker):
        self.session_factory = session_maker

    async def get(self, request):
        template_type = request.path_params['template_type']
        template_id = request.path_params['template_id']
        template_name = request.path_params['template_name']

        template_name = template_name.split('.json')[0]
        template_cls = None
        if template_type == "workflow":
            template_cls = WorkflowTemplate
        elif template_type == "task":
            template_cls = TaskTemplate
        session = self.session_factory()
        template = session.query(template_cls).filter_by(id=template_id, name=template_name).first()

        if not template:
            return Response(content="Not Found", status_code=404)

        file_content = str.encode(template.template)
        memory_file = BytesIO(file_content)
        session.commit()
        session.close()
        return StreamingResponse(memory_file)
