import datetime
from typing import Optional, List

import strawberry
from strawberry.file_uploads import Upload

from csirtmu.case_database.gql.enums import KnownInputOutputTypes, CaseTypeEnum, CasePriorityEnum, \
    CaseStateEnum, TaskRelationshipTypeEnum, TaskStateEnum


@strawberry.input
class FileRefCreate:
    source: str = None
    created_by: Optional[strawberry.ID] = None
    parent: Optional[strawberry.ID] = None
    display_name: Optional[str] = None


@strawberry.input
class FileCreateComment:
    file: Upload = None
    created_by: Optional[strawberry.ID] = None
    display_name: Optional[str] = None
    extension: Optional[str] = None
    name: strawberry.Private[Optional[str]] = None


@strawberry.input
class FileCreate:
    file: Upload = None
    created_by: Optional[strawberry.ID] = None
    parent: Optional[strawberry.ID] = None
    display_name: Optional[str] = None
    extension: Optional[str] = None
    name: strawberry.Private[Optional[str]] = None


@strawberry.input
class WorkflowTemplateInput:
    id: strawberry.ID
    name: Optional[str] = None


@strawberry.input
class CaseCreate:
    name: str
    type: CaseTypeEnum
    priority: CasePriorityEnum
    created_by: Optional[strawberry.ID] = None
    labels: Optional[List[strawberry.ID]] = None
    assignees: Optional[List[strawberry.ID]] = None
    description: Optional[str] = None
    state: Optional[CaseStateEnum] = None
    due_date: Optional[datetime.datetime] = None
    workflow_templates: Optional[List[WorkflowTemplateInput]] = None


@strawberry.input
class PredecessorInput:
    predecessor: strawberry.ID = None
    predecessor_condition: TaskRelationshipTypeEnum = TaskRelationshipTypeEnum.ON_COMPLETION


@strawberry.input
class ParentMixin:
    predecessors: List[PredecessorInput] = None


@strawberry.input
class TaskCreateParentless:
    name: str
    description: str
    stage: strawberry.ID
    created_by: Optional[strawberry.ID] = None
    due_date: Optional[datetime.datetime] = None
    input_description: Optional[str] = None
    input_type: Optional[KnownInputOutputTypes] = None
    input_format: Optional[str] = None
    input: Optional[str] = None
    output_type: Optional[KnownInputOutputTypes] = None
    output_format: Optional[str] = None
    output: Optional[str] = None
    output_description: Optional[str] = None
    # flags
    is_automated: Optional[bool] = False
    aggregates_results: Optional[bool] = False
    autotrigger: Optional[bool] = False
    is_decision: Optional[bool] = False
    processing_queue: Optional[str] = None
    predecessors: Optional[List[PredecessorInput]] = None

    # private
    input_file: strawberry.Private[Optional[Upload]] = None
    state: strawberry.Private[Optional[TaskStateEnum]] = TaskStateEnum.PENDING


@strawberry.input
class TaskCreateParentlessBulk:
    task: TaskCreateParentless
    input_file: Optional[Upload] = None


@strawberry.input
class TaskCreate(ParentMixin, TaskCreateParentless):
    stage: Optional[strawberry.ID] = None


@strawberry.input
class TaskCreateBulk:
    task: TaskCreate
    input_file: Optional[Upload] = None


@strawberry.input
class TemplateCreate:
    name: str
    description: str
    template: Optional[str]
