from csirtmu.strawberry_dmt.sqla_base import AutoBase, fk_for, table_name_for, pk_name_for
from sqlalchemy import Column, String, DateTime, Integer
from sqlalchemy.ext.declarative import AbstractConcreteBase
from sqlalchemy.ext.declarative import declared_attr
from sqlalchemy.orm import backref, relationship
from sqlalchemy.sql.functions import func
from sqlalchemy.sql.schema import ForeignKey


class Activity(AbstractConcreteBase, AutoBase):
    created = Column(DateTime(timezone=True), server_default=func.now())
    content = Column(String, nullable=False)


class Comment(Activity):
    subject = Column(String)
    last_updated = Column(
        DateTime(timezone=True), onupdate=func.current_timestamp(), server_default=func.now())
    reply_to_id = Column(Integer, ForeignKey(pk_name_for("Comment"), use_alter=True, ondelete="CASCADE",
                                             name="fk_comment_parent"))

    @declared_attr
    def reply_to(self):
        return relationship("Comment",
                            backref=backref("replies", cascade="all, delete, delete-orphan", passive_deletes=True),
                            remote_side=[self.id], uselist=False)

    author_id = Column(Integer, ForeignKey("case_db_user.id", ondelete='CASCADE'), nullable=False)
    author = relationship("CaseDBUser", backref=backref("comments", cascade="all,delete"))
    case_id = Column(Integer, ForeignKey(pk_name_for("Case"), ondelete='CASCADE'))
    case = relationship("Case", back_populates="comments")
    task_id = Column(Integer, ForeignKey(pk_name_for("Task"), ondelete='CASCADE'))
    task = relationship("Task", back_populates="comments")

    __mapper_args__ = {
        "polymorphic_identity": table_name_for("Comment"),
        "concrete": True
    }
