import string
import random
from csirtmu.strawberry_dmt.sqla_base import AutoPolymorphicBase
from sqlalchemy import Column, Integer, String, DateTime
from sqlalchemy.orm import Session
from sqlalchemy.sql.functions import func

from csirtmu.case_database.config import CONFIG

ALPHABET = string.ascii_lowercase + string.digits


def get_unique_identifier(context):
    unique_identifier = "".join(random.choices(ALPHABET, k=8))
    with Session(bind=CONFIG.database.engine, expire_on_commit=False) as session:
        while session.query(Event).filter_by(unique_identifier=unique_identifier).first() is not None:
            unique_identifier = random.choices(ALPHABET, k=8)
    return unique_identifier


class Event(AutoPolymorphicBase(on_column='type')):
    name = Column(String)
    description = Column(String)
    event_time = Column(DateTime)
    created = Column(DateTime(timezone=True), server_default=func.now())
    type = Column(String(50))

    unique_identifier = Column(String(8), unique=True, nullable=False, default=get_unique_identifier)


class StorageEvent(Event):
    app_name = Column(String, nullable=False)
    message = Column(String, nullable=False)
    proc_id = Column(Integer, nullable=False)


class FlowEvent(Event):
    pass
