import random
import string
from urllib.parse import urlparse

import strawberry
from csirtmu.strawberry_dmt.sqla_base import AutoBase
from sqlalchemy import Column, String, DateTime, Enum
from sqlalchemy.ext.hybrid import hybrid_property
from sqlalchemy.orm import Session
from sqlalchemy.sql.functions import func

from csirtmu.case_database.config import CONFIG
from csirtmu.case_database.enums import CaseManagementExternalReferencePlatformEnum, \
    CaseManagementExternalReferenceCategoryEnum

ALPHABET = string.ascii_lowercase + string.digits


def get_unique_identifier(context):
    unique_identifier = "".join(random.choices(ALPHABET, k=8))
    with Session(bind=CONFIG.database.engine, expire_on_commit=False) as session:
        while session.query(CaseManagementExternalReference).filter_by(
                unique_identifier=unique_identifier).first() is not None:
            unique_identifier = random.choices(ALPHABET, k=8)
    return unique_identifier


class CaseManagementExternalReference(AutoBase):
    url = Column(String, nullable=False, unique=True)
    created = Column(DateTime(timezone=True), server_default=func.now())
    last_updated = Column(
        DateTime(timezone=True), onupdate=func.current_timestamp(), server_default=func.now())
    category = Column(Enum(CaseManagementExternalReferenceCategoryEnum), nullable=False)
    unique_identifier = Column(String(8), unique=True, nullable=False, default=get_unique_identifier)

    @hybrid_property
    def platform(self) -> strawberry.enum(CaseManagementExternalReferencePlatformEnum):
        parsed = urlparse(self.url)
        host = str(parsed.hostname)
        if 'github' in host:
            return CaseManagementExternalReferencePlatformEnum.GITHUB
        if 'gitlab' in host:
            return CaseManagementExternalReferencePlatformEnum.GITLAB
        if 'mattermost' in host:
            return CaseManagementExternalReferencePlatformEnum.MATTERMOST
        if 'jira' in host:
            return CaseManagementExternalReferencePlatformEnum.JIRA
        if 'misp' in host:
            return CaseManagementExternalReferencePlatformEnum.MISP
        return CaseManagementExternalReferencePlatformEnum.OTHER
