import typing

from oso import Oso
from strawberry.permission import BasePermission
from strawberry.types import Info


def is_authorized(model, permission):
    class IsAuthorizedPermission(BasePermission):
        def has_permission(self, source: typing.Any, info: Info, **kwargs) -> bool:
            oso: Oso = info.context['authorization'].oso
            self.message = f'The current user is not authorized to perform this action for this resource class. ' \
                           f'u={getattr(info.context["request"].user, "uid", None)}, c={permission}, ' \
                           f'r={model.__name__}'
            return oso.is_allowed(info.context['request'].user, permission, model)

    return IsAuthorizedPermission
