from dataclasses import dataclass
from typing import Optional, Union

from dataclasses_json import dataclass_json, DataClassJsonMixin, config

from csirtmu.case_database.gql.enums import KnownInputOutputTypes
from csirtmu.case_database.models import Task
from csirtmu.case_database.services.mappings import input_output_map


class IgnoreNoneMixin(DataClassJsonMixin):
    dataclass_json_config = config(
        exclude=lambda f: f is None or f == []
    )["dataclasses_json"]


@dataclass_json
@dataclass
class TaskTemplateBase(IgnoreNoneMixin):
    name: str
    description: str
    input_type: Optional[str] = None
    input_format: Optional[str] = None
    input_description: Optional[str] = None
    output_type: Optional[str] = None
    output_format: Optional[str] = None
    output_description: Optional[str] = None
    processing_queue: Optional[str] = None
    is_automated: Optional[bool] = False
    aggregates_results: Optional[bool] = False
    autotrigger: Optional[bool] = False
    is_decision: Optional[bool] = False


class TaskGenerator:
    @staticmethod
    def parse_task_template(task_template: Union[str, TaskTemplateBase], case_identifier=None) -> Task:
        if isinstance(task_template, str):
            task_template = TaskTemplateBase.from_json(task_template)
        task_parameters = {"name": task_template.name, "description": task_template.description,
                           "processing_queue": task_template.processing_queue,
                           "is_automated": task_template.is_automated, "is_decision": task_template.is_decision,
                           "aggregates_results": task_template.aggregates_results,
                           "autotrigger": task_template.autotrigger}
        if task_template.input_type:
            if io_cls := input_output_map.get(KnownInputOutputTypes(task_template.input_type), None):
                task_parameters["input"] = io_cls()
            if task_template.input_format:
                task_parameters["input"].format_field = task_template.input_format
            task_parameters["input"].description = task_template.input_description

        if task_template.output_type:
            if io_cls := input_output_map.get(KnownInputOutputTypes(task_template.output_type), None):
                task_parameters["output"] = io_cls()
            if task_template.output_format:
                task_parameters["output"].format_field = task_template.output_format
            task_parameters["output"].description = task_template.output_description

        task = Task(**task_parameters)
        task.case_identifier = case_identifier

        return task
