from csirtmu.case_database.models import Task, Workflow
from csirtmu.case_database.services.mappings import input_output_reverse_map
from csirtmu.case_database.services.task_generator_service import TaskTemplateBase
from csirtmu.case_database.services.workflow_generator_service import TaskTemplate, StageTemplate, WorkflowTemplate


class TemplateGenerator:
    def parse_workflow(self, workflow: Workflow) -> WorkflowTemplate:
        stages = []
        for stage in workflow.stages:
            tasks = []
            for task in stage.tasks:
                relationships = dict(on_completion=[], on_false=[], on_true=[], blocked_by=[])
                for relationship in task.source_relationships:
                    relationships[relationship.relationship_type.value].append(relationship.target.id)
                task_template_base = self.parse_task(task).to_dict()
                tasks.append(TaskTemplate(id=task.id, **relationships, **task_template_base))
            stages.append(StageTemplate(stage.name, stage.description, tasks))

        return WorkflowTemplate(workflow.name, workflow.description, stages)

    @staticmethod
    def parse_task(task: Task) -> TaskTemplateBase:
        input_ = {}
        output_ = {}
        if task.input:
            input_["input_type"] = input_output_reverse_map[type(task.input)].value
            input_["input_description"] = task.input.description
            input_["input_format"] = task.input.format_field
        if task.output:
            output_["output_type"] = input_output_reverse_map[type(task.output)].value
            output_["output_description"] = task.output.description
            output_["output_format"] = task.output.format_field

        return TaskTemplateBase(name=task.name, description=task.description, is_decision=task.is_decision,
                                processing_queue=task.processing_queue, is_automated=task.is_automated,
                                aggregates_results=task.aggregates_results, autotrigger=task.autotrigger,
                                **input_, **output_)
