from typing import List

from csirtmu.case_database.config import CONFIG
from csirtmu.case_database.enums import TaskStateEnum


def get_file_location(file_id, file_name):
    return f"{CONFIG.external_url}/file/{file_id}/{file_name}"


def get_template_location(template_type, template_id, template_name):
    return f"{CONFIG.external_url}/template/{template_type}/{template_id}/{template_name}"


def has_accepting_predecessors(task, source, accepting_states: List[TaskStateEnum]):
    task_predecessors = [relationship.source for relationship in task.target_relationships if
                         relationship.source.id != source.id]
    return all(predecessor.state in accepting_states for predecessor in task_predecessors)


def has_resolved_predecessors(task, source):
    accepting_states = [TaskStateEnum.RESOLVED, TaskStateEnum.SKIPPED]
    return has_accepting_predecessors(task, source, accepting_states)


def has_skipped_predecessors(task, source):
    accepting_states = [TaskStateEnum.SKIPPED]
    return has_accepting_predecessors(task, source, accepting_states)


def has_multiple_predecessors(task):
    task_predecessors = [relationship.source for relationship in task.target_relationships]
    return len(task_predecessors) > 1
