from aiohttp import ClientSession
from minio import Minio
from redis.client import Redis
from starlette import status
from starlette.requests import Request
from starlette.responses import JSONResponse

from csirtmu.case_database.config import CONFIG

OK = "✌"
NOK = "🪦 healthyn't 🐁"


class AppState:
    def __init__(self):
        self.healthy = True


def create_healthcheck_liveness(state: AppState):
    async def healthcheck_liveness(request: Request):
        return JSONResponse(OK if state.healthy else NOK, status_code=200)

    return healthcheck_liveness


def create_healthcheck_readiness(state: AppState):
    async def healthcheck_readiness(request: Request):
        status_data = {"case_database_service": OK if state.healthy else NOK, "database": OK, "redis": OK, "minio": OK}
        ready = state.healthy
        # DB
        try:
            CONFIG.database.engine.connect().close()
        except Exception:
            status_data["database"] = NOK
            ready = False
        # Minio
        try:
            Minio(f"{CONFIG.minio_file_storage.host}:{CONFIG.minio_file_storage.port}", access_key=CONFIG.minio_file_storage.access_key,
                  secret_key=CONFIG.minio_file_storage.secret_key, secure=False).list_buckets()
        except Exception:
            status_data["minio"] = NOK
            ready = False
        # Redis
        try:
            connection = Redis(CONFIG.redis.host, CONFIG.redis.port, db=0, username=CONFIG.redis.username,
                               password=CONFIG.redis.password, socket_connect_timeout=1)
            connection.info()
        except Exception:
            status_data["redis"] = NOK
            ready = False
        return JSONResponse(status_data,
                            status_code=status.HTTP_200_OK if ready else status.HTTP_503_SERVICE_UNAVAILABLE)

    return healthcheck_readiness
