import os
from gql import gql, Client
from gql.transport.aiohttp import AIOHTTPTransport
from graphql.type.schema import GraphQLSchema
from graphql.utilities import print_schema
from pathlib import Path
import json

#load templates
templates_directory = (Path(__file__).parent / "tests/assets/templates")
templates = os.listdir(templates_directory)

if len(templates) == 0:
    print("No templates")
    exit(0)

template_queries = []

for template in templates:
    template_path = (templates_directory / template).resolve()
    with open(template_path, "r") as template_file:
        template_json = json.load(template_file)
        escaped_template = json.dumps(json.dumps(template_json))
        template_query = f"{{description: \"{template_json['description']}\", name: \"{template_json['name']}\", template: {escaped_template}}}"
        template_queries.append(template_query)

transport = AIOHTTPTransport(url="http://localhost:8001/graphql")
client = Client(transport=transport, fetch_schema_from_transport=True)

query = gql(f"""
    mutation UploadTemplates {{
        createWorkflowTemplateBulk(dataList: [{' '.join(template_queries)}]){{
            id
        }}
    }} 
    """)
result = client.execute(query)
print(result)
