-- STAGE task update

DO
$$
    BEGIN
        CREATE FUNCTION update_stage_progress_tr() RETURNS TRIGGER AS
        $update_stage_progress_tr$
        DECLARE
            cnt integer;
        BEGIN
            SELECT COUNT(*) FROM task WHERE task.stage_id = NEW.stage_id INTO cnt;
            UPDATE stage
            SET progress =
                    CASE
                        WHEN stage.state = 'REJECTED'
                            THEN 100.0
                        WHEN cnt > 0
                            THEN ((SELECT COUNT(*)
                                   FROM task
                                   WHERE task.stage_id = stage.id
                                     AND task.state IN ('SKIPPED', 'RESOLVED', 'REJECTED'))
                                      * 100.0 / cnt)
                        ELSE 0.0
                        END
            WHERE stage.id = NEW.stage_id;
            RETURN NEW;
        END;
        $update_stage_progress_tr$ LANGUAGE plpgsql;
    EXCEPTION
        WHEN duplicate_function THEN null;
    END;
$$;

CREATE TRIGGER update_stage_progress
    AFTER UPDATE OR INSERT
    ON task
    FOR EACH ROW
EXECUTE function update_stage_progress_tr();

-- STAGE state update

do
$$
    BEGIN
        CREATE FUNCTION update_stage_progress_state_tr() RETURNS TRIGGER AS
        $update_stage_progress_tr$
        DECLARE
            cnt integer;
        BEGIN
            SELECT COUNT(*) FROM task WHERE task.stage_id = NEW.id INTO cnt;
            NEW.progress :=
                    CASE
                        WHEN NEW.state = 'REJECTED'
                            THEN 100.0
                        WHEN cnt > 0
                            THEN ((SELECT COUNT(*)
                                   FROM task
                                   WHERE task.stage_id = NEW.id
                                     AND task.state IN ('SKIPPED', 'RESOLVED', 'REJECTED'))
                                      * 100.0 / cnt)
                        ELSE 0.0
                        END;
            RETURN NEW;
        END;
        $update_stage_progress_tr$ LANGUAGE plpgsql;
    EXCEPTION
        WHEN duplicate_function THEN null;
    END;
$$;


CREATE TRIGGER update_stage_state_progress
    AFTER UPDATE OR INSERT
    ON stage
    FOR EACH ROW
EXECUTE function update_stage_progress_state_tr();


-- WORKFLOW stage update


do
$$
    BEGIN
        CREATE FUNCTION update_workflow_progress_tr() RETURNS TRIGGER AS
        $update_workflow_progress_tr$
        DECLARE
            cnt integer;
        BEGIN
            SELECT COUNT(*) FROM stage WHERE stage.workflow_id = NEW.workflow_id INTO cnt;
            UPDATE workflow
            SET progress =
                    CASE
                        WHEN workflow.state = 'REJECTED'
                            THEN 100.0
                        WHEN cnt > 0
                            THEN ((SELECT COUNT(*)
                                   FROM stage
                                   WHERE stage.workflow_id = workflow.id
                                     AND stage.state IN ('DONE', 'REJECTED'))
                                      * 100.0 / cnt)
                        ELSE 0.0
                        END
            WHERE workflow.id = NEW.workflow_id;
            RETURN NEW;
        END;
        $update_workflow_progress_tr$ LANGUAGE plpgsql;
    EXCEPTION
        WHEN duplicate_function THEN null;
    END;
$$;

CREATE TRIGGER update_workflow_progress
    AFTER UPDATE OR INSERT
    ON stage
    FOR EACH ROW
EXECUTE function update_workflow_progress_tr();

-- WORKFLOW state update

do
$$
    BEGIN
        CREATE FUNCTION update_workflow_progress_state_tr() RETURNS TRIGGER AS
        $update_workflow_progress_state_tr$
        DECLARE
            cnt integer;
        BEGIN
            SELECT COUNT(*) FROM stage WHERE stage.workflow_id = NEW.id INTO cnt;
            NEW.progress :=
                    CASE
                        WHEN NEW.state = 'REJECTED'
                            THEN 100.0
                        WHEN cnt > 0
                            THEN ((SELECT COUNT(*)
                                   FROM stage
                                   WHERE stage.workflow_id = NEW.id
                                     AND stage.state IN ('DONE', 'REJECTED'))
                                      * 100.0 / cnt)
                        ELSE 0.0
                        END;
            RETURN NEW;
        END;
        $update_workflow_progress_state_tr$ LANGUAGE plpgsql;
    EXCEPTION
        WHEN duplicate_function THEN null;
    END;
$$;

CREATE TRIGGER update_workflow_state_progress
    AFTER UPDATE OR INSERT
    ON workflow
    FOR EACH ROW
EXECUTE function update_workflow_progress_state_tr();