-- STAGE self state

DROP FUNCTION IF EXISTS update_stage_state_tr();
CREATE FUNCTION update_stage_state_tr() RETURNS TRIGGER AS
$update_stage_state_tr$
DECLARE
    cnt integer;
BEGIN
    IF new.state != ('REJECTED' :: stagestateenum) AND new.state = old.state THEN
        DROP TABLE IF EXISTS tasks;
        CREATE TEMP TABLE tasks AS
        SELECT id, state FROM task WHERE task.stage_id = new.id;
        SELECT COUNT(*) FROM tasks INTO cnt;
        new.state :=
                CASE
                    WHEN cnt = 0
                        THEN 'PENDING' :: stagestateenum
                    WHEN cnt = (SELECT COUNT(*) FROM tasks WHERE tasks.state = 'PENDING')
                        THEN 'PENDING' :: stagestateenum
                    WHEN cnt = (SELECT COUNT(*) FROM tasks WHERE tasks.state = 'REJECTED')
                        THEN 'REJECTED' :: stagestateenum
                    WHEN cnt =
                         (SELECT COUNT(*) FROM tasks WHERE tasks.state IN ('REJECTED', 'RESOLVED', 'SKIPPED'))
                        THEN 'DONE' :: stagestateenum
                    ELSE 'IN_PROGRESS' :: stagestateenum
                    END;
        DROP TABLE tasks;
    END IF;
    RETURN new;
END;
$update_stage_state_tr$ LANGUAGE plpgsql;

CREATE TRIGGER update_stage_state
    AFTER UPDATE
    ON stage
    FOR EACH ROW
EXECUTE function update_stage_state_tr();

-- STAGE task state

DROP FUNCTION IF EXISTS update_stage_task_state_tr();
CREATE FUNCTION update_stage_task_state_tr() RETURNS TRIGGER AS
$update_stage_task_state_tr$
DECLARE
    cnt integer;
BEGIN
    IF (SELECT state FROM stage WHERE stage.id = new.stage_id) != 'REJECTED'::stagestateenum
        THEN
        DROP TABLE IF EXISTS tasks1;
        CREATE TEMP TABLE tasks1 AS
        SELECT id, state FROM task WHERE task.stage_id = new.stage_id;
        SELECT COUNT(*) FROM tasks1 INTO cnt;
        UPDATE stage
        SET state =
                CASE
                    WHEN cnt = 0
                        THEN 'PENDING' :: stagestateenum
                    WHEN cnt = (SELECT COUNT(*) FROM tasks1 WHERE tasks1.state = 'PENDING')
                        THEN 'PENDING' :: stagestateenum
                    WHEN cnt = (SELECT COUNT(*) FROM tasks1 WHERE tasks1.state = 'REJECTED')
                        THEN 'REJECTED' :: stagestateenum
                    WHEN cnt =
                         (SELECT COUNT(*) FROM tasks1 WHERE tasks1.state IN ('RESOLVED', 'REJECTED', 'SKIPPED'))
                        THEN 'DONE' :: stagestateenum
                    ELSE 'IN_PROGRESS' :: stagestateenum
                    END
        WHERE stage.id = new.stage_id;
        DROP TABLE tasks1;
    END IF;
    RETURN new;
END;
$update_stage_task_state_tr$ LANGUAGE plpgsql;

CREATE TRIGGER update_stage_task_state
    AFTER UPDATE OR INSERT
    ON task
    FOR EACH ROW
EXECUTE function update_stage_task_state_tr();

-- WORKFLOW self state

DROP FUNCTION IF EXISTS update_workflow_state_tr();
CREATE FUNCTION update_workflow_state_tr() RETURNS TRIGGER AS
$update_workflow_state_tr$
DECLARE
    cnt integer;
BEGIN
    IF new.state != ('REJECTED' :: workflowstateenum) AND new.state = old.state THEN
        DROP TABLE IF EXISTS stages;
        CREATE TEMP TABLE stages AS
        SELECT id, state FROM stage WHERE stage.workflow_id = new.id;
        SELECT COUNT(*) FROM stages INTO cnt;
        new.state :=
                CASE
                    WHEN cnt = 0
                        THEN 'IN_PROGRESS' :: workflowstateenum
                    WHEN (SELECT COUNT(*) FROM stages WHERE stages.state IN ('IN_PROGRESS', 'PENDING')) > 0
                        THEN 'IN_PROGRESS' :: workflowstateenum
                    ELSE 'DONE' :: workflowstateenum
                    END;
        DROP TABLE stages;
    END IF;
    RETURN new;
END;
$update_workflow_state_tr$ LANGUAGE plpgsql;

CREATE TRIGGER update_workflow_state
    AFTER UPDATE
    ON workflow
    FOR EACH ROW
EXECUTE function update_workflow_state_tr();

-- WORKFLOW stage state

DROP FUNCTION IF EXISTS update_workflow_stage_state_tr();
CREATE FUNCTION update_workflow_stage_state_tr() RETURNS TRIGGER AS
$update_workflow_stage_state_tr$
DECLARE
    cnt integer;
BEGIN

    IF (SELECT state FROM workflow WHERE workflow.id = new.workflow_id) != 'REJECTED'::workflowstateenum
        THEN
        DROP TABLE IF EXISTS stages1;
        CREATE TEMP TABLE stages1 AS
        SELECT id, state FROM stage WHERE stage.workflow_id = new.workflow_id;
        SELECT COUNT(*) FROM stages1 INTO cnt;
        UPDATE workflow
        SET state =
                CASE
                    WHEN cnt = 0
                        THEN 'IN_PROGRESS' :: workflowstateenum
                    WHEN (SELECT COUNT(*) FROM stages1 WHERE stages1.state IN ('IN_PROGRESS', 'PENDING')) > 0
                        THEN 'IN_PROGRESS' :: workflowstateenum
                    ELSE 'DONE' :: workflowstateenum
                    END
        WHERE workflow.id = new.workflow_id;
        DROP TABLE stages1;
    END IF;
    RETURN new;
END;
$update_workflow_stage_state_tr$ LANGUAGE plpgsql;

CREATE TRIGGER update_workflow_stage_state
    AFTER UPDATE OR INSERT
    ON stage
    FOR EACH ROW
EXECUTE function update_workflow_stage_state_tr();