"""Create tables

Revision ID: ac14153a4509
Revises: 
Create Date: 2022-06-16 16:08:35.044950

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.databases import postgres

# revision identifiers, used by Alembic.
revision = 'ac14153a4509'
down_revision = None
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('activity',
    sa.Column('created', sa.DateTime(timezone=True), server_default=sa.text('now()'), nullable=True),
    sa.Column('content', sa.String(), nullable=False),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('case_db_role',
    sa.Column('name', sa.String(), nullable=False),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('case_db_user',
    sa.Column('name', sa.String(), nullable=False),
    sa.Column('icon_src', sa.String(), nullable=True),
    sa.Column('global_identifier', sa.String(), nullable=False),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.PrimaryKeyConstraint('id'),
    sa.UniqueConstraint('global_identifier')
    )
    op.create_table('case_management_external_reference',
    sa.Column('url', sa.String(), nullable=False),
    sa.Column('created', sa.DateTime(timezone=True), server_default=sa.text('now()'), nullable=True),
    sa.Column('last_updated', sa.DateTime(timezone=True), nullable=True),
    sa.Column('category', sa.Enum('CONVERSATION', 'INTELLIGENCE', 'TICKET', name='casemanagementexternalreferencecategoryenum'), nullable=False),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.PrimaryKeyConstraint('id'),
    sa.UniqueConstraint('url')
    )
    op.create_table('event',
    sa.Column('created', sa.DateTime(timezone=True), server_default=sa.text('now()'), nullable=True),
    sa.Column('type', sa.String(length=50), nullable=True),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('label',
    sa.Column('name', sa.String(), nullable=False),
    sa.Column('backgroundColor', sa.String(), nullable=True),
    sa.Column('textColor', sa.String(), nullable=True),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('task_input_output',
    sa.Column('type', sa.String(length=50), nullable=True),
    sa.Column('input_of_id', sa.Integer(), nullable=True),
    sa.Column('output_of_id', sa.Integer(), nullable=True),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['input_of_id'], ['task.id'], name='fk_task_input', ondelete='CASCADE', use_alter=True),
    sa.ForeignKeyConstraint(['output_of_id'], ['task.id'], name='fk_task_output', ondelete='CASCADE', use_alter=True),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('task_reference',
    sa.Column('source_id', sa.Integer(), nullable=False),
    sa.Column('target_id', sa.Integer(), nullable=False),
    sa.Column('relationship_type', sa.Enum('REFERS_TO', name='taskreferencetypeenum'), nullable=False),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['source_id'], ['task.id'], name='fk_source_reference', ondelete='CASCADE', use_alter=True),
    sa.ForeignKeyConstraint(['target_id'], ['task.id'], name='fk_target_reference', ondelete='CASCADE', use_alter=True),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('task_relationship',
    sa.Column('source_id', sa.Integer(), nullable=False),
    sa.Column('target_id', sa.Integer(), nullable=False),
    sa.Column('relationship_type', sa.Enum('ON_COMPLETION', 'ON_TRUE', 'ON_FALSE', name='taskrelationshiptypeenum'), nullable=False),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['source_id'], ['task.id'], name='fk_source_relationship', ondelete='CASCADE', use_alter=True),
    sa.ForeignKeyConstraint(['target_id'], ['task.id'], name='fk_target_relationship', ondelete='CASCADE', use_alter=True),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('workflow_template',
    sa.Column('name', sa.String(), nullable=False),
    sa.Column('description', sa.String(), nullable=False),
    sa.Column('created', sa.DateTime(timezone=True), server_default=sa.text('now()'), nullable=True),
    sa.Column('last_updated', sa.DateTime(timezone=True), nullable=True),
    sa.Column('template', sa.String(), nullable=True),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('bool_input_output',
    sa.Column('boolean_value', sa.Boolean(), nullable=True),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['id'], ['task_input_output.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('case',
    sa.Column('weight', sa.Integer(), nullable=True),
    sa.Column('name', sa.String(), nullable=False),
    sa.Column('description', sa.String(), nullable=True),
    sa.Column('state', sa.Enum('IN_PROGRESS', 'OPEN', 'RESOLVED', 'REJECTED', name='casestateenum'), nullable=True),
    sa.Column('priority', sa.Enum('LOW', 'MEDIUM', 'HIGH', name='casepriorityenum'), nullable=False),
    sa.Column('type', sa.Enum('INCIDENT', 'CAMPAIGN', name='casetypeenum'), nullable=False),
    sa.Column('created', sa.DateTime(timezone=True), server_default=sa.text('now()'), nullable=True),
    sa.Column('created_by_id', sa.Integer(), nullable=True),
    sa.Column('last_updated', sa.DateTime(timezone=True), nullable=True),
    sa.Column('due_date', sa.DateTime(timezone=True), nullable=True),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['created_by_id'], ['case_db_user.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('case_db_user__m2m__case_db_role',
    sa.Column('case_db_user_id', sa.Integer(), nullable=False),
    sa.Column('case_db_role_id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['case_db_role_id'], ['case_db_role.id'], ),
    sa.ForeignKeyConstraint(['case_db_user_id'], ['case_db_user.id'], ),
    sa.PrimaryKeyConstraint('case_db_user_id', 'case_db_role_id')
    )
    op.create_table('case_file_item',
    sa.Column('name', sa.String(), nullable=False),
    sa.Column('created', sa.DateTime(timezone=True), server_default=sa.text('now()'), nullable=True),
    sa.Column('created_by_id', sa.Integer(), nullable=True),
    sa.Column('parent_id', sa.Integer(), nullable=True),
    sa.Column('type', sa.String(length=20), nullable=True),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['created_by_id'], ['case_db_user.id'], ),
    sa.ForeignKeyConstraint(['parent_id'], ['directory.id'], name='fk_cfi_parent', ondelete='CASCADE', use_alter=True),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('date_input_output',
    sa.Column('date_value', sa.Date(), nullable=True),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['id'], ['task_input_output.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('date_time_input_output',
    sa.Column('datetime_value', sa.DateTime(), nullable=True),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['id'], ['task_input_output.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('domain_input_output',
    sa.Column('domain_value', sa.String(), nullable=True),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['id'], ['task_input_output.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('email_address_input_output',
    sa.Column('email_address_value', sa.String(), nullable=True),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['id'], ['task_input_output.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('email_message_input_output',
    sa.Column('email_message_value', sa.String(), nullable=True),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['id'], ['task_input_output.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('file_input_output',
    sa.Column('file_value', sa.String(), nullable=True),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['id'], ['task_input_output.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('file_ref_input_output',
    sa.Column('file_ref_value', sa.String(), nullable=True),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['id'], ['task_input_output.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('hash_input_output',
    sa.Column('hash_value', sa.String(), nullable=True),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['id'], ['task_input_output.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('ip_input_output',
    sa.Column('ip_value', sa.String(), nullable=True),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['id'], ['task_input_output.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('json_form_input_output',
    sa.Column('json_form_value', sa.String(), nullable=True),
    sa.Column('json_form_schema', sa.String(), nullable=True),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['id'], ['task_input_output.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('json_input_output',
    sa.Column('json_value', sa.String(), nullable=True),
    sa.Column('json_schema', sa.String(), nullable=True),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['id'], ['task_input_output.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('storage_event',
    sa.Column('app_name', sa.String(), nullable=False),
    sa.Column('message', sa.String(), nullable=False),
    sa.Column('proc_id', sa.Integer(), nullable=False),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['id'], ['event.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('string_input_output',
    sa.Column('string_value', sa.String(), nullable=True),
    sa.Column('string_regex', sa.String(), nullable=True),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['id'], ['task_input_output.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('url_input_output',
    sa.Column('url_value', sa.String(), nullable=True),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['id'], ['task_input_output.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('case__m2m__case_db_user',
    sa.Column('case_id', sa.Integer(), nullable=False),
    sa.Column('case_db_user_id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['case_db_user_id'], ['case_db_user.id'], ondelete='CASCADE'),
    sa.ForeignKeyConstraint(['case_id'], ['case.id'], ondelete='CASCADE'),
    sa.PrimaryKeyConstraint('case_id', 'case_db_user_id')
    )
    op.create_table('case__m2m__case_management_external_reference',
    sa.Column('case_id', sa.Integer(), nullable=False),
    sa.Column('case_management_external_reference_id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['case_id'], ['case.id'], ondelete='CASCADE'),
    sa.ForeignKeyConstraint(['case_management_external_reference_id'], ['case_management_external_reference.id'], ondelete='CASCADE'),
    sa.PrimaryKeyConstraint('case_id', 'case_management_external_reference_id')
    )
    op.create_table('case__m2m__event',
    sa.Column('case_id', sa.Integer(), nullable=False),
    sa.Column('event_id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['case_id'], ['case.id'], ondelete='CASCADE'),
    sa.ForeignKeyConstraint(['event_id'], ['event.id'], ondelete='CASCADE'),
    sa.PrimaryKeyConstraint('case_id', 'event_id')
    )
    op.create_table('case__m2m__label',
    sa.Column('case_id', sa.Integer(), nullable=False),
    sa.Column('label_id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['case_id'], ['case.id'], ondelete='CASCADE'),
    sa.ForeignKeyConstraint(['label_id'], ['label.id'], ondelete='CASCADE'),
    sa.PrimaryKeyConstraint('case_id', 'label_id')
    )
    op.create_table('case_relationship',
    sa.Column('source_id', sa.Integer(), nullable=False),
    sa.Column('target_id', sa.Integer(), nullable=False),
    sa.Column('type', sa.Enum('RELATES', 'DUPLICATES', 'BLOCKS', 'FOLLOWS', 'INCLUDES', 'REQUIRES', name='caserelationshiptypeenum'), nullable=False),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['source_id'], ['case.id'], ),
    sa.ForeignKeyConstraint(['target_id'], ['case.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('directory',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('case_id', sa.Integer(), nullable=True),
    sa.ForeignKeyConstraint(['case_id'], ['case.id'], name='fk_root_directory', ondelete='CASCADE', use_alter=True),
    sa.ForeignKeyConstraint(['id'], ['case_file_item.id'], ondelete='CASCADE'),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('file',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('external_src', sa.String(), nullable=True),
    sa.Column('display_name', sa.String(), nullable=True),
    sa.Column('extension', sa.String(), nullable=True),
    sa.ForeignKeyConstraint(['id'], ['case_file_item.id'], ondelete='CASCADE'),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('workflow',
    sa.Column('weight', sa.Integer(), nullable=True),
    sa.Column('name', sa.String(), nullable=False),
    sa.Column('description', sa.String(), nullable=False),
    sa.Column('created', sa.DateTime(timezone=True), server_default=sa.text('now()'), nullable=True),
    sa.Column('last_updated', sa.DateTime(timezone=True), nullable=True),
    sa.Column('due_date', sa.DateTime(timezone=True), nullable=True),
    sa.Column('case_id', sa.Integer(), nullable=True),
    sa.Column('created_by_id', sa.Integer(), nullable=True),
    sa.Column('state_internal', sa.Enum('IN_PROGRESS', 'DONE', 'REJECTED', name='workflowstateenum'), nullable=True),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['case_id'], ['case.id'], ),
    sa.ForeignKeyConstraint(['created_by_id'], ['case_db_user.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('stage',
    sa.Column('weight', sa.Integer(), nullable=True),
    sa.Column('name', sa.String(), nullable=False),
    sa.Column('description', sa.String(), nullable=False),
    sa.Column('created', sa.DateTime(timezone=True), server_default=sa.text('now()'), nullable=True),
    sa.Column('last_updated', sa.DateTime(timezone=True), nullable=True),
    sa.Column('due_date', sa.DateTime(timezone=True), nullable=True),
    sa.Column('workflow_id', sa.Integer(), nullable=True),
    sa.Column('created_by_id', sa.Integer(), nullable=True),
    sa.Column('state_internal', sa.Enum('IN_PROGRESS', 'PENDING', 'DONE', 'REJECTED', name='stagestateenum'), nullable=True),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['created_by_id'], ['case_db_user.id'], ),
    sa.ForeignKeyConstraint(['workflow_id'], ['workflow.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('workflow__m2m__case_db_user',
    sa.Column('workflow_id', sa.Integer(), nullable=False),
    sa.Column('case_db_user_id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['case_db_user_id'], ['case_db_user.id'], ondelete='CASCADE'),
    sa.ForeignKeyConstraint(['workflow_id'], ['workflow.id'], ondelete='CASCADE'),
    sa.PrimaryKeyConstraint('workflow_id', 'case_db_user_id')
    )
    op.create_table('stage__m2m__case_db_user',
    sa.Column('stage_id', sa.Integer(), nullable=False),
    sa.Column('case_db_user_id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['case_db_user_id'], ['case_db_user.id'], ondelete='CASCADE'),
    sa.ForeignKeyConstraint(['stage_id'], ['stage.id'], ondelete='CASCADE'),
    sa.PrimaryKeyConstraint('stage_id', 'case_db_user_id')
    )
    op.create_table('task',
    sa.Column('weight', sa.Integer(), nullable=True),
    sa.Column('name', sa.String(), nullable=False),
    sa.Column('description', sa.String(), nullable=False),
    sa.Column('created', sa.DateTime(timezone=True), server_default=sa.text('now()'), nullable=True),
    sa.Column('last_updated', sa.DateTime(timezone=True), nullable=True),
    sa.Column('due_date', sa.DateTime(timezone=True), nullable=True),
    sa.Column('state', sa.Enum('RUNNING', 'OPEN', 'PENDING', 'RESOLVED', 'REJECTED', 'SKIPPED', name='taskstateenum'), nullable=True),
    sa.Column('stage_id', sa.Integer(), nullable=True),
    sa.Column('is_automated', sa.Boolean(), nullable=True),
    sa.Column('type', sa.String(), nullable=True),
    sa.Column('task_type', postgres.ENUM('DECISION_TASK', 'GENERIC_TASK', 'TASK', name='knowntasktypesenum'), nullable=True),
    sa.Column('processing_queue', sa.String(), nullable=True),
    sa.Column('created_by_id', sa.Integer(), nullable=True),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['created_by_id'], ['case_db_user.id'], ),
    sa.ForeignKeyConstraint(['stage_id'], ['stage.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('comment',
    sa.Column('created', sa.DateTime(timezone=True), server_default=sa.text('now()'), nullable=True),
    sa.Column('content', sa.String(), nullable=False),
    sa.Column('subject', sa.String(), nullable=True),
    sa.Column('last_updated', sa.DateTime(timezone=True), nullable=True),
    sa.Column('reply_to_id', sa.Integer(), nullable=True),
    sa.Column('author_id', sa.Integer(), nullable=False),
    sa.Column('case_id', sa.Integer(), nullable=True),
    sa.Column('task_id', sa.Integer(), nullable=True),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['author_id'], ['case_db_user.id'], ondelete='CASCADE'),
    sa.ForeignKeyConstraint(['case_id'], ['case.id'], ),
    sa.ForeignKeyConstraint(['reply_to_id'], ['comment.id'], name='fk_comment_parent', ondelete='CASCADE', use_alter=True),
    sa.ForeignKeyConstraint(['task_id'], ['task.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('decision_task',
    sa.Column('decision', sa.String(length=50), nullable=True),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['id'], ['task.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('generic_task',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['id'], ['task.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('task__m2m__case_db_user',
    sa.Column('task_id', sa.Integer(), nullable=False),
    sa.Column('case_db_user_id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['case_db_user_id'], ['case_db_user.id'], ondelete='CASCADE'),
    sa.ForeignKeyConstraint(['task_id'], ['task.id'], ondelete='CASCADE'),
    sa.PrimaryKeyConstraint('task_id', 'case_db_user_id')
    )
    op.create_table('task__m2m__case_management_external_reference',
    sa.Column('task_id', sa.Integer(), nullable=False),
    sa.Column('case_management_external_reference_id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['case_management_external_reference_id'], ['case_management_external_reference.id'], ondelete='CASCADE'),
    sa.ForeignKeyConstraint(['task_id'], ['task.id'], ondelete='CASCADE'),
    sa.PrimaryKeyConstraint('task_id', 'case_management_external_reference_id')
    )
    op.create_table('task__m2m__event',
    sa.Column('task_id', sa.Integer(), nullable=False),
    sa.Column('event_id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['event_id'], ['event.id'], ondelete='CASCADE'),
    sa.ForeignKeyConstraint(['task_id'], ['task.id'], ondelete='CASCADE'),
    sa.PrimaryKeyConstraint('task_id', 'event_id')
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_table('task__m2m__event')
    op.drop_table('task__m2m__case_management_external_reference')
    op.drop_table('task__m2m__case_db_user')
    op.drop_table('generic_task')
    op.drop_table('decision_task')
    op.drop_table('comment')
    op.drop_table('stage__m2m__case_db_user')
    op.drop_table('workflow__m2m__case_db_user')
    op.drop_table('stage')
    op.drop_table('workflow')
    op.drop_table('file')
    op.drop_table('directory')
    op.drop_table('case_relationship')
    op.drop_table('case__m2m__label')
    op.drop_table('case__m2m__event')
    op.drop_table('case__m2m__case_management_external_reference')
    op.drop_table('case__m2m__case_db_user')
    op.drop_table('url_input_output')
    op.drop_table('string_input_output')
    op.drop_table('storage_event')
    op.drop_table('json_input_output')
    op.drop_table('json_form_input_output')
    op.drop_table('ip_input_output')
    op.drop_table('hash_input_output')
    op.drop_table('file_ref_input_output')
    op.drop_table('file_input_output')
    op.drop_table('email_message_input_output')
    op.drop_table('email_address_input_output')
    op.drop_table('domain_input_output')
    op.drop_table('date_time_input_output')
    op.drop_table('date_input_output')
    op.drop_table('case_file_item')
    op.drop_table('case_db_user__m2m__case_db_role')
    op.drop_table('case')
    op.drop_table('bool_input_output')
    op.drop_table('workflow_template')
    op.drop_table('task_relationship')
    op.drop_table('task_reference')
    op.drop_table('task_input_output')
    op.drop_table('label')
    op.drop_table('event')
    op.drop_table('case_management_external_reference')
    op.drop_table('case_db_user')
    op.drop_table('case_db_role')
    op.drop_table('activity')
    op.drop_table('task')
    # ### end Alembic commands ###
