import json
import os

from deepdiff import DeepDiff
from graphql import build_ast_schema, get_introspection_query, introspection_from_schema, parse

from tests.conftest import BASE_DIR


class TestCaseDatabase:

    def test_graphql_schema_introspection(self, client):
        with open(os.path.join(BASE_DIR, 'assets/schema/schema.graphql'), 'r') as s:
            raw_schema = s.read()
        schema = build_ast_schema(parse(raw_schema))
        expected = introspection_from_schema(schema, schema_description=False, input_value_deprecation=False,
                                             directive_is_repeatable=False)

        query = get_introspection_query(specified_by_url=True)

        response = client.post('/graphql', json=dict(query=query))
        assert response.status_code == 200

        # Some nulls are for some reason wrapped in double quotes
        result_string = response.content.decode("utf8").replace('\"null\"', 'null')
        result = json.loads(result_string)['data']

        difference = DeepDiff(result, expected, ignore_private_variables=False, ignore_order=True)

        assert difference == {}
