# CSIRTMU Integration Test Service

Service used in integration testing of Service Gateway. 

## Content

- [CSIRTMU User Service](#csirtmu-user-service)
  - [Notes](#notes) 
  - [Data Model](#data-model)
  - [Configuration](#configuration)
  - [Dependencies](#dependencies)
  - [Endpoints](#endpoints)
  - [Docker](#docker)
  - [Local development](#local-development)


---

## Notes

In-container PostgreSQL port is 5431.

---

## Data Model

![](./docs/data_model.png)

---

## Configuration

All configuration files are in _config_ directory or _tests/config_ if running locally.

[Configuration Management Library](https://gitlab.orion.lan/orion/backend-python/libraries/csirtmu-dataclass-config-loader)

### Environment Variables

- **TEST_SERVICE_CONFIG_PATH**: "Path to service configuration yaml file"
- **JWT_AUTH_BACKEND_CONFIG_PATH**: "Path to authorization configuration yaml file"

### Authorization

- Authorization is configured using the [authorization.polar](https://docs.osohq.com/) file in the _config_ directory.

- All users (even unauthenticated) have the **is:default** role, which grants the user all permissions.

---


## Dependencies

- Authorization
  => [Service Gateway](https://gitlab.orion.lan/orion/backend-python/applications/csirtmu-service-gateway/)
- PostgreSQL (built-in in the container)

---

## Endpoints

The application listens by default on port 8000.

- **/**: Graph(i)QL endpoint
- **/graphql**: Graph(i)QL endpoint
- **/healthcheck/liveness**: Liveness healthcheck
- **/healthcheck/readiness**: Readiness healthcheck
- **/payload-bouncer**: Unauthorized test endpoint for payload bouncing (return-to-sender)
- **/payload-bouncer-authorized**: Authorized test endpoint for payload bouncing (return-to-sender)

---

## Local Development

Configuration for local development.

- Required dependencies:
  - Python 3.9+
  - pip
  - [Poetry](https://python-poetry.org/docs/master/#installing-with-the-official-installer)

  ```console
  $ poetry config repositories.ORION https://gitlab.orion.lan/api/v4/projects/2485/packages/pypi/simple`
  $ poetry config http-basic.ORION token <GITLAB_TOKEN>`
  $ poetry install --with dev`
  $ export USER_SERVICE_CONFIG_PATH=./tests/config/config.yaml`
  $ export JWT_AUTH_BACKEND_CONFIG_PATH=./tests/config/config_jwt_auth.yaml`
  ```

### Server

Start the server locally.

  ```console
  $ poetry run uvicorn --port 8000 --host 127.0.0.1 --factory csirtmu.integration_test_service.app:app
  ```

---

### Tests

Run tests.

  ```console
  $ poetry run tox
  ```

---

## Docker
* To be able to build and run the image, follow the instructions:
  * Build and run Docker image:
    ```console
    $ docker build -t csirtmu-integration-test-service --build-arg POETRY_HTTP_BASIC_ORION_USERNAME=token --build-arg POETRY_HTTP_BASIC_ORION_PASSWORD=<GITLAB_TOKEN> .`
    $ docker run -d -p 127.0.0.1:8000:8000 -n csirtmu-integration-test-service-container csirtmu-integration-test-service
    ```
* Build args **POETRY_HTTP_BASIC_ORION_USERNAME** and **POETRY_HTTP_BASIC_ORION_PASSWORD** are necessary
to download Python packages from private registries.

---

## Helm

This service does not have a Helm chart, as it's only used in CI as a part of integration tests of other services.

---
