from dataclasses import dataclass
from os import getenv
from pathlib import Path

from csirtmu.dataclass_config_loader import Omit
from csirtmu.dataclass_config_loader.load import load_dataclass_config
from sqlalchemy import create_engine
from sqlalchemy.engine import Engine

BASE_DIR = Path(__file__).parent.parent.parent


@dataclass
class Database:
    host: str
    port: int
    username: str
    password: str
    database: str
    engine: Omit[Engine]


@dataclass
class Config:
    database: Database


def _load_config(path: Path) -> Config:
    config = load_dataclass_config(path, Config, 'TEST_SERVICE')
    config.database.engine = create_engine(
        f'postgresql+psycopg2://{config.database.username}:{config.database.password}@'
        f'{config.database.host}:{config.database.port}/{config.database.database}',
        future=True)

    return config


config_path = Path(getenv('TEST_SERVICE_CONFIG_PATH', (BASE_DIR / 'config/config.yaml').resolve().__str__()))
CONFIG = _load_config(config_path)
