from typing import List, Optional

from csirtmu.starlette_jwt_auth.models import MappedUser
from csirtmu.strawberry_dmt.sqla_base import AutoBase
from sqlalchemy import Column, String, select
from sqlalchemy.orm import Session

from csirtmu.integration_test_service.config import CONFIG


class RelationUserMeta(type(AutoBase), type(MappedUser)):
    pass


class RelationUser(AutoBase, MappedUser, metaclass=RelationUserMeta):
    uid = Column(String, unique=True, nullable=False)
    capabilities: List[str]

    def __init__(self, uid: str, capabilities: Optional[List[str]] = None):
        super().__init__()
        self.uid = uid
        if capabilities:
            self.capabilities = capabilities
        else:
            self.capabilities = []

    @property
    def identity(self) -> str:
        return self.uid

    @property
    def is_authenticated(self) -> bool:
        return True

    @property
    def display_name(self) -> str:
        return self.uid

    @staticmethod
    def create_or_get(access_token: str, user_id: str, capabilities: List[str]) -> 'RelationUser':
        user = CONFIG.auth_connection.execute(
            select(RelationUser).where(RelationUser.uid == user_id)
        ).first()
        if user:
            user = RelationUser(user['uid'], capabilities=capabilities)
        else:
            with Session(CONFIG.engine) as s:
                user = RelationUser(uid=user_id, capabilities=capabilities)
                s.add(user)
                s.commit()
                s.refresh(user)
                s.expunge(user)
        return user
