from oso import Oso, NotFoundError, ForbiddenError
from starlette import status
from starlette.requests import Request
from starlette.responses import Response, JSONResponse

from csirtmu.integration_test_service.utils import PayloadBouncer
from csirtmu.integration_test_service.config import CONFIG

OK = "✌"
NOK = "🪦 healthyn't 🐁"


async def healthcheck_liveness(request: Request):
    return JSONResponse(OK, status_code=200)


async def healthcheck_readiness(request: Request):
    status_data = {"service": OK, "database": OK}
    ready = True
    try:
        CONFIG.engine.connect().close()
    except Exception:
        status_data["database"] = NOK
        ready = False
    return JSONResponse(status_data, status_code=status.HTTP_200_OK if ready else status.HTTP_503_SERVICE_UNAVAILABLE)


def create_payload_bouncer(oso: Oso, authorized: bool = True):
    async def payload_bouncer(request: Request):
        if authorized:
            try:
                oso.authorize(request.user, 'bounce', PayloadBouncer)
            except (NotFoundError, ForbiddenError):
                return Response(status_code=status.HTTP_401_UNAUTHORIZED)
        if request.method == 'GET':
            return JSONResponse({
                'headers': dict(request.headers),
                'args': dict(request.query_params),
            }, status_code=200)
        else:
            return JSONResponse({
                'headers': dict(request.headers),
                'args': dict(request.query_params),
                'body': await request.json()
            }, status_code=200)

    return payload_bouncer
