import os
from pathlib import Path

import pytest
import pytest_asyncio
from csirtmu.strawberry_dmt.sqla_base import Base
from sqlalchemy.orm import close_all_sessions, sessionmaker
from starlette.authentication import AuthCredentials, AuthenticationBackend
from starlette.testclient import TestClient

from csirtmu.integration_test_service.config import BASE_DIR
from csirtmu.integration_test_service.config import CONFIG
from csirtmu.integration_test_service.models import RelationUser


class MockAuthenticationBackend(AuthenticationBackend):
    async def authenticate(self, conn):
        user = RelationUser('frank', ['is:default'])
        return AuthCredentials(["authenticated"]), user


@pytest_asyncio.fixture(scope='session', autouse=True)
def migrate_tables():
    Base.metadata.drop_all(CONFIG.database.engine)
    Base.metadata.create_all(CONFIG.database.engine)
    yield
    Base.metadata.drop_all(CONFIG.database.engine)
    close_all_sessions()


@pytest.fixture()
def client():
    os.environ['TEST_SERVICE_OSO'] = (BASE_DIR / 'tests/assets/authorization_allow_any.polar').resolve().__str__()
    from csirtmu.integration_test_service.app import app
    return TestClient(app())


@pytest_asyncio.fixture
def session():
    session_factory = sessionmaker(CONFIG.database.engine)
    s = session_factory()

    yield s

    s.expunge_all()
    s.close()


@pytest.fixture()
def queries():
    with open(BASE_DIR / 'tests/assets/queries.graphql', 'r') as f:
        return f.read()


@pytest.fixture()
def mutations():
    with open(BASE_DIR / 'tests/assets/mutations.graphql', 'r') as f:
        return f.read()


@pytest_asyncio.fixture()
def user_id(client, queries, mutations) -> str:
    test_user_uid = 'Frank'

    response = client.post('/graphql', json=dict(query=queries, operationName='userListByUID',
                                                 variables={'uid': test_user_uid}))
    if id_ := response.json().get('data').get('id'):
        return id_

    response = client.post('/graphql', json=dict(query=mutations, operationName='createUser',
                                                 variables={'uid': test_user_uid}))

    data = response.json()
    return data['data']['createRelationUser']['id']
