# CSIRT-MU Service Gateway

Service gateway for microservices with authentication and authorization support.

## Content

- [CSIRT-MU Service Gateway](#csirt-mu-service-gateway)
  - [Compatibility Table](#compatibility-table)
  - [Configuration](#configuration)
  - [Dependencies](#dependencies)
  - [Endpoints](#endpoints)
  - [Docker](#docker)
  - [Helm](#helm)
  - [Local development](#local-development)
  - [Notes](#notes)

## Compatibility Table

| Service Gateway | Starlette Auth Backend | Django Auth Backend |
|-----------------|------------------------|---------------------|
| 0.1.14 - 0.2.7  | \>=0.1.0               | \>=0.0.9            |

See up-to-date compatibility table in _csirtmu/service_gateway/versions.py_.

---

## Configuration

All configuration files are in _config_ directory or _tests/config_ if running locally.

[Configuration Management Library](https://gitlab.orion.lan/orion/backend-python/libraries/csirtmu-dataclass-config-loader)

- Create `config.yaml` based on example `config/config-gateway-example.yaml`
- Create `authorization.polar` based on example `config/authorization-example.polar`
- Set path to `config.yaml` in env var `SERVICE_GATEWAY_CONFIG_PATH`
- Set path to `authorization.polar` in env var `SERVICE_GATEWAY_OSO`

### Environment Variables

- **SERVICE_GATEWAY_CONFIG_PATH**: "Path to service configuration yaml file"
- **JWT_AUTH_BACKEND_CONFIG_PATH**: "Path to authorization configuration yaml file"

[YAML Configuration Overloading](https://gitlab.orion.lan/orion/backend-python/libraries/csirtmu-dataclass-config-loader)

---

## Dependencies

- Authorization
  => [Service Gateway](https://gitlab.orion.lan/orion/backend-python/applications/csirtmu-service-gateway/)
- PostgreSQL instance (API keys)
- Cache/Dragonfly
- Keycloak

---

## Endpoints

The application listens by default on port 8000.

### Endpoints

Dynamically mapped through configuration plus:

- **/\_gateway/healthcheck/liveness**: Liveness healthcheck
- **/\_gateway/healthcheck/readiness**: Readiness healthcheck
- **/\_gateway/metrics**: Prometheus metrics endpoint
- **/\_gateway/version**: Authorization backend version endpoint (for use with Service Gateway)
- **/\_gateway/api-token**: [GET, POST, DELETE] API token endpoint
- **/\_gateway/api-token-capabilities**: [GET] List capabilities of API token

---

## Docker

* To be able to build and run the image, follow the instructions:
  - Build args **POETRY_HTTP_BASIC_ORION_USERNAME** and **POETRY_HTTP_BASIC_ORION_PASSWORD** are necessary
to download Python packages from private registries.
  - Mount your `config.yaml`, and pass `SERVICE_GATEWAY_CONFIG_PATH` variable to the container, base path for the
  application is /app/
  - Build and run Docker image:
    ```console
    $ docker build -t csirtmu-service-gateway --build-arg POETRY_HTTP_BASIC_ORION_USERNAME=token --build-arg POETRY_HTTP_BASIC_ORION_PASSWORD=<GITLAB_TOKEN> .
    $ docker run -d -p 127.0.0.1:8000:8000 -n csirtmu-service-gateway-container csirtmu-service-gateway
    ```

---

## Helm

Install to Kubernetes cluster using helm.

* Make sure you have `helm` installed, and Kubernetes cluster up and running.
* Add *orion* helm repository:
  ```console
  $ helm repo add --username orion --password <personal_access_token> gitlab-orion https://gitlab.orion.lan/api/v4/projects/2485/packages/helm/stable
  ```
* Download chart dependencies:
    ```console
    $ cd csirtmu-service-gateway-chart
    $ helm dependency update
    ```
* Create image pull secret *csirtmu-service-gateway-secret* with container registry pull permissions:
    ```console
    $ kubectl create secret docker-registry csirtmu-service-gateway-secret --docker-server=registry.gitlab.orion.lan:443 --docker-username=orion --docker-password=${CONTAINER_REGISTRY_PULL}
    ```
* To deploy Helm chart into kubernetes cluster run:
    ```console
    $ helm upgrade --install --create-namespace --namespace csirtmu-service-gateway csirtmu-service-gateway .
    ```
* If you want to be able to access the application locally, run:
    ```console
    $ kubectl port-forward --namespace <namespace> <pod-name> <local-port>:8000
    ```

---

## Local Development

Configuration for local development.

- Required dependencies:
  - Python 3.9+
  - pip
  - [Poetry](https://python-poetry.org/docs/master/#installing-with-the-official-installer)
- `poetry config repositories.ORION https://gitlab.orion.lan/api/v4/projects/2485/packages/pypi/simple`
- `poetry config http-basic.ORION token <GITLAB_TOKEN>`
- `poetry install --with dev`

### Server

Start the server locally.

- `poetry run uvicorn --port 8000 --host 127.0.0.1 --factory csirtmu.service_gateway.app:app`

### Tests

Run tests.

#### With Docker

```console
$ docker compose up -d
$ export KEYCLOAK_FIXTURES_CONFIG_PATH=./tests/config/keycloak_fixtures/config_local.yaml
$ export SERVICE_GATEWAY_CONFIG_PATH=./tests/config/gateway/config-local-integration-test.yaml
$ poetry run tox
```

#### Without docker

- Not supported
- Mock all needed services (keycloak, postgresql) and fix test config in `tests/examples/.env.example`.

---

## Notes

If you run keycloak at f.e. 127.0.0.1:10042 and will use 'localhost' instead of '127.0.0.1', you will not be able to use
auth tokens.
### Version table

When releasing new version (updating `VERSION.txt`), you have to update file `versions.py` accordingly. 

### Handling overlapping paths

Gateway is using Starlette router and routes are being loaded in the order they are specified in `./config/config.yaml`.

If you want to have 'overlapping' routes, you'll need to put the longer (more complex) ones before the shorter routes.

#### Don't do this

```yaml
version: '3'
routes:
  /muni/: "https://muni.cz"
  /muni/test/longer/path/: "https://muni.cz" # <-- Starlette will never match this one
```

#### Do this instead

```yaml
version: '3'
routes:
  /muni/test/longer/path/: "https://muni.cz"
  /muni/test/longer/: "https://muni.cz"
  /muni/: "https://muni.cz"
```
