from datetime import datetime, timedelta
from typing import Optional, Dict, List

from sqlalchemy.ext.asyncio import AsyncSession
from sqlalchemy.orm import sessionmaker

from csirtmu.service_gateway.auth_backend.api_token_model import APITokenModel
from csirtmu.service_gateway.config import CONFIG


async def register_api_token(
        api_token: str,
        capabilities: List[str],
        created: datetime,
        expires: datetime,
        created_by: str,
) -> APITokenModel:
    async_session = sessionmaker(
        CONFIG.database.engine, expire_on_commit=False, class_=AsyncSession
    )
    async with async_session() as s:
        async with s.begin():
            saved_token = APITokenModel(
                token=api_token,
                capabilities=capabilities,
                created=created,
                expires=expires,
                created_by=created_by,
            )
            s.add(saved_token)
        await s.commit()
    return saved_token


def get_token_created_and_expiration_datetime(expiration_iso: Optional[str] = None) -> tuple[datetime, datetime]:
    created = datetime.utcnow()
    expires = created + timedelta(seconds=CONFIG.api_token_config.expiration_seconds)

    if expiration_iso and datetime.fromisoformat(expiration_iso) < expires:
        expires = datetime.fromisoformat(expiration_iso)

    return created, expires
