from functools import cache
from typing import Dict, List, Optional

from csirtmu.oidc.utils.oidc_issuer import OpenIDConnectIssuer

from csirtmu.service_gateway.config import OIDCIssuer, BASE_DIR


@cache
def get_version():
    with open(BASE_DIR / 'VERSION.txt', 'r') as f:
        return f.readline().split(' ', 1)[0]


# returns Tuple[Optional[default_issuer], List[all_issuers]]
def get_oidc_issuer_from_dataclass(
        issuers: List[OIDCIssuer],
) -> tuple[Optional[str], Dict[str, OpenIDConnectIssuer]]:
    initialized_issuers = {}
    default_issuer_name: Optional[str] = None

    for issuer in issuers:
        initialized_issuers[issuer.name] = OpenIDConnectIssuer(
            issuer_url=issuer.url,
            jwks_default_kid=issuer.default_kid
        )

        if issuer.default and default_issuer_name is None:
            default_issuer_name = issuer.name
        elif issuer.default and default_issuer_name is not None:
            raise Exception('Default issuer is already set')

    return default_issuer_name, initialized_issuers
