import http from 'k6/http';
import { check } from 'k6';

/*
* Script for stress-testing using K6
* */

let tokens = {};
let isSetup = false;
const key_count = 100;
const body = {
    "client_id": "test-client",
    "username": "tester",
    "password": "tester",
    "grant_type": "password"
};


export function setup() {
    if (!isSetup) {
        for (let i = 0; i < key_count; i++) {
            tokens[i] = JSON.parse(http.post(
                `http://127.0.0.1:8021/realms/CSIRT-MU-TEST/protocol/openid-connect/token`,
                body,
                {headers: {'Content-Type': 'application/x-www-form-urlencoded'}}
            )['body'])['access_token'];
        }
        isSetup = true;
    }
    return {'key': tokens[Math.floor(Math.random() * key_count)]};
}

export default function (data) {
    const res = http.get('http://127.0.0.1:8020/test/payload-bouncer',
        {
            headers: {
                Authorization: `Bearer ${data['key']}`,
            },
            timeout: "10s"
        });
    check(res, { 'is status 200': (r) => r.status === 200 });
}

export let options = {
    stages: [
        { duration: '10s', target: 500 },
        { duration: '90s', target: 500 },
        { duration: '10s', target: 0 },
    ],
    thresholds: {
        http_req_duration: ['p(99)<5000','p(95)<1500'], // 95% of requests must complete below 1.5s
    },
};