import httpx
import pytest
from httpx import AsyncClient

from csirtmu.service_gateway.app import on_auth_error
from csirtmu.service_gateway.auth_backend.multi_backend_authentication_middleware import (
    MultiBackendAuthenticationMiddleware,
)
from csirtmu.service_gateway.config import CONFIG


@pytest.mark.asyncio
async def test_missing_backend():
    from csirtmu.service_gateway.app import ServiceGateway

    gateway = ServiceGateway()
    with pytest.raises(AttributeError):
        gateway.get_app().add_middleware(
            MultiBackendAuthenticationMiddleware, backends=[], on_error=on_auth_error
        )
        gateway.get_app().user_middleware.clear()
    await gateway.client_session.close()


@pytest.mark.asyncio
async def test_multi_backend(gateway, api_token):
    headers = {
        CONFIG.api_token_config.header_name: (
            f'{CONFIG.api_token_config.token_prefix} {api_token}'
        )
    }
    async with AsyncClient(
            app=gateway, base_url='http://testserver', follow_redirects=True
    ) as ac:
        response: httpx.Response = await ac.get('/test', headers=headers)

    assert response.status_code == 200


@pytest.mark.asyncio
async def test_alternative_provider(gateway, oidc_tokens):
    headers = {
        'Authorization': 'Bearer ' + oidc_tokens[0],
        CONFIG.oidc_config.oidc_provider_header_name: CONFIG.oidc_config.issuers[
            0
        ].name,
    }

    async with AsyncClient(
            app=gateway,
            base_url='http://testserver',
            headers=headers,
            follow_redirects=True,
    ) as ac:
        response: httpx.Response = await ac.get('/test')

    assert response.status_code == 200


@pytest.mark.asyncio
async def test_missing_token_header(gateway):
    async with AsyncClient(
            app=gateway, base_url='http://testserver', follow_redirects=True
    ) as ac:
        response: httpx.Response = await ac.get('/test')

    assert response.status_code == 401
