# CSIRTMU TTP Database

Tactics, Techniques, and Procedures database.

## Content

- [CSIRTMU TTP Database](#csirtmu-ttp-database)
  - [Data Model](#data-model)
  - [Configuration](#configuration)
  - [Runtime Dependencies](#runtime-dependencies)
  - [Application endpoints](#application-endpoints)
  - [Docker](#docker)
  - [Helm](#helm)
  - [Local development](#local-development)
  - [MITRE ATT&CK adapter](#MITRE-ATT&CK-adapter)

---

## Data Model

![](./docs/data_model_noattr.png)

---

## Configuration

All configuration files are in _config_ directory or _tests/config_ if running locally.

[Configuration Management Library](https://gitlab.orion.lan/orion/backend-python/libraries/csirtmu-dataclass-config-loader)

### Environment Variables

- **TTP_DATABASE_CONFIG_PATH**: "Path to service configuration yaml file"
- **JWT_AUTH_BACKEND_CONFIG_PATH**: "Path to authorization configuration yaml file"

[YAML Configuration Overloading](https://gitlab.orion.lan/orion/backend-python/libraries/csirtmu-dataclass-config-loader)

### Authorization

- Authorization is configured using the [authorization.polar](https://docs.osohq.com/) file in the _config_ directory.

- All users (even unauthenticated) have the **is:default** role, which grants the user all permissions.

---

## Runtime Dependencies

- Authorization
  => [Service Gateway](https://gitlab.orion.lan/orion/backend-python/applications/csirtmu-service-gateway)
- PostgreSQL instance

---

## Application Endpoints

The application listens by default on port 8000.

### Endpoints

- **/**: Graph(i)QL endpoint
- **/graphql**: Graph(i)QL endpoint
- **/healthcheck/liveness**: Liveness healthcheck
- **/healthcheck/readiness**: Readiness healthcheck
- **/metrics**: Prometheus metrics endpoint
- **/_auth_backend/version**: Authorization backend version endpoint (for use with Service Gateway)

---

## Docker

Build a docker image and start a container.

Build args **POETRY_HTTP_BASIC_ORION_USERNAME** and **POETRY_HTTP_BASIC_ORION_PASSWORD** are necessary
to download Python packages from private registries.

- `docker build -t csirtmu-ttp-database --build-arg POETRY_HTTP_BASIC_ORION_USERNAME=token --build-arg POETRY_HTTP_BASIC_ORION_PASSWORD=<GITLAB_TOKEN> .`
- `docker run -d -p 127.0.0.1:8000:8000 -n csirtmu-ttp-database-container csirtmu-ttp-database`

---

## Helm

Install to Kubernetes cluster using helm.

- `cd csirtmu-ttp-database-chart`
- `helm repo add --username orion --password <personal_access_token> gitlab-orion https://gitlab.orion.lan/api/v4/projects/2485/packages/helm/stable`
- `helm dependency update`
- `kubectl create secret docker-registry csirtmu-ttp-database-secret --docker-server=registry.gitlab.orion.lan:443 --docker-username=orion --docker-password=<password>`
- `helm upgrade --install ttp-database .`
- Expose on local machine: `kubectl port-forward ttp-database-csirtmu-ttp-database-chart 8000:8000`

---

## Local Development

Configuration for local development.

- Required dependencies:
  - Python 3.9+
  - pip
  - [Poetry](https://python-poetry.org/docs/master/#installing-with-the-official-installer)
- `poetry config repositories.ORION https://gitlab.orion.lan/api/v4/projects/2485/packages/pypi/simple`
- `poetry config http-basic.ORION token <GITLAB_TOKEN>`
- `poetry install --with dev`
- `export TTP_DATABASE_CONFIG_PATH=./tests/config/config.yaml`
- `export JWT_AUTH_BACKEND_CONFIG_PATH=./tests/config/config_jwt_auth.yaml`

### Server

Start the server locally.

- `poetry run uvicorn --port 8000 --host 127.0.0.1 --factory csirtmu.ttp_database.app:app`

### Tests

Run tests.

- `poetry run tox`

---

## MITRE ATT&CK adapter

Adapter is used for automatic update of the TTP database by the latest version of [MITRE ATT&CK enterprise matrix](https://attack.mitre.org/matrices/enterprise/).

It uses `stix2` library to manipulate with STIX data, which is the format in which the ATT&CK dataset is represented.
[Learn more](https://github.com/mitre/cti/blob/master/USAGE.md)

Run adapter with
- `poetry run python -m csirtmu.ttp_database.utils.mitre_adapter.mitre_adapter --mode=<MODE> <TTP_API_URL> <API_TOKEN>`

Additional options
- `-v | --verbose` Provides further details about adapter current status

Adapter can operate in two modes:
- ### Append-only
  - `--mode=append-only`

  Reflects only `ADD` changes.
  Consider this mode only if you will be making manual changes in DB, and it is unwanted to overwrite this modifications.

- ### Update
  - `--mode=update`

  Reflects all changes (`ADD/UPDATE/DELETE`). 

### Flow diagram
![](./docs/adapter_flow_diagram.png)
