import os
from dataclasses import dataclass
from os import getenv
from pathlib import Path
from typing import Optional

from csirtmu.dataclass_config_loader import Omit, load_dataclass_config
from csirtmu.starlette_jwt_auth import config as jwt_config
from sqlalchemy import create_engine
from sqlalchemy.engine import Engine
from sqlalchemy.ext.asyncio import AsyncEngine, create_async_engine
from sqlalchemy.pool import QueuePool

BASE_DIR = Path(__file__).parent.parent.parent


@dataclass
class Database:
    host: str
    port: int
    username: str
    password: str
    database: str
    engine: Omit[Engine] = None
    async_engine: Omit[AsyncEngine] = None



@dataclass
class Config:
    database: Database
    debug: Optional[bool] = False


def _load_config(path: Path) -> Config:
    config = load_dataclass_config(path, Config, "TTP_DATABASE")

    config.database.engine = create_engine(
        f'postgresql+psycopg2://{config.database.username}:{config.database.password}@{config.database.host}:{config.database.port}/{config.database.database}',
        future=True)
    config.database.async_engine = create_async_engine(
        f'postgresql+asyncpg://{config.database.username}:{config.database.password}@{config.database.host}:{config.database.port}/{config.database.database}',
        future=True, echo=config.debug, poolclass=QueuePool)

    return config


CONFIG = _load_config(
    Path(getenv('TTP_DATABASE_CONFIG_PATH', (BASE_DIR / 'config/config.yaml').resolve().__str__())))
jwt_config.conf_path = Path(os.getenv('JWT_AUTH_BACKEND_CONFIG_PATH', BASE_DIR / 'config/config_jwt_auth.yaml'))
