from csirtmu.strawberry_dmt.field_hints import Relationship
from csirtmu.strawberry_dmt.model_type import model_type, ModelTypeBase, ModelTypeInterface, model_type_interface
from csirtmu.strawberry_dmt.schema_registry import SchemaRegistry

from csirtmu.ttp_database import models


@model_type_interface(models.TTP)
class ITTP(ModelTypeInterface):
    external_references = Relationship('ExternalReference')


@model_type(models.TTP, interfaces=[ITTP])
class TTP(ModelTypeBase):
    pass


@model_type(models.MalwareProcedure, interfaces=[ITTP])
class MalwareProcedure(ModelTypeBase):
    malware_technique = Relationship('Technique')
    malware = Relationship('Malware')

    class Meta:
        exclude_create_fields = ["created", "modified", "unique_identifier"]
        exclude_update_fields = ["created", "modified", "unique_identifier"]


@model_type(models.GroupProcedure, interfaces=[ITTP])
class GroupProcedure(ModelTypeBase):
    group_technique = Relationship('Technique')
    group = Relationship('TTPGroup')

    class Meta:
        exclude_create_fields = ["created", "modified", "unique_identifier"]
        exclude_update_fields = ["created", "modified", "unique_identifier"]


@model_type(models.ToolProcedure, interfaces=[ITTP])
class ToolProcedure(ModelTypeBase):
    tool_technique = Relationship('Technique')
    tool = Relationship('Tool')

    class Meta:
        exclude_create_fields = ["created", "modified", "unique_identifier"]
        exclude_update_fields = ["created", "modified", "unique_identifier"]


@model_type(models.TechniqueMitigationRelationship)
class TechniqueMitigationRelationship(ModelTypeBase):
    technique = Relationship('Technique')
    mitigation = Relationship('Mitigation')
    external_references = Relationship('ExternalReference')


@model_type(models.ExternalReference)
class ExternalReference(ModelTypeBase):
    ttps = Relationship('ITTP')
    tools = Relationship('Tool')
    malware = Relationship('Malware')
    groups = Relationship('TTPGroup')
    mitigations = Relationship('Mitigation')
    technique_mitigation_relationships = Relationship('TechniqueMitigationRelationship')


@model_type(models.Tactic, interfaces=[ITTP])
class Tactic(ModelTypeBase):
    techniques = Relationship('Technique')

    class Meta:
        exclude_create_fields = ["created", "modified", "unique_identifier"]
        exclude_update_fields = ["created", "modified", "unique_identifier"]


@model_type(models.Technique, interfaces=[ITTP])
class Technique(ModelTypeBase):
    tactics = Relationship('Tactic')
    mitigations = Relationship('TechniqueMitigationRelationship')
    platforms = Relationship('TTPPlatform')
    sub_techniques = Relationship('Technique')
    sub_technique_of = Relationship('Technique')
    group_procedures = Relationship('GroupProcedure')
    tool_procedures = Relationship('ToolProcedure')
    malware_procedures = Relationship('MalwareProcedure')

    class Meta:
        exclude_create_fields = ["created", "modified", "unique_identifier"]
        exclude_update_fields = ["created", "modified", "unique_identifier"]


@model_type(models.Malware)
class Malware(ModelTypeBase):
    techniques_used = Relationship('MalwareProcedure')
    platforms = Relationship('TTPPlatform')
    aliases = Relationship('Alias')
    groups = Relationship('TTPGroup')
    external_references = Relationship('ExternalReference')

    class Meta:
        exclude_create_fields = ["created", "modified"]
        exclude_update_fields = ["created", "modified"]


@model_type(models.Tool)
class Tool(ModelTypeBase):
    techniques_used = Relationship('ToolProcedure')
    platforms = Relationship('TTPPlatform')
    aliases = Relationship('Alias')
    groups = Relationship('TTPGroup')
    external_references = Relationship('ExternalReference')

    class Meta:
        exclude_create_fields = ["created", "modified"]
        exclude_update_fields = ["created", "modified"]


@model_type(models.Group)
class TTPGroup(ModelTypeBase):
    aliases = Relationship('Alias')
    malware = Relationship('Malware')
    tools = Relationship('Tool')
    techniques_used = Relationship('GroupProcedure')
    external_references = Relationship('ExternalReference')

    class Meta:
        exclude_create_fields = ["created", "modified"]
        exclude_update_fields = ["created", "modified"]


@model_type(models.Mitigation)
class Mitigation(ModelTypeBase):
    techniques = Relationship('TechniqueMitigationRelationship')
    external_references = Relationship('ExternalReference')

    class Meta:
        exclude_create_fields = ["created", "modified"]
        exclude_update_fields = ["created", "modified"]


@model_type(models.Platform)
class TTPPlatform(ModelTypeBase):
    techniques = Relationship('Technique')
    malware = Relationship('Malware')
    tools = Relationship('Tool')


@model_type(models.Alias)
class Alias(ModelTypeBase):
    malware = Relationship('Malware')
    tools = Relationship('Tool')
    groups = Relationship('TTPGroup')


registry = SchemaRegistry([
    ITTP,
    GroupProcedure,
    ToolProcedure,
    MalwareProcedure,
    ExternalReference,
    Alias,
    Malware,
    Tool,
    TTPPlatform,
    Technique,
    Tactic,
    Mitigation,
    TTPGroup,
    TechniqueMitigationRelationship,
])

queries = registry.queries()
mutations = registry.mutations()
