import click
from gql import Client, gql
from gql.transport.aiohttp import AIOHTTPTransport


async def try_connection():
    query = """
        query tryConnection {
          _service {
            __typename
          }
        }
    """
    try:
        await post(query)
    except Exception as e:
        raise SystemExit(e)


async def post(query):
    api_url = click.get_current_context().params.get("api_url")
    token = click.get_current_context().params.get("token")
    transport = AIOHTTPTransport(url=api_url, headers={'Authorization': f'Token {token}'})

    async with Client(transport=transport, execute_timeout=100) as session:
        try:
            return await session.execute(gql(query))
        except Exception as e:
            if click.get_current_context().params.get("verbose"):
                print(str(e))
