from dataclasses import dataclass, field
from typing import List, Dict, Optional

from dataclasses_json import dataclass_json, Undefined, config


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclass
class MitreTactic:
    id: str
    type: str
    name: str
    description: str
    external_references: List[Dict] = field(default_factory=list)


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclass
class AttackPattern:
    id: str
    type: str
    name: str
    description: str
    kill_chain_phases: List[Dict]
    external_references: List[Dict] = field(default_factory=list)
    platforms: List[str] = field(default_factory=list, metadata=config(field_name="x_mitre_platforms"))
    x_mitre_is_subtechnique: bool = False


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclass
class IntrusionSet:
    id: str
    type: str
    name: str
    description: str
    external_references: List[Dict] = field(default_factory=list)
    aliases: List[str] = field(default_factory=list)


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclass
class Mitigation:
    id: str
    type: str
    name: str
    description: str
    external_references: List[Dict] = field(default_factory=list)


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclass
class Software:
    id: str
    type: str
    name: str
    description: str
    external_references: List[Dict] = field(default_factory=list)
    platforms: List[str] = field(default_factory=list, metadata=config(field_name="x_mitre_platforms"))
    aliases: List[str] = field(default_factory=list, metadata=config(field_name="x_mitre_aliases"))


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclass
class ExternalReference:
    sourceName: str = field(metadata=config(field_name="source_name"))
    description: Optional[str] = None
    externalId: Optional[str] = field(metadata=config(field_name="external_id"), default=None)
    url: Optional[str] = None
