from typing import Dict

from csirtmu.ttp_database.utils.mitre_adapter.queries import query_part, wrap_query_parts


class FetchedEntities:
    tools: Dict
    malware: Dict
    groups: Dict
    tactics: Dict
    techniques: Dict
    mitigations: Dict
    platforms: Dict
    aliases: Dict
    references: Dict

    async def reload(self):
        external_references_filter = '(filter: {AND: {OR: {sourceName: {exact: "mitre-attack"} }}} )'
        data_args = ["id", f'externalReferences{external_references_filter} {{data{{externalId}} }}']

        query_parts = [await query_part('Tool', fields=data_args+["name"]),
                       await query_part('Malware', fields=data_args+["name"]),
                       await query_part('TtpGroup', fields=data_args+["name"]),
                       await query_part('Tactic', fields=["id", "tacticName"]),
                       await query_part('Mitigation', fields=data_args+["name"]),
                       await query_part('TtpPlatform', fields=["id", "value"]),
                       await query_part('Alias', fields=["id", "value"]),
                       await query_part('ExternalReference', fields=["id", "sourceName", "url"]),
                       await query_part('Technique', fields=data_args+["techniqueName"])]

        result = await wrap_query_parts(query_parts)

        self.tools = result[f'getToolList']['data']
        self.malware = result[f'getMalwareList']['data']
        self.groups = result[f'getTtpGroupList']['data']
        self.tactics = result[f'getTacticList']['data']
        self.mitigations = result[f'getMitigationList']['data']
        self.platforms = result[f'getTtpPlatformList']['data']
        self.aliases = result[f'getAliasList']['data']
        self.references = result[f'getExternalReferenceList']['data']
        self.techniques = result[f'getTechniqueList']['data']
