import asyncio
from multiprocessing import Pool

from csirtmu.ttp_database.utils.mitre_adapter.dataclasses_models import IntrusionSet
from csirtmu.ttp_database.utils.mitre_adapter.fetched_entities import FetchedEntities
from csirtmu.ttp_database.utils.mitre_adapter.handlers.default_handler import DefaultHandler
from csirtmu.ttp_database.utils.mitre_adapter.mutations import mutation_format
from csirtmu.ttp_database.utils.mitre_adapter.relationships_helper import RelationshipsHelper
from csirtmu.ttp_database.utils.mitre_adapter.utils import verbose_print, InitializedObject, \
    create_entities, get_ids_by_names, related_names, parser


class GroupHandler(DefaultHandler):
    def __init__(self, fetched_entities: FetchedEntities, relationships_helper: RelationshipsHelper):
        self.fetched_entities = fetched_entities
        self.relationships_helper = relationships_helper
        super().__init__("intrusion-set", self.seed_groups, IntrusionSet)

    def _init_groups(self, val):
        async def _init():
            aliases = list(filter(lambda x: x != val.get("name"), val.get("aliases", None)))
            aliases_ids = get_ids_by_names(aliases, self.fetched_entities.aliases, "value")
            tools_ids = get_ids_by_names(related_names(self.relationships_helper.get_related(val.get('id'), 'uses', 'tool')),
                                         self.fetched_entities.tools)
            malware_ids = get_ids_by_names(related_names(self.relationships_helper.get_related(val.get('id'), 'uses', 'malware')),
                                           self.fetched_entities.malware)
            external_references = get_ids_by_names([ref.get("url") for ref in val.get("external_references") if ref.get("url")],
                                                   self.fetched_entities.references, "url")
            return InitializedObject(base_entity={'name': val.get("name"),
                                                  'description': val.get("description"),
                                                  'tools': tools_ids,
                                                  'malware': malware_ids,
                                                  'aliases': aliases_ids,
                                                  'external_references': external_references})

        return asyncio.run(_init())

    async def seed_groups(self, groups):
        verbose_print(f"Seeding groups...")
        await self.fetched_entities.reload()

        with Pool() as pool:
            output = pool.map(self._init_groups, [val for key, val in groups])

        await create_entities(mutation_format('createTtpGroup', parser([x.base_entity for x in output])))