from multiprocessing import Pool
from typing import List

from csirtmu.ttp_database.utils.mitre_adapter.dataclasses_models import Mitigation
from csirtmu.ttp_database.utils.mitre_adapter.fetched_entities import FetchedEntities
from csirtmu.ttp_database.utils.mitre_adapter.handlers.default_handler import DefaultHandler
from csirtmu.ttp_database.utils.mitre_adapter.mutations import mutation_format
from csirtmu.ttp_database.utils.mitre_adapter.utils import verbose_print, InitializedObject, \
    create_entities, get_ids_by_names, parser


class MitigationHandler(DefaultHandler):
    def __init__(self, fetched_entities: FetchedEntities):
        self.fetched_entities = fetched_entities
        super().__init__("course-of-action", self.seed_mitigations, Mitigation)
    
    def _init_mitigations(self, val):
        external_references = get_ids_by_names([ref.get("url") for ref in val.get("external_references") if ref.get("url")],
                                               self.fetched_entities.references, "url")

        return InitializedObject(
            base_entity={'name': val.get("name"),
                         'description': val.get("description"),
                         'external_references': external_references})

    async def seed_mitigations(self, mitigations):
        verbose_print(f"Seeding mitigations...")
        await self.fetched_entities.reload()

        with Pool() as pool:
            output: List[InitializedObject] = pool.map(self._init_mitigations, [val for key, val in mitigations])

        await create_entities(mutation_format('createMitigation', parser([x.base_entity for x in output])))