from multiprocessing import Pool
from typing import List

from csirtmu.ttp_database.utils.mitre_adapter.dataclasses_models import MitreTactic
from csirtmu.ttp_database.utils.mitre_adapter.fetched_entities import FetchedEntities
from csirtmu.ttp_database.utils.mitre_adapter.handlers.default_handler import DefaultHandler
from csirtmu.ttp_database.utils.mitre_adapter.mutations import mutation_format
from csirtmu.ttp_database.utils.mitre_adapter.utils import verbose_print, InitializedObject, \
    create_entities, get_ids_by_names, parser


class TacticHandler(DefaultHandler):
    def __init__(self, fetched_entities: FetchedEntities):
        self.fetched_entities = fetched_entities
        super().__init__("x-mitre-tactic", self.seed_tactics, MitreTactic)

    def _init_tactics(self, val):
        external_references = get_ids_by_names([ref.get("url") for ref in val.get("external_references") if ref.get("url")],
                                               self.fetched_entities.references, "url")
        return InitializedObject(base_entity={'tacticName': val.get("name"),
                                              'description': val.get("description"),
                                              'external_references': external_references})

    async def seed_tactics(self, tactics):
        verbose_print(f"Seeding tactics...")
        await self.fetched_entities.reload()

        with Pool() as pool:
            output: List[InitializedObject] = pool.map(self._init_tactics, [val for key, val in tactics])

        await create_entities(mutation_format('createTactic', parser([x.base_entity for x in output])))