from stix2 import Filter
from stix2.utils import get_type_from_id

from csirtmu.ttp_database.utils.mitre_adapter.utils import default_filter


class RelationshipsHelper:
    def __init__(self, ms, relationships):
        self.ms_new = ms
        self.relationships = relationships

    def get_related(self, source_id, relationship_type: str, target_type: str, reversed_relation=False):
        related_relationships = self.get_relationships(source_id, relationship_type, target_type, reversed_relation)
        if reversed_relation:
            target_refs = [r.source_ref for r in related_relationships]
        else:
            target_refs = [r.target_ref for r in related_relationships]

        return default_filter(self.ms_new, target_type, Filter('id', 'in', target_refs))

    def get_relations_with_related_entities(self, source_id, relationship_type: str, target_type: str,
                                            reversed_relation=False):
        related_relationships = self.get_relationships(source_id, relationship_type, target_type, reversed_relation)
        result = []

        for relationship in related_relationships:
            reference = relationship.source_ref if reversed_relation else relationship.target_ref
            related_entity = default_filter(self.ms_new, target_type, Filter('id', '=', reference))
            # If is null it means relationship is deprecated/revoked and related entity does not exists in enterprise collection
            if related_entity:
                result.append((relationship, related_entity[0]))

        return result

    def get_relationships(self, source_id, relationship_type: str, target_type: str, reversed_relation=False):
        if reversed_relation:
            related_relationships = list(filter(
                lambda relationship:
                relationship.relationship_type == relationship_type
                and relationship.target_ref == source_id
                and get_type_from_id(relationship.source_ref) == target_type, self.relationships))

        else:
            related_relationships = list(filter(
                lambda relationship:
                relationship.relationship_type == relationship_type
                and relationship.source_ref == source_id
                and get_type_from_id(relationship.target_ref) == target_type, self.relationships))

        return related_relationships

    @staticmethod
    def get_related_ids(related_entities):
        return [r.target_ref for r in related_entities]
