from starlette import status
from starlette.requests import Request
from starlette.responses import JSONResponse

from csirtmu.ttp_database.config import CONFIG

OK = "✌"
NOK = "🪦 healthyn't 🐁"


class AppState:
    def __init__(self):
        self.healthy = True


def create_healthcheck_liveness(state: AppState):
    async def healthcheck_liveness(request: Request):
        return JSONResponse(OK if state.healthy else NOK, status_code=200)

    return healthcheck_liveness


def create_healthcheck_readiness(state: AppState):
    async def healthcheck_readiness(request: Request):
        status_data = {"ttp_database_service": OK if state.healthy else NOK, "database": OK}
        ready = state.healthy
        # DB
        try:
            CONFIG.database.engine.connect().close()
        except Exception:
            status_data["database"] = NOK
            ready = False
        return JSONResponse(status_data,
                            status_code=status.HTTP_200_OK if ready else status.HTTP_503_SERVICE_UNAVAILABLE)

    return healthcheck_readiness
