from datetime import datetime, timedelta

from csirtmu.ttp_database.models import TTP, Malware
from tests.conftest import BASE_DIR
from authlib.jose import jwt
from csirtmu.starlette_jwt_auth.config import CONFIG as AUTH_CONFIG


class TestAuth:
    def test_query_unauthorized(self, client_strict_auth):
        with open(BASE_DIR / 'assets/queries.graphql', 'r') as fp:
            query = fp.read()

        response = client_strict_auth.post('/graphql', json=dict(query=query, operationName='getTTP'))
        assert response.status_code == 200
        response = response.json()
        assert response['data'] is None
        assert response['errors'] is not None

    def test_query_authorized(self, client_strict_auth, session):
        test_object = Malware(name='TTP-object')
        session.add(test_object)
        session.expire_on_commit = False
        session.commit()
        session.expunge(test_object)
        with open(BASE_DIR / 'assets/queries.graphql', 'r') as fp:
            query = fp.read()

        token = jwt.encode(header={'alg': 'HS512'},
                           payload={
                               'iss': AUTH_CONFIG.gateway.token_issuer,
                               'aud': AUTH_CONFIG.gateway.token_audience,
                               'exp': datetime.now() + timedelta(days=120),
                               'iat': datetime.now(),
                               'jti': 123456,
                               'scope': 'eduperson_entitlement',
                               'username': 'Pepa',
                               'capabilities': ['is:batman']
                           },
                           key=AUTH_CONFIG.gateway.token_key)
        response = client_strict_auth.post('/graphql', json=dict(query=query, operationName='getMalwareByID',
                                                                 variables=dict(id='1')),
                                           headers={'Authorization': f'Token {token.decode("utf-8")}'})
        assert response.status_code == 200
        response = response.json()
        assert response['data']['getMalware'] is not None
        assert response.get('errors') is None