import os
from pathlib import Path

import alembic.config
from alembic.autogenerate import compare_metadata
from alembic.runtime.migration import MigrationContext
from sqlalchemy import engine_from_config, pool

from csirtmu.ttp_database import models
from csirtmu.ttp_database.config import CONFIG

BASE_DIR = Path(__file__).parent.parent


def test_migrations_up_to_date(migrate_tables):
    config = alembic.config.Config(str(BASE_DIR / 'alembic.ini'))
    os.chdir(str(BASE_DIR))
    config.set_main_option("sqlalchemy.url",
                           f"postgresql+psycopg2://{CONFIG.database.username}:{CONFIG.database.password}"
                           f"@{CONFIG.database.host}:{CONFIG.database.port}/{CONFIG.database.database}")
    connectable = engine_from_config(
        config.get_section(config.config_ini_section),
        prefix="sqlalchemy.",
        poolclass=pool.NullPool,
    )
    with connectable.connect() as connection:
        # upgrade(config, "head")
        mc = MigrationContext.configure(connection)
        diff = compare_metadata(mc, models.AutoBase.metadata)

    assert diff == [], 'Please run `alembic revision --autogenerate -m "<message>"` ' \
                       'to create a new migration with database changes'
