# CSIRTMU User Profile Introspection Service

Microservice for inspecting user profiles from keycloak.

## Content

- [CSIRTMU User Profile Introspection Service](#csirtmu-user-profile-introspection-service)
  - [Configuration](#configuration)
  - [Dependencies](#dependencies)
  - [Endpoints](#endpoints)
  - [Local development](#local-development)
  - [Docker](#docker)
  - [Helm](#helm)

---

## Configuration

All configuration files are in _config_ directory or _tests/config_ if running locally.

[Configuration Management Library](https://gitlab.orion.lan/orion/backend-python/libraries/csirtmu-dataclass-config-loader)

### Environment Variables

- **USER_PROFILE_SERVICE_CONFIG_PATH**: "Path to service configuration yaml file"
- **JWT_AUTH_BACKEND_CONFIG_PATH**: "Path to authorization configuration yaml file"

### Authorization

- Authorization is configured using the [authorization.polar](https://docs.osohq.com/) file in the _config_ directory.

- All users (even unauthenticated) have the **is:default** role, which grants the user all permissions.

---

## Dependencies

- Authorization
  => [Service Gateway](https://gitlab.orion.lan/orion/backend-python/applications/csirtmu-service-gateway/)
- Keycloak instance

---

## Endpoints

The application listens by default on port 8000.

- **/**: Graph(i)QL endpoint
- **/graphql**: Graph(i)QL endpoint
- **/healthcheck/liveness**: Liveness healthcheck
- **/healthcheck/readiness**: Readiness healthcheck
- **/metrics**: Prometheus metrics endpoint
- **/\_auth_backend/version**: Authorization backend version endpoint (for use with Service Gateway)

---

## Local Development

Configuration for local development.

- Required dependencies:
  - Python 3.9+
  - pip
  - [Poetry](https://python-poetry.org/docs/master/#installing-with-the-official-installer)

  ```console
  $ poetry config repositories.ORION https://gitlab.orion.lan/api/v4/projects/2485/packages/pypi/simple
  $ poetry config http-basic.ORION token <GITLAB_TOKEN>
  $ poetry install --with dev
  $ export USER_PROFILE_SERVICE_CONFIG_PATH=./tests/config/user_service/config.yaml
  $ export JWT_AUTH_BACKEND_CONFIG_PATH=./tests/config/gateway/config.yaml
  ```

### Server

* Start the server locally.

  ```console
  $ poetry run uvicorn --port 8000 --host 127.0.0.1 --factory csirtmu.user_profile_introspection_service.app:app
  ```

---

## Docker
* To be able to build and run the image, follow the instructions:
  * Build and run Docker image:
    ```console
    $ docker build -t csirtmu-user-profile-introspection --build-arg POETRY_HTTP_BASIC_ORION_USERNAME=token --build-arg POETRY_HTTP_BASIC_ORION_PASSWORD=<GITLAB_TOKEN> .`
    $ docker run -d -p 127.0.0.1:8000:8000 -n csirtmu-user-profile-introspection-container csirtmu-user-profile-introspection
    ```
* Build args **POETRY_HTTP_BASIC_ORION_USERNAME** and **POETRY_HTTP_BASIC_ORION_PASSWORD** are necessary
to download Python packages from private registries.


---

## Helm

Install to Kubernetes cluster using helm.
  * Add *gitlab-orion* helm repository:
    ```console
    $ helm repo add --username orion --password ${PACKAGE_REGISTRY_PULL} gitlab-orion https://gitlab.orion.lan/api/v4/projects/2485/packages/helm/stable
    ```
  * Download chart dependencies:
    ```console
    $ cd csirtmu-user-profile-introspection-chart
    $ helm dependency update
    ```
  * Create namespace:
    ```console
    $ kubectl create namespace csirtmu-user-profile-introspection
    ```

  * Create *csirtmu-user-profile-introspection-secret* secret with credentials to a container registry:
    ```console
    $ kubectl create secret docker-registry csirtmu-user-profile-introspection-secret --docker-server=registry.gitlab.orion.lan:443 --docker-username=orion --docker-password=<password>
    ```
  * To deploy Helm chart into kubernetes cluster run:
    ```console
    $ helm upgrade --install --namespace user-profile-introspection csirtmu-user-profile-introspection .
    ```
  * If you want to be able to access the application locally, run:
    ```console
    $ kubectl port-forward --namespace user-profile-introspection <pod-name> <local-port>:8000
    ```

---
