from dataclasses import dataclass
from os import getenv
from pathlib import Path

from csirtmu.dataclass_config_loader import Omit, load_dataclass_config

from csirtmu.user_profile_introspection_service.keycloak_client.keycloak_client import KeycloakClient

BASE_DIR = Path(__file__).parent.parent.parent


@dataclass
class KeycloakCredentials:
    base_url: str
    realm: str
    client_id: str
    username: str
    password: str


@dataclass
class Config:
    keycloak_credentials: KeycloakCredentials
    keycloak_client: Omit[KeycloakClient] = None


def _load_config(path: Path) -> Config:
    config = load_dataclass_config(path, Config, 'USER_PROFILE_SERVICE')
    config.keycloak_client = KeycloakClient(**config.keycloak_credentials.__dict__)
    return config


CONFIG = _load_config(Path(getenv('USER_PROFILE_SERVICE_CONFIG_PATH', (BASE_DIR / 'config/config.yaml').resolve())))
