from typing import Optional

import strawberry
from csirtmu.starlette_jwt_auth.config import CONFIG as AUTH_CONFIG
from strawberry.types import Info

from csirtmu.user_profile_introspection_service.config import CONFIG
from csirtmu.user_profile_introspection_service.keycloak_client.keycloak_client import KeycloakClient
from csirtmu.user_profile_introspection_service.resolvers_description import DESCRIPTIONS
from csirtmu.user_profile_introspection_service.schema_models import UserInfoSearchInput, UserInfoSearchResult, User


@strawberry.type
class Query:
    @strawberry.field(description=DESCRIPTIONS['get_token_introspection'])
    async def get_token_introspection(self, info: Info) -> Optional[User]:
        info.context['oso'].authorize(info.context['request'].user, "can:self-introspect", KeycloakClient)

        user_identity = info.context['request'].user.identity
        realm, user_id = user_identity[user_identity.rfind('/') + 1:].split(AUTH_CONFIG.jwt_username_separator)

        return await CONFIG.keycloak_client.get_user_by_id(user_id, realm)

    @strawberry.field(description=DESCRIPTIONS['get_user'])
    async def get_user(self, info: Info, user_id: str, realm: str) -> Optional[User]:
        info.context['oso'].authorize(info.context['request'].user, "can:query", KeycloakClient)
        return await CONFIG.keycloak_client.get_user_by_id(user_id, realm)

    @strawberry.field(description=DESCRIPTIONS['user_search'])
    async def user_search(self, info: Info, filter: UserInfoSearchInput) -> UserInfoSearchResult:
        info.context['oso'].authorize(info.context['request'].user, "can:search", KeycloakClient)
        result = await CONFIG.keycloak_client.search(filter)
        return UserInfoSearchResult(data=result)


schema = strawberry.Schema(query=Query)
