import httpx
from requests import RequestException
from starlette import status
from starlette.requests import Request
from starlette.responses import JSONResponse

from csirtmu.user_profile_introspection_service.config import CONFIG

OK = "✌"
NOK = "🪦 healthyn't 🐁"


async def healthcheck_liveness(request: Request):
    return JSONResponse(OK, status_code=200)


async def healthcheck_readiness(request: Request):
    status_data = {"user_profile_introspection_service": OK, "keycloak": OK}
    ready = True
    try:
        async with httpx.AsyncClient() as ac:
            response = await ac.get(CONFIG.keycloak_credentials.base_url)
            if response.status_code != 200:
                status_data['keycloak'] = NOK
                ready = False
    except RequestException:
        status_data['keycloak'] = NOK
        ready = False
    return JSONResponse(status_data, status_code=status.HTTP_200_OK if ready else status.HTTP_503_SERVICE_UNAVAILABLE)
