from typing import Tuple

import requests
from requests import RequestException


def get_endpoint(host: str, port: str):
    return f'http://{host}:{port}'


def get_tokens_for_user(realm_auth_endpoint: str, username: str, password: str, client_id: str = 'admin-cli') \
        -> Tuple[str, str]:
    response = requests.post(realm_auth_endpoint, data={
        'client_id': client_id,
        'username': username,
        'password': password,
        'grant_type': 'password'
    })
    response.raise_for_status()
    master_tokens = response.json()
    return master_tokens.get('access_token'), master_tokens.get('refresh_token')


def refresh_access_token(realm_auth_endpoint: str, refresh_token: str, client_id: str) -> str:
    response = requests.post(realm_auth_endpoint, data={
        'client_id': client_id,
        'grant_type': 'refresh_token',
        'refresh_token': refresh_token
    })

    if response.status_code == 200:
        response = response.json()
        return response.get('access_token')
    else:
        raise RequestException('Unauthorized, refresh token is invalid or expired')


def get_auth_endpoint_for_realm(endpoint: str, realm: str, legacy: bool = False):
    endpoint = endpoint + '/auth' if legacy else endpoint
    return f'{endpoint}/realms/{realm}/protocol/openid-connect/token'
