import httpx

from tests.conftest import TEST_KEYCLOAK_LEGACY


def test_configure_keycloak_instance(keycloak_client, keycloak_base_url):
    realm_name = 'test-realm'
    client_name = 'test-client'
    username, password = 'test', 'test'

    keycloak_client.create_realm(realm_name)
    keycloak_client.create_client(realm=realm_name, client=client_name, client_secret=client_name + 'secret')
    keycloak_client.create_user(username=username, password=password, realm=realm_name,
                                first_name='Doctor', last_name='Who', email='thedoctor@example.com')

    token_endpoint = f'realms/{realm_name}/protocol/openid-connect/token'
    if TEST_KEYCLOAK_LEGACY:
        token_endpoint = 'auth/' + token_endpoint

    auth_response = httpx.post(url=f'{keycloak_base_url}{token_endpoint}',
                               data={
                                   'client_id': client_name,
                                   'grant_type': 'password',
                                   'username': username,
                                   'password': password
                               })
    assert auth_response.status_code == 200
    assert 'access_token' in auth_response.json()
