import time
from collections import OrderedDict
from typing import Optional


class AuthenticationCache:
    def __init__(self, max_size: int = 1000, ttl_default: int = 3600):
        self._cache = OrderedDict()
        self._cache_max_size = max_size
        self._ttl_default = ttl_default

    def add(self, key, value, ttl: int = None):
        if key in self._cache:
            # LRU
            self._cache.move_to_end(key)
        elif len(self._cache) == self._cache_max_size:
            # Size
            self._cache.pop(next(iter(self._cache)))

        # Add to cache
        ttl = time.time() + (ttl if ttl else self._ttl_default)
        self._cache[key] = value, ttl

    def get(self, key) -> Optional[any]:
        value, ttl = self._cache.get(key, (None, None))
        if value is None:
            return None

        if ttl < time.time():
            self._cache.pop(key)
            return None

        self._cache.move_to_end(key)  # LRU
        return value
