from typing import Optional, List


def extract_access_token(auth_header, keyword: str = 'Bearer') -> Optional[str]:
    auth = auth_header.split()

    # todo should not be better to raise a InvalidHeader() exception
    if not auth or auth[0].lower() != keyword.lower():
        return None

    if len(auth) == 1 or len(auth) > 2:
        raise ValueError("Invalid auth header")

    try:
        access_token: str = auth[1]
    except UnicodeError as ex:
        raise ValueError("Invalid auth header")

    return access_token


def extract_auth_header(request, auth_header_name: str = 'Authorization') -> Optional[str]:
    return request.headers.get(auth_header_name)


def collect_watched_claims(jwt_data: dict, watched_claims: List[str]) -> List[str]:
    capabilities = []
    for claim in watched_claims:
        value = jwt_data.get(claim, [])
        if isinstance(value, list):
            for v in value:
                capabilities.append(f'{claim}|{v}')
        else:
            capabilities.append(f'{claim}|{value}')
    return capabilities
