from time import sleep

import pytest

from csirtmu.oidc.utils.authentication_cache import AuthenticationCache


def test_insert():
    cache = AuthenticationCache(max_size=10)
    cache.add(key='foo', value='bar')

    item = cache.get('foo')
    assert item is not None
    assert item == 'bar'


def get_queue_start(cache: AuthenticationCache):
    return next(iter(cache._cache))


@pytest.mark.parametrize("cache_size", [0, 1, 2, 10, 100])
def test_ordering(cache_size):
    cache = AuthenticationCache(max_size=cache_size)
    for i in range(cache._cache_max_size):
        cache.add(i, i)

    for i in range(1, len(cache._cache.keys()) - 1):
        assert cache.get(i) == cache.get(i - 1) + 1


def test_overfill():
    cache = AuthenticationCache(max_size=10)

    for i in range(cache._cache_max_size * 2):
        cache.add(i, i)

    for i in range(cache._cache_max_size + 1, cache._cache_max_size * 2 - 1):
        assert cache.get(i) == cache.get(i - 1) + 1 == i


@pytest.mark.parametrize("cache_size", [10, 100])
def test_lru(cache_size):
    cache = AuthenticationCache(max_size=cache_size)

    for i in range(cache._cache_max_size):
        cache.add(i, i)

    for i in range(cache._cache_max_size):
        cache.get(i)

    for i in range(1, cache._cache_max_size):
        cache.get(i)

    cache_list = list(iter(cache._cache))
    assert cache_list[0] == 0

    cache.get(cache_size // 2)
    cache_list = list(iter(cache._cache))
    assert cache_list[cache_size - 1] == cache_size // 2


def test_expired_key():
    cache = AuthenticationCache(max_size=3)

    cache.add(1, 'foo')
    cache.add(2, 'foo', ttl=1)
    cache.add(3, 'foo', 5)

    sleep(1)

    assert cache.get(2) is None
    assert len(cache._cache) == 2
