import os
from dataclasses import dataclass
from pathlib import Path
from typing import Optional

from csirtmu.dataclass_config_loader.load import load_dataclass_config


@dataclass
class Gateway:
    token_issuer: Optional[str]
    token_header_name: Optional[str]
    token_prefix: Optional[str]
    token_audience: Optional[str]
    token_key: Optional[str]


@dataclass
class JwtAuthConfig:
    debug: Optional[bool]
    gateway: Optional[Gateway]
    jwt_username_separator: Optional[str]
    leeway: Optional[int] = 0


CONFIG = load_dataclass_config(
    Path(os.getenv('JWT_AUTH_BACKEND_CONFIG_PATH', Path.cwd() / 'config' / 'config_jwt_auth.yaml')),
    JwtAuthConfig,
    'JWT_AUTH'
)
