import os
from dataclasses import dataclass
from pathlib import Path

from csirtmu.dataclass_config_loader.load import load_dataclass_config
from dataclasses_json import dataclass_json
from oso import Oso
from sqlalchemy import create_engine
from sqlalchemy.engine import Engine
from sqlalchemy.orm import sessionmaker


@dataclass_json
@dataclass
class DB:
    db_name: str = 'db'
    db_path: str = (Path(__file__).parent.parent.parent.parent / f'{db_name}.sqlite3').resolve()
    engine: Engine = create_engine(f'sqlite:///{db_path}')
    session: sessionmaker = sessionmaker(engine)


@dataclass_json
@dataclass
class Config:
    oso = Oso()
    db: DB


def _load_config(path: Path) -> Config:
    config = from_dataclass(path, Config)
    config = override_config_with_envs(config, 'JWT_AUTH')
    return config


CONFIG = load_dataclass_config(
    os.getenv('TEST_APP_CONFIG_PATH', Path(__file__).parent.parent / 'config-example.yaml'),
    Config,
    'JWT_AUTH'
)
