from typing import List

from sqlalchemy import Column, Integer, String
from sqlalchemy.orm import Session, declarative_base

from csirtmu.starlette_jwt_auth.models import MappedUser
from tests.examples.example_application.config import DB

Base = declarative_base()


class IPAddress(Base):
    __tablename__ = 'ip_address_black'
    id = Column(Integer, primary_key=True)


class UserMeta(type(Base), type(MappedUser)):
    pass


class DatabaseUser(Base, MappedUser, metaclass=UserMeta):
    __tablename__ = 'my_user'
    uid = Column(String, primary_key=True)

    @property
    def is_authenticated(self) -> bool:
        return True

    @property
    def display_name(self) -> str:
        return self.uid

    @property
    def identity(self) -> str:
        return self.uid

    @staticmethod
    def create_or_get(access_token: str, user_id: str, capabilities: List[str]) -> 'DatabaseUser':
        session: Session
        with DB.session() as session:
            session.expire_on_commit = False
            user = session.get(DatabaseUser, {'uid': user_id})
            if not user:
                user = DatabaseUser(uid=user_id)
                session.add(user)
                session.commit()
                session.expunge(user)
        user.capabilities = capabilities
        return user
