from typing import List

import strawberry
from sqlalchemy_oso.session import AuthorizedSession
from strawberry import Schema
from strawberry.types import Info

from tests.examples.example_application.config import CONFIG
from tests.examples.example_application.models import IPAddress
from tests.examples.example_application.utils import get_request_user


@strawberry.type
class IPAddressType:
    id: int


@strawberry.type
class Query:
    @strawberry.field
    def ips(self, info: Info) -> List[IPAddressType]:
        with AuthorizedSession(bind=config.db.engine, oso=config.oso,
                               user=get_request_user(info.context['request']),
                               checked_permissions={IPAddress: 'read'}) as session:
            return session.query(IPAddress).all()


config = CONFIG
schema = Schema(query=Query)
