import httpx
import pytest
from httpx import AsyncClient
from oso import Oso
from sqlalchemy.orm import Session

from tests.examples.example_application.models import IPAddress


@pytest.mark.asyncio
async def test_simple_permission(oso: Oso, oso_session_factory):
    session: Session = oso_session_factory()
    q = session.query(IPAddress)
    assert len(q.all()) == 1


@pytest.mark.asyncio
async def test_starlette_app_without_token(unused_tcp_port, example_app):
    async with AsyncClient(app=example_app, base_url=f'http://localhost:{unused_tcp_port}') as ac:
        response: httpx.Response = await ac.post('/')
        assert response.status_code == 403


@pytest.mark.asyncio
async def test_starlette_app_with_token(unused_tcp_port, auth_config, authorized_token, example_app):
    headers = {
        auth_config.gateway.token_header_name: f'{auth_config.gateway.token_prefix} {authorized_token}'
    }
    async with AsyncClient(app=example_app, base_url=f'http://localhost:{unused_tcp_port}', headers=headers) as ac:
        response: httpx.Response = await ac.post('/', json={'query': 'query { ips { id } }'})
        assert response.status_code == 200
        assert len(response.json()['data']['ips']) == 1


@pytest.mark.asyncio
async def test_starlette_app_with_token_multiple_claims(unused_tcp_port, auth_config, authorized_token_2, example_app):
    headers = {
        auth_config.gateway.token_header_name: f'{auth_config.gateway.token_prefix} {authorized_token_2}'
    }
    async with AsyncClient(app=example_app, base_url=f'http://localhost:{unused_tcp_port}', headers=headers) as ac:
        response: httpx.Response = await ac.post('/', json={'query': 'query { ips { id } }'})
        assert response.status_code == 200
        assert len(response.json()['data']['ips']) == 1


@pytest.mark.asyncio
async def test_starlette_app_with_unauthorized_token(unused_tcp_port, unauthorized_valid_token, auth_config,
                                                     example_app):
    headers = {
        auth_config.gateway.token_header_name: f'{auth_config.gateway.token_prefix} {unauthorized_valid_token}'
    }
    async with AsyncClient(app=example_app, base_url=f'http://localhost:{unused_tcp_port}',
                           headers=headers) as ac:
        response: httpx.Response = await ac.post('/', json={'query': 'query { ips { id } }'})
        assert response.status_code == 200
        assert len(response.json()['data']['ips']) == 0
