import { HttpClientModule } from '@angular/common/http';
import { NgModule } from '@angular/core';
import { BrowserModule } from '@angular/platform-browser';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { ApolloApiModule } from '@orion/api';
import { ApiConfig, OrionConfig } from '@orion/common';
import { LoginPageModule } from '@orion/login-components';
import { NotFoundModule } from '@orion/shared-components/not-found';
import { ConfirmationGuard } from '@orion/shared-services';
import { APP_CONFIG, appConfigProvider, configurableModuleFactory } from '@sentinel/common/dynamic-env';
import { SENTINEL_CONTROLS_CONFIG } from '@sentinel/components/config';
import { NotificationModule } from '@sentinel/layout/notification';
import { HIGHLIGHT_OPTIONS } from 'ngx-highlightjs';
import { AppRoutingModule } from './app-routing.module';
import { AppComponent } from './app.component';
import { AuthModule } from './auth.module';
import { RouteReuseStrategy, TitleStrategy } from '@angular/router';
import { OrionTitleStrategyService } from './orion-title-strategy.service';
import { ServiceWorkerModule } from '@angular/service-worker';
import { OrionRouteReuseStrategy } from '@orion/shared/services/global';
import { ORION_CARD_CONFIG, ORION_FILTER_PANEL_CONFIG } from '@csirtmu-orion/microframework/config';

@NgModule({
  declarations: [AppComponent],
  imports: [
    BrowserModule,
    BrowserAnimationsModule,
    HttpClientModule,
    AppRoutingModule,
    AuthModule,
    NotFoundModule,
    LoginPageModule,
    NotificationModule,
    ApolloApiModule.forRoot({}),
    ServiceWorkerModule.register('orion-service-worker.js', {
      enabled: true,
      registrationStrategy: 'registerImmediately',
    }),
  ],
  providers: [
    appConfigProvider,
    ConfirmationGuard,
    {
      provide: TitleStrategy,
      useClass: OrionTitleStrategyService,
    },
    {
      provide: RouteReuseStrategy,
      useClass: OrionRouteReuseStrategy,
    },
    {
      provide: ApiConfig,
      useFactory: configurableModuleFactory<OrionConfig>('apiConfig'),
      deps: [APP_CONFIG],
    },
    { provide: SENTINEL_CONTROLS_CONFIG, useValue: { buttonStyle: 'flat', maxItemsCount: 1, withMargin: false } },
    { provide: ORION_CARD_CONFIG, useValue: { elevation: 0 } },
    { provide: ORION_FILTER_PANEL_CONFIG, useValue: { withSubmitButton: true } },
    {
      provide: HIGHLIGHT_OPTIONS,
      useValue: {
        coreLibraryLoader: () => import('highlight.js/lib/core'),
        languages: {
          xml: () => import('highlight.js/lib/languages/xml'),
        },
      },
    },
  ],
  bootstrap: [AppComponent],
})
export class AppModule {}
