import { ChangeDetectionStrategy, Component, Input, OnChanges, SimpleChanges } from '@angular/core';
import { SentinelControlItem } from '@sentinel/components/controls';
import { defer, of } from 'rxjs';
import { AssetDetailSharedMainContentFragment } from './asset-detail-shared-main-content.generated';
import { AssetTagFragment } from './asset-tags';

@Component({
  selector: 'orion-asset-detail-main-content',
  templateUrl: './asset-detail-main-content.component.html',
  styleUrls: ['./asset-detail-main-content.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class AssetDetailMainContentComponent implements OnChanges {
  @Input() asset?: AssetDetailSharedMainContentFragment;
  controls?: SentinelControlItem[];
  tags: AssetTagFragment[] = [];

  ngOnChanges(changes: SimpleChanges): void {
    if ('asset' in changes && this.asset && 'tags' in this.asset) {
      this.tags = this.asset?.tags?.data;
    }
    if ('asset' in changes && this.asset && this.asset.netboxUrl && !this.controls) {
      const url = this.asset.netboxUrl;
      this.controls = [
        new SentinelControlItem(
          'netboxLink',
          'Open in Netbox',
          'primary',
          of(false),
          defer(() => this.openNetboxLink(url))
        ),
      ];
    }
  }

  private openNetboxLink(url: string): void {
    window.open(url, '_blank');
  }
}
