import { ChangeDetectionStrategy, Component, Input, OnChanges, OnInit, SimpleChanges } from '@angular/core';
import { AssetCveService } from './asset-cve.service';
import { Observable } from 'rxjs';
import { AssetCveFragment } from './graphql';

@Component({
  selector: 'orion-asset-cve',
  templateUrl: './asset-cve.component.html',
  styleUrls: ['./asset-cve.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [AssetCveService],
})
export class AssetCveComponent implements OnInit, OnChanges {
  @Input() assetUid?: string;
  entities$?: Observable<AssetCveFragment[]>;
  isLoading$?: Observable<boolean>;
  hasError$?: Observable<boolean>;

  constructor(private entitiesService: AssetCveService) {}

  ngOnInit(): void {
    this.entities$ = this.entitiesService.data$;
    this.isLoading$ = this.entitiesService.isLoading$;
    this.hasError$ = this.entitiesService.hasError$;
  }

  ngOnChanges(changes: SimpleChanges): void {
    if ('assetUid' in changes && this.assetUid !== undefined) {
      this.entitiesService.update(this.assetUid);
    }
  }

  onTryAgain(): void {
    this.entitiesService.recoverAfterError();
  }
}
