import { Injectable } from '@angular/core';
import { ApolloEntitiesService } from '@csirtmu-orion/microframework/apollo-services';
import { AssetCveFragment, GetAssetCvesQuery, GetAssetCvesQueryService, GetAssetCvesQueryVariables } from './graphql';

@Injectable()
export class AssetCveService extends ApolloEntitiesService<
  GetAssetCvesQuery,
  GetAssetCvesQueryVariables,
  AssetCveFragment
> {
  constructor(public getQuery: GetAssetCvesQueryService) {
    super(getQuery, 'Fetching asset CVEs');
  }

  update(assetUid: string): void {
    this.updateVariables(assetUid);
    this.updateQuery();
  }

  protected updateVariables(assetUid: string): void {
    this.variables = this.createVariables(assetUid);
  }

  protected createVariables(assetUid: string): GetAssetCvesQueryVariables {
    return {
      assetUid: assetUid,
    };
  }

  protected toFragments(query: GetAssetCvesQuery): AssetCveFragment[] {
    return (query?.findByAsset ?? []) as AssetCveFragment[];
  }
}
