import { Injectable } from '@angular/core';
import { ActivatedRoute, Data, ParamMap, Params, Router } from '@angular/router';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';
import { RelatedCaseFilterService } from '@orion/case-components/filters';
import { RelatedCaseFilter } from '@orion/case-types';
import { Observable, of } from 'rxjs';

@Injectable()
export class AssetRelatedCasesFilterService extends RelatedCaseFilterService {
  constructor(protected router: Router, protected activatedRoute: ActivatedRoute) {
    super(router, activatedRoute);
  }

  protected toQueryParams(filter: RelatedCaseFilter): Params {
    const params = super.toQueryParams(filter);
    delete params.asset;
    return params;
  }

  protected createFilterFromRoute(
    queryParamMap: ParamMap,
    paramMap: ParamMap,
    data: Data
  ): Observable<RelatedCaseFilter> {
    const idParam = paramMap.get(ASSET_ID_PARAM_SELECTOR) ?? undefined;
    const type = data.assetType;
    return of({ asset: { assetId: { exact: idParam }, assetType: { exact: type } } });
  }
}
