import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  CircuitAssetDetailFragment,
  GetCircuitQuery,
  GetCircuitQueryService,
  GetCircuitQueryVariables,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class CircuitAssetDetailService extends ApolloRoutedEntityService<
  GetCircuitQuery,
  GetCircuitQueryVariables,
  CircuitAssetDetailFragment
> {
  constructor(getQuery: GetCircuitQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching circuit');
  }

  protected createVariables(entityId: string): GetCircuitQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetCircuitQuery): Optional<CircuitAssetDetailFragment> {
    return query?.circuit;
  }
}
