import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  CircuitTerminationAssetDetailFragment,
  GetCircuitTerminationQuery,
  GetCircuitTerminationQueryService,
  GetCircuitTerminationQueryVariables,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class CircuitTerminationAssetDetailService extends ApolloRoutedEntityService<
  GetCircuitTerminationQuery,
  GetCircuitTerminationQueryVariables,
  CircuitTerminationAssetDetailFragment
> {
  constructor(getQuery: GetCircuitTerminationQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching circuit termination');
  }

  protected createVariables(entityId: string): GetCircuitTerminationQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetCircuitTerminationQuery): Optional<CircuitTerminationAssetDetailFragment> {
    return query?.circuitTermination;
  }
}
