import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  CircuitTypeAssetDetailFragment,
  GetCircuitTypeQuery,
  GetCircuitTypeQueryService,
  GetCircuitTypeQueryVariables,
} from './graphql';

@Injectable()
export class CircuitTypeAssetDetailService extends ApolloRoutedEntityService<
  GetCircuitTypeQuery,
  GetCircuitTypeQueryVariables,
  CircuitTypeAssetDetailFragment
> {
  constructor(getQuery: GetCircuitTypeQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching circuit type');
  }

  protected createVariables(entityId: string): GetCircuitTypeQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetCircuitTypeQuery): Optional<CircuitTypeAssetDetailFragment> {
    return query.circuitType;
  }
}
