import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  GetProviderQuery,
  GetProviderQueryService,
  GetProviderQueryVariables,
  ProviderAssetDetailFragment,
} from './graphql';

@Injectable()
export class ProviderAssetDetailService extends ApolloRoutedEntityService<
  GetProviderQuery,
  GetProviderQueryVariables,
  ProviderAssetDetailFragment
> {
  constructor(getQuery: GetProviderQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching provider');
  }

  protected createVariables(entityId: string): GetProviderQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetProviderQuery): Optional<ProviderAssetDetailFragment> {
    return query.provider;
  }
}
