import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  GetProviderNetworkQuery,
  GetProviderNetworkQueryService,
  GetProviderNetworkQueryVariables,
  ProviderNetworkAssetDetailFragment,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class ProviderNetworkAssetDetailService extends ApolloRoutedEntityService<
  GetProviderNetworkQuery,
  GetProviderNetworkQueryVariables,
  ProviderNetworkAssetDetailFragment
> {
  constructor(getQuery: GetProviderNetworkQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching provider network');
  }

  protected createVariables(entityId: string): GetProviderNetworkQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetProviderNetworkQuery): Optional<ProviderNetworkAssetDetailFragment> {
    return query.providerNetwork;
  }
}
