import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  GetWirelessLinkQuery,
  GetWirelessLinkQueryService,
  GetWirelessLinkQueryVariables,
  WirelessLinkAssetDetailFragment,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class WirelessLinkAssetDetailService extends ApolloRoutedEntityService<
  GetWirelessLinkQuery,
  GetWirelessLinkQueryVariables,
  WirelessLinkAssetDetailFragment
> {
  constructor(getQuery: GetWirelessLinkQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching wireless link');
  }

  protected createVariables(entityId: string): GetWirelessLinkQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetWirelessLinkQuery): Optional<WirelessLinkAssetDetailFragment> {
    return query.wirelessLink;
  }
}
