import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  ConsolePortAssetDetailFragment,
  GetConsolePortQuery,
  GetConsolePortQueryService,
  GetConsolePortQueryVariables,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class ConsolePortAssetDetailService extends ApolloRoutedEntityService<
  GetConsolePortQuery,
  GetConsolePortQueryVariables,
  ConsolePortAssetDetailFragment
> {
  constructor(getQuery: GetConsolePortQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching console port');
  }

  protected createVariables(entityId: string): GetConsolePortQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetConsolePortQuery): Optional<ConsolePortAssetDetailFragment> {
    return query?.consolePort;
  }
}
