import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  ConsoleServerPortDetailFragment,
  GetConsoleServerPortQuery,
  GetConsoleServerPortQueryService,
  GetConsoleServerPortQueryVariables,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class ConsoleServerPortDetailService extends ApolloRoutedEntityService<
  GetConsoleServerPortQuery,
  GetConsoleServerPortQueryVariables,
  ConsoleServerPortDetailFragment
> {
  constructor(getQuery: GetConsoleServerPortQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching console server port');
  }

  protected createVariables(entityId: string): GetConsoleServerPortQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetConsoleServerPortQuery): Optional<ConsoleServerPortDetailFragment> {
    return query.consoleServerPort;
  }
}
