import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  DeviceBayAssetDetailFragment,
  GetDeviceBayQuery,
  GetDeviceBayQueryService,
  GetDeviceBayQueryVariables,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class DeviceBayAssetDetailService extends ApolloRoutedEntityService<
  GetDeviceBayQuery,
  GetDeviceBayQueryVariables,
  DeviceBayAssetDetailFragment
> {
  constructor(getQuery: GetDeviceBayQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching device bay');
  }

  protected createVariables(entityId: string): GetDeviceBayQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetDeviceBayQuery): Optional<DeviceBayAssetDetailFragment> {
    return query.deviceBay;
  }
}
