import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import { DeviceAssetDetailFragment, GetDeviceQuery, GetDeviceQueryService, GetDeviceQueryVariables } from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class DeviceAssetDetailService extends ApolloRoutedEntityService<
  GetDeviceQuery,
  GetDeviceQueryVariables,
  DeviceAssetDetailFragment
> {
  constructor(getQuery: GetDeviceQueryService, protected activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching device');
  }

  protected createVariables(entityId: string): GetDeviceQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetDeviceQuery): Optional<DeviceAssetDetailFragment> {
    return query.device;
  }
}
