import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  DeviceRoleAssetDetailFragment,
  GetDeviceRoleQuery,
  GetDeviceRoleQueryService,
  GetDeviceRoleQueryVariables,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class DeviceRoleAssetDetailService extends ApolloRoutedEntityService<
  GetDeviceRoleQuery,
  GetDeviceRoleQueryVariables,
  DeviceRoleAssetDetailFragment
> {
  constructor(getQuery: GetDeviceRoleQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching device role');
  }

  protected createVariables(entityId: string): GetDeviceRoleQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetDeviceRoleQuery): Optional<DeviceRoleAssetDetailFragment> {
    return query?.deviceRole;
  }
}
