import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  DeviceTypeAssetDetailFragment,
  GetDeviceTypeQuery,
  GetDeviceTypeQueryService,
  GetDeviceTypeQueryVariables,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class DeviceTypeAssetDetailService extends ApolloRoutedEntityService<
  GetDeviceTypeQuery,
  GetDeviceTypeQueryVariables,
  DeviceTypeAssetDetailFragment
> {
  constructor(getQuery: GetDeviceTypeQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching device type');
  }

  protected createVariables(entityId: string): GetDeviceTypeQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetDeviceTypeQuery): Optional<DeviceTypeAssetDetailFragment> {
    return query?.deviceType;
  }
}
