import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  FrontPortAssetDetailFragment,
  GetFrontPortQuery,
  GetFrontPortQueryService,
  GetFrontPortQueryVariables,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class FrontPortAssetDetailService extends ApolloRoutedEntityService<
  GetFrontPortQuery,
  GetFrontPortQueryVariables,
  FrontPortAssetDetailFragment
> {
  constructor(getQuery: GetFrontPortQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching front port');
  }

  protected createVariables(entityId: string): GetFrontPortQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetFrontPortQuery): Optional<FrontPortAssetDetailFragment> {
    return query?.frontPort;
  }
}
