import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  GetInterfaceQuery,
  GetInterfaceQueryService,
  GetInterfaceQueryVariables,
  InterfaceAssetDetailFragment,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class InterfaceAssetDetailService extends ApolloRoutedEntityService<
  GetInterfaceQuery,
  GetInterfaceQueryVariables,
  InterfaceAssetDetailFragment
> {
  constructor(getQuery: GetInterfaceQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching interface');
  }

  protected createVariables(entityId: string): GetInterfaceQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetInterfaceQuery): Optional<InterfaceAssetDetailFragment> {
    return query.interface;
  }
}
