import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  GetInventoryItemQuery,
  GetInventoryItemQueryService,
  GetInventoryItemQueryVariables,
  InventoryItemAssetDetailFragment,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class InventoryItemDetailService extends ApolloRoutedEntityService<
  GetInventoryItemQuery,
  GetInventoryItemQueryVariables,
  InventoryItemAssetDetailFragment
> {
  constructor(getQuery: GetInventoryItemQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching inventory item');
  }

  protected createVariables(entityId: string): GetInventoryItemQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetInventoryItemQuery): Optional<InventoryItemAssetDetailFragment> {
    return query?.inventoryItem;
  }
}
