import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  GetManufacturerQuery,
  GetManufacturerQueryService,
  GetManufacturerQueryVariables,
  ManufacturerAssetDetailFragment,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class ManufacturerAssetDetailService extends ApolloRoutedEntityService<
  GetManufacturerQuery,
  GetManufacturerQueryVariables,
  ManufacturerAssetDetailFragment
> {
  constructor(getQuery: GetManufacturerQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching manufacturer');
  }

  protected createVariables(entityId: string): GetManufacturerQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetManufacturerQuery): Optional<ManufacturerAssetDetailFragment> {
    return query?.manufacturer;
  }
}
