import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  GetPlatformQuery,
  GetPlatformQueryService,
  GetPlatformQueryVariables,
  PlatformAssetDetailFragment,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class PlatformAssetDetailService extends ApolloRoutedEntityService<
  GetPlatformQuery,
  GetPlatformQueryVariables,
  PlatformAssetDetailFragment
> {
  constructor(getQuery: GetPlatformQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching platform');
  }

  protected createVariables(entityId: string): GetPlatformQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetPlatformQuery): Optional<PlatformAssetDetailFragment> {
    return query?.platform;
  }
}
