import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  GetPowerOutletQuery,
  GetPowerOutletQueryService,
  GetPowerOutletQueryVariables,
  PowerOutletAssetDetailFragment,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class PowerOutletAssetDetailService extends ApolloRoutedEntityService<
  GetPowerOutletQuery,
  GetPowerOutletQueryVariables,
  PowerOutletAssetDetailFragment
> {
  constructor(getQuery: GetPowerOutletQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching power outlet');
  }

  protected createVariables(entityId: string): GetPowerOutletQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetPowerOutletQuery): Optional<PowerOutletAssetDetailFragment> {
    return query.powerOutlet;
  }
}
