import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  GetPowerPortQuery,
  GetPowerPortQueryService,
  GetPowerPortQueryVariables,
  PowerPortAssetDetailFragment,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class PowerPortAssetDetailService extends ApolloRoutedEntityService<
  GetPowerPortQuery,
  GetPowerPortQueryVariables,
  PowerPortAssetDetailFragment
> {
  constructor(getQuery: GetPowerPortQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching power port');
  }

  protected createVariables(entityId: string): GetPowerPortQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetPowerPortQuery): Optional<PowerPortAssetDetailFragment> {
    return query.powerPort;
  }
}
