import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  GetRearPortQuery,
  GetRearPortQueryService,
  GetRearPortQueryVariables,
  RearPortAssetDetailFragment,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class RearPortAssetDetailService extends ApolloRoutedEntityService<
  GetRearPortQuery,
  GetRearPortQueryVariables,
  RearPortAssetDetailFragment
> {
  constructor(getQuery: GetRearPortQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching rear port');
  }

  protected createVariables(entityId: string): GetRearPortQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetRearPortQuery): Optional<RearPortAssetDetailFragment> {
    return query.rearPort;
  }
}
