import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  GetVirtualChassisQuery,
  GetVirtualChassisQueryService,
  GetVirtualChassisQueryVariables,
  VirtualChassisAssetDetailFragment,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class VirtualChassisAssetDetailService extends ApolloRoutedEntityService<
  GetVirtualChassisQuery,
  GetVirtualChassisQueryVariables,
  VirtualChassisAssetDetailFragment
> {
  constructor(getQuery: GetVirtualChassisQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching virtual chassis');
  }

  protected createVariables(entityId: string): GetVirtualChassisQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetVirtualChassisQuery): Optional<VirtualChassisAssetDetailFragment> {
    return query?.virtualChassis;
  }
}
