import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  AggregateDetailFragment,
  GetAggregateQuery,
  GetAggregateQueryService,
  GetAggregateQueryVariables,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class AggregateAssetDetailService extends ApolloRoutedEntityService<
  GetAggregateQuery,
  GetAggregateQueryVariables,
  AggregateDetailFragment
> {
  constructor(public getQuery: GetAggregateQueryService, protected activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching aggregate');
  }

  protected createVariables(entityId: string): GetAggregateQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetAggregateQuery): Optional<AggregateDetailFragment> {
    return query?.aggregate;
  }
}
