import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import { AsnAssetDetailFragment, GetAsnQuery, GetAsnQueryService, GetAsnQueryVariables } from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class AsnAssetDetailService extends ApolloRoutedEntityService<
  GetAsnQuery,
  GetAsnQueryVariables,
  AsnAssetDetailFragment
> {
  constructor(getQuery: GetAsnQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching ASN');
  }

  protected createVariables(entityId: string): GetAsnQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetAsnQuery): Optional<AsnAssetDetailFragment> {
    return query.asn;
  }
}
