import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  FhrpGroupAssetDetailFragment,
  GetFhrpGroupQuery,
  GetFhrpGroupQueryService,
  GetFhrpGroupQueryVariables,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class FhrpGroupAssetDetailService extends ApolloRoutedEntityService<
  GetFhrpGroupQuery,
  GetFhrpGroupQueryVariables,
  FhrpGroupAssetDetailFragment
> {
  constructor(getQuery: GetFhrpGroupQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching FHRP Groups');
  }

  protected createVariables(entityId: string): GetFhrpGroupQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetFhrpGroupQuery): Optional<FhrpGroupAssetDetailFragment> {
    return query.fhrpGroup;
  }
}
