import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  GetIpAddressQuery,
  GetIpAddressQueryService,
  GetIpAddressQueryVariables,
  IpAddressAssetDetailFragment,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class IpAddressAssetDetailService extends ApolloRoutedEntityService<
  GetIpAddressQuery,
  GetIpAddressQueryVariables,
  IpAddressAssetDetailFragment
> {
  constructor(getQuery: GetIpAddressQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching IP address');
  }

  protected createVariables(entityId: string): GetIpAddressQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetIpAddressQuery): Optional<IpAddressAssetDetailFragment> {
    return query?.ipAddress;
  }
}
