import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  GetIpRangeQuery,
  GetIpRangeQueryService,
  GetIpRangeQueryVariables,
  IpRangeAssetDetailFragment,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class IpRangeAssetDetailService extends ApolloRoutedEntityService<
  GetIpRangeQuery,
  GetIpRangeQueryVariables,
  IpRangeAssetDetailFragment
> {
  constructor(getQuery: GetIpRangeQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching IP range');
  }

  protected createVariables(entityId: string): GetIpRangeQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetIpRangeQuery): Optional<IpRangeAssetDetailFragment> {
    return query?.ipRange;
  }
}
