import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  GetPrefixAndVlanRoleQuery,
  GetPrefixAndVlanRoleQueryService,
  GetPrefixAndVlanRoleQueryVariables,
  PrefixAndVlanRoleAssetDetailFragment,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class PrefixAndVlanRoleAssetDetailService extends ApolloRoutedEntityService<
  GetPrefixAndVlanRoleQuery,
  GetPrefixAndVlanRoleQueryVariables,
  PrefixAndVlanRoleAssetDetailFragment
> {
  constructor(getQuery: GetPrefixAndVlanRoleQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching role');
  }

  protected createVariables(entityId: string): GetPrefixAndVlanRoleQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetPrefixAndVlanRoleQuery): Optional<PrefixAndVlanRoleAssetDetailFragment> {
    return query?.role;
  }
}
