import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import { GetPrefixQuery, GetPrefixQueryService, GetPrefixQueryVariables, PrefixAssetDetailFragment } from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class PrefixAssetDetailService extends ApolloRoutedEntityService<
  GetPrefixQuery,
  GetPrefixQueryVariables,
  PrefixAssetDetailFragment
> {
  constructor(getQuery: GetPrefixQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching prefix');
  }

  protected createVariables(entityId: string): GetPrefixQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetPrefixQuery): Optional<PrefixAssetDetailFragment> {
    return query?.prefix;
  }
}
