import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  GetRirDetailQuery,
  GetRirDetailQueryService,
  GetRirDetailQueryVariables,
  RirAssetDetailFragment,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class RirAssetDetailService extends ApolloRoutedEntityService<
  GetRirDetailQuery,
  GetRirDetailQueryVariables,
  RirAssetDetailFragment
> {
  constructor(getQuery: GetRirDetailQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching RIR');
  }

  protected createVariables(entityId: string): GetRirDetailQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetRirDetailQuery): Optional<RirAssetDetailFragment> {
    return query?.rir;
  }
}
