import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  GetRouteTargetDetailQuery,
  GetRouteTargetDetailQueryService,
  GetRouteTargetDetailQueryVariables,
  RouteTargetAssetDetailFragment,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class RouteTargetAssetDetailService extends ApolloRoutedEntityService<
  GetRouteTargetDetailQuery,
  GetRouteTargetDetailQueryVariables,
  RouteTargetAssetDetailFragment
> {
  constructor(getQuery: GetRouteTargetDetailQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching route target');
  }

  protected createVariables(entityId: string): GetRouteTargetDetailQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetRouteTargetDetailQuery): Optional<RouteTargetAssetDetailFragment> {
    return query?.routeTarget;
  }
}
