import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  GetServiceDetailQuery,
  GetServiceDetailQueryService,
  GetServiceDetailQueryVariables,
  ServiceAssetDetailFragment,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class ServiceAssetDetailService extends ApolloRoutedEntityService<
  GetServiceDetailQuery,
  GetServiceDetailQueryVariables,
  ServiceAssetDetailFragment
> {
  constructor(getQuery: GetServiceDetailQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching service');
  }

  protected createVariables(entityId: string): GetServiceDetailQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetServiceDetailQuery): Optional<ServiceAssetDetailFragment> {
    return query?.serviceAsset;
  }
}
