import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  GetVlanDetailQuery,
  GetVlanDetailQueryService,
  GetVlanDetailQueryVariables,
  VlanAssetDetailFragment,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class VlanAssetDetailService extends ApolloRoutedEntityService<
  GetVlanDetailQuery,
  GetVlanDetailQueryVariables,
  VlanAssetDetailFragment
> {
  constructor(getQuery: GetVlanDetailQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching VLAN');
  }

  protected createVariables(entityId: string): GetVlanDetailQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetVlanDetailQuery): Optional<VlanAssetDetailFragment> {
    return query?.vlan;
  }
}
