import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  GetVlanGroupDetailQuery,
  GetVlanGroupDetailQueryService,
  GetVlanGroupDetailQueryVariables,
  VlanGroupAssetDetailFragment,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class VlanGroupAssetDetailService extends ApolloRoutedEntityService<
  GetVlanGroupDetailQuery,
  GetVlanGroupDetailQueryVariables,
  VlanGroupAssetDetailFragment
> {
  constructor(getQuery: GetVlanGroupDetailQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching VLAN group');
  }

  protected createVariables(entityId: string): GetVlanGroupDetailQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetVlanGroupDetailQuery): Optional<VlanGroupAssetDetailFragment> {
    return query?.vlanGroup;
  }
}
