import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  GetVrfDetailQuery,
  GetVrfDetailQueryService,
  GetVrfDetailQueryVariables,
  VrfAssetDetailFragment,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class VrfAssetDetailService extends ApolloRoutedEntityService<
  GetVrfDetailQuery,
  GetVrfDetailQueryVariables,
  VrfAssetDetailFragment
> {
  constructor(getQuery: GetVrfDetailQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching VRF');
  }

  protected createVariables(entityId: string): GetVrfDetailQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetVrfDetailQuery): Optional<VrfAssetDetailFragment> {
    return query?.vrf;
  }
}
