import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  GetLocationQuery,
  GetLocationQueryService,
  GetLocationQueryVariables,
  LocationAssetDetailFragment,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class LocationAssetDetailService extends ApolloRoutedEntityService<
  GetLocationQuery,
  GetLocationQueryVariables,
  LocationAssetDetailFragment
> {
  constructor(getQuery: GetLocationQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching location');
  }

  protected createVariables(entityId: string): GetLocationQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetLocationQuery): Optional<LocationAssetDetailFragment> {
    return query.location;
  }
}
