import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import { GetRackQuery, GetRackQueryService, GetRackQueryVariables, RackAssetDetailFragment } from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class RackAssetDetailService extends ApolloRoutedEntityService<
  GetRackQuery,
  GetRackQueryVariables,
  RackAssetDetailFragment
> {
  constructor(getQuery: GetRackQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching rack');
  }

  protected createVariables(entityId: string): GetRackQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetRackQuery): Optional<RackAssetDetailFragment> {
    return query.rack;
  }
}
