import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  GetRackReservationQuery,
  GetRackReservationQueryService,
  GetRackReservationQueryVariables,
  RackReservationAssetDetailFragment,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class RackReservationAssetDetailService extends ApolloRoutedEntityService<
  GetRackReservationQuery,
  GetRackReservationQueryVariables,
  RackReservationAssetDetailFragment
> {
  constructor(getQuery: GetRackReservationQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching rack reservation');
  }

  protected createVariables(entityId: string): GetRackReservationQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetRackReservationQuery): Optional<RackReservationAssetDetailFragment> {
    return query.rackReservation;
  }
}
