import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  GetRackRoleQuery,
  GetRackRoleQueryService,
  GetRackRoleQueryVariables,
  RackRoleAssetDetailFragment,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class RackRoleAssetDetailService extends ApolloRoutedEntityService<
  GetRackRoleQuery,
  GetRackRoleQueryVariables,
  RackRoleAssetDetailFragment
> {
  constructor(getQuery: GetRackRoleQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching rack role');
  }

  protected createVariables(entityId: string): GetRackRoleQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetRackRoleQuery): Optional<RackRoleAssetDetailFragment> {
    return query.rackRole;
  }
}
