import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import { GetRegionQuery, GetRegionQueryService, GetRegionQueryVariables, RegionAssetDetailFragment } from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class RegionAssetDetailService extends ApolloRoutedEntityService<
  GetRegionQuery,
  GetRegionQueryVariables,
  RegionAssetDetailFragment
> {
  constructor(getQuery: GetRegionQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching region');
  }

  protected createVariables(entityId: string): GetRegionQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetRegionQuery): Optional<RegionAssetDetailFragment> {
    return query.region;
  }
}
