import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import { GetSiteQuery, GetSiteQueryService, GetSiteQueryVariables, SiteAssetDetailFragment } from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class SiteAssetDetailService extends ApolloRoutedEntityService<
  GetSiteQuery,
  GetSiteQueryVariables,
  SiteAssetDetailFragment
> {
  constructor(getQuery: GetSiteQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching site');
  }

  protected createVariables(entityId: string): GetSiteQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetSiteQuery): Optional<SiteAssetDetailFragment> {
    return query.site;
  }
}
