import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  GetSiteGroupQuery,
  GetSiteGroupQueryService,
  GetSiteGroupQueryVariables,
  SiteGroupAssetDetailFragment,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class SiteGroupAssetDetailService extends ApolloRoutedEntityService<
  GetSiteGroupQuery,
  GetSiteGroupQueryVariables,
  SiteGroupAssetDetailFragment
> {
  constructor(getQuery: GetSiteGroupQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching site group');
  }

  protected createVariables(entityId: string): GetSiteGroupQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetSiteGroupQuery): Optional<SiteGroupAssetDetailFragment> {
    return query.siteGroup;
  }
}
