import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  GetTenantDetailQuery,
  GetTenantDetailQueryService,
  GetTenantDetailQueryVariables,
  TenantAssetDetailFragment,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class TenantAssetDetailService extends ApolloRoutedEntityService<
  GetTenantDetailQuery,
  GetTenantDetailQueryVariables,
  TenantAssetDetailFragment
> {
  constructor(getQuery: GetTenantDetailQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching tenant');
  }

  protected createVariables(entityId: string): GetTenantDetailQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetTenantDetailQuery): Optional<TenantAssetDetailFragment> {
    return query.tenant;
  }
}
