import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  GetTenantGroupDetailQuery,
  GetTenantGroupDetailQueryService,
  GetTenantGroupDetailQueryVariables,
  TenantGroupAssetDetailFragment,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class TenantGroupAssetDetailService extends ApolloRoutedEntityService<
  GetTenantGroupDetailQuery,
  GetTenantGroupDetailQueryVariables,
  TenantGroupAssetDetailFragment
> {
  constructor(getQuery: GetTenantGroupDetailQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching tenant group');
  }

  protected createVariables(entityId: string): GetTenantGroupDetailQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetTenantGroupDetailQuery): Optional<TenantGroupAssetDetailFragment> {
    return query.tenantGroup;
  }
}
