import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  GetPowerFeedQuery,
  GetPowerFeedQueryService,
  GetPowerFeedQueryVariables,
  PowerFeedAssetDetailFragment,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class PowerFeedAssetDetailService extends ApolloRoutedEntityService<
  GetPowerFeedQuery,
  GetPowerFeedQueryVariables,
  PowerFeedAssetDetailFragment
> {
  constructor(getQuery: GetPowerFeedQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching power feed');
  }

  protected createVariables(entityId: string): GetPowerFeedQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetPowerFeedQuery): Optional<PowerFeedAssetDetailFragment> {
    return query.powerFeed;
  }
}
