import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  GetPowerPanelQuery,
  GetPowerPanelQueryService,
  GetPowerPanelQueryVariables,
  PowerPanelAssetDetailFragment,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class PowerPanelAssetDetailService extends ApolloRoutedEntityService<
  GetPowerPanelQuery,
  GetPowerPanelQueryVariables,
  PowerPanelAssetDetailFragment
> {
  constructor(getQuery: GetPowerPanelQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching power panel');
  }

  protected createVariables(entityId: string): GetPowerPanelQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetPowerPanelQuery): Optional<PowerPanelAssetDetailFragment> {
    return query.powerPanel;
  }
}
