import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  ClusterAssetDetailFragment,
  GetClusterQuery,
  GetClusterQueryService,
  GetClusterQueryVariables,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class ClusterAssetDetailService extends ApolloRoutedEntityService<
  GetClusterQuery,
  GetClusterQueryVariables,
  ClusterAssetDetailFragment
> {
  constructor(getQuery: GetClusterQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching cluster');
  }

  protected createVariables(entityId: string): GetClusterQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetClusterQuery): Optional<ClusterAssetDetailFragment> {
    return query.cluster;
  }
}
