import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  ClusterTypeAssetDetailFragment,
  GetClusterTypeQuery,
  GetClusterTypeQueryService,
  GetClusterTypeQueryVariables,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class ClusterTypeAssetDetailService extends ApolloRoutedEntityService<
  GetClusterTypeQuery,
  GetClusterTypeQueryVariables,
  ClusterTypeAssetDetailFragment
> {
  constructor(getQuery: GetClusterTypeQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching cluster type');
  }

  protected createVariables(entityId: string): GetClusterTypeQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetClusterTypeQuery): Optional<ClusterTypeAssetDetailFragment> {
    return query.clusterType;
  }
}
