import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import { GetVmQuery, GetVmQueryService, GetVmQueryVariables, VmAssetDetailFragment } from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class VmAssetDetailService extends ApolloRoutedEntityService<
  GetVmQuery,
  GetVmQueryVariables,
  VmAssetDetailFragment
> {
  constructor(getQuery: GetVmQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching virtual machine');
  }

  protected createVariables(entityId: string): GetVmQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetVmQuery): Optional<VmAssetDetailFragment> {
    return query.virtualMachine;
  }
}
