import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  GetVmInterfaceQuery,
  GetVmInterfaceQueryService,
  GetVmInterfaceQueryVariables,
  VmInterfaceDetailFragment,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class VmInterfaceDetailService extends ApolloRoutedEntityService<
  GetVmInterfaceQuery,
  GetVmInterfaceQueryVariables,
  VmInterfaceDetailFragment
> {
  constructor(getQuery: GetVmInterfaceQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching VM interface');
  }

  protected createVariables(entityId: string): GetVmInterfaceQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetVmInterfaceQuery): Optional<VmInterfaceDetailFragment> {
    return query.vmInterface;
  }
}
