import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  GetWirelessLanQuery,
  GetWirelessLanQueryService,
  GetWirelessLanQueryVariables,
  WirelessLanAssetDetailFragment,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class WirelessLanDetailService extends ApolloRoutedEntityService<
  GetWirelessLanQuery,
  GetWirelessLanQueryVariables,
  WirelessLanAssetDetailFragment
> {
  constructor(getQuery: GetWirelessLanQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching wireless LAN');
  }

  protected createVariables(entityId: string): GetWirelessLanQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetWirelessLanQuery): Optional<WirelessLanAssetDetailFragment> {
    return query.wirelessLan;
  }
}
