import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  GetWirelessLanGroupQuery,
  GetWirelessLanGroupQueryService,
  GetWirelessLanGroupQueryVariables,
  WirelessLanGroupAssetDetailFragment,
} from './graphql';
import { ASSET_ID_PARAM_SELECTOR } from '@orion/asset-paths';

@Injectable()
export class WirelessLanGroupDetailService extends ApolloRoutedEntityService<
  GetWirelessLanGroupQuery,
  GetWirelessLanGroupQueryVariables,
  WirelessLanGroupAssetDetailFragment
> {
  constructor(getQuery: GetWirelessLanGroupQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching wireless LAN group');
  }

  protected createVariables(entityId: string): GetWirelessLanGroupQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(ASSET_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetWirelessLanGroupQuery): Optional<WirelessLanGroupAssetDetailFragment> {
    return query.wirelessLanGroup;
  }
}
