import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, CircuitFilterConverter } from '@orion/asset-types';
import { CircuitFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  CircuitAssetOverviewFragment,
  GetCircuitOverviewQuery,
  GetCircuitOverviewQueryService,
  GetCircuitOverviewQueryVariables,
} from './graphql';

@Injectable()
export class CircuitAssetOverviewService extends AssetTypeOverviewService<
  GetCircuitOverviewQuery,
  GetCircuitOverviewQueryVariables,
  CircuitAssetOverviewFragment,
  AssetClientFilter,
  CircuitFilterAndFilterEntry
> {
  constructor(public getQuery: GetCircuitOverviewQueryService) {
    super(getQuery, 'Fetching circuits');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, CircuitFilterAndFilterEntry> {
    return new CircuitFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetCircuitOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(query: GetCircuitOverviewQuery): CursorPaginatedResponse<CircuitAssetOverviewFragment> {
    return query.circuitList;
  }

  protected toFragments(query: GetCircuitOverviewQuery): CircuitAssetOverviewFragment[] {
    return query.circuitList.data;
  }
}
