import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, CircuitTerminationFilterConverter } from '@orion/asset-types';
import { CircuitTerminationFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  CircuitTerminationAssetOverviewFragment,
  GetCircuitTerminationOverviewQuery,
  GetCircuitTerminationOverviewQueryService,
  GetCircuitTerminationOverviewQueryVariables,
} from './graphql';

@Injectable()
export class CircuitTerminationAssetOverviewService extends AssetTypeOverviewService<
  GetCircuitTerminationOverviewQuery,
  GetCircuitTerminationOverviewQueryVariables,
  CircuitTerminationAssetOverviewFragment,
  AssetClientFilter,
  CircuitTerminationFilterAndFilterEntry
> {
  constructor(public getQuery: GetCircuitTerminationOverviewQueryService) {
    super(getQuery, 'Fetching circuit terminations');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, CircuitTerminationFilterAndFilterEntry> {
    return new CircuitTerminationFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetCircuitTerminationOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(
    query: GetCircuitTerminationOverviewQuery
  ): CursorPaginatedResponse<CircuitTerminationAssetOverviewFragment> {
    return query.circuitTerminationList;
  }

  protected toFragments(query: GetCircuitTerminationOverviewQuery): CircuitTerminationAssetOverviewFragment[] {
    return query.circuitTerminationList.data;
  }
}
