import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, CircuitTypeFilterConverter } from '@orion/asset-types';
import { CircuitTypeFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  CircuitTypeAssetOverviewFragment,
  GetCircuitTypeOverviewQuery,
  GetCircuitTypeOverviewQueryService,
  GetCircuitTypeOverviewQueryVariables,
} from './graphql';

@Injectable()
export class CircuitTypeAssetOverviewService extends AssetTypeOverviewService<
  GetCircuitTypeOverviewQuery,
  GetCircuitTypeOverviewQueryVariables,
  CircuitTypeAssetOverviewFragment,
  AssetClientFilter,
  CircuitTypeFilterAndFilterEntry
> {
  constructor(public getQuery: GetCircuitTypeOverviewQueryService) {
    super(getQuery, 'Fetching circuit types');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, CircuitTypeFilterAndFilterEntry> {
    return new CircuitTypeFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetCircuitTypeOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(
    query: GetCircuitTypeOverviewQuery
  ): CursorPaginatedResponse<CircuitTypeAssetOverviewFragment> {
    return query.circuitTypeList;
  }

  protected toFragments(query: GetCircuitTypeOverviewQuery): CircuitTypeAssetOverviewFragment[] {
    return query.circuitTypeList.data;
  }
}
