import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, ProviderNetworkFilterConverter } from '@orion/asset-types';
import { ProviderNetworkFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetProviderNetworkOverviewQuery,
  GetProviderNetworkOverviewQueryService,
  GetProviderNetworkOverviewQueryVariables,
  ProviderNetworkAssetOverviewFragment,
} from './graphql';

@Injectable()
export class ProviderNetworkAssetOverviewService extends AssetTypeOverviewService<
  GetProviderNetworkOverviewQuery,
  GetProviderNetworkOverviewQueryVariables,
  ProviderNetworkAssetOverviewFragment,
  AssetClientFilter,
  ProviderNetworkFilterAndFilterEntry
> {
  constructor(public getQuery: GetProviderNetworkOverviewQueryService) {
    super(getQuery, 'Fetching provider networks');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, ProviderNetworkFilterAndFilterEntry> {
    return new ProviderNetworkFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetProviderNetworkOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(
    query: GetProviderNetworkOverviewQuery
  ): CursorPaginatedResponse<ProviderNetworkAssetOverviewFragment> {
    return query.providerNetworkList;
  }

  protected toFragments(query: GetProviderNetworkOverviewQuery): ProviderNetworkAssetOverviewFragment[] {
    return query.providerNetworkList.data;
  }
}
