import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, ProviderFilterConverter } from '@orion/asset-types';
import { ProviderFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetProviderOverviewQuery,
  GetProviderOverviewQueryService,
  GetProviderOverviewQueryVariables,
  ProviderAssetOverviewFragment,
} from './graphql';

@Injectable()
export class ProviderAssetOverviewService extends AssetTypeOverviewService<
  GetProviderOverviewQuery,
  GetProviderOverviewQueryVariables,
  ProviderAssetOverviewFragment,
  AssetClientFilter,
  ProviderFilterAndFilterEntry
> {
  constructor(public getQuery: GetProviderOverviewQueryService) {
    super(getQuery, 'Fetching providers');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, ProviderFilterAndFilterEntry> {
    return new ProviderFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetProviderOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(query: GetProviderOverviewQuery): CursorPaginatedResponse<ProviderAssetOverviewFragment> {
    return query.providerList;
  }

  protected toFragments(query: GetProviderOverviewQuery): ProviderAssetOverviewFragment[] {
    return query.providerList.data;
  }
}
