import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, CableFilterConverter } from '@orion/asset-types';
import { CableFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  CableAssetOverviewFragment,
  GetCableOverviewQuery,
  GetCableOverviewQueryService,
  GetCableOverviewQueryVariables,
} from './graphql';

@Injectable()
export class CableAssetOverviewService extends AssetTypeOverviewService<
  GetCableOverviewQuery,
  GetCableOverviewQueryVariables,
  CableAssetOverviewFragment,
  AssetClientFilter,
  CableFilterAndFilterEntry
> {
  constructor(public getQuery: GetCableOverviewQueryService) {
    super(getQuery, 'Fetching cables');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, CableFilterAndFilterEntry> {
    return new CableFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetCableOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(query: GetCableOverviewQuery): CursorPaginatedResponse<CableAssetOverviewFragment> {
    return query.cableList;
  }

  protected toFragments(query: GetCableOverviewQuery): CableAssetOverviewFragment[] {
    return query.cableList.data;
  }
}
