import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, WirelessLinkFilterConverter } from '@orion/asset-types';
import { WirelessLinkFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetWirelessLinkOverviewQuery,
  GetWirelessLinkOverviewQueryService,
  GetWirelessLinkOverviewQueryVariables,
  WirelessLinkAssetOverviewFragment,
} from './graphql';

@Injectable()
export class WirelessLinkAssetOverviewService extends AssetTypeOverviewService<
  GetWirelessLinkOverviewQuery,
  GetWirelessLinkOverviewQueryVariables,
  WirelessLinkAssetOverviewFragment,
  AssetClientFilter,
  WirelessLinkFilterAndFilterEntry
> {
  constructor(public getQuery: GetWirelessLinkOverviewQueryService) {
    super(getQuery, 'Fetching wireless links');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, WirelessLinkFilterAndFilterEntry> {
    return new WirelessLinkFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetWirelessLinkOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(
    query: GetWirelessLinkOverviewQuery
  ): CursorPaginatedResponse<WirelessLinkAssetOverviewFragment> {
    return query.wirelessLinkList;
  }

  protected toFragments(query: GetWirelessLinkOverviewQuery): WirelessLinkAssetOverviewFragment[] {
    return query.wirelessLinkList.data;
  }
}
