import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, ConsolePortFilterConverter } from '@orion/asset-types';
import { ConsolePortFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  ConsolePortAssetOverviewFragment,
  GetConsolePortOverviewQuery,
  GetConsolePortOverviewQueryService,
  GetConsolePortOverviewQueryVariables,
} from './graphql';

@Injectable()
export class ConsolePortAssetOverviewService extends AssetTypeOverviewService<
  GetConsolePortOverviewQuery,
  GetConsolePortOverviewQueryVariables,
  ConsolePortAssetOverviewFragment,
  AssetClientFilter,
  ConsolePortFilterAndFilterEntry
> {
  constructor(public getQuery: GetConsolePortOverviewQueryService) {
    super(getQuery, 'Fetching console ports');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, ConsolePortFilterAndFilterEntry> {
    return new ConsolePortFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetConsolePortOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(
    query: GetConsolePortOverviewQuery
  ): CursorPaginatedResponse<ConsolePortAssetOverviewFragment> {
    return query.consolePortList;
  }

  protected toFragments(query: GetConsolePortOverviewQuery): ConsolePortAssetOverviewFragment[] {
    return query.consolePortList.data;
  }
}
