import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, ConsoleServerPortFilterConverter } from '@orion/asset-types';
import { ConsoleServerPortFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  ConsoleServerPortAssetOverviewFragment,
  GetConsoleServerPortOverviewQuery,
  GetConsoleServerPortOverviewQueryService,
  GetConsoleServerPortOverviewQueryVariables,
} from './graphql';

@Injectable()
export class ConsoleServerPortAssetOverviewService extends AssetTypeOverviewService<
  GetConsoleServerPortOverviewQuery,
  GetConsoleServerPortOverviewQueryVariables,
  ConsoleServerPortAssetOverviewFragment,
  AssetClientFilter,
  ConsoleServerPortFilterAndFilterEntry
> {
  constructor(public getQuery: GetConsoleServerPortOverviewQueryService) {
    super(getQuery, 'Fetching console server ports');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, ConsoleServerPortFilterAndFilterEntry> {
    return new ConsoleServerPortFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetConsoleServerPortOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(
    query: GetConsoleServerPortOverviewQuery
  ): CursorPaginatedResponse<ConsoleServerPortAssetOverviewFragment> {
    return query.consoleServerPortList;
  }

  protected toFragments(query: GetConsoleServerPortOverviewQuery): ConsoleServerPortAssetOverviewFragment[] {
    return query.consoleServerPortList.data;
  }
}
