import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, DeviceBayFilterConverter } from '@orion/asset-types';
import { DeviceBayFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  DeviceBayAssetOverviewFragment,
  GetDeviceBayOverviewQuery,
  GetDeviceBayOverviewQueryService,
  GetDeviceBayOverviewQueryVariables,
} from './graphql';

@Injectable()
export class DeviceBayAssetOverviewService extends AssetTypeOverviewService<
  GetDeviceBayOverviewQuery,
  GetDeviceBayOverviewQueryVariables,
  DeviceBayAssetOverviewFragment,
  AssetClientFilter,
  DeviceBayFilterAndFilterEntry
> {
  constructor(public getQuery: GetDeviceBayOverviewQueryService) {
    super(getQuery, 'Fetching device bays');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, DeviceBayFilterAndFilterEntry> {
    return new DeviceBayFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetDeviceBayOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(
    query: GetDeviceBayOverviewQuery
  ): CursorPaginatedResponse<DeviceBayAssetOverviewFragment> {
    return query.deviceBayList;
  }

  protected toFragments(query: GetDeviceBayOverviewQuery): DeviceBayAssetOverviewFragment[] {
    return query.deviceBayList.data;
  }
}
