import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, DeviceFilterConverter } from '@orion/asset-types';
import { DeviceFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  DeviceAssetOverviewFragment,
  GetDeviceOverviewQuery,
  GetDeviceOverviewQueryService,
  GetDeviceOverviewQueryVariables,
} from './graphql';

@Injectable()
export class DeviceAssetOverviewService extends AssetTypeOverviewService<
  GetDeviceOverviewQuery,
  GetDeviceOverviewQueryVariables,
  DeviceAssetOverviewFragment,
  AssetClientFilter,
  DeviceFilterAndFilterEntry
> {
  constructor(public getQuery: GetDeviceOverviewQueryService) {
    super(getQuery, 'Fetching device assets');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, DeviceFilterAndFilterEntry> {
    return new DeviceFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetDeviceOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(query: GetDeviceOverviewQuery): CursorPaginatedResponse<DeviceAssetOverviewFragment> {
    return query.deviceList;
  }

  protected toFragments(query: GetDeviceOverviewQuery): DeviceAssetOverviewFragment[] {
    return query.deviceList.data;
  }
}
