import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, DeviceRoleFilterConverter } from '@orion/asset-types';
import { DeviceRoleFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  DeviceRoleAssetOverviewFragment,
  GetDeviceRoleOverviewQuery,
  GetDeviceRoleOverviewQueryService,
  GetDeviceRoleOverviewQueryVariables,
} from './graphql';

@Injectable()
export class DeviceRoleAssetOverviewService extends AssetTypeOverviewService<
  GetDeviceRoleOverviewQuery,
  GetDeviceRoleOverviewQueryVariables,
  DeviceRoleAssetOverviewFragment,
  AssetClientFilter,
  DeviceRoleFilterAndFilterEntry
> {
  constructor(public getQuery: GetDeviceRoleOverviewQueryService) {
    super(getQuery, 'Fetching device roles');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, DeviceRoleFilterAndFilterEntry> {
    return new DeviceRoleFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetDeviceRoleOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(
    query: GetDeviceRoleOverviewQuery
  ): CursorPaginatedResponse<DeviceRoleAssetOverviewFragment> {
    return query.deviceRoleList;
  }

  protected toFragments(query: GetDeviceRoleOverviewQuery): DeviceRoleAssetOverviewFragment[] {
    return query.deviceRoleList.data;
  }
}
