import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, DeviceTypeFilterConverter } from '@orion/asset-types';
import { DeviceTypeFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  DeviceTypeAssetOverviewFragment,
  GetDeviceTypeOverviewQuery,
  GetDeviceTypeOverviewQueryService,
  GetDeviceTypeOverviewQueryVariables,
} from './graphql';

@Injectable()
export class DeviceTypeAssetOverviewService extends AssetTypeOverviewService<
  GetDeviceTypeOverviewQuery,
  GetDeviceTypeOverviewQueryVariables,
  DeviceTypeAssetOverviewFragment,
  AssetClientFilter,
  DeviceTypeFilterAndFilterEntry
> {
  constructor(public getQuery: GetDeviceTypeOverviewQueryService) {
    super(getQuery, 'Fetching device types');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, DeviceTypeFilterAndFilterEntry> {
    return new DeviceTypeFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetDeviceTypeOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(
    query: GetDeviceTypeOverviewQuery
  ): CursorPaginatedResponse<DeviceTypeAssetOverviewFragment> {
    return query.deviceTypeList;
  }

  protected toFragments(query: GetDeviceTypeOverviewQuery): DeviceTypeAssetOverviewFragment[] {
    return query.deviceTypeList.data;
  }
}
