import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, FrontPortFilterConverter } from '@orion/asset-types';
import { FrontPortFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  FrontPortAssetOverviewFragment,
  GetFrontPortOverviewQuery,
  GetFrontPortOverviewQueryService,
  GetFrontPortOverviewQueryVariables,
} from './graphql';

@Injectable()
export class FrontPortAssetOverviewService extends AssetTypeOverviewService<
  GetFrontPortOverviewQuery,
  GetFrontPortOverviewQueryVariables,
  FrontPortAssetOverviewFragment,
  AssetClientFilter,
  FrontPortFilterAndFilterEntry
> {
  constructor(public getQuery: GetFrontPortOverviewQueryService) {
    super(getQuery, 'Fetching front ports');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, FrontPortFilterAndFilterEntry> {
    return new FrontPortFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetFrontPortOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(
    query: GetFrontPortOverviewQuery
  ): CursorPaginatedResponse<FrontPortAssetOverviewFragment> {
    return query.frontPortList;
  }

  protected toFragments(query: GetFrontPortOverviewQuery): FrontPortAssetOverviewFragment[] {
    return query.frontPortList.data;
  }
}
