import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, InterfaceFilterConverter } from '@orion/asset-types';
import { InterfaceFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetInterfaceOverviewQuery,
  GetInterfaceOverviewQueryService,
  GetInterfaceOverviewQueryVariables,
  InterfaceAssetOverviewFragment,
} from './graphql';

@Injectable()
export class InterfaceAssetOverviewService extends AssetTypeOverviewService<
  GetInterfaceOverviewQuery,
  GetInterfaceOverviewQueryVariables,
  InterfaceAssetOverviewFragment,
  AssetClientFilter,
  InterfaceFilterAndFilterEntry
> {
  constructor(public getQuery: GetInterfaceOverviewQueryService) {
    super(getQuery, 'Fetching interfaces');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, InterfaceFilterAndFilterEntry> {
    return new InterfaceFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetInterfaceOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(
    query: GetInterfaceOverviewQuery
  ): CursorPaginatedResponse<InterfaceAssetOverviewFragment> {
    return query.interfaceList;
  }

  protected toFragments(query: GetInterfaceOverviewQuery): InterfaceAssetOverviewFragment[] {
    return query.interfaceList.data;
  }
}
