import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, InventoryItemFilterConverter } from '@orion/asset-types';
import { InventoryItemFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetInventoryItemOverviewQuery,
  GetInventoryItemOverviewQueryService,
  GetInventoryItemOverviewQueryVariables,
  InventoryItemAssetOverviewFragment,
} from './graphql';

@Injectable()
export class InventoryItemAssetOverviewService extends AssetTypeOverviewService<
  GetInventoryItemOverviewQuery,
  GetInventoryItemOverviewQueryVariables,
  InventoryItemAssetOverviewFragment,
  AssetClientFilter,
  InventoryItemFilterAndFilterEntry
> {
  constructor(public getQuery: GetInventoryItemOverviewQueryService) {
    super(getQuery, 'Fetching inventory items');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, InventoryItemFilterAndFilterEntry> {
    return new InventoryItemFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetInventoryItemOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(
    query: GetInventoryItemOverviewQuery
  ): CursorPaginatedResponse<InventoryItemAssetOverviewFragment> {
    return query.inventoryItemList;
  }

  protected toFragments(query: GetInventoryItemOverviewQuery): InventoryItemAssetOverviewFragment[] {
    return query.inventoryItemList.data;
  }
}
