import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, ManufacturerFilterConverter } from '@orion/asset-types';
import { ManufacturerFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetManufacturerOverviewQuery,
  GetManufacturerOverviewQueryService,
  GetManufacturerOverviewQueryVariables,
  ManufacturerAssetOverviewFragment,
} from './graphql';

@Injectable()
export class ManufacturerAssetOverviewService extends AssetTypeOverviewService<
  GetManufacturerOverviewQuery,
  GetManufacturerOverviewQueryVariables,
  ManufacturerAssetOverviewFragment,
  AssetClientFilter,
  ManufacturerFilterAndFilterEntry
> {
  constructor(public getQuery: GetManufacturerOverviewQueryService) {
    super(getQuery, 'Fetching manufacturers');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, ManufacturerFilterAndFilterEntry> {
    return new ManufacturerFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetManufacturerOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(
    query: GetManufacturerOverviewQuery
  ): CursorPaginatedResponse<ManufacturerAssetOverviewFragment> {
    return query.manufacturerList;
  }

  protected toFragments(query: GetManufacturerOverviewQuery): ManufacturerAssetOverviewFragment[] {
    return query.manufacturerList.data;
  }
}
