import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, PlatformFilterConverter } from '@orion/asset-types';
import { PlatformFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetPlatformOverviewQuery,
  GetPlatformOverviewQueryService,
  GetPlatformOverviewQueryVariables,
  PlatformAssetOverviewFragment,
} from './graphql';

@Injectable()
export class PlatformAssetOverviewService extends AssetTypeOverviewService<
  GetPlatformOverviewQuery,
  GetPlatformOverviewQueryVariables,
  PlatformAssetOverviewFragment,
  AssetClientFilter,
  PlatformFilterAndFilterEntry
> {
  constructor(public getQuery: GetPlatformOverviewQueryService) {
    super(getQuery, 'Fetching platforms');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, PlatformFilterAndFilterEntry> {
    return new PlatformFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetPlatformOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(query: GetPlatformOverviewQuery): CursorPaginatedResponse<PlatformAssetOverviewFragment> {
    return query.platformList;
  }

  protected toFragments(query: GetPlatformOverviewQuery): PlatformAssetOverviewFragment[] {
    return query.platformList.data;
  }
}
