import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, PowerOutletFilterConverter } from '@orion/asset-types';
import { PowerOutletFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetPowerOutletOverviewQuery,
  GetPowerOutletOverviewQueryService,
  GetPowerOutletOverviewQueryVariables,
  PowerOutletAssetOverviewFragment,
} from './graphql';

@Injectable()
export class PowerOutletAssetOverviewService extends AssetTypeOverviewService<
  GetPowerOutletOverviewQuery,
  GetPowerOutletOverviewQueryVariables,
  PowerOutletAssetOverviewFragment,
  AssetClientFilter,
  PowerOutletFilterAndFilterEntry
> {
  constructor(public getQuery: GetPowerOutletOverviewQueryService) {
    super(getQuery, 'Fetching power outlets');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, PowerOutletFilterAndFilterEntry> {
    return new PowerOutletFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetPowerOutletOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(
    query: GetPowerOutletOverviewQuery
  ): CursorPaginatedResponse<PowerOutletAssetOverviewFragment> {
    return query.powerOutletList;
  }

  protected toFragments(query: GetPowerOutletOverviewQuery): PowerOutletAssetOverviewFragment[] {
    return query.powerOutletList.data;
  }
}
