import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, PowerPortFilterConverter } from '@orion/asset-types';
import { PowerPortFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetPowerPortOverviewQuery,
  GetPowerPortOverviewQueryService,
  GetPowerPortOverviewQueryVariables,
  PowerPortAssetOverviewFragment,
} from './graphql';

@Injectable()
export class PowerPortAssetOverviewService extends AssetTypeOverviewService<
  GetPowerPortOverviewQuery,
  GetPowerPortOverviewQueryVariables,
  PowerPortAssetOverviewFragment,
  AssetClientFilter,
  PowerPortFilterAndFilterEntry
> {
  constructor(public getQuery: GetPowerPortOverviewQueryService) {
    super(getQuery, 'Fetching power ports');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, PowerPortFilterAndFilterEntry> {
    return new PowerPortFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetPowerPortOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(
    query: GetPowerPortOverviewQuery
  ): CursorPaginatedResponse<PowerPortAssetOverviewFragment> {
    return query.powerPortList;
  }

  protected toFragments(query: GetPowerPortOverviewQuery): PowerPortAssetOverviewFragment[] {
    return query.powerPortList.data;
  }
}
