import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, RearPortFilterConverter } from '@orion/asset-types';
import { RearPortFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetRearPortOverviewQuery,
  GetRearPortOverviewQueryService,
  GetRearPortOverviewQueryVariables,
  RearPortAssetOverviewFragment,
} from './graphql';

@Injectable()
export class RearPortAssetOverviewService extends AssetTypeOverviewService<
  GetRearPortOverviewQuery,
  GetRearPortOverviewQueryVariables,
  RearPortAssetOverviewFragment,
  AssetClientFilter,
  RearPortFilterAndFilterEntry
> {
  constructor(public getQuery: GetRearPortOverviewQueryService) {
    super(getQuery, 'Fetching rear ports');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, RearPortFilterAndFilterEntry> {
    return new RearPortFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetRearPortOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(query: GetRearPortOverviewQuery): CursorPaginatedResponse<RearPortAssetOverviewFragment> {
    return query.rearPortList;
  }

  protected toFragments(query: GetRearPortOverviewQuery): RearPortAssetOverviewFragment[] {
    return query.rearPortList.data;
  }
}
