import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, VirtualChassisFilterConverter } from '@orion/asset-types';
import { VirtualChassisFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetVirtualChassisOverviewQuery,
  GetVirtualChassisOverviewQueryService,
  GetVirtualChassisOverviewQueryVariables,
  VirtualChassisAssetOverviewFragment,
} from './graphql';

@Injectable()
export class VirtualChassisAssetOverviewService extends AssetTypeOverviewService<
  GetVirtualChassisOverviewQuery,
  GetVirtualChassisOverviewQueryVariables,
  VirtualChassisAssetOverviewFragment,
  AssetClientFilter,
  VirtualChassisFilterAndFilterEntry
> {
  constructor(public getQuery: GetVirtualChassisOverviewQueryService) {
    super(getQuery, 'Fetching virtual chassis');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, VirtualChassisFilterAndFilterEntry> {
    return new VirtualChassisFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetVirtualChassisOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(
    query: GetVirtualChassisOverviewQuery
  ): CursorPaginatedResponse<VirtualChassisAssetOverviewFragment> {
    return query.virtualChassisList;
  }

  protected toFragments(query: GetVirtualChassisOverviewQuery): VirtualChassisAssetOverviewFragment[] {
    return query.virtualChassisList.data;
  }
}
