import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AggregateFilterConverter, AssetClientFilter } from '@orion/asset-types';
import { AggregateFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  AggregateAssetOverviewFragment,
  GetAggregateOverviewQuery,
  GetAggregateOverviewQueryService,
  GetAggregateOverviewQueryVariables,
} from './graphql';

@Injectable()
export class AggregateAssetOverviewService extends AssetTypeOverviewService<
  GetAggregateOverviewQuery,
  GetAggregateOverviewQueryVariables,
  AggregateAssetOverviewFragment,
  AssetClientFilter,
  AggregateFilterAndFilterEntry
> {
  public constructor(public getQuery: GetAggregateOverviewQueryService) {
    super(getQuery, 'Fetching aggregates');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, AggregateFilterAndFilterEntry> {
    return new AggregateFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetAggregateOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(
    query: GetAggregateOverviewQuery
  ): CursorPaginatedResponse<AggregateAssetOverviewFragment> {
    return query.aggregateList;
  }

  protected toFragments(query: GetAggregateOverviewQuery): AggregateAssetOverviewFragment[] {
    return query.aggregateList.data;
  }
}
