import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AsnFilterConverter, AssetClientFilter } from '@orion/asset-types';
import { AsnFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  AsnAssetOverviewFragment,
  GetAsnOverviewQuery,
  GetAsnOverviewQueryService,
  GetAsnOverviewQueryVariables,
} from './graphql';

@Injectable()
export class AsnAssetOverviewService extends AssetTypeOverviewService<
  GetAsnOverviewQuery,
  GetAsnOverviewQueryVariables,
  AsnAssetOverviewFragment,
  AssetClientFilter,
  AsnFilterAndFilterEntry
> {
  public constructor(getQuery: GetAsnOverviewQueryService) {
    super(getQuery, 'Fetching ANSs');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, AsnFilterAndFilterEntry> {
    return new AsnFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetAsnOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(query: GetAsnOverviewQuery): CursorPaginatedResponse<AsnAssetOverviewFragment> {
    return query.asnList;
  }

  protected toFragments(query: GetAsnOverviewQuery): AsnAssetOverviewFragment[] {
    return query.asnList.data;
  }
}
