import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, FhrpGroupFilterConverter } from '@orion/asset-types';
import { FhrpGroupFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  FhrpGroupAssetOverviewFragment,
  GetFhrpGroupOverviewQuery,
  GetFhrpGroupOverviewQueryService,
  GetFhrpGroupOverviewQueryVariables,
} from './graphql';

@Injectable()
export class FhrpGroupAssetOverviewService extends AssetTypeOverviewService<
  GetFhrpGroupOverviewQuery,
  GetFhrpGroupOverviewQueryVariables,
  FhrpGroupAssetOverviewFragment,
  AssetClientFilter,
  FhrpGroupFilterAndFilterEntry
> {
  constructor(public getQuery: GetFhrpGroupOverviewQueryService) {
    super(getQuery, 'Fetching FHRP groups');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, FhrpGroupFilterAndFilterEntry> {
    return new FhrpGroupFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetFhrpGroupOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(
    query: GetFhrpGroupOverviewQuery
  ): CursorPaginatedResponse<FhrpGroupAssetOverviewFragment> {
    return query.fhrpGroupList;
  }

  protected toFragments(query: GetFhrpGroupOverviewQuery): FhrpGroupAssetOverviewFragment[] {
    return query.fhrpGroupList.data;
  }
}
