import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, IpAddressFilterConverter } from '@orion/asset-types';
import { IpAddressFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetIpAddressOverviewQuery,
  GetIpAddressOverviewQueryService,
  GetIpAddressOverviewQueryVariables,
  IpAddressAssetOverviewFragment,
} from './graphql';

@Injectable()
export class IpAddressAssetOverviewService extends AssetTypeOverviewService<
  GetIpAddressOverviewQuery,
  GetIpAddressOverviewQueryVariables,
  IpAddressAssetOverviewFragment,
  AssetClientFilter,
  IpAddressFilterAndFilterEntry
> {
  constructor(public getQuery: GetIpAddressOverviewQueryService) {
    super(getQuery, 'Fetching IP addresses');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, IpAddressFilterAndFilterEntry> {
    return new IpAddressFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetIpAddressOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(
    query: GetIpAddressOverviewQuery
  ): CursorPaginatedResponse<IpAddressAssetOverviewFragment> {
    return query.ipAddressList;
  }

  protected toFragments(query: GetIpAddressOverviewQuery): IpAddressAssetOverviewFragment[] {
    return query.ipAddressList.data;
  }
}
