import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, IpRangeFilterConverter } from '@orion/asset-types';
import { IpRangeFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetIpRangeOverviewQuery,
  GetIpRangeOverviewQueryService,
  GetIpRangeOverviewQueryVariables,
  IpRangeAssetOverviewFragment,
} from './graphql';

@Injectable()
export class IpRangeAssetOverviewService extends AssetTypeOverviewService<
  GetIpRangeOverviewQuery,
  GetIpRangeOverviewQueryVariables,
  IpRangeAssetOverviewFragment,
  AssetClientFilter,
  IpRangeFilterAndFilterEntry
> {
  constructor(public getQuery: GetIpRangeOverviewQueryService) {
    super(getQuery, 'Fetching IP ranges');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, IpRangeFilterAndFilterEntry> {
    return new IpRangeFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetIpRangeOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(query: GetIpRangeOverviewQuery): CursorPaginatedResponse<IpRangeAssetOverviewFragment> {
    return query.ipRangeList;
  }

  protected toFragments(query: GetIpRangeOverviewQuery): IpRangeAssetOverviewFragment[] {
    return query.ipRangeList.data;
  }
}
