import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, RoleFilterConverter } from '@orion/asset-types';
import { RoleFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetPrefixAndVlanRoleOverviewQuery,
  GetPrefixAndVlanRoleOverviewQueryService,
  GetPrefixAndVlanRoleOverviewQueryVariables,
  PrefixAndVlanRoleAssetOverviewFragment,
} from './graphql';

@Injectable()
export class PrefixAndVlanRoleAssetOverviewService extends AssetTypeOverviewService<
  GetPrefixAndVlanRoleOverviewQuery,
  GetPrefixAndVlanRoleOverviewQueryVariables,
  PrefixAndVlanRoleAssetOverviewFragment,
  AssetClientFilter,
  RoleFilterAndFilterEntry
> {
  constructor(getQuery: GetPrefixAndVlanRoleOverviewQueryService) {
    super(getQuery, 'Fetching prefix and VLAN roles');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, RoleFilterAndFilterEntry> {
    return new RoleFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetPrefixAndVlanRoleOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(
    query: GetPrefixAndVlanRoleOverviewQuery
  ): CursorPaginatedResponse<PrefixAndVlanRoleAssetOverviewFragment> {
    return query.roleList;
  }

  protected toFragments(query: GetPrefixAndVlanRoleOverviewQuery): PrefixAndVlanRoleAssetOverviewFragment[] {
    return query.roleList.data;
  }
}
