import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, PrefixFilterConverter } from '@orion/asset-types';
import { PrefixFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetPrefixOverviewQuery,
  GetPrefixOverviewQueryService,
  GetPrefixOverviewQueryVariables,
  PrefixAssetOverviewFragment,
} from './graphql';

@Injectable()
export class PrefixAssetOverviewService extends AssetTypeOverviewService<
  GetPrefixOverviewQuery,
  GetPrefixOverviewQueryVariables,
  PrefixAssetOverviewFragment,
  AssetClientFilter,
  PrefixFilterAndFilterEntry
> {
  constructor(public getQuery: GetPrefixOverviewQueryService) {
    super(getQuery, 'Fetching prefixes');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, PrefixFilterAndFilterEntry> {
    return new PrefixFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetPrefixOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(query: GetPrefixOverviewQuery): CursorPaginatedResponse<PrefixAssetOverviewFragment> {
    return query.prefixList;
  }

  protected toFragments(query: GetPrefixOverviewQuery): PrefixAssetOverviewFragment[] {
    return query.prefixList.data;
  }
}
