import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, RirFilterConverter } from '@orion/asset-types';
import { RirFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetRirOverviewQuery,
  GetRirOverviewQueryService,
  GetRirOverviewQueryVariables,
  RirAssetOverviewFragment,
} from './graphql';

@Injectable()
export class RirAssetOverviewService extends AssetTypeOverviewService<
  GetRirOverviewQuery,
  GetRirOverviewQueryVariables,
  RirAssetOverviewFragment,
  AssetClientFilter,
  RirFilterAndFilterEntry
> {
  constructor(getQuery: GetRirOverviewQueryService) {
    super(getQuery, 'Fetching RIRs');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, RirFilterAndFilterEntry> {
    return new RirFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetRirOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(query: GetRirOverviewQuery): CursorPaginatedResponse<RirAssetOverviewFragment> {
    return query.rirList;
  }

  protected toFragments(query: GetRirOverviewQuery): RirAssetOverviewFragment[] {
    return query.rirList.data;
  }
}
