import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, RouteTargetFilterConverter } from '@orion/asset-types';
import { RouteTargetFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetRouteTargetOverviewQuery,
  GetRouteTargetOverviewQueryService,
  GetRouteTargetOverviewQueryVariables,
  RouteTargetAssetOverviewFragment,
} from './graphql';

@Injectable()
export class RouteTargetAssetOverviewService extends AssetTypeOverviewService<
  GetRouteTargetOverviewQuery,
  GetRouteTargetOverviewQueryVariables,
  RouteTargetAssetOverviewFragment,
  AssetClientFilter,
  RouteTargetFilterAndFilterEntry
> {
  constructor(getQuery: GetRouteTargetOverviewQueryService) {
    super(getQuery, 'Fetching route targets');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, RouteTargetFilterAndFilterEntry> {
    return new RouteTargetFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetRouteTargetOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(
    query: GetRouteTargetOverviewQuery
  ): CursorPaginatedResponse<RouteTargetAssetOverviewFragment> {
    return query.routeTargetList;
  }

  protected toFragments(query: GetRouteTargetOverviewQuery): RouteTargetAssetOverviewFragment[] {
    return query.routeTargetList.data;
  }
}
