import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, ServiceFilterConverter } from '@orion/asset-types';
import { ServiceFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetServiceOverviewQuery,
  GetServiceOverviewQueryService,
  GetServiceOverviewQueryVariables,
  ServiceAssetOverviewFragment,
} from './graphql';

@Injectable()
export class ServiceAssetOverviewService extends AssetTypeOverviewService<
  GetServiceOverviewQuery,
  GetServiceOverviewQueryVariables,
  ServiceAssetOverviewFragment,
  AssetClientFilter,
  ServiceFilterAndFilterEntry
> {
  constructor(getQuery: GetServiceOverviewQueryService) {
    super(getQuery, 'Fetching services');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, ServiceFilterAndFilterEntry> {
    return new ServiceFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetServiceOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(query: GetServiceOverviewQuery): CursorPaginatedResponse<ServiceAssetOverviewFragment> {
    return query.serviceAssetList;
  }

  protected toFragments(query: GetServiceOverviewQuery): ServiceAssetOverviewFragment[] {
    return query.serviceAssetList.data;
  }
}
