import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, VlanGroupFilterConverter } from '@orion/asset-types';
import { VlanGroupFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetVlanGroupOverviewQuery,
  GetVlanGroupOverviewQueryService,
  GetVlanGroupOverviewQueryVariables,
  VlanGroupAssetOverviewFragment,
} from './graphql';

@Injectable()
export class VlanGroupAssetOverviewService extends AssetTypeOverviewService<
  GetVlanGroupOverviewQuery,
  GetVlanGroupOverviewQueryVariables,
  VlanGroupAssetOverviewFragment,
  AssetClientFilter,
  VlanGroupFilterAndFilterEntry
> {
  constructor(getQuery: GetVlanGroupOverviewQueryService) {
    super(getQuery, 'Fetching VLAN groups');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, VlanGroupFilterAndFilterEntry> {
    return new VlanGroupFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetVlanGroupOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(
    query: GetVlanGroupOverviewQuery
  ): CursorPaginatedResponse<VlanGroupAssetOverviewFragment> {
    return query.vlanGroupList;
  }

  protected toFragments(query: GetVlanGroupOverviewQuery): VlanGroupAssetOverviewFragment[] {
    return query.vlanGroupList.data;
  }
}
