import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, VlanFilterConverter } from '@orion/asset-types';
import { VlanFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetVlanOverviewQuery,
  GetVlanOverviewQueryService,
  GetVlanOverviewQueryVariables,
  VlanAssetOverviewFragment,
} from './graphql';

@Injectable()
export class VlanAssetOverviewService extends AssetTypeOverviewService<
  GetVlanOverviewQuery,
  GetVlanOverviewQueryVariables,
  VlanAssetOverviewFragment,
  AssetClientFilter,
  VlanFilterAndFilterEntry
> {
  constructor(getQuery: GetVlanOverviewQueryService) {
    super(getQuery, 'Fetching VLANs');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, VlanFilterAndFilterEntry> {
    return new VlanFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetVlanOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(query: GetVlanOverviewQuery): CursorPaginatedResponse<VlanAssetOverviewFragment> {
    return query.vlanList;
  }

  protected toFragments(query: GetVlanOverviewQuery): VlanAssetOverviewFragment[] {
    return query.vlanList.data;
  }
}
