import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, VRFFilterConverter } from '@orion/asset-types';
import { VrfFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetVrfOverviewQuery,
  GetVrfOverviewQueryService,
  GetVrfOverviewQueryVariables,
  VrfAssetOverviewFragment,
} from './graphql';

@Injectable()
export class VrfAssetOverviewService extends AssetTypeOverviewService<
  GetVrfOverviewQuery,
  GetVrfOverviewQueryVariables,
  VrfAssetOverviewFragment,
  AssetClientFilter,
  VrfFilterAndFilterEntry
> {
  constructor(getQuery: GetVrfOverviewQueryService) {
    super(getQuery, 'Fetching VRFs');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, VrfFilterAndFilterEntry> {
    return new VRFFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetVrfOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(query: GetVrfOverviewQuery): CursorPaginatedResponse<VrfAssetOverviewFragment> {
    return query.vrfList;
  }

  protected toFragments(query: GetVrfOverviewQuery): VrfAssetOverviewFragment[] {
    return query.vrfList.data;
  }
}
