import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, LocationFilterConverter } from '@orion/asset-types';
import { LocationFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetLocationOverviewQuery,
  GetLocationOverviewQueryService,
  GetLocationOverviewQueryVariables,
  LocationAssetOverviewFragment,
} from './graphql';

@Injectable()
export class LocationAssetOverviewService extends AssetTypeOverviewService<
  GetLocationOverviewQuery,
  GetLocationOverviewQueryVariables,
  LocationAssetOverviewFragment,
  AssetClientFilter,
  LocationFilterAndFilterEntry
> {
  public constructor(public getQuery: GetLocationOverviewQueryService) {
    super(getQuery, 'Fetching locations');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, LocationFilterAndFilterEntry> {
    return new LocationFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetLocationOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(query: GetLocationOverviewQuery): CursorPaginatedResponse<LocationAssetOverviewFragment> {
    return query.locationList;
  }

  protected toFragments(query: GetLocationOverviewQuery): LocationAssetOverviewFragment[] {
    return query.locationList.data;
  }
}
