import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, RackFilterConverter } from '@orion/asset-types';
import { RackFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetRackOverviewQuery,
  GetRackOverviewQueryService,
  GetRackOverviewQueryVariables,
  RackAssetOverviewFragment,
} from './graphql';

@Injectable()
export class RackAssetOverviewService extends AssetTypeOverviewService<
  GetRackOverviewQuery,
  GetRackOverviewQueryVariables,
  RackAssetOverviewFragment,
  AssetClientFilter,
  RackFilterAndFilterEntry
> {
  public constructor(public getQuery: GetRackOverviewQueryService) {
    super(getQuery, 'Fetching racks');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, RackFilterAndFilterEntry> {
    return new RackFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetRackOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(query: GetRackOverviewQuery): CursorPaginatedResponse<RackAssetOverviewFragment> {
    return query.rackList;
  }

  protected toFragments(query: GetRackOverviewQuery): RackAssetOverviewFragment[] {
    return query.rackList.data;
  }
}
