import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, RackReservationFilterConverter } from '@orion/asset-types';
import { RackReservationFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetRackReservationOverviewQuery,
  GetRackReservationOverviewQueryService,
  GetRackReservationOverviewQueryVariables,
  RackReservationAssetOverviewFragment,
} from './graphql';

@Injectable()
export class RackReservationAssetOverviewService extends AssetTypeOverviewService<
  GetRackReservationOverviewQuery,
  GetRackReservationOverviewQueryVariables,
  RackReservationAssetOverviewFragment,
  AssetClientFilter,
  RackReservationFilterAndFilterEntry
> {
  public constructor(public getQuery: GetRackReservationOverviewQueryService) {
    super(getQuery, 'Fetching rack reservations');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, RackReservationFilterAndFilterEntry> {
    return new RackReservationFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetRackReservationOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(
    query: GetRackReservationOverviewQuery
  ): CursorPaginatedResponse<RackReservationAssetOverviewFragment> {
    return query.rackReservationList;
  }

  protected toFragments(query: GetRackReservationOverviewQuery): RackReservationAssetOverviewFragment[] {
    return query.rackReservationList.data;
  }
}
