import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, RackRoleFilterConverter } from '@orion/asset-types';
import { RackRoleFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetRackRoleOverviewQuery,
  GetRackRoleOverviewQueryService,
  GetRackRoleOverviewQueryVariables,
  RackRoleAssetOverviewFragment,
} from './graphql';

@Injectable()
export class RackRoleAssetOverviewService extends AssetTypeOverviewService<
  GetRackRoleOverviewQuery,
  GetRackRoleOverviewQueryVariables,
  RackRoleAssetOverviewFragment,
  AssetClientFilter,
  RackRoleFilterAndFilterEntry
> {
  public constructor(public getQuery: GetRackRoleOverviewQueryService) {
    super(getQuery, 'Fetching rack roles');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, RackRoleFilterAndFilterEntry> {
    return new RackRoleFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetRackRoleOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(query: GetRackRoleOverviewQuery): CursorPaginatedResponse<RackRoleAssetOverviewFragment> {
    return query.rackRoleList;
  }

  protected toFragments(query: GetRackRoleOverviewQuery): RackRoleAssetOverviewFragment[] {
    return query.rackRoleList.data;
  }
}
