import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, RegionFilterConverter } from '@orion/asset-types';
import { RegionFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetRegionOverviewQuery,
  GetRegionOverviewQueryService,
  GetRegionOverviewQueryVariables,
  RegionAssetOverviewFragment,
} from './graphql';

@Injectable()
export class RegionAssetOverviewService extends AssetTypeOverviewService<
  GetRegionOverviewQuery,
  GetRegionOverviewQueryVariables,
  RegionAssetOverviewFragment,
  AssetClientFilter,
  RegionFilterAndFilterEntry
> {
  public constructor(public getQuery: GetRegionOverviewQueryService) {
    super(getQuery, 'Fetching regions');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, RegionFilterAndFilterEntry> {
    return new RegionFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetRegionOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(query: GetRegionOverviewQuery): CursorPaginatedResponse<RegionAssetOverviewFragment> {
    return query.regionList;
  }

  protected toFragments(query: GetRegionOverviewQuery): RegionAssetOverviewFragment[] {
    return query.regionList.data;
  }
}
