import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, SiteGroupFilterConverter } from '@orion/asset-types';
import { SiteGroupFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetSiteGroupOverviewQuery,
  GetSiteGroupOverviewQueryService,
  GetSiteGroupOverviewQueryVariables,
  SiteGroupAssetOverviewFragment,
} from './graphql';

@Injectable()
export class SiteGroupAssetOverviewService extends AssetTypeOverviewService<
  GetSiteGroupOverviewQuery,
  GetSiteGroupOverviewQueryVariables,
  SiteGroupAssetOverviewFragment,
  AssetClientFilter,
  SiteGroupFilterAndFilterEntry
> {
  public constructor(public getQuery: GetSiteGroupOverviewQueryService) {
    super(getQuery, 'Fetching site groups');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, SiteGroupFilterAndFilterEntry> {
    return new SiteGroupFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetSiteGroupOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(
    query: GetSiteGroupOverviewQuery
  ): CursorPaginatedResponse<SiteGroupAssetOverviewFragment> {
    return query.siteGroupList;
  }

  protected toFragments(query: GetSiteGroupOverviewQuery): SiteGroupAssetOverviewFragment[] {
    return query.siteGroupList.data;
  }
}
