import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, SiteFilterConverter } from '@orion/asset-types';
import { SiteFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetSiteOverviewQuery,
  GetSiteOverviewQueryService,
  GetSiteOverviewQueryVariables,
  SiteAssetOverviewFragment,
} from './graphql';

@Injectable()
export class SiteAssetOverviewService extends AssetTypeOverviewService<
  GetSiteOverviewQuery,
  GetSiteOverviewQueryVariables,
  SiteAssetOverviewFragment,
  AssetClientFilter,
  SiteFilterAndFilterEntry
> {
  constructor(public getQuery: GetSiteOverviewQueryService) {
    super(getQuery, 'Fetching sites');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, SiteFilterAndFilterEntry> {
    return new SiteFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetSiteOverviewQueryVariables {
    return {
      ...this.createPaginationVariables(paginationEvent),
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected getQueryResponse(query: GetSiteOverviewQuery): CursorPaginatedResponse<SiteAssetOverviewFragment> {
    return query.siteList;
  }

  protected toFragments(query: GetSiteOverviewQuery): SiteAssetOverviewFragment[] {
    return query.siteList.data;
  }
}
