import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, TenantGroupFilterConverter } from '@orion/asset-types';
import { TenantGroupFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetTenantGroupOverviewQuery,
  GetTenantGroupOverviewQueryService,
  GetTenantGroupOverviewQueryVariables,
  TenantGroupAssetOverviewFragment,
} from './graphql';

@Injectable()
export class TenantGroupAssetOverviewService extends AssetTypeOverviewService<
  GetTenantGroupOverviewQuery,
  GetTenantGroupOverviewQueryVariables,
  TenantGroupAssetOverviewFragment,
  AssetClientFilter,
  TenantGroupFilterAndFilterEntry
> {
  constructor(public getQuery: GetTenantGroupOverviewQueryService) {
    super(getQuery, 'Fetching tenant groups');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, TenantGroupFilterAndFilterEntry> {
    return new TenantGroupFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetTenantGroupOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(
    query: GetTenantGroupOverviewQuery
  ): CursorPaginatedResponse<TenantGroupAssetOverviewFragment> {
    return query.tenantGroupList;
  }

  protected toFragments(query: GetTenantGroupOverviewQuery): TenantGroupAssetOverviewFragment[] {
    return query.tenantGroupList.data;
  }
}
