import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, TenantFilterConverter } from '@orion/asset-types';
import { TenantFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetTenantOverviewQuery,
  GetTenantOverviewQueryService,
  GetTenantOverviewQueryVariables,
  TenantAssetOverviewFragment,
} from './graphql';

@Injectable()
export class TenantAssetOverviewService extends AssetTypeOverviewService<
  GetTenantOverviewQuery,
  GetTenantOverviewQueryVariables,
  TenantAssetOverviewFragment,
  AssetClientFilter,
  TenantFilterAndFilterEntry
> {
  constructor(public getQuery: GetTenantOverviewQueryService) {
    super(getQuery, 'Fetching tenants');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, TenantFilterAndFilterEntry> {
    return new TenantFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetTenantOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(query: GetTenantOverviewQuery): CursorPaginatedResponse<TenantAssetOverviewFragment> {
    return query.tenantList;
  }

  protected toFragments(query: GetTenantOverviewQuery): TenantAssetOverviewFragment[] {
    return query.tenantList.data;
  }
}
