import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, PowerFeedFilterConverter } from '@orion/asset-types';
import { PowerFeedFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetPowerFeedOverviewQuery,
  GetPowerFeedOverviewQueryService,
  GetPowerFeedOverviewQueryVariables,
  PowerFeedAssetOverviewFragment,
} from './graphql';

@Injectable()
export class PowerFeedAssetOverviewService extends AssetTypeOverviewService<
  GetPowerFeedOverviewQuery,
  GetPowerFeedOverviewQueryVariables,
  PowerFeedAssetOverviewFragment,
  AssetClientFilter,
  PowerFeedFilterAndFilterEntry
> {
  constructor(public getQuery: GetPowerFeedOverviewQueryService) {
    super(getQuery, 'Fetching power feeds');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, PowerFeedFilterAndFilterEntry> {
    return new PowerFeedFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetPowerFeedOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(
    query: GetPowerFeedOverviewQuery
  ): CursorPaginatedResponse<PowerFeedAssetOverviewFragment> {
    return query.powerFeedList;
  }

  protected toFragments(query: GetPowerFeedOverviewQuery): PowerFeedAssetOverviewFragment[] {
    return query.powerFeedList.data;
  }
}
