import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, PowerPanelFilterConverter } from '@orion/asset-types';
import { PowerPanelFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetPowerPanelOverviewQuery,
  GetPowerPanelOverviewQueryService,
  GetPowerPanelOverviewQueryVariables,
  PowerPanelAssetOverviewFragment,
} from './graphql';

@Injectable()
export class PowerPanelAssetOverviewService extends AssetTypeOverviewService<
  GetPowerPanelOverviewQuery,
  GetPowerPanelOverviewQueryVariables,
  PowerPanelAssetOverviewFragment,
  AssetClientFilter,
  PowerPanelFilterAndFilterEntry
> {
  constructor(public getQuery: GetPowerPanelOverviewQueryService) {
    super(getQuery, 'Fetching power panels');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, PowerPanelFilterAndFilterEntry> {
    return new PowerPanelFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetPowerPanelOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(
    query: GetPowerPanelOverviewQuery
  ): CursorPaginatedResponse<PowerPanelAssetOverviewFragment> {
    return query.powerPanelList;
  }

  protected toFragments(query: GetPowerPanelOverviewQuery): PowerPanelAssetOverviewFragment[] {
    return query.powerPanelList.data;
  }
}
