import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, ClusterGroupFilterConverter } from '@orion/asset-types';
import { ClusterGroupFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  ClusterGroupAssetOverviewFragment,
  GetClusterGroupOverviewQuery,
  GetClusterGroupOverviewQueryService,
  GetClusterGroupOverviewQueryVariables,
} from './graphql';

@Injectable()
export class ClusterGroupAssetOverviewService extends AssetTypeOverviewService<
  GetClusterGroupOverviewQuery,
  GetClusterGroupOverviewQueryVariables,
  ClusterGroupAssetOverviewFragment,
  AssetClientFilter,
  ClusterGroupFilterAndFilterEntry
> {
  constructor(public getQuery: GetClusterGroupOverviewQueryService) {
    super(getQuery, 'Fetching cluster groups');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, ClusterGroupFilterAndFilterEntry> {
    return new ClusterGroupFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetClusterGroupOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(
    query: GetClusterGroupOverviewQuery
  ): CursorPaginatedResponse<ClusterGroupAssetOverviewFragment> {
    return query.clusterGroupList;
  }

  protected toFragments(query: GetClusterGroupOverviewQuery): ClusterGroupAssetOverviewFragment[] {
    return query.clusterGroupList.data;
  }
}
