import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, ClusterFilterConverter } from '@orion/asset-types';
import { ClusterFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  ClusterAssetOverviewFragment,
  GetClusterOverviewQuery,
  GetClusterOverviewQueryService,
  GetClusterOverviewQueryVariables,
} from './graphql';

@Injectable()
export class ClusterAssetOverviewService extends AssetTypeOverviewService<
  GetClusterOverviewQuery,
  GetClusterOverviewQueryVariables,
  ClusterAssetOverviewFragment,
  AssetClientFilter,
  ClusterFilterAndFilterEntry
> {
  constructor(public getQuery: GetClusterOverviewQueryService) {
    super(getQuery, 'Fetching clusters');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, ClusterFilterAndFilterEntry> {
    return new ClusterFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetClusterOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(query: GetClusterOverviewQuery): CursorPaginatedResponse<ClusterAssetOverviewFragment> {
    return query.clusterList;
  }

  protected toFragments(query: GetClusterOverviewQuery): ClusterAssetOverviewFragment[] {
    return query.clusterList.data;
  }
}
