import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, ClusterTypeFilterConverter } from '@orion/asset-types';
import { ClusterTypeFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  ClusterTypeAssetOverviewFragment,
  GetClusterTypeOverviewQuery,
  GetClusterTypeOverviewQueryService,
  GetClusterTypeOverviewQueryVariables,
} from './graphql';

@Injectable()
export class ClusterTypeAssetOverviewService extends AssetTypeOverviewService<
  GetClusterTypeOverviewQuery,
  GetClusterTypeOverviewQueryVariables,
  ClusterTypeAssetOverviewFragment,
  AssetClientFilter,
  ClusterTypeFilterAndFilterEntry
> {
  constructor(public getQuery: GetClusterTypeOverviewQueryService) {
    super(getQuery, 'Fetching cluster types');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, ClusterTypeFilterAndFilterEntry> {
    return new ClusterTypeFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetClusterTypeOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(
    query: GetClusterTypeOverviewQuery
  ): CursorPaginatedResponse<ClusterTypeAssetOverviewFragment> {
    return query.clusterTypeList;
  }

  protected toFragments(query: GetClusterTypeOverviewQuery): ClusterTypeAssetOverviewFragment[] {
    return query.clusterTypeList.data;
  }
}
