import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, VMInterfaceFilterConverter } from '@orion/asset-types';
import { VmInterfaceFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetVmInterfaceOverviewQuery,
  GetVmInterfaceOverviewQueryService,
  GetVmInterfaceOverviewQueryVariables,
  VmInterfaceAssetOverviewFragment,
} from './graphql';

@Injectable()
export class VmInterfaceAssetOverviewService extends AssetTypeOverviewService<
  GetVmInterfaceOverviewQuery,
  GetVmInterfaceOverviewQueryVariables,
  VmInterfaceAssetOverviewFragment,
  AssetClientFilter,
  VmInterfaceFilterAndFilterEntry
> {
  constructor(public getQuery: GetVmInterfaceOverviewQueryService) {
    super(getQuery, 'Fetching VM interfaces');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, VmInterfaceFilterAndFilterEntry> {
    return new VMInterfaceFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetVmInterfaceOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(
    query: GetVmInterfaceOverviewQuery
  ): CursorPaginatedResponse<VmInterfaceAssetOverviewFragment> {
    return query.vmInterfaceList;
  }

  protected toFragments(query: GetVmInterfaceOverviewQuery): VmInterfaceAssetOverviewFragment[] {
    return query.vmInterfaceList.data;
  }
}
