import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, VirtualMachineFilterConverter } from '@orion/asset-types';
import { VirtualMachineFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetVmOverviewQuery,
  GetVmOverviewQueryService,
  GetVmOverviewQueryVariables,
  VmAssetOverviewFragment,
} from './graphql';

@Injectable()
export class VmAssetOverviewService extends AssetTypeOverviewService<
  GetVmOverviewQuery,
  GetVmOverviewQueryVariables,
  VmAssetOverviewFragment,
  AssetClientFilter,
  VirtualMachineFilterAndFilterEntry
> {
  constructor(public getQuery: GetVmOverviewQueryService) {
    super(getQuery, 'Fetching virtual machines');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, VirtualMachineFilterAndFilterEntry> {
    return new VirtualMachineFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetVmOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(query: GetVmOverviewQuery): CursorPaginatedResponse<VmAssetOverviewFragment> {
    return query.virtualMachineList;
  }

  protected toFragments(query: GetVmOverviewQuery): VmAssetOverviewFragment[] {
    return query.virtualMachineList.data;
  }
}
