import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, WirelessLanGroupFilterConverter } from '@orion/asset-types';
import { WirelessLanGroupFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetWirelessLanGroupOverviewQuery,
  GetWirelessLanGroupOverviewQueryService,
  GetWirelessLanGroupOverviewQueryVariables,
  WirelessLanGroupAssetOverviewFragment,
} from './graphql';

@Injectable()
export class WirelessLanGroupAssetOverviewService extends AssetTypeOverviewService<
  GetWirelessLanGroupOverviewQuery,
  GetWirelessLanGroupOverviewQueryVariables,
  WirelessLanGroupAssetOverviewFragment,
  AssetClientFilter,
  WirelessLanGroupFilterAndFilterEntry
> {
  constructor(public getQuery: GetWirelessLanGroupOverviewQueryService) {
    super(getQuery, 'Fetching wireless LAN groups');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, WirelessLanGroupFilterAndFilterEntry> {
    return new WirelessLanGroupFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetWirelessLanGroupOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(
    query: GetWirelessLanGroupOverviewQuery
  ): CursorPaginatedResponse<WirelessLanGroupAssetOverviewFragment> {
    return query.wirelessLanGroupList;
  }

  protected toFragments(query: GetWirelessLanGroupOverviewQuery): WirelessLanGroupAssetOverviewFragment[] {
    return query.wirelessLanGroupList.data;
  }
}
