import { Injectable } from '@angular/core';
import { AssetTypeOverviewService } from '@orion/asset-services';
import { AssetClientFilter, WirelessLanFilterConverter } from '@orion/asset-types';
import { WirelessLanFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import {
  GetWirelessLanOverviewQuery,
  GetWirelessLanOverviewQueryService,
  GetWirelessLanOverviewQueryVariables,
  WirelessLanAssetOverviewFragment,
} from './graphql';

@Injectable()
export class WirelessLanAssetOverviewService extends AssetTypeOverviewService<
  GetWirelessLanOverviewQuery,
  GetWirelessLanOverviewQueryVariables,
  WirelessLanAssetOverviewFragment,
  AssetClientFilter,
  WirelessLanFilterAndFilterEntry
> {
  constructor(public getQuery: GetWirelessLanOverviewQueryService) {
    super(getQuery, 'Fetching wireless LANs');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, WirelessLanFilterAndFilterEntry> {
    return new WirelessLanFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: AssetClientFilter
  ): GetWirelessLanOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createPaginationVariables(paginationEvent),
    };
  }

  protected getQueryResponse(
    query: GetWirelessLanOverviewQuery
  ): CursorPaginatedResponse<WirelessLanAssetOverviewFragment> {
    return query.wirelessLanList;
  }

  protected toFragments(query: GetWirelessLanOverviewQuery): WirelessLanAssetOverviewFragment[] {
    return query.wirelessLanList.data;
  }
}
