import { ChangeDetectionStrategy, Component, Input, ViewChild } from '@angular/core';
import { AssetCategoryMetadataFragment } from './asset-category-metadata-card';
import { SidebarStateService } from '@sentinel/layout/sidebar';
import { combineLatest } from 'rxjs';
import { FullWidthPageContentService } from '@orion/shared/services/global';
import { NgxMasonryComponent } from 'ngx-masonry';
import { Destroyable } from '@sentinel/common';
import { delay, takeUntil } from 'rxjs/operators';

@Component({
  selector: 'orion-asset-metadata-categories',
  templateUrl: './asset-metadata-categories.component.html',
  styleUrls: ['./asset-metadata-categories.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class AssetMetadataCategoriesComponent extends Destroyable() {
  @Input() categories: AssetCategoryMetadataFragment[] = [];
  @Input() isLoading: boolean = false;
  @ViewChild('masonry', { static: false }) masonryComponent?: NgxMasonryComponent;
  cardPlaceholders = [...Array(8).keys()];

  constructor(private sidebarStatus: SidebarStateService, private widthService: FullWidthPageContentService) {
    super();
    combineLatest([this.sidebarStatus.state$, this.widthService.fullWidth$])
      .pipe(takeUntil(this.destroy$), delay(500)) // delay circa by animation it takes to expand and hide the sidebar
      .subscribe(() => {
        if (this.masonryComponent) {
          this.masonryComponent.layout();
        }
      });
  }
}
