import { Injectable } from '@angular/core';
import { EXCLUDED_ASSETS_TYPES } from '@orion/asset-types';
import { CategoryEnum } from '@orion/graphql-types';
import { ApolloEntitiesService } from '@csirtmu-orion/microframework/apollo-services';
import { AssetCategoryMetadataFragment } from './asset-metadata-categories';
import {
  GetAssetMetadataCategoriesQuery,
  GetAssetMetadataCategoriesQueryService,
  GetAssetMetadataCategoriesQueryVariables,
} from './graphql';

@Injectable()
export class AssetsCategoriesService extends ApolloEntitiesService<
  GetAssetMetadataCategoriesQuery,
  GetAssetMetadataCategoriesQueryVariables,
  AssetCategoryMetadataFragment
> {
  constructor(protected queryService: GetAssetMetadataCategoriesQueryService) {
    super(queryService, 'Fetching asset categories', { fetchPolicy: 'cache-first' });
  }

  update(): void {
    this.updateVariables();
    this.updateQuery();
  }

  protected createVariables(): GetAssetMetadataCategoriesQueryVariables {
    const excludedTypeFilters = EXCLUDED_ASSETS_TYPES.map((type) => {
      return {
        OR: [{ assetData: { assetType: { except_: type } } }],
      };
    });
    return {
      filter: {
        AND: [{ OR: [{ name: { except_: CategoryEnum.OTHER } }] }, ...excludedTypeFilters],
      },
    };
  }

  protected toFragments(query: GetAssetMetadataCategoriesQuery): AssetCategoryMetadataFragment[] {
    const categories = [...query.metadataCategories.data]; // need to reassign for sorting because the query data are read-only
    try {
      categories.sort((prev, curr) => prev.name.localeCompare(curr.name));
    } catch (e) {
      console.error(e);
    }
    return categories;
  }
}
