import { ChangeDetectionStrategy, Component, OnInit } from '@angular/core';
import { AssetSelectionFragment } from '@orion/asset-components/selection';
import {
  AddEntityControlsService,
  CreateEntityAssociationService,
} from '@orion/shared-components/related-entity-overview';
import { EntityAddAssociationService } from '@orion/shared-services';
import { SentinelControlItem } from '@sentinel/components/controls';
import { Observable } from 'rxjs';
import { AssetListService } from './asset-list.service';
import { EntityAddAssetsFilterService } from './entity-add-assets-filter.service';

@Component({
  selector: 'orion-add-related-assets',
  templateUrl: './add-related-assets.component.html',
  styleUrls: ['./add-related-assets.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [AddEntityControlsService, AssetListService],
})
export class AddRelatedAssetsComponent implements OnInit {
  controls$?: Observable<SentinelControlItem[]>;
  assetsToSelect$?: Observable<AssetSelectionFragment[]>;
  isLoading$?: Observable<boolean>;
  hasError$?: Observable<boolean>;
  isSaving$?: Observable<boolean>;

  constructor(
    private selectionService: EntityAddAssociationService<AssetSelectionFragment>,
    private controlsService: AddEntityControlsService,
    private assetsService: AssetListService,
    private filterService: EntityAddAssetsFilterService,
    private addEntityService: CreateEntityAssociationService
  ) {}

  ngOnInit(): void {
    this.controls$ = this.controlsService.controls$;
    this.isLoading$ = this.assetsService.isLoading$;
    this.hasError$ = this.assetsService.hasError$;
    this.isSaving$ = this.addEntityService.isSaving$;
    this.assetsToSelect$ = this.assetsService.data$;
  }

  onSelectionChange(selection: AssetSelectionFragment[]): void {
    this.selectionService.select(selection);
  }

  onSearch(value: string): void {
    this.filterService.updateAndSubmit({ termSearch: value });
    this.assetsService.update(this.filterService.get());
  }

  onTryAgain(): void {
    this.assetsService.recoverAfterError();
  }
}
