import { Injectable } from '@angular/core';
import { AssetSelectionFragment } from '@orion/asset-components/selection';
import { AssetClientFilter, AssetFilterConverter } from '@orion/asset-types';
import { AssetFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { GetAssetListQuery, GetAssetListQueryService, GetAssetListQueryVariables } from './graphql';
import { ApolloFilterablePollingService } from '@orion/shared-services';

@Injectable()
export class AssetListService extends ApolloFilterablePollingService<
  GetAssetListQuery,
  GetAssetListQueryVariables,
  AssetSelectionFragment,
  AssetClientFilter,
  AssetFilterAndFilterEntry
> {
  constructor(public getQuery: GetAssetListQueryService) {
    super(getQuery, 'Fetching assets');
  }

  protected createFilterConverter(): FilterConverter<AssetClientFilter, AssetFilterAndFilterEntry> {
    return new AssetFilterConverter();
  }

  protected createVariables(clientFilter: AssetClientFilter): GetAssetListQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected toFragments(query: GetAssetListQuery): AssetSelectionFragment[] {
    return query?.assetList?.data;
  }
}
