import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap, Params, Router } from '@angular/router';
import { RelatedAssetClientFilter } from '@orion/asset-types';
import { KnownAssetsEnum } from '@orion/graphql-types';
import { QueryParamFilterService } from '@csirtmu-orion/microframework/filter-services';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import { Observable, of } from 'rxjs';

@Injectable()
export class RelatedAssetFilterService extends QueryParamFilterService<RelatedAssetClientFilter> {
  constructor(protected router: Router, protected activatedRoute: ActivatedRoute) {
    super(router, activatedRoute);
  }

  protected createEmptyFilter(): RelatedAssetClientFilter {
    return { assetType: undefined };
  }

  protected toQueryParams(filter: RelatedAssetClientFilter): Params {
    const params = super.toQueryParams(filter);
    delete params.taskIds;
    delete params.caseId;
    return params;
  }

  protected createFilterFromRoute(queryParamMap: ParamMap, paramMap: ParamMap): Observable<RelatedAssetClientFilter> {
    const assetTypeParam = queryParamMap.get('assetType');
    if (assetTypeParam === null) {
      return of(this.EMPTY_FILTER);
    }
    const assetType = this.resolveAssetType(this.deslugify(assetTypeParam));
    return of({ assetType });
  }

  private resolveAssetType(value?: string): Optional<KnownAssetsEnum> {
    return value ? enumFromValue(KnownAssetsEnum, value) : undefined;
  }
}
