import { Injectable } from '@angular/core';
import { RelatedAssetClientFilter, RelatedAssetFilterConverter } from '@orion/asset-types';
import { AssetFederationBaseFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import {
  GetRelatedAssetsQuery,
  GetRelatedAssetsQueryService,
  GetRelatedAssetsQueryVariables,
  RelatedAssetFragment,
} from './graphql';
import { ApolloFilterablePollingService } from '@orion/shared-services';

@Injectable()
export class RelatedAssetService extends ApolloFilterablePollingService<
  GetRelatedAssetsQuery,
  GetRelatedAssetsQueryVariables,
  RelatedAssetFragment,
  RelatedAssetClientFilter,
  AssetFederationBaseFilterAndFilterEntry[]
> {
  public constructor(public getQuery: GetRelatedAssetsQueryService) {
    super(getQuery, 'Fetching related assets');
  }

  protected createFilterConverter(): FilterConverter<
    RelatedAssetClientFilter,
    AssetFederationBaseFilterAndFilterEntry[]
  > {
    return new RelatedAssetFilterConverter();
  }

  protected createVariables(clientFilter: RelatedAssetClientFilter): GetRelatedAssetsQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected toFragments(query: GetRelatedAssetsQuery): RelatedAssetFragment[] {
    return query?.getFederatedAssetList?.data ?? [];
  }
}
