import { ChangeDetectionStrategy, Component, OnChanges, Optional, SimpleChanges } from '@angular/core';
import { RelatedAssetClientFilter } from '@orion/asset-types';
import { KnownAssetsEnum } from '@orion/graphql-types';
import {
  CreateAssociationViewStateService,
  RelatedEntityControlsService,
  RelatedEntityOverviewDirective,
} from '@orion/shared-components/related-entity-overview';
import { enumFromValue } from '@sentinel/common/utils';
import { EntityAddAssetsFilterService } from './add-related-assets';
import { RelatedAssetFragment } from './graphql';

@Component({
  selector: 'orion-related-assets-overview',
  templateUrl: './related-assets-overview.component.html',
  styleUrls: ['./related-assets-overview.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [EntityAddAssetsFilterService],
})
export class RelatedAssetsOverviewComponent
  extends RelatedEntityOverviewDirective<RelatedAssetFragment, RelatedAssetClientFilter>
  implements OnChanges
{
  constructor(
    @Optional() protected controlsService: RelatedEntityControlsService,
    @Optional() protected viewStateService: CreateAssociationViewStateService,
    private filterService: EntityAddAssetsFilterService
  ) {
    super(controlsService, viewStateService);
  }

  ngOnChanges(changes: SimpleChanges): void {
    super.ngOnChanges(changes);
    if ('entities' in changes && this.entities && this.entities.length > 0) {
      const relatedAssets = this.entities.map((entity) => {
        const type = entity.assetType ? enumFromValue(KnownAssetsEnum, entity.assetType) : KnownAssetsEnum.ASSET;
        return {
          id: entity.id,
          type: type ?? KnownAssetsEnum.ASSET,
        };
      });
      this.filterService.exclude(relatedAssets);
    } else {
    }
  }
}
