import { ChangeDetectionStrategy, Component, OnInit } from '@angular/core';
import { SidebarSizeService, SidebarState, SidebarStateService } from '@sentinel/layout/sidebar';
import { Observable } from 'rxjs';
import { AssetNavDomain } from './asset-nav';
import { AssetNavDomainsService } from './asset-nav-domains.service';

@Component({
  selector: 'orion-asset-nav-sidebar',
  templateUrl: './asset-nav-sidebar.component.html',
  styleUrls: ['./asset-nav-sidebar.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class AssetNavSidebarComponent implements OnInit {
  navDomains: AssetNavDomain[] = [];
  state$?: Observable<SidebarState>;

  constructor(
    private sidebarStateService: SidebarStateService,
    private sidebarSizeService: SidebarSizeService,
    private domainService: AssetNavDomainsService
  ) {}

  ngOnInit(): void {
    this.sidebarSizeService.setWidth({
      expanded: 'min(250px, 100vw)',
      semiCollapsed: this.sidebarSizeService.DEFAULT_SEMI_COLLAPSED_WIDTH,
    });
    this.state$ = this.sidebarStateService.state$;
    this.navDomains = this.domainService.domains;
  }

  onDomainSelected(domain: AssetNavDomain): void {
    if (this.sidebarStateService.geState() === 'semi-collapsed') {
      this.sidebarStateService.toggleState();
    }
    this.domainService.toggle(domain);
  }
}
