import { navigateToAssetTypeOverview } from '@orion/asset-components/base-view';
import { KnownAssetsEnum } from '@orion/graphql-types';

export interface AssetNavItem {
  name: string;
  link: string;
}

export interface AssetNavCategory {
  name: string;
  items: AssetNavItem[];
}

export interface AssetNavDomain {
  icon: string;
  name: string;
  expanded: boolean;
  categories: AssetNavCategory[];
}

export const SITE_ITEMS: AssetNavItem[] = [
  {
    name: 'Sites',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.SITE),
  },
  {
    name: 'Regions',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.REGION),
  },
  {
    name: 'Site Groups',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.SITE_GROUP),
  },
  {
    name: 'Locations',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.LOCATION),
  },
];

export const RACK_ITEMS: AssetNavItem[] = [
  {
    name: 'Racks',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.RACK),
  },
  {
    name: 'Rack Roles',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.RACK_ROLE),
  },
  {
    name: 'Reservations',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.RACK_RESERVATION),
  },
];

export const TENANCY_ITEMS: AssetNavItem[] = [
  {
    name: 'Tenants',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.TENANT),
  },
  {
    name: 'Tenant Groups',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.TENANT_GROUP),
  },
];

export const DEVICE_ITEMS: AssetNavItem[] = [
  {
    name: 'Devices',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.DEVICE),
  },
  {
    name: 'Device Roles',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.DEVICE_ROLE),
  },
  {
    name: 'Platforms',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.PLATFORM),
  },
  {
    name: 'Virtual Chassis',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.VIRTUAL_CHASSIS),
  },
];

export const DEVICE_TYPE_ITEMS: AssetNavItem[] = [
  {
    name: 'Device Types',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.DEVICE_TYPE),
  },
  {
    name: 'Manufacturers',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.MANUFACTURER),
  },
];

export const DEVICE_COMPONENT_ITEMS: AssetNavItem[] = [
  {
    name: 'Interfaces',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.INTERFACE),
  },
  {
    name: 'Front Ports',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.FRONT_PORT),
  },
  {
    name: 'Rear Ports',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.REAR_PORT),
  },
  {
    name: 'Console Ports',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.CONSOLE_PORT),
  },
  {
    name: 'Console Server Ports',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.CONSOLE_SERVER_PORT),
  },
  {
    name: 'Power Ports',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.POWER_PORT),
  },
  {
    name: 'Power Outlets',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.POWER_OUTLET),
  },
  {
    name: 'Device Bays',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.DEVICE_BAY),
  },
  {
    name: 'Inventory Items',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.INVENTORY_ITEM),
  },
];

export const CONNECTION_ITEMS: AssetNavItem[] = [
  {
    name: 'Cables',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.CABLE),
  },
  {
    name: 'Wireless Links',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.WIRELESS_LINK),
  },
];

export const WIRELESS_ITEMS: AssetNavItem[] = [
  {
    name: 'Wireless LANs',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.WIRELESS_LAN),
  },
  {
    name: 'Wireless LAN Groups',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.WIRELESS_LAN_GROUP),
  },
];

export const IP_ADDRESS_ITEMS: AssetNavItem[] = [
  {
    name: 'IP Addresses',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.IP_ADDRESS),
  },
  {
    name: 'IP Ranges',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.IP_RANGE),
  },
];

export const PREFIX_ITEMS: AssetNavItem[] = [
  {
    name: 'Prefix',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.PREFIX),
  },
  {
    name: 'Prefix & VLAN Roles',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.ROLE),
  },
];

export const ASN_ITEMS: AssetNavItem[] = [
  {
    name: 'ASNs',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.ASN),
  },
];
export const AGGREGATE_ITEMS: AssetNavItem[] = [
  {
    name: 'Aggregates',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.AGGREGATE),
  },
  {
    name: 'RIRs',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.RIR),
  },
];

export const VRF_ITEMS: AssetNavItem[] = [
  {
    name: 'VRFs',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.VRF),
  },
  {
    name: 'Route Targets',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.ROUTE_TARGET),
  },
];

export const VLAN_ITEMS: AssetNavItem[] = [
  {
    name: 'VLAN',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.VLAN),
  },
  {
    name: 'VLAN Groups',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.VLAN_GROUP),
  },
];

export const OTHER_IPAM_ITEMS: AssetNavItem[] = [
  {
    name: 'FHRP Groups',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.FHRP_GROUP),
  },
  {
    name: 'Services',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.SERVICE),
  },
];

export const VIRTUAL_MACHINE_ITEMS: AssetNavItem[] = [
  {
    name: 'Virtual Machines',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.VIRTUAL_MACHINE),
  },
  {
    name: 'Interfaces',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.VM_INTERFACE),
  },
];

export const CLUSTER_ITEMS: AssetNavItem[] = [
  {
    name: 'Clusters',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.CLUSTER),
  },
  {
    name: 'Cluster Types',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.CLUSTER_TYPE),
  },
  {
    name: 'Cluster Groups',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.CLUSTER_GROUP),
  },
];

export const CIRCUIT_ITEMS: AssetNavItem[] = [
  {
    name: 'Circuits',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.CIRCUIT),
  },
  {
    name: 'Circuit Types',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.CIRCUIT_TYPE),
  },
];

export const PROVIDER_ITEMS: AssetNavItem[] = [
  {
    name: 'Providers',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.PROVIDER),
  },
  {
    name: 'Provider Networks',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.PROVIDER_NETWORK),
  },
];

export const POWER_ITEMS: AssetNavItem[] = [
  {
    name: 'Power Feeds',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.POWER_FEED),
  },
  {
    name: 'Power Panels',
    link: navigateToAssetTypeOverview(KnownAssetsEnum.POWER_PANEL),
  },
];

export const ORGANIZATION_CATEGORIES: AssetNavCategory[] = [
  {
    name: 'Sites',
    items: SITE_ITEMS,
  },
  {
    name: 'Racks',
    items: RACK_ITEMS,
  },
  {
    name: 'Tenancy',
    items: TENANCY_ITEMS,
  },
];

export const DEVICE_CATEGORIES: AssetNavCategory[] = [
  {
    name: 'Devices',
    items: DEVICE_ITEMS,
  },
  {
    name: 'Device Types',
    items: DEVICE_TYPE_ITEMS,
  },
  {
    name: 'Device Components',
    items: DEVICE_COMPONENT_ITEMS,
  },
];

export const CONNECTION_CATEGORIES: AssetNavCategory[] = [
  {
    name: 'Connections',
    items: CONNECTION_ITEMS,
  },
];

export const WIRELESS_CATEGORIES: AssetNavCategory[] = [
  {
    name: 'Wireless',
    items: WIRELESS_ITEMS,
  },
];

export const IPAM_CATEGORIES: AssetNavCategory[] = [
  {
    name: 'IP Addresses',
    items: IP_ADDRESS_ITEMS,
  },
  {
    name: 'Prefixes',
    items: PREFIX_ITEMS,
  },
  {
    name: 'ASNS',
    items: ASN_ITEMS,
  },
  {
    name: 'Aggregates',
    items: AGGREGATE_ITEMS,
  },
  {
    name: 'VRFS',
    items: VRF_ITEMS,
  },
  {
    name: 'VLANS',
    items: VLAN_ITEMS,
  },
  {
    name: 'Other',
    items: OTHER_IPAM_ITEMS,
  },
];

export const VIRTUALIZATION_CATEGORIES: AssetNavCategory[] = [
  {
    name: 'Virtual Machines',
    items: VIRTUAL_MACHINE_ITEMS,
  },
  {
    name: 'Clusters',
    items: CLUSTER_ITEMS,
  },
];

export const CIRCUIT_CATEGORIES: AssetNavCategory[] = [
  {
    name: 'Circuits',
    items: CIRCUIT_ITEMS,
  },
  {
    name: 'Providers',
    items: PROVIDER_ITEMS,
  },
];

export const POWER_CATEGORIES: AssetNavCategory[] = [
  {
    name: 'Power',
    items: POWER_ITEMS,
  },
];

export const ASSET_NAV_DOMAINS: AssetNavDomain[] = [
  {
    name: 'Organization',
    icon: 'domain',
    expanded: false,
    categories: ORGANIZATION_CATEGORIES,
  },
  {
    name: 'Devices',
    icon: 'devices',
    expanded: false,
    categories: DEVICE_CATEGORIES,
  },
  {
    name: 'Connections',
    icon: 'cable',
    expanded: false,
    categories: CONNECTION_CATEGORIES,
  },
  {
    name: 'Wireless',
    icon: 'wifi',
    expanded: false,
    categories: WIRELESS_CATEGORIES,
  },
  {
    name: 'IPAM',
    icon: 'public',
    expanded: false,
    categories: IPAM_CATEGORIES,
  },
  {
    name: 'Virtualization',
    icon: 'laptop',
    expanded: false,
    categories: VIRTUALIZATION_CATEGORIES,
  },
  {
    name: 'Circuits',
    icon: 'developer_board',
    expanded: false,
    categories: CIRCUIT_CATEGORIES,
  },
  {
    name: 'Power',
    icon: 'power',
    expanded: false,
    categories: POWER_CATEGORIES,
  },
];
