import { Injectable } from '@angular/core';
import { AssetClientFilter } from '@orion/asset-types';
import { FilterChip, StringValueChip } from '@csirtmu-orion/microframework/filter';
import { FilterChipsService } from '@csirtmu-orion/microframework/filter-services';
import { DateValueChip } from '@csirtmu-orion/microframework/filters';
import { AssetSharedOverviewFilterService } from './asset-shared-overview-filter.service';

@Injectable()
export class AssetSharedOverviewFilterChipsService extends FilterChipsService<AssetClientFilter> {
  constructor(protected filterService: AssetSharedOverviewFilterService) {
    super(filterService);
  }

  protected createChips(filter?: AssetClientFilter): FilterChip[] {
    const chips = [];
    if (filter?.from) {
      chips.push(new DateValueChip(filter.from, 'from'));
    }
    if (filter?.to) {
      chips.push(new DateValueChip(filter.to, 'to'));
    }
    if (filter?.termSearch) {
      chips.push(new StringValueChip(filter?.termSearch));
    }
    return chips;
  }
  removeChip(removedChip: FilterChip): void {
    if (removedChip instanceof DateValueChip && removedChip.direction === 'from') {
      this.filterService.updateAndSubmit({ from: undefined });
    }
    if (removedChip instanceof DateValueChip && removedChip.direction === 'to') {
      this.filterService.updateAndSubmit({ to: undefined });
    }
    if (removedChip instanceof StringValueChip) {
      this.filterService.updateAndSubmit({ termSearch: undefined });
    }
  }
}
