import { Injectable } from '@angular/core';
import { ActivatedRoute, Data, ParamMap, Params, Router } from '@angular/router';
import { AssetClientFilter } from '@orion/asset-types';
import { QueryParamFilterService } from '@csirtmu-orion/microframework/filter-services';
import { Observable, of } from 'rxjs';

@Injectable()
export class AssetSharedOverviewFilterService extends QueryParamFilterService<AssetClientFilter> {
  constructor(protected router: Router, protected activatedRoute: ActivatedRoute) {
    super(router, activatedRoute);
  }

  protected toQueryParams(filter: AssetClientFilter): Params {
    const params = super.toQueryParams(filter);
    if (filter.from) {
      params.from = filter.from.valueOf();
    }
    if (filter.to) {
      params.to = filter.to.valueOf();
    }
    return params;
  }

  protected createEmptyFilter(): AssetClientFilter {
    return { from: undefined, to: undefined, termSearch: undefined };
  }

  protected createFilterFromRoute(
    queryParamMap: ParamMap,
    paramMap: ParamMap,
    data: Data
  ): Observable<AssetClientFilter> {
    const termSearchParam = queryParamMap.get('termSearch');
    const from = this.deslugifyTimestamp(queryParamMap.get('from'));
    const to = this.deslugifyTimestamp(queryParamMap.get('to'));
    const termSearch = this.deslugify(termSearchParam);
    if (termSearchParam === null && from === null && to === null) {
      return of(this.EMPTY_FILTER);
    }
    return of({ from, to, termSearch });
  }
}
