import { ApolloPaginatedDmtService } from '@csirtmu-orion/microframework/apollo-services';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { QuerySingleFilter } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import { Optional } from '@sentinel/common/utils';
import * as Apollo from 'apollo-angular';
import { DEFAULT_POLL_INTERVAL_OVERVIEW_PAGE } from '@orion/common';

export abstract class AssetTypeOverviewService<
  Query,
  QueryVariables,
  Entity,
  ClientFilter,
  ApiFilter
> extends ApolloPaginatedDmtService<Query, QueryVariables, Entity, unknown> {
  filterConverter: FilterConverter<Partial<ClientFilter>, ApiFilter>;

  protected abstract createFilterConverter(): FilterConverter<ClientFilter, ApiFilter>;

  protected constructor(public getQuery: Apollo.Query<Query, QueryVariables>, operationName: string) {
    super(getQuery, operationName, { pollInterval: DEFAULT_POLL_INTERVAL_OVERVIEW_PAGE });
    this.filterConverter = this.createFilterConverter();
  }

  update(paginationEvent: IPaginationEvent, clientFilter: ClientFilter): void {
    if (!this.initialized$.getValue()) {
      this.initialize();
    }
    this.lastPaginationEvent = paginationEvent;
    this.updateVariables(paginationEvent, clientFilter);
    this.updateQuery();
  }

  protected strToOrderable(sort: string): Optional<unknown> {
    return undefined;
  }

  protected abstract createVariables(paginationEvent: IPaginationEvent, clientFilter: ClientFilter): QueryVariables;

  protected updateVariables(paginationEvent: IPaginationEvent, clientFilter: ClientFilter): void {
    this.variables = this.createVariables(paginationEvent, clientFilter);
  }

  protected createFilterVariables(clientFilter: ClientFilter): QuerySingleFilter<ApiFilter> {
    return { filter: this.filterConverter.convert(clientFilter) };
  }
}
