import { ASSET_TYPENAMES, AssetTypename } from './asset-typenames';

export class AssetIconResolver {
  private static map: Map<AssetTypename, string> = AssetIconResolver.createMap();

  private static createMap(): Map<AssetTypename, string> {
    const map = new Map<AssetTypename, string>([
      ['ASNType', '123'],
      ['AggregateType', 'cloud'],
      ['CableType', 'cable'],
      ['CircuitTerminationType', 'developer_board'],
      ['CircuitType', 'developer_board'],
      ['CircuitTypeType', 'developer_board'],
      ['ClusterGroupType', 'group'],
      ['ClusterType', 'radar'],
      ['ClusterTypeType', 'radar'],
      ['ConsolePortType', 'settings_input_svideo'],
      ['ConsoleServerPortType', 'settings_input_svideo'],
      ['DeviceType', 'laptop'],
      ['DeviceBayType', 'device_hub'],
      ['DeviceRoleType', 'policy'],
      ['DeviceTypeType', 'laptop'],
      ['FHRPGroupType', 'group'],
      ['FrontPortType', 'settings_input_svideo'],
      ['IPAddressType', 'public'],
      ['IPRangeType', 'cloud'],
      ['InterfaceType', 'device_hub'],
      ['InventoryItemType', 'inventory'],
      ['LocationType', 'room'],
      ['ManufacturerType', 'precision_manufacturing'],
      ['PlatformType', 'api'],
      ['PowerFeedType', 'bolt'],
      ['PowerOutletType', 'outlet'],
      ['PowerPanelType', 'power_input'],
      ['PowerPortType', 'power'],
      ['PrefixType', 'cloud'],
      ['ProviderType', 'business'],
      ['ProviderNetworkType', 'cloud'],
      ['RIRType', 'list_alt'],
      ['RackType', 'storage'],
      ['RackReservationType', 'sticky_note_2'],
      ['RackRoleType', 'policy'],
      ['RearPortType', 'settings_input_svideo'],
      ['RegionType', 'location_city'],
      ['RoleType', 'policy'],
      ['RouteTargetType', 'route'],
      ['ServiceType', 'miscellaneous_services'],
      ['SiteType', 'domain'],
      ['SiteGroupType', 'group'],
      ['TenantType', 'person'],
      ['TenantGroupType', 'group'],
      ['VLANType', 'cloud'],
      ['VLANGroupType', 'group'],
      ['VMInterfaceType', 'settings_input_svideo'],
      ['VRFType', 'alt_route'],
      ['VirtualChassisType', 'router'],
      ['VirtualMachineType', 'laptop'],
      ['WirelessLanGroupType', 'group'],
      ['WirelessLanType', 'wifi'],
      ['WirelessLinkType', 'link'],
    ]);

    if (map.size < ASSET_TYPENAMES.length) {
      console.warn(
        'AssetIconMap is not properly initiated. There are Asset types missing an icon. These types will fallback to default icon'
      );
    }
    return map;
  }

  static resolve(typename?: AssetTypename): string {
    const fallbackIcon = 'help_outline';
    if (typename) {
      return this.map.get(typename) ?? fallbackIcon;
    }
    return fallbackIcon;
  }
}
