import {
  AssetBaseViewCircuitTerminationTypeFragment,
  AssetBaseViewFragment,
  AssetBaseViewIpRangeTypeFragment,
  AssetBaseViewRackReservationTypeFragment,
  AssetFederationBaseViewCircuitTerminationTypeFragment,
  AssetFederationBaseViewFragment,
  AssetFederationBaseViewIpRangeTypeFragment,
  AssetFederationBaseViewRackReservationTypeFragment,
} from '@orion/asset-components/base-view';

export class AssetNameResolver {
  static resolve(asset?: AssetBaseViewFragment | AssetFederationBaseViewFragment, withTypename = false): string {
    if (asset === undefined) {
      return '';
    }
    const typename = asset.__typename;
    if ('name' in asset) {
      const maybeName = asset.name ?? asset.id;
      const name = maybeName !== '' ? maybeName : asset.id;
      return withTypename ? `${typename}: ${name}` : name;
    }
    if ('address' in asset) {
      const name = asset.address ?? asset.id;
      return withTypename ? `${typename}: ${name}` : name;
    }
    if (isCircuitTerminationFragment(asset)) {
      return asset.circuit?.name ? `Termination of ${asset.circuit.name} circuit` : 'Unknown circuit termination';
    }
    if (isRackReservationFragment(asset)) {
      return asset.rack?.name ? `Reservation for ${asset.rack.name} rack` : 'Unknown rack reservation';
    }
    if (isIPRangeFragment(asset)) {
      const name = `${asset.startAddress} - ${asset.endAddress}`;
      return withTypename ? `${typename}: ${name}` : name;
    }
    return withTypename ? `${typename}: ${asset.id}` : asset.id;
  }
}

function isCircuitTerminationFragment(
  fragment: AssetBaseViewFragment | AssetFederationBaseViewFragment
): fragment is AssetBaseViewCircuitTerminationTypeFragment | AssetFederationBaseViewCircuitTerminationTypeFragment {
  return fragment.__typename === 'CircuitTerminationType';
}

function isRackReservationFragment(
  fragment: AssetBaseViewFragment | AssetFederationBaseViewFragment
): fragment is AssetBaseViewRackReservationTypeFragment | AssetFederationBaseViewRackReservationTypeFragment {
  return fragment.__typename === 'RackReservationType';
}

function isIPRangeFragment(
  fragment: AssetBaseViewFragment | AssetFederationBaseViewFragment
): fragment is AssetBaseViewIpRangeTypeFragment | AssetFederationBaseViewIpRangeTypeFragment {
  return fragment.__typename === 'IPRangeType';
}
