import { convertDateTimeFilter } from '@orion/common';
import {
  AggregateFilterAndFilterEntry,
  AggregateFilterOrFilterEntry,
  AsnFilterAndFilterEntry,
  AsnFilterOrFilterEntry,
  AssetFilter,
  AssetFilterAndFilterEntry,
  AssetFilterOrFilterEntry,
  CableFilterAndFilterEntry,
  CableFilterOrFilterEntry,
  CircuitFilterAndFilterEntry,
  CircuitFilterOrFilterEntry,
  CircuitTerminationFilterAndFilterEntry,
  CircuitTerminationFilterOrFilterEntry,
  CircuitTypeFilterAndFilterEntry,
  CircuitTypeFilterOrFilterEntry,
  ClusterFilterAndFilterEntry,
  ClusterFilterOrFilterEntry,
  ClusterGroupFilterAndFilterEntry,
  ClusterGroupFilterOrFilterEntry,
  ClusterTypeFilterAndFilterEntry,
  ClusterTypeFilterOrFilterEntry,
  ConsolePortFilterAndFilterEntry,
  ConsolePortFilterOrFilterEntry,
  ConsoleServerPortFilterAndFilterEntry,
  ConsoleServerPortFilterOrFilterEntry,
  DeviceBayFilterAndFilterEntry,
  DeviceBayFilterOrFilterEntry,
  DeviceFilterAndFilterEntry,
  DeviceFilterOrFilterEntry,
  DeviceRoleFilterAndFilterEntry,
  DeviceRoleFilterOrFilterEntry,
  DeviceTypeFilterAndFilterEntry,
  DeviceTypeFilterOrFilterEntry,
  FhrpGroupFilterAndFilterEntry,
  FhrpGroupFilterOrFilterEntry,
  FrontPortFilterAndFilterEntry,
  FrontPortFilterOrFilterEntry,
  InterfaceFilterAndFilterEntry,
  InterfaceFilterOrFilterEntry,
  InventoryItemFilterAndFilterEntry,
  InventoryItemFilterOrFilterEntry,
  IpAddressFilterAndFilterEntry,
  IpAddressFilterOrFilterEntry,
  IpRangeFilterAndFilterEntry,
  IpRangeFilterOrFilterEntry,
  LocationFilterAndFilterEntry,
  LocationFilterOrFilterEntry,
  ManufacturerFilterAndFilterEntry,
  ManufacturerFilterOrFilterEntry,
  PlatformFilterAndFilterEntry,
  PlatformFilterOrFilterEntry,
  PowerFeedFilterAndFilterEntry,
  PowerFeedFilterOrFilterEntry,
  PowerOutletFilterAndFilterEntry,
  PowerOutletFilterOrFilterEntry,
  PowerPanelFilterAndFilterEntry,
  PowerPanelFilterOrFilterEntry,
  PowerPortFilterAndFilterEntry,
  PowerPortFilterOrFilterEntry,
  PrefixFilterAndFilterEntry,
  PrefixFilterOrFilterEntry,
  ProviderFilterAndFilterEntry,
  ProviderFilterOrFilterEntry,
  ProviderNetworkFilterAndFilterEntry,
  ProviderNetworkFilterOrFilterEntry,
  RackFilterAndFilterEntry,
  RackFilterOrFilterEntry,
  RackReservationFilterAndFilterEntry,
  RackReservationFilterOrFilterEntry,
  RackRoleFilterAndFilterEntry,
  RackRoleFilterOrFilterEntry,
  RearPortFilterAndFilterEntry,
  RearPortFilterOrFilterEntry,
  RegionFilterAndFilterEntry,
  RegionFilterOrFilterEntry,
  RirFilterAndFilterEntry,
  RirFilterOrFilterEntry,
  RoleFilterAndFilterEntry,
  RoleFilterOrFilterEntry,
  RouteTargetFilterAndFilterEntry,
  RouteTargetFilterOrFilterEntry,
  ServiceFilterAndFilterEntry,
  ServiceFilterOrFilterEntry,
  SiteFilterAndFilterEntry,
  SiteFilterOrFilterEntry,
  SiteGroupFilterAndFilterEntry,
  SiteGroupFilterOrFilterEntry,
  TenantFilterAndFilterEntry,
  TenantFilterOrFilterEntry,
  TenantGroupFilterAndFilterEntry,
  TenantGroupFilterOrFilterEntry,
  VirtualChassisFilterAndFilterEntry,
  VirtualChassisFilterOrFilterEntry,
  VirtualMachineFilterAndFilterEntry,
  VirtualMachineFilterOrFilterEntry,
  VlanFilterAndFilterEntry,
  VlanFilterOrFilterEntry,
  VlanGroupFilterAndFilterEntry,
  VlanGroupFilterOrFilterEntry,
  VmInterfaceFilterAndFilterEntry,
  VmInterfaceFilterOrFilterEntry,
  VrfFilterAndFilterEntry,
  VrfFilterOrFilterEntry,
  WirelessLanFilterAndFilterEntry,
  WirelessLanFilterOrFilterEntry,
  WirelessLanGroupFilterAndFilterEntry,
  WirelessLanGroupFilterOrFilterEntry,
  WirelessLinkFilterAndFilterEntry,
  WirelessLinkFilterOrFilterEntry,
} from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { AssetClientFilter, AssetIdentification } from './asset-client-filter';

function createSharedFilter(clientFilter?: AssetClientFilter): AssetFilterOrFilterEntry[] {
  const andFilter: AssetFilter = {};
  if (clientFilter?.id) {
    andFilter.id = { exact: clientFilter.id };
  }
  if (clientFilter?.termSearch) {
    andFilter.Name = { iContains: clientFilter.termSearch };
  }
  if (clientFilter?.from || clientFilter?.to) {
    andFilter.created = convertDateTimeFilter(clientFilter, false);
  }
  if (clientFilter?.type) {
    andFilter.assetType = { exact: clientFilter.type };
  }
  if (clientFilter?.notIn && clientFilter.notIn.length > 0) {
    const notInFilter = createNotInFilter(clientFilter.notIn);
    if (clientFilter?.termSearch) {
      return [{ OR: [andFilter, { id: { exact: clientFilter.termSearch } }] }, ...notInFilter];
    } else {
      return [{ OR: [andFilter] }, ...notInFilter];
    }
  }
  return [{ OR: [andFilter] }];
}

// creating list of AND filters that filter out assets. A bit complex because Assets are identified by its id AND type.
function createNotInFilter(notIn: AssetIdentification[]): AssetFilterOrFilterEntry[] {
  return notIn.map((asset) => {
    return {
      negate: true,
      OR: [{ id: { exact: asset.id }, assetType: { exact: asset.type } }],
    };
  });
}

export class AssetFilterConverter implements FilterConverter<AssetClientFilter, AssetFilterAndFilterEntry> {
  convert(clientFilter?: AssetClientFilter): AssetFilterAndFilterEntry {
    const andFilters: AssetFilterOrFilterEntry[] = [];
    if (clientFilter?.idOrTermSearch) {
      const isNumber = !Number.isNaN(Number.parseInt(clientFilter.idOrTermSearch));
      if (isNumber) {
        andFilters.push({
          OR: [{ id: { exact: clientFilter.idOrTermSearch } }, { Name: { iContains: clientFilter.idOrTermSearch } }],
        });
      } else {
        andFilters.push({ OR: [{ Name: { iContains: clientFilter.idOrTermSearch } }] });
      }
    }
    andFilters.push(...createSharedFilter(clientFilter));
    return { AND: andFilters };
  }
}

export class AggregateFilterConverter implements FilterConverter<AssetClientFilter, AggregateFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): AggregateFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      const termSearchFilters: AggregateFilterOrFilterEntry = { OR: [] };
      termSearchFilters.OR.push({ prefix: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class AsnFilterConverter implements FilterConverter<AssetClientFilter, AsnFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): AsnFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      const termSearchFilters: AsnFilterOrFilterEntry = { OR: [] };
      termSearchFilters.OR.push({ Name: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class CableFilterConverter implements FilterConverter<AssetClientFilter, CableFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): CableFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      const termSearchFilters: CableFilterOrFilterEntry = { OR: [] };
      termSearchFilters.OR.push({ label: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class CircuitFilterConverter implements FilterConverter<AssetClientFilter, CircuitFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): CircuitFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      const termSearchFilters: CircuitFilterOrFilterEntry = { OR: [] };
      termSearchFilters.OR.push({ cid: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class CircuitTerminationFilterConverter
  implements FilterConverter<AssetClientFilter, CircuitTerminationFilterAndFilterEntry>
{
  convert(source?: AssetClientFilter): CircuitTerminationFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      const termSearchFilters: CircuitTerminationFilterOrFilterEntry = { OR: [] };
      termSearchFilters.OR.push({ Name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class CircuitTypeFilterConverter implements FilterConverter<AssetClientFilter, CircuitTypeFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): CircuitTypeFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      const termSearchFilters: CircuitTypeFilterOrFilterEntry = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });
      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class ClusterFilterConverter implements FilterConverter<AssetClientFilter, ClusterFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): ClusterFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      const termSearchFilters: ClusterFilterOrFilterEntry = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class ClusterGroupFilterConverter
  implements FilterConverter<AssetClientFilter, ClusterGroupFilterAndFilterEntry>
{
  convert(source?: AssetClientFilter): ClusterGroupFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: ClusterGroupFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });
      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class ClusterTypeFilterConverter implements FilterConverter<AssetClientFilter, ClusterTypeFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): ClusterTypeFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      const termSearchFilters: ClusterTypeFilterOrFilterEntry = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });
      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class ConsolePortFilterConverter implements FilterConverter<AssetClientFilter, ConsolePortFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): ConsolePortFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      const termSearchFilters: ConsolePortFilterOrFilterEntry = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ label: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class ConsoleServerPortFilterConverter
  implements FilterConverter<AssetClientFilter, ConsoleServerPortFilterAndFilterEntry>
{
  convert(source?: AssetClientFilter): ConsoleServerPortFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      const termSearchFilters: ConsoleServerPortFilterOrFilterEntry = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ label: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class DeviceFilterConverter implements FilterConverter<AssetClientFilter, DeviceFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): DeviceFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      const termSearchFilters: DeviceFilterOrFilterEntry = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ assetTag: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ serial: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class DeviceBayFilterConverter implements FilterConverter<AssetClientFilter, DeviceBayFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): DeviceBayFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      const termSearchFilters: DeviceBayFilterOrFilterEntry = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ label: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class DeviceRoleFilterConverter implements FilterConverter<AssetClientFilter, DeviceRoleFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): DeviceRoleFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      const termSearchFilters: DeviceRoleFilterOrFilterEntry = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });
      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class DeviceTypeFilterConverter implements FilterConverter<AssetClientFilter, DeviceTypeFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): DeviceTypeFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      const termSearchFilters: DeviceTypeFilterOrFilterEntry = { OR: [] };
      termSearchFilters.OR.push({ frontImage: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ rearImage: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ partNumber: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ model: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class FhrpGroupFilterConverter implements FilterConverter<AssetClientFilter, FhrpGroupFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): FhrpGroupFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      const termSearchFilters: FhrpGroupFilterOrFilterEntry = { OR: [] };
      termSearchFilters.OR.push({ authKey: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ authType: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ protocol: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ ipAddresses: { address: { iContains: source.termSearch } } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class FrontPortFilterConverter implements FilterConverter<AssetClientFilter, FrontPortFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): FrontPortFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      const termSearchFilters: FrontPortFilterOrFilterEntry = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ label: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class InterfaceFilterConverter implements FilterConverter<AssetClientFilter, InterfaceFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): InterfaceFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      const termSearchFilters: InterfaceFilterOrFilterEntry = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ label: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ macAddress: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class InventoryItemFilterConverter
  implements FilterConverter<AssetClientFilter, InventoryItemFilterAndFilterEntry>
{
  convert(source?: AssetClientFilter): InventoryItemFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: InventoryItemFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ assetTag: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ label: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ partId: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ serial: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class IpAddressFilterConverter implements FilterConverter<AssetClientFilter, IpAddressFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): IpAddressFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: IpAddressFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ address: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ dnsName: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class IpRangeFilterConverter implements FilterConverter<AssetClientFilter, IpRangeFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): IpRangeFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: IpRangeFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ startAddress: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ endAddress: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class LocationFilterConverter implements FilterConverter<AssetClientFilter, LocationFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): LocationFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: LocationFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });
      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class ManufacturerFilterConverter
  implements FilterConverter<AssetClientFilter, ManufacturerFilterAndFilterEntry>
{
  convert(source?: AssetClientFilter): ManufacturerFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: ManufacturerFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });
      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class PlatformFilterConverter implements FilterConverter<AssetClientFilter, PlatformFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): PlatformFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: PlatformFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ napalmArgs: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ napalmDriver: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });
      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class PowerFeedFilterConverter implements FilterConverter<AssetClientFilter, PowerFeedFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): PowerFeedFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: PowerFeedFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class PowerOutletFilterConverter implements FilterConverter<AssetClientFilter, PowerOutletFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): PowerOutletFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: PowerOutletFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ label: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class PowerPanelFilterConverter implements FilterConverter<AssetClientFilter, PowerPanelFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): PowerPanelFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: PowerPanelFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class PowerPortFilterConverter implements FilterConverter<AssetClientFilter, PowerPortFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): PowerPortFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: PowerPortFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ label: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class PrefixFilterConverter implements FilterConverter<AssetClientFilter, PrefixFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): PrefixFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: PrefixFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ prefix: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class ProviderFilterConverter implements FilterConverter<AssetClientFilter, ProviderFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): ProviderFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: ProviderFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ account: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ adminContact: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ nocContact: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ portalUrl: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class ProviderNetworkFilterConverter
  implements FilterConverter<AssetClientFilter, ProviderNetworkFilterAndFilterEntry>
{
  convert(source?: AssetClientFilter): ProviderNetworkFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: ProviderNetworkFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class RackFilterConverter implements FilterConverter<AssetClientFilter, RackFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): RackFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: RackFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ assetTag: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ facilityId: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ serial: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class RackReservationFilterConverter
  implements FilterConverter<AssetClientFilter, RackReservationFilterAndFilterEntry>
{
  convert(source?: AssetClientFilter): RackReservationFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: RackReservationFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class RackRoleFilterConverter implements FilterConverter<AssetClientFilter, RackRoleFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): RackRoleFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: RackRoleFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });
      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class RearPortFilterConverter implements FilterConverter<AssetClientFilter, RearPortFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): RearPortFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: RearPortFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ label: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class RegionFilterConverter implements FilterConverter<AssetClientFilter, RegionFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): RegionFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: RegionFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });
      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class RirFilterConverter implements FilterConverter<AssetClientFilter, RirFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): RirFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: RirFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });
      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class RoleFilterConverter implements FilterConverter<AssetClientFilter, RoleFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): RoleFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: RoleFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });
      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class RouteTargetFilterConverter implements FilterConverter<AssetClientFilter, RouteTargetFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): RouteTargetFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: RouteTargetFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class ServiceFilterConverter implements FilterConverter<AssetClientFilter, ServiceFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): ServiceFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: ServiceFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class SiteFilterConverter implements FilterConverter<AssetClientFilter, SiteFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): SiteFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      const termSearchFilters: SiteFilterOrFilterEntry = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ contactEmail: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ contactName: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ contactPhone: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ facility: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ physicalAddress: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ shippingAddress: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class SiteGroupFilterConverter implements FilterConverter<AssetClientFilter, SiteGroupFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): SiteGroupFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: SiteGroupFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });
      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class TenantFilterConverter implements FilterConverter<AssetClientFilter, TenantFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): TenantFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: TenantFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class TenantGroupFilterConverter implements FilterConverter<AssetClientFilter, TenantGroupFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): TenantGroupFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: TenantGroupFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });
      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class VirtualChassisFilterConverter
  implements FilterConverter<AssetClientFilter, VirtualChassisFilterAndFilterEntry>
{
  convert(source?: AssetClientFilter): VirtualChassisFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: VirtualChassisFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ domain: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class VirtualMachineFilterConverter
  implements FilterConverter<AssetClientFilter, VirtualMachineFilterAndFilterEntry>
{
  convert(source?: AssetClientFilter): VirtualMachineFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: VirtualMachineFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ localContextData: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class VlanFilterConverter implements FilterConverter<AssetClientFilter, VlanFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): VlanFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: VlanFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class VlanGroupFilterConverter implements FilterConverter<AssetClientFilter, VlanGroupFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): VlanGroupFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: VlanGroupFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });
      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class VMInterfaceFilterConverter implements FilterConverter<AssetClientFilter, VmInterfaceFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): VmInterfaceFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: VmInterfaceFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ macAddress: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class VRFFilterConverter implements FilterConverter<AssetClientFilter, VrfFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): VrfFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: VrfFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ rd: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class WirelessLanFilterConverter implements FilterConverter<AssetClientFilter, WirelessLanFilterAndFilterEntry> {
  convert(source?: AssetClientFilter): WirelessLanFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: WirelessLanFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ ssid: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });

      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class WirelessLanGroupFilterConverter
  implements FilterConverter<AssetClientFilter, WirelessLanGroupFilterAndFilterEntry>
{
  convert(source?: AssetClientFilter): WirelessLanGroupFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: WirelessLanGroupFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ name: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });
      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}

export class WirelessLinkFilterConverter
  implements FilterConverter<AssetClientFilter, WirelessLinkFilterAndFilterEntry>
{
  convert(source?: AssetClientFilter): WirelessLinkFilterAndFilterEntry {
    const sharedFilter = createSharedFilter(source);
    if (source?.termSearch) {
      let termSearchFilters: WirelessLinkFilterOrFilterEntry;
      termSearchFilters = { OR: [] };
      termSearchFilters.OR.push({ ssid: { iContains: source.termSearch } });
      termSearchFilters.OR.push({ description: { iContains: source.termSearch } });
      return { AND: [...sharedFilter, termSearchFilters] };
    }
    return { AND: sharedFilter };
  }
}
