import { CommonModule } from '@angular/common';
import { HTTP_INTERCEPTORS } from '@angular/common/http';
import { NgModule } from '@angular/core';
import { OrionConfig } from '@orion/common';
import { OidcProviderHeaderInterceptor, UnauthorizedInterceptor } from '@orion/shared/services/interceptors';
import {
  SentinelAuthConfig,
  SentinelAuthErrorHandler,
  SentinelAuthModule,
  SentinelAuthorizationStrategy,
} from '@sentinel/auth';
import { SentinelAuthGuardWithLogin, SentinelNegativeAuthGuard } from '@sentinel/auth/guards';
import { APP_CONFIG, configurableModuleFactory } from '@sentinel/common/dynamic-env';
import { ErrorHandlerService, OrionAuthorizationStrategyService } from './shared/services/global';

@NgModule({
  imports: [
    CommonModule,
    SentinelAuthModule.forRoot({ guardLoginPageRedirect: '', guardMainPageRedirect: '', providers: [] }),
  ],
  providers: [
    SentinelAuthGuardWithLogin,
    SentinelNegativeAuthGuard,
    {
      provide: SentinelAuthErrorHandler,
      useClass: ErrorHandlerService,
    },
    {
      provide: SentinelAuthorizationStrategy,
      useClass: OrionAuthorizationStrategyService,
    },
    {
      provide: SentinelAuthConfig,
      useFactory: configurableModuleFactory<OrionConfig>('authConfig'),
      deps: [APP_CONFIG],
    },
    {
      provide: HTTP_INTERCEPTORS,
      useClass: OidcProviderHeaderInterceptor,
      multi: true,
    },
    {
      provide: HTTP_INTERCEPTORS,
      useClass: UnauthorizedInterceptor,
      multi: true,
    },
  ],
})
export class AuthModule {}
