import { NgModule } from '@angular/core';
import { RouterModule, Routes } from '@angular/router';
import { ASSETS_PATH } from '@orion/asset-paths';
import { CASES_PATH } from '@orion/case-paths';
import { IPFIX_PATH } from '@orion/data-platform-paths';
import { EXTERNAL_REFERENCES_PATH } from '@orion/external-reference-paths';
import { LABELS_PATH } from '@orion/label-paths';
import { OBSERVABLES_PATH } from '@orion/observable-paths';
import { ObservableRedirectService } from '@orion/observable-services';
import { USER_ACCOUNTING_PATH } from '@orion/user-accounting-paths';
import { TaskRedirectService } from '@orion/task-services';
import { TTP_PATH } from '@orion/ttps-paths';
import { TtpRedirectService } from '@orion/ttps-services';
import { USER_PARAM_SELECTOR, USERS_PATH } from '@orion/user-paths';
import { WORKFLOW_TEMPLATE_PATH } from '@orion/workflow-template-paths';
import { AuthSectionComponent } from './auth-section.component';
import { UserBreadcrumbResolver } from '@orion/user-services';

const routes: Routes = [
  {
    path: '',
    redirectTo: 'dashboard',
    pathMatch: 'full',
  },
  {
    path: '',
    component: AuthSectionComponent,
    children: [
      {
        path: 'dashboard',
        loadChildren: () => import('../routes/dashboard/dashboard.module').then((m) => m.DashboardModule),
        data: {
          breadcrumb: 'Home',
        },
      },
      {
        path: ASSETS_PATH,
        loadChildren: () => import('../routes/asset/overview/asset-overview.module').then((m) => m.AssetOverviewModule),
        data: {
          breadcrumb: 'Assets',
        },
      },
      {
        path: OBSERVABLES_PATH,
        loadChildren: () =>
          import('../routes/observable/overview/observable-overview.module').then((m) => m.ObservableOverviewModule),
        data: {
          breadcrumb: 'Observables',
        },
      },
      {
        path: IPFIX_PATH,
        loadChildren: () => import('../routes/ipfix/overview/ipfix-overview.module').then((m) => m.IpfixOverviewModule),
        data: {
          breadcrumb: 'IPFIX',
        },
      },
      {
        path: USER_ACCOUNTING_PATH,
        loadChildren: () =>
          import('../routes/user-accounting/overview/user-accounting-overview.module').then(
            (m) => m.UserAccountingOverviewModule
          ),
        data: {
          breadcrumb: 'User Accounting',
        },
      },
      {
        path: CASES_PATH,
        data: {
          breadcrumb: 'Cases',
        },
        loadChildren: () => import('../routes/case/overview/case-overview.module').then((m) => m.CaseOverviewModule),
      },
      {
        path: TTP_PATH,
        loadChildren: () => import('../routes/ttps/overview/ttps-overview.module').then((m) => m.TTPsOverviewModule),
        data: {
          breadcrumb: 'TTPs',
        },
      },
      {
        path: EXTERNAL_REFERENCES_PATH,
        loadChildren: () =>
          import('../routes/external-reference/overview/external-reference-overview.module').then(
            (m) => m.ExternalReferenceOverviewModule
          ),
        data: {
          breadcrumb: 'External References',
        },
      },
      {
        path: `${USERS_PATH}/:${USER_PARAM_SELECTOR}`,
        loadChildren: () => import('../routes/user/detail/user-detail.module').then((m) => m.UserDetailModule),
        resolve: {
          breadcrumb: UserBreadcrumbResolver,
        },
      },
      {
        path: LABELS_PATH,
        loadChildren: () => import('../routes/label/overview/label-overview.module').then((m) => m.LabelOverviewModule),
        data: {
          breadcrumb: 'Labels',
        },
      },
      {
        path: WORKFLOW_TEMPLATE_PATH,
        loadChildren: () =>
          import('../routes/workflow-template/overview/workflow-template-overview.module').then(
            (m) => m.WorkflowTemplateOverviewModule
          ),
        data: {
          breadcrumb: 'Workflow Templates',
        },
      },
      {
        path: 'task/:id',
        canLoad: [TaskRedirectService],
        loadChildren: () => import('../routes/case/detail/case-detail.module').then((m) => m.CaseDetailModule),
      },
      {
        path: `${OBSERVABLES_PATH}/:id`,
        canLoad: [ObservableRedirectService],
        loadChildren: () =>
          import('../routes/observable/overview/observable-overview.module').then((m) => m.ObservableOverviewModule),
      },
      {
        path: `${TTP_PATH}/:id`,
        canLoad: [TtpRedirectService],
        loadChildren: () => import('../routes/ttps/overview/ttps-overview.module').then((m) => m.TTPsOverviewModule),
      },
      {
        path: 'notification',
        loadChildren: () =>
          import('../routes/notification/notification-overview.module').then((m) => m.NotificationOverviewModule),
        data: {
          breadcrumb: 'Notifications',
        },
      },
    ],
  },
];

@NgModule({
  imports: [RouterModule.forChild(routes)],
  exports: [RouterModule],
})
export class AuthSectionRoutingModule {}
