import { CommonModule } from '@angular/common';
import { NgModule } from '@angular/core';
import { MatDividerModule } from '@angular/material/divider';
import { ObservableNavigator, ObservableRedirectService } from '@orion/observable-services';
import { UserAccountingNavigator } from '@orion/user-accounting-services';
import { TaskNavigator, TaskRedirectService } from '@orion/task-services';
import { TTPNavigator, TtpRedirectService } from '@orion/ttps-services';
import { UserBreadcrumbResolver, UserNavigator } from '@orion/user-services';
import { SentinelPipesModule } from '@sentinel/common/pipes';
import { SentinelMarkdownEditorModule } from '@sentinel/components/markdown-editor';
import { SentinelMarkdownViewModule } from '@sentinel/components/markdown-view';
import { SentinelBreadcrumbsModule } from '@sentinel/layout/breadcrumbs';
import { SentinelLayout1SansProvidersModule } from '@sentinel/layout/layout1';
import { TimeagoModule } from 'ngx-timeago';
import { orionMarkdownConfig } from '../routes/shared';
import { AuthSectionRoutingModule } from './auth-section-routing.module';
import { AuthSectionComponent } from './auth-section.component';
import { MatButtonModule } from '@angular/material/button';
import { MatIconModule } from '@angular/material/icon';
import { UserSettingsMenuModule } from '../user-settings/components/user-settings-menu';
import { OrionSidebarModule } from '@csirtmu-orion/microframework/sidebar';
import { SentinelSidebarToggleModule } from '@sentinel/layout/sidebar';

@NgModule({
  declarations: [AuthSectionComponent],
  imports: [
    CommonModule,
    AuthSectionRoutingModule,
    SentinelPipesModule,
    SentinelLayout1SansProvidersModule,
    SentinelBreadcrumbsModule,
    TimeagoModule.forRoot(),
    SentinelMarkdownEditorModule.forRoot(orionMarkdownConfig),
    SentinelMarkdownViewModule.forRoot(orionMarkdownConfig.markdownParser),
    MatDividerModule,
    MatButtonModule,
    MatIconModule,
    UserSettingsMenuModule,
    OrionSidebarModule,
    SentinelSidebarToggleModule,
  ],
  exports: [AuthSectionComponent],
  providers: [
    UserNavigator,
    TaskNavigator,
    TaskRedirectService,
    ObservableNavigator,
    ObservableRedirectService,
    TTPNavigator,
    TtpRedirectService,
    UserAccountingNavigator,
    UserBreadcrumbResolver,
  ],
})
export class AuthSectionModule {}
