import { ChangeDetectionStrategy, Component, Input, OnChanges, SimpleChanges } from '@angular/core';
import { SentinelControlItem } from '@sentinel/components/controls';
import { defer, of } from 'rxjs';
import { CaseManagementExternalReferenceDetailFragment } from '../graphql';

@Component({
  selector: 'orion-external-reference-detail-content',
  templateUrl: './external-reference-detail-content.component.html',
  styleUrls: ['./external-reference-detail-content.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class ExternalReferenceDetailContentComponent implements OnChanges {
  @Input() externalReference?: CaseManagementExternalReferenceDetailFragment;
  controls: SentinelControlItem[] = [];

  ngOnChanges(changes: SimpleChanges): void {
    if ('externalReference' in changes && this.externalReference && this.externalReference.url) {
      const url = this.externalReference.url;
      this.controls = [
        new SentinelControlItem(
          'open',
          'Open in new tab',
          'primary',
          of(false),
          defer(() => this.openExternalReference(url))
        ),
      ];
    }
  }

  private openExternalReference(url: string): void {
    window.open(url, '_blank');
  }
}
