import { Injectable } from '@angular/core';
import { CaseTableFragment } from '@orion/case-components/shared';
import { ApolloChildEntitiesService } from '@csirtmu-orion/microframework/apollo-services';
import {
  GetExternalReferenceRelatedCasesQuery,
  GetExternalReferenceRelatedCasesQueryService,
  GetExternalReferenceRelatedCasesQueryVariables,
} from './external-reference-related-cases.operation.generated';

@Injectable()
export class ExternalReferenceRelatedCasesService extends ApolloChildEntitiesService<
  GetExternalReferenceRelatedCasesQuery,
  GetExternalReferenceRelatedCasesQueryVariables,
  CaseTableFragment
> {
  constructor(getQuery: GetExternalReferenceRelatedCasesQueryService) {
    super(getQuery, 'Fetching related cases');
  }

  protected createVariables(parentId: string): GetExternalReferenceRelatedCasesQueryVariables {
    return { id: parentId };
  }

  protected toFragments(query: GetExternalReferenceRelatedCasesQuery): CaseTableFragment[] {
    const caseIdsSet: Set<string> = new Set<string>();
    const uniqueCaseFragments: CaseTableFragment[] = [];
    query.getCaseManagementExternalReference?.relatedCases?.data.forEach((caseFragment) => {
      if (!caseIdsSet.has(caseFragment.id)) {
        caseIdsSet.add(caseFragment.id);
        uniqueCaseFragments.push(caseFragment);
      }
    });
    query.getCaseManagementExternalReference?.relatedTasks?.data.forEach((task) => {
      const caseFragment = task.stage?.workflow?.case;
      if (caseFragment?.id && !caseIdsSet.has(caseFragment.id)) {
        caseIdsSet.add(caseFragment.id);
        uniqueCaseFragments.push(caseFragment);
      }
    });
    return uniqueCaseFragments;
  }
}
