import { Injectable } from '@angular/core';
import { ExternalReferenceClientFilter, ExternalReferenceFilterConverter } from '@orion/case-types';
import { CaseManagementExternalReferenceOrdEnum, ExternalReferenceFilter1AndFilterEntry } from '@orion/graphql-types';
import { ApolloPaginatedFilterableService } from '@csirtmu-orion/microframework/apollo-services';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import {
  GetCaseManagementExternalReferenceListQuery,
  GetCaseManagementExternalReferenceListQueryService,
  GetCaseManagementExternalReferenceListQueryVariables,
} from './external-reference-list.operation.generated';
import { ExternalReferenceListElementFragment } from './external-reference-selection';

@Injectable()
export class ExternalReferenceListService extends ApolloPaginatedFilterableService<
  GetCaseManagementExternalReferenceListQuery,
  GetCaseManagementExternalReferenceListQueryVariables,
  ExternalReferenceListElementFragment,
  CaseManagementExternalReferenceOrdEnum,
  ExternalReferenceClientFilter,
  ExternalReferenceFilter1AndFilterEntry
> {
  constructor(public getQuery: GetCaseManagementExternalReferenceListQueryService) {
    super(getQuery, 'Fetching external references');
  }

  protected createFilterConverter(): FilterConverter<
    ExternalReferenceClientFilter,
    ExternalReferenceFilter1AndFilterEntry[]
  > {
    return new ExternalReferenceFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: ExternalReferenceClientFilter
  ): GetCaseManagementExternalReferenceListQueryVariables {
    return {
      ...this.createPaginationVariables(paginationEvent),
      ...this.createOrderVariables(paginationEvent.sort, paginationEvent.sortDir),
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected getQueryResponse(
    query: GetCaseManagementExternalReferenceListQuery
  ): CursorPaginatedResponse<ExternalReferenceListElementFragment> {
    return query.getCaseManagementExternalReferenceList;
  }

  protected strToOrderable(sort: string): Optional<CaseManagementExternalReferenceOrdEnum> {
    return enumFromValue(CaseManagementExternalReferenceOrdEnum, sort);
  }
}
