import { ChangeDetectionStrategy, Component, Input, OnChanges, OnInit, Optional, SimpleChanges } from '@angular/core';
import { ExternalReferenceClientFilter } from '@orion/case-types';
import {
  ExternalReferenceAddViewMode,
  ExternalReferenceControlsService,
  ExternalReferenceViewStateService,
} from '@orion/external-reference-services/overview';
import { SentinelControlItem } from '@sentinel/components/controls';
import { EntityPaginableFilterableOverviewDirective } from '@csirtmu-orion/microframework/entity-smart-directives';
import { Observable } from 'rxjs';
import { take } from 'rxjs/operators';
import { ExternalReferenceOverviewFragment } from './graphql';

export const EXTERNAL_REFERENCE_PROVIDERS = [ExternalReferenceControlsService, ExternalReferenceViewStateService];

@Component({
  selector: 'orion-external-reference-overview',
  templateUrl: './external-reference-overview.component.html',
  styleUrls: ['./external-reference-overview.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class ExternalReferenceOverviewComponent
  extends EntityPaginableFilterableOverviewDirective<ExternalReferenceOverviewFragment, ExternalReferenceClientFilter>
  implements OnInit, OnChanges
{
  @Input() withActions = true;
  displayedAddComponent$?: Observable<ExternalReferenceAddViewMode | undefined>;
  controls$?: Observable<SentinelControlItem[]>;

  constructor(
    @Optional() private controlsService: ExternalReferenceControlsService,
    @Optional() private viewStateService?: ExternalReferenceViewStateService
  ) {
    super();
  }

  ngOnInit(): void {
    this.initViewState();
  }

  ngOnChanges(changes: SimpleChanges): void {
    if ('withActions' in changes && this.withActions) {
      this.initViewState();
    }
  }

  onControlsClicked(item: SentinelControlItem): void {
    item.result$?.pipe(take(1)).subscribe();
  }

  private initViewState() {
    if (this.viewStateService) {
      this.displayedAddComponent$ = this.viewStateService.displayedAddComponent$;
      this.controls$ = this.controlsService.controls$;
    }
  }
}
