import { Injectable } from '@angular/core';
import { ExternalReferenceClientFilter } from '@orion/case-types';
import { FilterChip, StringValueChip } from '@csirtmu-orion/microframework/filter';
import { FilterChipsService } from '@csirtmu-orion/microframework/filter-services';
import { DateValueChip } from '@csirtmu-orion/microframework/filters';
import { ExternalReferenceCategoryFilterChip } from './chips';
import { ExternalReferenceFilterService } from './external-reference-filter.service';

@Injectable()
export class ExternalReferenceFilterChipsService extends FilterChipsService<ExternalReferenceClientFilter> {
  constructor(protected filterService: ExternalReferenceFilterService) {
    super(filterService);
  }

  protected createChips(filter?: ExternalReferenceClientFilter): FilterChip[] {
    const chips = [];
    if (filter?.url) {
      chips.push(new StringValueChip(filter.url));
    }
    if (filter?.category) {
      chips.push(new ExternalReferenceCategoryFilterChip(filter.category));
    }
    if (filter?.from) {
      chips.push(new DateValueChip(filter.from, 'from'));
    }
    if (filter?.to) {
      chips.push(new DateValueChip(filter.to, 'to'));
    }
    return chips;
  }

  removeChip(removedChip: FilterChip): void {
    if (removedChip instanceof StringValueChip) {
      this.filterService.updateAndSubmit({ url: undefined });
    }
    if (removedChip instanceof DateValueChip && removedChip.direction === 'from') {
      this.filterService.updateAndSubmit({ from: undefined });
    }
    if (removedChip instanceof DateValueChip && removedChip.direction === 'to') {
      this.filterService.updateAndSubmit({ to: undefined });
    }
    if (removedChip instanceof ExternalReferenceCategoryFilterChip) {
      this.filterService.updateAndSubmit({ category: undefined });
    }
  }
}
