import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap, Params, Router } from '@angular/router';
import { ExternalReferenceClientFilter } from '@orion/case-types';
import { CaseManagementExternalReferenceCategoryEnum } from '@orion/graphql-types';
import { QueryParamFilterService } from '@csirtmu-orion/microframework/filter-services';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import { Observable, of } from 'rxjs';

@Injectable()
export class ExternalReferenceFilterService extends QueryParamFilterService<ExternalReferenceClientFilter> {
  constructor(protected router: Router, protected activatedRoute: ActivatedRoute) {
    super(router, activatedRoute);
  }

  protected toQueryParams(filter: ExternalReferenceClientFilter): Params {
    const params = super.toQueryParams(filter);
    if (filter.from) {
      params.from = filter.from.valueOf();
    }
    if (filter.to) {
      params.to = filter.to.valueOf();
    }
    delete params.taskIds;
    delete params.caseId;
    return params;
  }

  protected createEmptyFilter(): ExternalReferenceClientFilter {
    return { url: undefined, from: undefined, to: undefined, category: undefined };
  }

  protected createFilterFromRoute(
    queryParamMap: ParamMap,
    paramMap: ParamMap
  ): Observable<ExternalReferenceClientFilter> {
    const url = this.deslugify(queryParamMap.get('url'));
    const categoryParam = this.deslugify(queryParamMap.get('category'));
    const category = this.resolveCategory(categoryParam);
    const from = this.deslugifyTimestamp(queryParamMap.get('from'));
    const to = this.deslugifyTimestamp(queryParamMap.get('to'));
    return of({ url, category: category, from, to });
  }

  protected resolveCategory(value?: string): Optional<CaseManagementExternalReferenceCategoryEnum> {
    return value ? enumFromValue(CaseManagementExternalReferenceCategoryEnum, value) : undefined;
  }
}
