import { ExternalReferenceActionsService } from '@orion/external-reference-services/overview';
import { CaseManagementExternalReferenceOrdEnum } from '@orion/graphql-types';
import { IPaginatedElements } from '@sentinel/common/pagination';
import { isLoading } from '@sentinel/common/utils';
import { Column, Row, RowAction, SentinelTable } from '@sentinel/components/table';
import { defer, of } from 'rxjs';
import { map } from 'rxjs/operators';
import { ExternalReferenceTableFragment } from './external-reference-table.fragment.generated';

export class ExternalReferenceTable extends SentinelTable<ExternalReferenceTableFragment> {
  constructor(
    resource: IPaginatedElements<ExternalReferenceTableFragment>,
    actionService?: ExternalReferenceActionsService
  ) {
    const columns = [
      new Column('reference', 'Reference', true, CaseManagementExternalReferenceOrdEnum.URL),
      new Column('category', 'Category', true, CaseManagementExternalReferenceOrdEnum.CATEGORY),
      new Column('platform', 'platform', false),
      new Column('created', 'Created', true, CaseManagementExternalReferenceOrdEnum.CREATED),
    ];
    const rows = resource.elements.map(
      (ticket) => new Row(ticket, ExternalReferenceTable.createActions(ticket, actionService))
    );
    super(rows, columns);
    this.pagination = resource.pagination;
  }

  private static createActions(
    reference: ExternalReferenceTableFragment,
    actionService?: ExternalReferenceActionsService
  ): RowAction[] {
    if (actionService) {
      return [
        new RowAction(
          'open',
          'Open URL in new tab',
          'open_in_new',
          'primary',
          'Open URL in new tab',
          of(false),
          defer(() => this.openReference(reference.url)),
          actionService.removalInProgress$.pipe(map((state) => isLoading(state, reference.id)))
        ),
        new RowAction(
          'remove',
          'Remove',
          'clear',
          'warn',
          'Remove external reference association',
          of(false),
          defer(() => actionService.removeAssociation(reference.id)),
          actionService.removalInProgress$.pipe(map((state) => isLoading(state, reference.id)))
        ),
      ];
    } else {
      return [];
    }
  }

  private static openReference(url: string): void {
    window.open(url, '_blank');
  }
}
