import { Injectable } from '@angular/core';
import { ExternalReferenceClientFilter, ExternalReferenceFilterConverter } from '@orion/case-types';
import {
  CaseManagementExternalReferenceFilter1AndFilterEntry,
  CaseManagementExternalReferenceOrdEnum,
} from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import { ExternalReferenceOverviewFragment } from '../../components/external-references';
import {
  GetExternalReferencesQuery,
  GetExternalReferencesQueryService,
  GetExternalReferencesQueryVariables,
} from './graphql';
import { ApolloPaginatedFilterablePollingService } from '@orion/shared-services';

@Injectable()
export class ExternalReferenceOverviewService extends ApolloPaginatedFilterablePollingService<
  GetExternalReferencesQuery,
  GetExternalReferencesQueryVariables,
  ExternalReferenceOverviewFragment,
  CaseManagementExternalReferenceOrdEnum,
  ExternalReferenceClientFilter,
  CaseManagementExternalReferenceFilter1AndFilterEntry
> {
  constructor(public getQuery: GetExternalReferencesQueryService) {
    super(getQuery, 'Fetching external references');
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: ExternalReferenceClientFilter
  ): GetExternalReferencesQueryVariables {
    return {
      ...this.createPaginationVariables(paginationEvent),
      ...this.createOrderVariables(paginationEvent.sort, paginationEvent.sortDir),
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected createFilterConverter(): FilterConverter<
    ExternalReferenceClientFilter,
    CaseManagementExternalReferenceFilter1AndFilterEntry[]
  > {
    return new ExternalReferenceFilterConverter();
  }

  protected strToOrderable(sort: string): Optional<CaseManagementExternalReferenceOrdEnum> {
    return enumFromValue(CaseManagementExternalReferenceOrdEnum, sort);
  }

  protected getQueryResponse(
    query: GetExternalReferencesQuery
  ): CursorPaginatedResponse<ExternalReferenceOverviewFragment> {
    return query.getCaseManagementExternalReferenceList;
  }
}
