import * as SchemaTypes from '../../../../graphql/generated/base-types/base-types';

import * as Apollo from 'apollo-angular';
import { gql } from 'apollo-angular';
import { ExternalReferenceOverviewFragmentDoc } from '../../../components/external-references/graphql/external-reference-overview.fragment.generated';
import { ExternalReferenceTableFragmentDoc } from '../../../components/external-references/table/external-reference-table.fragment.generated';
import { ExternalReferenceRowFragmentDoc } from '../../../components/external-references/table/rows/external-reference-row.fragment.generated';
import { Injectable } from '@angular/core';

export type GetExternalReferencesQueryVariables = SchemaTypes.Exact<{
  filter?: SchemaTypes.InputMaybe<Array<SchemaTypes.CaseManagementExternalReferenceFilter1AndFilterEntry>>;
  order?: SchemaTypes.InputMaybe<Array<SchemaTypes.CaseManagementExternalReferenceOrdEnumOrderingEntry>>;
  cursor?: SchemaTypes.InputMaybe<SchemaTypes.Scalars['String']>;
  limit?: SchemaTypes.InputMaybe<SchemaTypes.Scalars['Int']>;
}>;

export type GetExternalReferencesQuery = {
  __typename?: 'Query';
  getCaseManagementExternalReferenceList: {
    __typename?: 'CaseManagementExternalReferencePaginated';
    previous?: string | undefined;
    next?: string | undefined;
    totalCount: number;
    data: Array<{
      __typename?: 'CaseManagementExternalReference';
      id: string;
      platform: SchemaTypes.CaseManagementExternalReferencePlatformEnum;
      category: SchemaTypes.CaseManagementExternalReferenceCategoryEnum;
      created?: any | undefined;
      url: string;
    }>;
  };
};

export type CreateExternalReferenceMutationVariables = SchemaTypes.Exact<{
  reference: SchemaTypes.CaseManagementExternalReferenceCreate;
}>;

export type CreateExternalReferenceMutation = {
  __typename?: 'Mutation';
  createCaseManagementExternalReference: { __typename?: 'CreateResult'; id: string };
};

export type UpdateExternalReferenceMutationVariables = SchemaTypes.Exact<{
  patch: SchemaTypes.CaseManagementExternalReferenceUpdate;
  id: SchemaTypes.Scalars['ID'];
}>;

export type UpdateExternalReferenceMutation = {
  __typename?: 'Mutation';
  updateCaseManagementExternalReference: { __typename?: 'MutateResult'; id?: string | undefined };
};

export type DeleteExternalReferenceMutationVariables = SchemaTypes.Exact<{
  id: SchemaTypes.Scalars['ID'];
}>;

export type DeleteExternalReferenceMutation = {
  __typename?: 'Mutation';
  deleteCaseManagementExternalReference: { __typename?: 'MutateResult'; id?: string | undefined };
};

export const GetExternalReferencesDocument = gql`
  query getExternalReferences(
    $filter: [CaseManagementExternalReferenceFilter1ANDFilterEntry!]
    $order: [CaseManagementExternalReferenceOrdEnumOrderingEntry!]
    $cursor: String
    $limit: Int
  ) {
    getCaseManagementExternalReferenceList(filter: $filter, ordering: $order, cursor: $cursor, limit: $limit) {
      data {
        ...externalReferenceOverview
      }
      previous
      next
      totalCount
    }
  }
  ${ExternalReferenceOverviewFragmentDoc}
  ${ExternalReferenceTableFragmentDoc}
  ${ExternalReferenceRowFragmentDoc}
`;

@Injectable({
  providedIn: 'root',
})
export class GetExternalReferencesQueryService extends Apollo.Query<
  GetExternalReferencesQuery,
  GetExternalReferencesQueryVariables
> {
  document = GetExternalReferencesDocument;
  client = 'graphApi';
  constructor(apollo: Apollo.Apollo) {
    super(apollo);
  }
}
export const CreateExternalReferenceDocument = gql`
  mutation createExternalReference($reference: CaseManagementExternalReferenceCreate!) {
    createCaseManagementExternalReference(data: $reference) {
      id
    }
  }
`;

@Injectable({
  providedIn: 'root',
})
export class CreateExternalReferenceMutationService extends Apollo.Mutation<
  CreateExternalReferenceMutation,
  CreateExternalReferenceMutationVariables
> {
  document = CreateExternalReferenceDocument;
  client = 'graphApi';
  constructor(apollo: Apollo.Apollo) {
    super(apollo);
  }
}
export const UpdateExternalReferenceDocument = gql`
  mutation updateExternalReference($patch: CaseManagementExternalReferenceUpdate!, $id: ID!) {
    updateCaseManagementExternalReference(data: $patch, id: $id) {
      id
    }
  }
`;

@Injectable({
  providedIn: 'root',
})
export class UpdateExternalReferenceMutationService extends Apollo.Mutation<
  UpdateExternalReferenceMutation,
  UpdateExternalReferenceMutationVariables
> {
  document = UpdateExternalReferenceDocument;
  client = 'graphApi';
  constructor(apollo: Apollo.Apollo) {
    super(apollo);
  }
}
export const DeleteExternalReferenceDocument = gql`
  mutation deleteExternalReference($id: ID!) {
    deleteCaseManagementExternalReference(id: $id) {
      id
    }
  }
`;

@Injectable({
  providedIn: 'root',
})
export class DeleteExternalReferenceMutationService extends Apollo.Mutation<
  DeleteExternalReferenceMutation,
  DeleteExternalReferenceMutationVariables
> {
  document = DeleteExternalReferenceDocument;
  client = 'graphApi';
  constructor(apollo: Apollo.Apollo) {
    super(apollo);
  }
}
