import { FormControl, FormGroup } from '@angular/forms';
import { urlValidator } from '@orion/common';
import { CaseManagementExternalReferenceCategoryEnum } from '@orion/graphql-types';
import { BaseReactiveForm, SentinelValidators } from '@sentinel/common';
import { CreateExternalReferenceData } from './create-external-reference-data';

export interface CreateExternalReferenceFormModel {
  url: FormControl<string>;
  category: FormControl<CaseManagementExternalReferenceCategoryEnum>;
}

export class CreateExternalReferenceForm extends BaseReactiveForm<CreateExternalReferenceFormModel> {
  constructor(url?: string, category?: CaseManagementExternalReferenceCategoryEnum) {
    const formGroup = new FormGroup<CreateExternalReferenceFormModel>({
      url: new FormControl<string>(url ?? '', { nonNullable: true, initialValueIsDefault: true }),
      category: new FormControl<CaseManagementExternalReferenceCategoryEnum>(
        category ?? CaseManagementExternalReferenceCategoryEnum.TICKET,
        { nonNullable: true, initialValueIsDefault: true }
      ),
    });
    formGroup.controls.url.setValidators([SentinelValidators.noWhitespace, urlValidator]);
    formGroup.controls.category.setValidators([SentinelValidators.required]);
    formGroup.controls.url.updateValueAndValidity({ emitEvent: false });
    formGroup.controls.category.updateValueAndValidity();
    super(formGroup);
  }

  getData(): CreateExternalReferenceData {
    return {
      url: this.formGroup.controls.url.value,
      category: this.formGroup.controls.category.value,
    };
  }
}
