import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap, Router } from '@angular/router';
import { CASE_PARAM_SELECTOR } from '@orion/case-paths';
import { ExternalReferenceClientFilter } from '@orion/case-types';
import { ExternalReferenceFilterService } from '@orion/external-reference-components/overview';
import { Observable } from 'rxjs';
import { concatMap, map } from 'rxjs/operators';
import { CaseNestedTaskIdsService } from '../detail/case-nested-task-ids.service';

@Injectable()
export class CaseExternalReferenceFilterService extends ExternalReferenceFilterService {
  constructor(
    protected router: Router,
    protected activatedRoute: ActivatedRoute,
    protected caseNestedTaskIdsService: CaseNestedTaskIdsService
  ) {
    super(router, activatedRoute);
  }

  protected createFilterFromRoute(
    queryParamMap: ParamMap,
    paramMap: ParamMap
  ): Observable<ExternalReferenceClientFilter> {
    const caseId = paramMap.get(CASE_PARAM_SELECTOR);
    return super.createFilterFromRoute(queryParamMap, paramMap).pipe(
      concatMap((baseFilter) =>
        this.caseNestedTaskIdsService.ids$.pipe(
          map((taskIds) => {
            baseFilter.taskIds = taskIds;
            baseFilter.caseId = caseId ?? undefined;
            return baseFilter;
          })
        )
      )
    );
  }
}
