import { Injectable } from '@angular/core';
import { ControlsService } from '@orion/shared-services';
import { ApolloResult, ApolloResultType } from '@csirtmu-orion/microframework/graphql';
import {
  SentinelControlItem,
  SentinelControlMenuItem,
  SentinelExpandableControlItem,
} from '@sentinel/components/controls';
import { combineLatest, defer, NEVER, of } from 'rxjs';
import { map, tap } from 'rxjs/operators';
import { FileItemRowFragment } from '../case-file-items';
import { CaseFileItemsActionsService, CaseFileItemSelectionService } from '../services';

@Injectable()
export class FileItemControlsService extends ControlsService {
  constructor(
    private actionService: CaseFileItemsActionsService,
    private selectionService: CaseFileItemSelectionService
  ) {
    super();
    this.controls$ = this.selectionService.selected$.pipe(map((selected) => this.createControls(selected)));
  }

  private createControls(selected: FileItemRowFragment[]): SentinelControlItem[] {
    return [
      new SentinelExpandableControlItem('ADD', 'Add', 'primary', NEVER, [
        new SentinelControlMenuItem(
          'ADD_FILE',
          'File',
          'primary',
          of(false),
          defer(() => this.actionService.createFile()),
          'file_upload'
        ),
        new SentinelControlMenuItem(
          'ADD_DIR',
          'Directory',
          'primary',
          of(false),
          defer(() => this.actionService.createDirectory()).pipe(tap((result) => this.onActionResult(result))),
          'create_new_folder'
        ),
      ]),
      new SentinelControlItem(
        'DOWNLOAD',
        `Download (${selected.length})`,
        'accent',
        combineLatest([
          of(selected.length < 1),
          this.actionService.downloadInProgress$.pipe(map((state) => state.isLoading)),
        ]).pipe(map((conditions) => conditions.some((condition) => condition))),
        defer(() => this.actionService.download(selected).pipe(tap((result) => this.onActionResult(result)))),
        this.actionService.downloadInProgress$.pipe(map((state) => state.isLoading))
      ),
      new SentinelControlItem(
        'DELETE',
        `Delete (${selected.length})`,
        'warn',
        combineLatest([
          of(selected.length < 1),
          this.actionService.deleteInProgress$.pipe(map((state) => state.isLoading)),
        ]).pipe(map((conditions) => conditions.some((condition) => condition))),
        defer(() => this.actionService.delete(selected).pipe(tap((result) => this.onActionResult(result)))),
        this.actionService.deleteInProgress$.pipe(map((state) => state.isLoading))
      ),
    ];
  }

  private onActionResult(result: ApolloResult): void {
    if (result.type === ApolloResultType.SUCCESS) {
      this.selectionService.clear();
    }
  }
}
