import {
  ChangeDetectionStrategy,
  Component,
  EventEmitter,
  Input,
  OnChanges,
  OnInit,
  Output,
  SimpleChanges,
} from '@angular/core';
import { Observable } from 'rxjs';
import { take } from 'rxjs/operators';
import { CaseFileItemsActionsService, CaseFileItemSelectionService, CaseFileViewStateService } from '../services';
import { ActiveFileItemDirectoryFragment, ActiveFileItemFragment } from './active-file-item.fragment.generated';
import { FileItemBreadcrumbFragment } from './file-item-breadcrumbs';
import { CaseFileItemNameFragment, FileItemRowFragment } from './file-item-table';
import { FileItemsBreadcrumbsService } from './file-items-breadcrumbs.service';

@Component({
  selector: 'orion-case-file-items',
  templateUrl: './case-file-items.component.html',
  styleUrls: ['./case-file-items.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class CaseFileItemsComponent implements OnInit, OnChanges {
  @Input() activeFileItem?: ActiveFileItemFragment;
  @Output() getFileItem: EventEmitter<string> = new EventEmitter<string>();
  createDirectoryComponentDisplayed$?: Observable<boolean>;
  uploadFileComponentDisplayed$?: Observable<boolean>;
  breadcrumbsFromRoot$?: Observable<FileItemBreadcrumbFragment[]>;
  children: FileItemRowFragment[] = [];

  constructor(
    private breadcrumbsService: FileItemsBreadcrumbsService,
    private viewService: CaseFileViewStateService,
    private actionsService: CaseFileItemsActionsService,
    private selectionService: CaseFileItemSelectionService
  ) {}

  ngOnInit(): void {
    this.breadcrumbsFromRoot$ = this.breadcrumbsService.successorsFromRoot$;
    this.createDirectoryComponentDisplayed$ = this.viewService.createDirectoryComponentDisplayed$;
    this.uploadFileComponentDisplayed$ = this.viewService.uploadFileComponentDisplayed$;
  }

  ngOnChanges(changes: SimpleChanges): void {
    if ('activeFileItem' in changes && this.activeFileItem && this.isDirectory(this.activeFileItem)) {
      this.children = this.activeFileItem?.children?.data ?? [];
    }
  }

  onBreadcrumbItemClicked(item: FileItemBreadcrumbFragment): void {
    this.getFileItem.emit(item.id);
  }

  onItemClicked(item: CaseFileItemNameFragment): void {
    if (item.__typename === 'Directory') {
      this.getFileItem.emit(item.id);
    }
    if (item.__typename === 'File') {
      this.actionsService.download([item]).pipe(take(1)).subscribe();
    }
  }

  onSelectionChange(selected: FileItemRowFragment[]): void {
    this.selectionService.setSelected(selected);
  }

  private isDirectory(fileItem: ActiveFileItemFragment): fileItem is ActiveFileItemDirectoryFragment {
    return fileItem.__typename === 'Directory';
  }
}
