import { Injectable } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { namedOperations } from '@orion/named-operations';
import { CreateEntityService } from '@orion/shared-services';
import { NotificationService } from '@orion/shared/services/global';
import {
  ApolloOperationResultResolver,
  ApolloResult,
  ApolloResultType,
  createApolloContextErrorTitle,
} from '@csirtmu-orion/microframework/graphql';
import { Observable, of } from 'rxjs';
import { catchError, map } from 'rxjs/operators';
import { CreateDirectoryMutationService, CreateDirectoryMutationVariables } from '../../../graphql';
import { ActiveCaseFileItemStateService, CaseFileViewStateService } from '../../../services';
import { CreateEditCaseFileItemForm } from '../create-edit-case-file-item-form';

@Injectable()
export class CreateDirectoryService extends CreateEntityService<CreateEditCaseFileItemForm> {
  constructor(
    protected notificationService: NotificationService,
    protected activatedRoute: ActivatedRoute,
    private activeCaseFileService: ActiveCaseFileItemStateService,
    private createDirMutation: CreateDirectoryMutationService,
    private viewStateService: CaseFileViewStateService
  ) {
    super('Directory', notificationService, activatedRoute);
  }

  protected createForm(): Observable<CreateEditCaseFileItemForm> {
    return of(new CreateEditCaseFileItemForm());
  }

  protected createEntity(form: CreateEditCaseFileItemForm): Observable<ApolloResult> {
    const parent = this.activeCaseFileService.getActiveCaseFile();
    if (parent) {
      const vars: CreateDirectoryMutationVariables = {
        directory: {
          parent: parent?.id,
          name: form.getData().name,
        },
      };
      return this.createDirMutation
        .mutate(vars, {
          refetchQueries: [namedOperations.Query.getActiveCaseFileItem],
          awaitRefetchQueries: true,
          context: createApolloContextErrorTitle('Creating directory'),
        })
        .pipe(
          map((result) => ApolloOperationResultResolver.resolve(result)),
          catchError((err) => ApolloOperationResultResolver.handleError(err))
        );
    } else {
      this.notificationService.emit('error', 'Created directory has no parent directory');
      return of(new ApolloResult(ApolloResultType.ERROR));
    }
  }

  protected handleCancel(): Observable<boolean> {
    this.viewStateService.hideCreateDirectoryComponent();
    return of(true);
  }

  protected onSaveError(): Observable<boolean> {
    return of(true);
  }

  protected onSaveSuccess(): Observable<boolean> {
    this.viewStateService.hideCreateDirectoryComponent();
    return of(true);
  }
}
