import { FormControl, FormGroup } from '@angular/forms';
import { BaseReactiveForm, SentinelValidators } from '@sentinel/common';

export interface CreateEditCaseFileItemFormModel {
  name: FormControl<string>;
}

export interface CreateEditCaseFileItemData {
  name: string;
}

export class CreateEditCaseFileItemForm extends BaseReactiveForm<CreateEditCaseFileItemFormModel> {
  constructor(name?: string) {
    const formGroup = new FormGroup<CreateEditCaseFileItemFormModel>({
      name: new FormControl<string>(name ?? '', { nonNullable: true, initialValueIsDefault: true }),
    });
    formGroup.controls.name.setValidators([SentinelValidators.noWhitespace]);
    formGroup.controls.name.updateValueAndValidity();
    super(formGroup);
  }

  setName(name: string): void {
    this.formGroup.controls.name.setValue(name);
  }

  getData(): CreateEditCaseFileItemData {
    return {
      name: this.formGroup.controls.name.value,
    };
  }
}
