import { ChangeDetectionStrategy, Component, Input, SimpleChanges } from '@angular/core';
import { CaseFileItemNameFragment, CreateEditCaseFileItemForm } from '@orion/case-components/case-file';
import { EntityModifyDirective } from '@orion/shared-components/create-edit';
import { EntityModifyBaseService, ModifyEntityControlsService } from '@orion/shared-services';
import { EMPTY, Observable } from 'rxjs';
import { take } from 'rxjs/operators';
import { EditCaseFileItemService } from './edit-file-item.service';

@Component({
  selector: 'orion-edit-case-file-item',
  templateUrl: './edit-case-file-item.component.html',
  styleUrls: ['./edit-case-file-item.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [ModifyEntityControlsService, { provide: EntityModifyBaseService, useClass: EditCaseFileItemService }],
})
export class EditCaseFileItemComponent extends EntityModifyDirective<CreateEditCaseFileItemForm> {
  @Input() item?: CaseFileItemNameFragment;

  constructor(
    protected editService: EntityModifyBaseService<CreateEditCaseFileItemForm>,
    protected controlsService: ModifyEntityControlsService
  ) {
    super(editService, controlsService);
  }

  ngOnChanges(changes: SimpleChanges): void {
    if ('item' in changes && this.item && this.editService instanceof EditCaseFileItemService) {
      let init$: Observable<unknown>;
      if (this.item.__typename === 'Directory') {
        init$ = this.editService.init(this.item.id, this.item.name, this.item.__typename);
      } else if (this.item.__typename === 'File') {
        init$ = this.editService.init(this.item.id, this.item.displayName ?? '', this.item.__typename);
      } else {
        init$ = EMPTY;
      }
      init$.pipe(take(1)).subscribe();
    }
  }
}
