import { ChangeDetectionStrategy, Component, EventEmitter, OnInit, Output } from '@angular/core';
import { EntityTableDirective } from '@csirtmu-orion/microframework/entity-smart-directives';
import { Observable } from 'rxjs';
import { CaseFileItemsActionsService, CaseFileViewStateService } from '../../services';
import { CaseFileItemNameFragment } from './abstract-file-item';
import { FileItemRowFragment } from './file-item-row.fragment.generated';
import { FileItemTable } from './file-item-table';

@Component({
  selector: 'orion-file-item-table',
  templateUrl: './file-item-table.component.html',
  styleUrls: ['./file-item-table.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class FileItemTableComponent extends EntityTableDirective<FileItemRowFragment, FileItemTable> implements OnInit {
  @Output() itemClicked: EventEmitter<CaseFileItemNameFragment> = new EventEmitter<CaseFileItemNameFragment>();
  editedId$?: Observable<string | null>;

  constructor(private actionService: CaseFileItemsActionsService, private viewService: CaseFileViewStateService) {
    super();
  }

  ngOnInit(): void {
    this.editedId$ = this.viewService.editedId$;
  }

  protected createTable(entities: FileItemRowFragment[]): FileItemTable {
    return new FileItemTable(entities, this.actionService);
  }

  onItemClicked(item: CaseFileItemNameFragment): void {
    this.onRowSelection([]);
    this.itemClicked.emit(item);
  }
}
