import { CaseFileItemsActionsService, FileItemRowFragment } from '@orion/case-components/case-file';
import { isLoading } from '@sentinel/common/utils';
import { Column, Row, RowAction, SentinelTable } from '@sentinel/components/table';
import { defer, of } from 'rxjs';
import { map } from 'rxjs/operators';

export class FileItemTable extends SentinelTable<FileItemRowFragment> {
  constructor(caseFiles: FileItemRowFragment[], service: CaseFileItemsActionsService) {
    const columns = [new Column('name', 'Name', false), new Column('created', 'created', false)];
    const rows = caseFiles.map((caseFile) => new Row(caseFile, FileItemTable.createActions(caseFile, service)));
    super(rows, columns);
    this.selectable = true;
  }

  private static createActions(caseFile: FileItemRowFragment, service: CaseFileItemsActionsService): RowAction[] {
    const editAction = new RowAction(
      'edit',
      'Rename',
      'create',
      'primary',
      'Rename',
      of(false),
      defer(() => service.edit(caseFile.id))
    );
    const downloadAction = new RowAction(
      'download',
      'Download',
      'file_download',
      'primary',
      'Download',
      of(false),
      defer(() => service.download([caseFile])),
      service.downloadInProgress$.pipe(map((state) => isLoading(state, caseFile.id)))
    );
    const deleteAction = new RowAction(
      'delete',
      'Delete',
      'delete',
      'warn',
      'Delete',
      of(false),
      defer(() => service.delete([caseFile])),
      service.deleteInProgress$.pipe(map((state) => isLoading(state, caseFile.id)))
    );
    const fileActions = [editAction, downloadAction, deleteAction];
    const dirActions = [editAction, deleteAction];

    if (caseFile.__typename === 'Directory') {
      return dirActions;
    } else if (caseFile.__typename === 'File') {
      return fileActions;
    } else {
      return [];
    }
  }
}
