import { Injectable } from '@angular/core';
import { Observable } from 'rxjs';
import { map, tap } from 'rxjs/operators';
import { ActiveCaseFileItemStateService } from '../services';
import { FileItemBreadcrumbFragment } from './file-item-breadcrumbs';

@Injectable()
export class FileItemsBreadcrumbsService {
  private currSuccessors: FileItemBreadcrumbFragment[] = [];
  successorsFromRoot$: Observable<FileItemBreadcrumbFragment[]>;

  constructor(private activeCaseFileItemService: ActiveCaseFileItemStateService) {
    this.successorsFromRoot$ = this.activeCaseFileItemService.activeCaseFile$.pipe(
      map((item) => (item ? this.updateBreadcrumbs(item) : [])),
      tap((successors) => (this.currSuccessors = successors))
    );
  }

  private updateBreadcrumbs(item: FileItemBreadcrumbFragment): FileItemBreadcrumbFragment[] {
    return this.alreadyInPath(item) ? this.removeSuccessors(item) : this.append(item);
  }

  private removeSuccessors(toRemove: FileItemBreadcrumbFragment): FileItemBreadcrumbFragment[] {
    const curr = this.currSuccessors;
    const toRemoveIndex = curr.findIndex((item) => item.id === toRemove.id);
    if (toRemoveIndex !== -1 && toRemoveIndex !== curr.length - 1) {
      return curr.slice(0, toRemoveIndex + 1);
    } else return curr;
  }

  private alreadyInPath(item: FileItemBreadcrumbFragment): boolean {
    const curr = this.currSuccessors;
    return curr.some((currItem) => currItem.id === item.id);
  }

  private append(item: FileItemBreadcrumbFragment): FileItemBreadcrumbFragment[] {
    const curr = this.currSuccessors;
    return [...curr, item];
  }
}
