import { ChangeDetectionStrategy, Component, Input, OnChanges, SimpleChanges } from '@angular/core';
import { Destroyable } from '@sentinel/common';
import { Optional } from '@sentinel/common/utils';
import { defer, Observable } from 'rxjs';
import { tap } from 'rxjs/operators';
import { ActiveFileItemFragment } from './case-file-items';
import { RootDirFragment } from './graphql';
import { ActiveCaseFileItemQueryService, ActiveCaseFileItemStateService } from './services';

@Component({
  selector: 'orion-case-root-dir',
  templateUrl: './case-root-dir.component.html',
  styleUrls: ['./case-root-dir.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class CaseRootDirComponent extends Destroyable() implements OnChanges {
  @Input() rootDir?: RootDirFragment;
  fileItem$?: Observable<Optional<ActiveFileItemFragment>>;
  hasError$?: Observable<boolean>;
  isLoading$?: Observable<boolean>;
  onTryAgain$: Observable<void> = defer(() => this.activeCaseFileItemQueryService.recoverAfterError());

  constructor(
    private activeCaseFileItemQueryService: ActiveCaseFileItemQueryService,
    private activeCaseFileItemStateService: ActiveCaseFileItemStateService
  ) {
    super();
  }

  ngOnChanges(changes: SimpleChanges): void {
    if ('rootDir' in changes && this.rootDir) {
      this.activeCaseFileItemQueryService.updateVars(this.rootDir.id);
      if (this.fileItem$) {
        // in case rootDir changed we need to reset the state, to reset the file breadcrumbs
        this.activeCaseFileItemStateService.reset();
      } else {
        this.fileItem$ = this.activeCaseFileItemQueryService.data$?.pipe(
          tap((activeCaseFile) => {
            if (activeCaseFile) {
              this.activeCaseFileItemStateService.setActiveCaseFile(activeCaseFile);
            }
          })
        );
        this.hasError$ = this.activeCaseFileItemQueryService.hasError$;
        this.isLoading$ = this.activeCaseFileItemQueryService.isLoading$;
      }
    }
  }

  onGetFileItem(id: string): void {
    if (id !== this.activeCaseFileItemStateService?.getActiveCaseFile()?.id) {
      this.activeCaseFileItemQueryService.updateVars(id);
    }
  }
}
