import * as SchemaTypes from '../../../../graphql/generated/base-types/base-types';

import * as Apollo from 'apollo-angular';
import { gql } from 'apollo-angular';
import { ActiveFileItemFragmentDoc } from '../case-file-items/active-file-item.fragment.generated';
import { FileItemRowFragmentDoc } from '../case-file-items/file-item-table/file-item-row.fragment.generated';
import { CaseFileItemNameFragmentDoc } from '../case-file-items/file-item-table/abstract-file-item/case-file-item-name.fragment.generated';
import { Injectable } from '@angular/core';

export type GetActiveCaseFileItemQueryVariables = SchemaTypes.Exact<{
  id: SchemaTypes.Scalars['ID'];
}>;

export type GetActiveCaseFileItemQuery = {
  __typename?: 'Query';
  getCaseFileItem?:
    | { __typename?: 'CaseFileItemBase'; id: string; name: string }
    | {
        __typename?: 'Directory';
        id: string;
        name: string;
        children?:
          | {
              __typename?: 'CaseFileItemNestedList';
              totalCount: number;
              data: Array<
                | { __typename?: 'CaseFileItemBase'; id: string; name: string }
                | { __typename?: 'Directory'; id: string; created?: any | undefined; name: string }
                | {
                    __typename?: 'File';
                    id: string;
                    created?: any | undefined;
                    src: string;
                    displayName?: string | undefined;
                    extension?: string | undefined;
                  }
              >;
            }
          | undefined;
      }
    | { __typename?: 'File'; id: string; name: string }
    | undefined;
};

export type CreateDirectoryMutationVariables = SchemaTypes.Exact<{
  directory: SchemaTypes.DirectoryCreate;
}>;

export type CreateDirectoryMutation = {
  __typename?: 'Mutation';
  createDirectory: { __typename?: 'CreateResult'; id: string };
};

export type CreateFileMutationVariables = SchemaTypes.Exact<{
  file: SchemaTypes.Scalars['Upload'];
  parentId: SchemaTypes.Scalars['ID'];
  filename: SchemaTypes.Scalars['String'];
  extension: SchemaTypes.Scalars['String'];
}>;

export type CreateFileMutation = {
  __typename?: 'Mutation';
  createFile?: { __typename?: 'MutationResult'; id?: number | undefined } | undefined;
};

export type DeleteCaseFileItemsMutationVariables = SchemaTypes.Exact<{
  ids: Array<SchemaTypes.Scalars['ID']>;
}>;

export type DeleteCaseFileItemsMutation = {
  __typename?: 'Mutation';
  deleteCaseFileItemBaseBulk: Array<{ __typename?: 'MutateResult'; id?: string | undefined }>;
};

export type UpdateDirectoryMutationVariables = SchemaTypes.Exact<{
  id: SchemaTypes.Scalars['ID'];
  patch: SchemaTypes.DirectoryUpdate;
}>;

export type UpdateDirectoryMutation = {
  __typename?: 'Mutation';
  updateDirectory: { __typename?: 'MutateResult'; id?: string | undefined };
};

export type UpdateFileMutationVariables = SchemaTypes.Exact<{
  id: SchemaTypes.Scalars['ID'];
  patch: SchemaTypes.FileUpdate;
}>;

export type UpdateFileMutation = {
  __typename?: 'Mutation';
  updateFile: { __typename?: 'MutateResult'; id?: string | undefined };
};

export const GetActiveCaseFileItemDocument = gql`
  query getActiveCaseFileItem($id: ID!) {
    getCaseFileItem(id: $id) {
      ...activeFileItem
    }
  }
  ${ActiveFileItemFragmentDoc}
  ${FileItemRowFragmentDoc}
  ${CaseFileItemNameFragmentDoc}
`;

@Injectable({
  providedIn: 'root',
})
export class GetActiveCaseFileItemQueryService extends Apollo.Query<
  GetActiveCaseFileItemQuery,
  GetActiveCaseFileItemQueryVariables
> {
  document = GetActiveCaseFileItemDocument;
  client = 'graphApi';
  constructor(apollo: Apollo.Apollo) {
    super(apollo);
  }
}
export const CreateDirectoryDocument = gql`
  mutation createDirectory($directory: DirectoryCreate!) {
    createDirectory(data: $directory) {
      id
    }
  }
`;

@Injectable({
  providedIn: 'root',
})
export class CreateDirectoryMutationService extends Apollo.Mutation<
  CreateDirectoryMutation,
  CreateDirectoryMutationVariables
> {
  document = CreateDirectoryDocument;
  client = 'graphApi';
  constructor(apollo: Apollo.Apollo) {
    super(apollo);
  }
}
export const CreateFileDocument = gql`
  mutation createFile($file: Upload!, $parentId: ID!, $filename: String!, $extension: String!) {
    createFile(data: { displayName: $filename, extension: $extension, parent: $parentId, file: $file }) {
      id
    }
  }
`;

@Injectable({
  providedIn: 'root',
})
export class CreateFileMutationService extends Apollo.Mutation<CreateFileMutation, CreateFileMutationVariables> {
  document = CreateFileDocument;
  client = 'graphApi';
  constructor(apollo: Apollo.Apollo) {
    super(apollo);
  }
}
export const DeleteCaseFileItemsDocument = gql`
  mutation deleteCaseFileItems($ids: [ID!]!) {
    deleteCaseFileItemBaseBulk(ids: $ids) {
      id
    }
  }
`;

@Injectable({
  providedIn: 'root',
})
export class DeleteCaseFileItemsMutationService extends Apollo.Mutation<
  DeleteCaseFileItemsMutation,
  DeleteCaseFileItemsMutationVariables
> {
  document = DeleteCaseFileItemsDocument;
  client = 'graphApi';
  constructor(apollo: Apollo.Apollo) {
    super(apollo);
  }
}
export const UpdateDirectoryDocument = gql`
  mutation updateDirectory($id: ID!, $patch: DirectoryUpdate!) {
    updateDirectory(id: $id, data: $patch) {
      id
    }
  }
`;

@Injectable({
  providedIn: 'root',
})
export class UpdateDirectoryMutationService extends Apollo.Mutation<
  UpdateDirectoryMutation,
  UpdateDirectoryMutationVariables
> {
  document = UpdateDirectoryDocument;
  client = 'graphApi';
  constructor(apollo: Apollo.Apollo) {
    super(apollo);
  }
}
export const UpdateFileDocument = gql`
  mutation updateFile($id: ID!, $patch: FileUpdate!) {
    updateFile(id: $id, data: $patch) {
      id
    }
  }
`;

@Injectable({
  providedIn: 'root',
})
export class UpdateFileMutationService extends Apollo.Mutation<UpdateFileMutation, UpdateFileMutationVariables> {
  document = UpdateFileDocument;
  client = 'graphApi';
  constructor(apollo: Apollo.Apollo) {
    super(apollo);
  }
}
