import { Injectable } from '@angular/core';
import { FileDownloadService } from '@orion/shared-services';
import { NotificationService } from '@orion/shared/services/global';
import { ApolloResult, ApolloResultType } from '@csirtmu-orion/microframework/graphql';
import { forkJoin, Observable, of } from 'rxjs';
import { map } from 'rxjs/operators';
import { FileItemRowFileFragment, FileItemRowFragment } from '../../case-file-items';

@Injectable()
export class CaseFileDownloadService {
  constructor(private downloadService: FileDownloadService, private notification: NotificationService) {}

  download(fileItems: FileItemRowFragment[]): Observable<ApolloResult> {
    const files = fileItems.filter((item) => this.isFile(item)) as FileItemRowFileFragment[];
    if (files.length !== fileItems.length) {
      this.notification.emit(
        'warning',
        'Only file download is supported at the moment. Selected files will be download'
      );
    }
    const downloads$ = files.map((file) =>
      file.src
        ? this.downloadService.download(file.src, `${file.displayName}.${file.extension}`)
        : of(new ApolloResult(ApolloResultType.ERROR))
    );
    return forkJoin(downloads$).pipe(
      map((results) => {
        if (results.some((file) => file.type === ApolloResultType.ERROR)) {
          this.notification.emit('error', files.length > 1 ? 'Download of some files failed' : 'Download failed');
          return new ApolloResult(ApolloResultType.ERROR);
        }
        this.notification.emit(
          'success',
          files.length > 1 ? 'File was successfully downloaded' : 'Files were successfully downloaded'
        );
        return new ApolloResult(ApolloResultType.SUCCESS);
      })
    );
  }

  private isFile(fileItem: FileItemRowFragment): fileItem is FileItemRowFileFragment {
    return fileItem.__typename === 'File';
  }
}
