import { Injectable } from '@angular/core';
import { ApolloResult } from '@csirtmu-orion/microframework/graphql';
import { ENTITY_NOT_LOADING_STATE, EntityLoadingState } from '@sentinel/common/utils';
import { BehaviorSubject, Observable } from 'rxjs';
import { tap } from 'rxjs/operators';
import { FileItemRowFragment } from '../../case-file-items';
import { CaseFileViewStateService } from '../case-file-view-state.service';
import { CaseFileDownloadService } from './case-file-download.service';
import { DeleteFileItemService } from './delete-file-item.service';

@Injectable()
export class CaseFileItemsActionsService {
  constructor(
    private viewStateService: CaseFileViewStateService,
    private downloadService: CaseFileDownloadService,
    private deleteService: DeleteFileItemService
  ) {}

  private deleteInProgressSubject$: BehaviorSubject<EntityLoadingState> = new BehaviorSubject<EntityLoadingState>(
    ENTITY_NOT_LOADING_STATE
  );
  deleteInProgress$: Observable<EntityLoadingState> = this.deleteInProgressSubject$.asObservable();
  private downloadInProgressSubject$: BehaviorSubject<EntityLoadingState> = new BehaviorSubject<EntityLoadingState>(
    ENTITY_NOT_LOADING_STATE
  );
  downloadInProgress$: Observable<EntityLoadingState> = this.downloadInProgressSubject$.asObservable();

  createFile(): void {
    this.viewStateService.displayUploadFileComponent();
  }

  createDirectory(): void {
    this.viewStateService.displayCreateDirectoryComponent();
  }

  delete(fileItems: FileItemRowFragment[]): Observable<ApolloResult> {
    const ids = fileItems.map((fileItem) => fileItem.id);
    this.deleteInProgressSubject$.next({ isLoading: true, ids: ids });
    return this.deleteService.delete(ids).pipe(
      tap({
        next: () => this.deleteInProgressSubject$.next(ENTITY_NOT_LOADING_STATE),
        error: () => this.deleteInProgressSubject$.next(ENTITY_NOT_LOADING_STATE),
      })
    );
  }

  download(fileItems: FileItemRowFragment[]): Observable<ApolloResult> {
    const ids = fileItems.map((fileItem) => fileItem.id);
    this.downloadInProgressSubject$.next({ isLoading: true, ids: ids });
    return this.downloadService.download(fileItems).pipe(
      tap({
        next: () => this.downloadInProgressSubject$.next(ENTITY_NOT_LOADING_STATE),
        error: () => this.downloadInProgressSubject$.next(ENTITY_NOT_LOADING_STATE),
      })
    );
  }

  edit(id: string): void {
    this.viewStateService.edit(id);
  }
}
