import { ChangeDetectionStrategy, Component } from '@angular/core';
import { EventsFilterChipsService, FlowEventsFilterService } from '@orion/event-components/filters';
import { FlowEventFragment, RelatedFlowEventsService } from '@orion/event-components/related-flow-events';
import { FlowEventClientFilter } from '@orion/event-types';
import { FlowEventOrdEnum } from '@orion/graphql-types';
import {
  INIT_PAGINATION_EVENT_BASE_TOKEN,
  PaginationBaseInit,
  PaginationService,
  QueryParamPaginationService,
} from '@csirtmu-orion/microframework/pagination-services';
import { EntityPaginableFilterableSmartOverviewDirective } from '@csirtmu-orion/microframework/entity-smart-directives';
import { CaseRelatedFlowEventsFilterService } from './case-related-flow-events-filter.service';

@Component({
  selector: 'orion-case-related-events',
  templateUrl: './case-related-events.component.html',
  styleUrls: ['./case-related-events.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [
    RelatedFlowEventsService,
    FlowEventsFilterService,
    EventsFilterChipsService,
    { provide: PaginationService, useClass: QueryParamPaginationService },
    { provide: FlowEventsFilterService, useClass: CaseRelatedFlowEventsFilterService },
    {
      provide: INIT_PAGINATION_EVENT_BASE_TOKEN,
      useValue: new PaginationBaseInit(10, FlowEventOrdEnum.CREATED, 'desc'),
    },
  ],
})
export class CaseRelatedEventsComponent extends EntityPaginableFilterableSmartOverviewDirective<
  FlowEventFragment,
  FlowEventClientFilter
> {
  constructor(
    protected eventsService: RelatedFlowEventsService,
    protected filterService: FlowEventsFilterService,
    protected chipsService: EventsFilterChipsService,
    protected paginationService: PaginationService
  ) {
    super(eventsService, filterService, paginationService, chipsService);
  }
}
