import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap, Router } from '@angular/router';
import { CASE_PARAM_SELECTOR } from '@orion/case-paths';
import { FlowEventsFilterService } from '@orion/event-components/filters';
import { FlowEventClientFilter } from '@orion/event-types';
import { Observable } from 'rxjs';
import { concatMap, map } from 'rxjs/operators';
import { CaseNestedTaskIdsService } from '../detail/case-nested-task-ids.service';

@Injectable()
export class CaseRelatedFlowEventsFilterService extends FlowEventsFilterService {
  constructor(
    protected router: Router,
    protected activatedRoute: ActivatedRoute,
    protected caseNestedTaskIdsService: CaseNestedTaskIdsService
  ) {
    super(router, activatedRoute);
  }

  protected createFilterFromRoute(queryParamMap: ParamMap, paramMap: ParamMap): Observable<FlowEventClientFilter> {
    const caseId = paramMap.get(CASE_PARAM_SELECTOR);
    return super.createFilterFromRoute(queryParamMap, paramMap).pipe(
      concatMap((baseFilter) =>
        this.caseNestedTaskIdsService.ids$.pipe(
          map((taskIds) => {
            baseFilter.taskIds = taskIds;
            baseFilter.caseId = caseId ?? undefined;
            return baseFilter;
          })
        )
      )
    );
  }
}
