import { isLoading } from '@sentinel/common/utils';
import { Column, Row, RowAction, SentinelTable } from '@sentinel/components/table';
import { defer, of } from 'rxjs';
import { map } from 'rxjs/operators';
import { CaseRelationshipView } from './case-relationship-view';
import { CaseRelationshipActionsService } from './case-relationship.actions.service';

export class CaseRelationshipViewTable extends SentinelTable<CaseRelationshipView> {
  constructor(relationshipViews: CaseRelationshipView[], service: CaseRelationshipActionsService) {
    const columns = [
      new Column('relationshipType', 'Relationship', false),
      new Column('name', 'Name', false),
      new Column('assignees', 'Assignees', false),
      new Column('state', 'State', false),
    ];
    const rows = relationshipViews.map(
      (relationship) =>
        new Row(relationship, [
          new RowAction(
            'delete',
            'Delete',
            'clear',
            'warn',
            'Delete relationship',
            of(false),
            defer(() => service.delete(relationship.id)),
            service.deletingInProgress$.pipe(map((state) => isLoading(state, relationship.id)))
          ),
        ])
    );
    super(rows, columns);
  }
}
