import { ChangeDetectionStrategy, Component, Input, OnChanges, SimpleChanges } from '@angular/core';
import { CreateCaseRelationship } from '@orion/case-types';
import { Destroyable } from '@sentinel/common';
import { takeUntil } from 'rxjs/operators';
import { CaseRelationshipViewsResolver } from './case-relationship-type-view-resolver';
import { CaseRelationshipView } from './case-relationship-view';
import { CaseRelationshipActionsService } from './case-relationship.actions.service';
import { CaseWithRelationshipsFragment } from './graphql';
import { RelationshipAddEvent, RelationshipAddEventPayload } from './relationship-overview';

@Component({
  selector: 'orion-case-relationship',
  templateUrl: './case-relationship.component.html',
  styleUrls: ['./case-relationship.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [CaseRelationshipActionsService],
})
export class CaseRelationshipComponent extends Destroyable() implements OnChanges {
  @Input() case?: CaseWithRelationshipsFragment;
  relationshipViews?: CaseRelationshipView[];

  constructor(private relationshipActionsService: CaseRelationshipActionsService) {
    super();
  }

  ngOnChanges(changes: SimpleChanges): void {
    if ('case' in changes && this.case) {
      this.createRelationshipViews(this.case);
    }
  }

  onAddRelationship(event: RelationshipAddEvent): void {
    if (this.case) {
      const createRelationships = this.convertToCreateRelationships(event.payload, this.case.id);
      this.relationshipActionsService.create(createRelationships).pipe(takeUntil(this.destroy$)).subscribe();
    }
  }

  private createRelationshipViews(fromCase: CaseWithRelationshipsFragment): void {
    const sourceRelationships = fromCase.sourceRelationships?.data ?? [];
    const targetRelationships = fromCase.targetRelationships?.data ?? [];
    this.relationshipViews = CaseRelationshipViewsResolver.resolve(sourceRelationships, targetRelationships);
  }

  private convertToCreateRelationships(
    payload: RelationshipAddEventPayload,
    sourceId: string
  ): CreateCaseRelationship[] {
    // if reverse case-name type was selected in UI we simply swap position of source and target case
    if (payload.isReversed) {
      return payload.targetIds.map((targetId) => new CreateCaseRelationship(targetId, sourceId, payload.type));
    } else {
      return payload.targetIds.map((targetId) => new CreateCaseRelationship(sourceId, targetId, payload.type));
    }
  }
}
