import { Pipe, PipeTransform } from '@angular/core';
import { CaseRelationshipReversed } from '@orion/case-types';
import { CaseRelationshipTypeEnum } from '@orion/graphql-types';
import { CaseRelationshipViewType } from './case-relationship-view-type';

@Pipe({
  name: 'caseRelationship',
})
export class CaseRelationshipPipe implements PipeTransform {
  transform(value: CaseRelationshipViewType): string {
    const preposition = this.resolvePreposition(value);
    const verb = this.resolveVerb(value);
    const prepositionAfter = this.resolveAfterPreposition(value);
    return `${preposition} ${verb} ${prepositionAfter}`;
  }

  private resolvePreposition(value: CaseRelationshipViewType): string {
    switch (value) {
      case CaseRelationshipTypeEnum.RELATES:
      case CaseRelationshipReversed.RELATES:
      case CaseRelationshipReversed.BLOCKED:
      case CaseRelationshipReversed.DUPLICATED:
      case CaseRelationshipReversed.PART_OF:
      case CaseRelationshipReversed.REQUIRED: {
        return 'is';
      }
      default: {
        return '';
      }
    }
  }

  private resolveVerb(value: CaseRelationshipViewType): string {
    if (value === CaseRelationshipTypeEnum.RELATES || value === CaseRelationshipReversed.RELATES) {
      return 'related';
    } else {
      return value.toLocaleLowerCase();
    }
  }

  private resolveAfterPreposition(value: CaseRelationshipViewType): string {
    switch (value) {
      case CaseRelationshipReversed.BLOCKED:
      case CaseRelationshipReversed.DUPLICATED:
      case CaseRelationshipReversed.REQUIRED: {
        return 'by';
      }
      case CaseRelationshipTypeEnum.RELATES:
      case CaseRelationshipReversed.RELATES: {
        return 'to';
      }
      default: {
        return '';
      }
    }
  }
}
