import { ChangeDetectionStrategy, Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { CaseRelationshipReverseMatcher } from '@orion/case-types';
import { Observable } from 'rxjs';
import { CaseRelationshipGroup } from '../case-relationship-type-group';
import { CaseRelationshipView } from '../case-relationship-view';
import { CaseRelationshipViewStateService } from '../case-relationship-view-state.service';
import { allUniqueCaseRelationshipViewTypes, isCaseRelationship } from '../case-relationship-view-type';
import { CaseRelationshipSavedEvent } from './create-relationship';
import { RelationshipAddEvent, RelationshipAddEventPayload } from './events';

@Component({
  selector: 'orion-case-relationship-overview',
  templateUrl: './case-relationship-overview.component.html',
  styleUrls: ['./case-relationship-overview.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class CaseRelationshipOverviewComponent implements OnInit {
  @Input() caseId?: string;
  @Input() relationships?: CaseRelationshipView[];
  @Output() addRelationship: EventEmitter<RelationshipAddEvent> = new EventEmitter<RelationshipAddEvent>();
  createComponentDisplayed$?: Observable<boolean>;
  possibleRelationshipTypes = allUniqueCaseRelationshipViewTypes;

  constructor(private viewState: CaseRelationshipViewStateService) {}

  ngOnInit(): void {
    this.createComponentDisplayed$ = this.viewState.addComponentDisplayed$;
  }

  trackByFn(index: number, item: CaseRelationshipGroup): string {
    return item.type.toString();
  }

  hideCreateComponent(): void {
    this.viewState.hideAddComponent();
  }

  saveRelationship(event: CaseRelationshipSavedEvent): void {
    this.hideCreateComponent();
    let payload: RelationshipAddEventPayload;
    if (isCaseRelationship(event.type)) {
      payload = new RelationshipAddEventPayload(event.targetIds, event.type, false);
    } else {
      const reversedBackType = CaseRelationshipReverseMatcher.reverse(event.type);
      payload = new RelationshipAddEventPayload(event.targetIds, reversedBackType, true);
    }
    this.addRelationship.emit(new RelationshipAddEvent(payload));
  }
}
