import { Injectable } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { CreateCaseDTO, CreateCaseForm } from '@orion/case-types';
import { CreateEntityService } from '@orion/shared-services';
import { NotificationService } from '@orion/shared/services/global';
import { CurrentUserService } from '@orion/user-services';
import {
  ApolloOperationResultResolver,
  ApolloResult,
  createApolloContextErrorTitle,
} from '@csirtmu-orion/microframework/graphql';
import { from, Observable, of } from 'rxjs';
import { catchError, map } from 'rxjs/operators';
import { CreateCaseMutationService, CreateCaseMutationVariables } from './graphql';

@Injectable()
export class CreateCaseService extends CreateEntityService<CreateCaseForm> {
  constructor(
    protected notificationService: NotificationService,
    protected activatedRoute: ActivatedRoute,
    private router: Router,
    private activeUser: CurrentUserService,
    private createMutation: CreateCaseMutationService
  ) {
    super('Case', notificationService, activatedRoute);
  }

  protected createForm(): Observable<CreateCaseForm> {
    return of(new CreateCaseForm());
  }

  protected createEntity(form: CreateCaseForm): Observable<ApolloResult> {
    const authorId = this.activeUser.getCurrentUser()?.id;
    const createCase = new CreateCaseDTO(form.getData(), authorId);
    const vars: CreateCaseMutationVariables = { case: createCase };
    return this.createMutation.mutate(vars, { context: createApolloContextErrorTitle('Creating case') }).pipe(
      map((res) => ApolloOperationResultResolver.resolve(res)),
      catchError((err) => ApolloOperationResultResolver.handleError(err))
    );
  }

  protected handleCancel(): Observable<boolean> {
    return this.navigateToOverview();
  }

  protected onSaveError(): Observable<boolean> {
    return of(false);
  }

  protected onSaveSuccess(): Observable<boolean> {
    return this.navigateToOverview();
  }

  private navigateToOverview(): Observable<boolean> {
    return from(this.router.navigate(['../'], { relativeTo: this.activatedRoute }));
  }
}
