import { ChangeDetectionStrategy, Component, EventEmitter, OnInit, Output } from '@angular/core';
import { WorkflowTemplateOrdEnum } from '@orion/graphql-types';
import {
  WorkflowTemplateListFragment,
  WorkflowTemplateListService,
} from '@orion/workflow-components/workflow-template-selection';
import {
  INIT_PAGINATION_EVENT_BASE_TOKEN,
  PaginationBaseInit,
  PaginationService,
} from '@csirtmu-orion/microframework/pagination-services';
import { Observable } from 'rxjs';
import { map } from 'rxjs/operators';

export interface SelectedWorkflowTemplate {
  id: string;
  name?: string;
  originalName?: string;
}

@Component({
  selector: 'orion-case-link-workflow-template',
  templateUrl: './case-link-workflow-template.component.html',
  styleUrls: ['./case-link-workflow-template.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [
    WorkflowTemplateListService,
    PaginationService,
    {
      provide: INIT_PAGINATION_EVENT_BASE_TOKEN,
      useValue: new PaginationBaseInit(50, WorkflowTemplateOrdEnum.NAME, 'asc'),
    },
  ],
})
export class CaseLinkWorkflowTemplateComponent implements OnInit {
  @Output() valueChange: EventEmitter<SelectedWorkflowTemplate[]> = new EventEmitter<SelectedWorkflowTemplate[]>();
  selected: SelectedWorkflowTemplate[] = [];
  workflowTemplates$?: Observable<WorkflowTemplateListFragment[]>;
  workflowTemplatesIsLoading$?: Observable<boolean>;
  workflowTemplatesHasError$?: Observable<boolean>;

  constructor(private templatesService: WorkflowTemplateListService, private paginationService: PaginationService) {}

  ngOnInit(): void {
    this.workflowTemplates$ = this.templatesService.data$.pipe(map((paginated) => paginated.elements));
    this.workflowTemplatesIsLoading$ = this.templatesService.isLoading$;
    this.workflowTemplatesHasError$ = this.templatesService.hasError$;
  }

  onSelectionChange(selectedTemplates: WorkflowTemplateListFragment[]): void {
    this.selected = selectedTemplates.map((selected) => {
      return { id: selected.id, name: selected.name, originalName: selected.name };
    }); // need to create new objects because the fragments are read-only
    this.valueChange.emit(this.selected);
  }

  onSearch(value: string): void {
    this.templatesService.update(this.paginationService.get(), { name: value });
  }

  onSearchTryAgain(): void {
    this.templatesService.recoverAfterError();
  }

  onNameChange(): void {
    this.valueChange.emit(this.selected);
  }
}
