import { ChangeDetectionStrategy, Component, Input, OnChanges, SimpleChanges } from '@angular/core';
import { FormGroup } from '@angular/forms';
import { CreateCaseForm } from '@orion/case-types';
import { EntityFormModel } from '@orion/common';
import { CasePriorityEnum, CaseTypeEnum } from '@orion/graphql-types';
import { SelectedWorkflowTemplate } from './case-link-workflow-template';

@Component({
  selector: 'orion-create-case-form',
  templateUrl: './create-case-form.component.html',
  styleUrls: ['./create-case-form.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class CreateCaseFormComponent implements OnChanges {
  @Input() form?: CreateCaseForm;
  priorities = Object.values(CasePriorityEnum);
  caseTypes = Object.values(CaseTypeEnum);

  sharedFormGroup?: FormGroup<EntityFormModel>;

  ngOnChanges(changes: SimpleChanges): void {
    if ('form' in changes && this.form) {
      this.sharedFormGroup = this.form.formGroup as unknown as FormGroup<EntityFormModel>;
    }
  }

  onTemplateSelectionChange(workflowTemplates: SelectedWorkflowTemplate[]): void {
    this.form?.formGroup.controls.workflowTemplates.setValue(workflowTemplates);
  }
}
