import { ChangeDetectionStrategy, Component, OnInit } from '@angular/core';
import { CaseUpdate } from '@orion/graphql-types';
import {
  EditableEntityPageCanDeactivateService,
  EntityEditEventService,
  EntityEditModeService,
  PatchEntityEditService,
} from '@orion/shared-components/editable-entity';
import { EditableEntityDetailPageBaseDirective } from '@orion/shared-components/entity-base';
import { EntityEditService } from '@orion/shared-components/entity-edit';
import { tap } from 'rxjs/operators';
import { CaseDetailService } from './case-detail.service';
import { CaseNestedTaskIdsService } from './case-nested-task-ids.service';
import { CasePatchService } from './case-patch.service';
import { CaseDetailFragment } from './graphql';
import { CaseNestedStageIdsService } from './case-nested-stage-ids.service';

@Component({
  selector: 'orion-case-detail-page',
  templateUrl: './case-detail-page.component.html',
  styleUrls: ['./case-detail-page.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [
    CaseDetailService,
    CasePatchService,
    CaseNestedTaskIdsService,
    CaseNestedStageIdsService,
    EntityEditModeService,
    EntityEditEventService,
    EditableEntityPageCanDeactivateService,
    { provide: EntityEditService, useClass: PatchEntityEditService },
  ],
})
export class CaseDetailPageComponent
  extends EditableEntityDetailPageBaseDirective<CaseDetailFragment, CaseUpdate>
  implements OnInit
{
  constructor(
    protected caseService: CaseDetailService,
    protected casePatchService: CasePatchService,
    protected caseTaskIdsService: CaseNestedTaskIdsService,
    protected caseStageIdsService: CaseNestedStageIdsService,
    protected canDeactivateService: EditableEntityPageCanDeactivateService
  ) {
    super(caseService, casePatchService, canDeactivateService);
  }

  ngOnInit() {
    super.ngOnInit();
    this.entity$ = this.entityService.data$.pipe(
      tap((data) => {
        if (data) {
          this.caseTaskIdsService.update(data);
          this.caseStageIdsService.update(data);
        }
      })
    );
  }
}
