import { Injectable } from '@angular/core';
import { Observable, ReplaySubject } from 'rxjs';
import { CaseDetailFragment } from './graphql';

@Injectable()
export class CaseNestedStageIdsService {
  private idsSubject$: ReplaySubject<string[]> = new ReplaySubject<string[]>();
  ids$: Observable<string[]> = this.idsSubject$.asObservable();

  update(caseFragment: CaseDetailFragment): void {
    this.idsSubject$.next(this.getStageIds(caseFragment));
  }

  private getStageIds(caseFragment: CaseDetailFragment): string[] {
    const ids: string[] = [];
    caseFragment.workflowsWithStageIds?.data.forEach((workflow) =>
      workflow.stageIds?.data.forEach((stage) => ids.push(stage.id))
    );
    return ids;
  }
}
