import { Injectable } from '@angular/core';
import { Observable, ReplaySubject } from 'rxjs';
import { CaseDetailFragment } from './graphql';

@Injectable()
export class CaseNestedTaskIdsService {
  private idsSubject$: ReplaySubject<string[]> = new ReplaySubject<string[]>();
  ids$: Observable<string[]> = this.idsSubject$.asObservable();

  update(caseFragment: CaseDetailFragment): void {
    this.idsSubject$.next(this.getTaskIds(caseFragment));
  }

  private getTaskIds(caseFragment: CaseDetailFragment): string[] {
    const ids: string[] = [];
    caseFragment.workflowsWithTaskIds?.data.forEach((workflow) =>
      workflow.stagesWithTaskIds?.data.forEach((stage) => stage.taskIds?.data.forEach((task) => ids.push(task.id)))
    );
    return ids;
  }
}
