import { Injectable } from '@angular/core';
import { CaseStateEnum } from '@orion/graphql-types';
import { ControlsService } from '@orion/shared-services';
import { Optional } from '@sentinel/common/utils';
import { SentinelControlItem } from '@sentinel/components/controls';
import { BehaviorSubject, combineLatest, defer, Observable } from 'rxjs';
import { map } from 'rxjs/operators';
import { CaseDetailActionService } from './case-detail-action.service';
import { CaseDetailMainContentFragment } from './graphql';

@Injectable()
export class CaseDetailControlsService extends ControlsService {
  case$: BehaviorSubject<Optional<CaseDetailMainContentFragment>> = new BehaviorSubject<
    Optional<CaseDetailMainContentFragment>
  >(undefined);

  constructor(private caseActionService: CaseDetailActionService) {
    super();
    this.controls$ = this.case$.pipe(map((currCase) => (currCase ? this.createControls(currCase) : [])));
  }

  onCaseChanged(newCase: CaseDetailMainContentFragment): void {
    this.case$.next(newCase);
  }

  private createControls(currCase: CaseDetailMainContentFragment): SentinelControlItem[] {
    if (currCase.state === CaseStateEnum.OPEN || currCase.state === CaseStateEnum.IN_PROGRESS) {
      return [
        new SentinelControlItem(
          'RESOLVE_CASE',
          'Resolve',
          'primary',
          this.isDisabled(),
          defer(() => this.caseActionService.resolve(currCase.id)),
          this.caseActionService.resolveInProgress$
        ),
        new SentinelControlItem(
          'REJECT_CASE',
          'Reject',
          'primary',
          this.isDisabled(),
          defer(() => this.caseActionService.reject(currCase.id)),
          this.caseActionService.rejectInProgress$
        ),
      ];
    } else {
      return [];
    }
  }

  private isDisabled(): Observable<boolean> {
    return combineLatest([this.caseActionService.resolveInProgress$, this.caseActionService.rejectInProgress$]).pipe(
      map((progressStates) => progressStates.some((isInProgress) => isInProgress))
    );
  }
}
