import {
  ChangeDetectionStrategy,
  Component,
  EventEmitter,
  Input,
  OnChanges,
  OnInit,
  Output,
  SimpleChanges,
} from '@angular/core';
import { CaseUpdate } from '@orion/graphql-types';
import { EditableEntityPatchEvent, EntityEditModeService } from '@orion/shared-components/editable-entity';
import { EntityUpdateEvent } from '@csirtmu-orion/microframework/graphql';
import { SentinelControlItem } from '@sentinel/components/controls';
import { Observable } from 'rxjs';
import { CaseDetailActionService } from './case-detail-action.service';
import { CaseDetailControlsService } from './case-detail-controls.service';
import { CaseDetailMainContentFragment } from './graphql';

@Component({
  selector: 'orion-case-detail-main-content',
  templateUrl: './case-detail-main-content.component.html',
  styleUrls: ['./case-detail-main-content.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [CaseDetailControlsService, CaseDetailActionService],
})
export class CaseDetailMainContentComponent implements OnInit, OnChanges {
  @Input() case?: CaseDetailMainContentFragment;
  @Output() updateCase: EventEmitter<EntityUpdateEvent<CaseUpdate>> = new EventEmitter<EntityUpdateEvent<CaseUpdate>>();
  controls$?: Observable<SentinelControlItem[]>;
  editMode$?: Observable<boolean>;

  constructor(private editService: EntityEditModeService, private controlService: CaseDetailControlsService) {}

  ngOnInit(): void {
    this.controls$ = this.controlService.controls$;
    this.editMode$ = this.editService.editMode$;
  }

  ngOnChanges(changes: SimpleChanges): void {
    if ('case' in changes && this.case) {
      this.controlService.onCaseChanged(this.case);
    }
  }

  onPatch(event: EditableEntityPatchEvent): void {
    if (this.case) {
      const patchEvent: EntityUpdateEvent<CaseUpdate> = {
        id: this.case.id,
        patch: {
          name: event.name,
          description: event.description,
        },
      };
      this.updateCase.emit(patchEvent);
    }
  }
}
