import { Injectable } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { CASE_PARAM_SELECTOR } from '@orion/case-paths';
import { CommentFileRefs, EntityCommentFileUploadService } from '@orion/comment-components';
import { FilenameWithExtension } from '@orion/common';
import { NotificationService } from '@orion/shared/services/global';
import { CurrentUserService } from '@orion/user-services';
import { Observable, of, throwError } from 'rxjs';
import { concatMap } from 'rxjs/operators';
import {
  UploadCaseCommentFileMutation,
  UploadCaseCommentFileMutationService,
  UploadCaseCommentFileMutationVariables,
} from '../../graphql';

@Injectable()
export class UploadCaseCommentFileService extends EntityCommentFileUploadService<
  UploadCaseCommentFileMutation,
  UploadCaseCommentFileMutationVariables
> {
  constructor(
    protected notificationService: NotificationService,
    protected uploadMutation: UploadCaseCommentFileMutationService,
    private currUserService: CurrentUserService,
    private activatedRoute: ActivatedRoute
  ) {
    super(notificationService, uploadMutation);
  }

  protected getRefs(): Observable<CommentFileRefs> {
    const userId = this.currUserService.getCurrentUser()?.id;
    return this.activatedRoute.paramMap.pipe(
      concatMap((paramMap) => {
        const caseId = paramMap.get(CASE_PARAM_SELECTOR);
        if (userId && caseId) {
          return of({ authorId: userId, entityId: caseId });
        } else {
          return throwError('Could not retrieve author id or case id of comment');
        }
      })
    );
  }

  protected createVars(
    file: File,
    fileMeta: FilenameWithExtension,
    entityId: string,
    authorId: string
  ): UploadCaseCommentFileMutationVariables {
    return {
      caseId: entityId,
      authorId: authorId,
      file: file,
      filename: fileMeta.name,
      extension: fileMeta.extension,
    };
  }

  protected resolveUrlFromResponse(response: UploadCaseCommentFileMutation): string | undefined {
    return response.createFileFromCommentInCase?.url;
  }
}
