import {
  ChangeDetectionStrategy,
  Component,
  EventEmitter,
  Input,
  OnChanges,
  Output,
  SimpleChanges,
} from '@angular/core';
import { AssigneeListElementFragment } from '@orion/case-services';
import { CaseClientFilter } from '@orion/case-types';
import { CasePriorityEnum, CaseStateEnum, CaseTypeEnum } from '@orion/graphql-types';
import { LabelListElementFragment } from '@orion/label-services';
import { trackById } from '@sentinel/common/utils';
import { OrionFilterDirective } from '@csirtmu-orion/microframework/filters';
import { CaseFilterService } from './case-filter.service';

@Component({
  selector: 'orion-case-filters',
  templateUrl: './case-filters.component.html',
  styleUrls: ['./case-filters.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class CaseFiltersComponent extends OrionFilterDirective implements OnChanges {
  @Input() activeFilter?: CaseClientFilter;
  @Input() possibleAssignees?: AssigneeListElementFragment[];
  @Input() possibleLabels?: LabelListElementFragment[];
  @Output() searchAssignees: EventEmitter<string> = new EventEmitter<string>();
  @Output() searchLabels: EventEmitter<string> = new EventEmitter<string>();
  preselectedAssignees: AssigneeListElementFragment[] = [];
  preselectedLabels: LabelListElementFragment[] = [];

  trackByFn = trackById;
  possibleStates: CaseStateEnum[] = Object.values(CaseStateEnum);
  possibleTypes: CaseTypeEnum[] = Object.values(CaseTypeEnum);
  possiblePriorities: CasePriorityEnum[] = Object.values(CasePriorityEnum);

  constructor(protected filterService: CaseFilterService) {
    super(filterService);
  }

  ngOnChanges(changes: SimpleChanges): void {
    if ('activeFilter' in changes && this.activeFilter) {
      if (this.activeFilter.assignees) {
        this.preselectedAssignees = [...this.activeFilter.assignees];
      }
      if (this.activeFilter.labels) {
        this.preselectedLabels = [...this.activeFilter.labels];
      }
    }
  }

  onNameChange(value?: string): void {
    this.filterService.update({ name: value });
  }

  onStateChange(state?: CaseStateEnum): void {
    this.filterService.update({ state: state });
  }

  onTypeChange(type?: CaseTypeEnum): void {
    this.filterService.update({ type: type });
  }

  onDateChange(date: Date): void {
    this.filterService.update({ dueDateUntil: date });
  }

  onAssigneesChange(assignees: AssigneeListElementFragment[]): void {
    this.filterService.update({ assignees: [...assignees] });
  }

  onSearchAssignees(value: string): void {
    this.searchAssignees.emit(value);
  }

  onPriorityChange(priority?: CasePriorityEnum): void {
    this.filterService.update({ priority: priority });
  }

  onLabelChange(labels: LabelListElementFragment[]): void {
    this.filterService.update({ labels: [...labels] });
  }

  onSearchLabels(value: string): void {
    this.searchLabels.emit(value);
  }
}
