import { Injectable } from '@angular/core';
import { CaseClientFilter } from '@orion/case-types';
import { AssigneeFilterChip } from '@orion/shared-components/filters';
import { FilterChip, StringValueChip } from '@csirtmu-orion/microframework/filter';
import { FilterChipsService } from '@csirtmu-orion/microframework/filter-services';
import { DateValueChip } from '@csirtmu-orion/microframework/filters';
import { CaseFilterService } from '../case-filter.service';
import { CasePriorityFilterChip } from './case-priority-filter-chip';
import { CaseStateFilterChip } from './case-state-filter-chip';
import { CaseFilterChip } from './case-type-filter-chip';
import { LabelFilterChip } from './label-filter-chip';

@Injectable()
export class CaseFilterChipsService extends FilterChipsService<CaseClientFilter> {
  private readonly DUE_DATE_CHIP_NAME = 'Due date';
  constructor(protected filterService: CaseFilterService) {
    super(filterService);
  }

  removeChip(removedChip: FilterChip): void {
    if (removedChip instanceof StringValueChip) {
      this.filterService.updateAndSubmit({ name: undefined });
    }
    if (removedChip instanceof CaseStateFilterChip) {
      this.filterService.updateAndSubmit({ state: undefined });
    }
    if (removedChip instanceof CaseFilterChip) {
      this.filterService.updateAndSubmit({ type: undefined });
    }
    if (removedChip instanceof CasePriorityFilterChip) {
      this.filterService.updateAndSubmit({ priority: undefined });
    }
    if (removedChip instanceof LabelFilterChip) {
      this.filterService.removeLabel(removedChip.label);
    }
    if (removedChip instanceof AssigneeFilterChip) {
      this.filterService.removeAssignee(removedChip.assignee);
    }
    if (removedChip instanceof DateValueChip && removedChip.direction === 'from') {
      this.filterService.updateAndSubmit({ from: undefined });
    }
    if (removedChip instanceof DateValueChip && removedChip.direction === 'to') {
      this.filterService.updateAndSubmit({ to: undefined });
    }
    if (
      removedChip instanceof DateValueChip &&
      removedChip.direction === 'to' &&
      removedChip.name === this.DUE_DATE_CHIP_NAME
    ) {
      this.filterService.updateAndSubmit({ dueDateUntil: undefined });
    }
  }

  protected createChips(filter?: CaseClientFilter): FilterChip[] {
    if (filter === undefined || filter === this.filterService.EMPTY_FILTER) {
      return [];
    } else {
      const chips = [];
      if (filter.name) {
        chips.push(new StringValueChip(filter.name));
      }
      if (filter.state) {
        chips.push(new CaseStateFilterChip(filter.state));
      }
      if (filter.type) {
        chips.push(new CaseFilterChip(filter.type));
      }
      if (filter?.priority) {
        chips.push(new CasePriorityFilterChip(filter.priority));
      }
      if (filter?.from) {
        chips.push(new DateValueChip(filter.from, 'from'));
      }
      if (filter?.to) {
        chips.push(new DateValueChip(filter.to, 'to'));
      }
      if (filter?.dueDateUntil) {
        chips.push(new DateValueChip(filter.dueDateUntil, 'to', this.DUE_DATE_CHIP_NAME));
      }
      if (filter?.labels && filter.labels.length > 0) {
        chips.push(...filter.labels.map((label) => new LabelFilterChip(label)));
      }
      if (filter.assignees && filter.assignees.length > 0) {
        chips.push(...filter.assignees.map((assignee) => new AssigneeFilterChip(assignee)));
      }
      return chips;
    }
  }
}
