import { ChangeDetectionStrategy, Component, OnInit } from '@angular/core';
import { CaseOverviewElementFragment } from '@orion/case-components/overview';
import { CaseClientFilter } from '@orion/case-types';
import { CaseOrdEnum } from '@orion/graphql-types';
import {
  INIT_PAGINATION_EVENT_BASE_TOKEN,
  PaginationBaseInit,
  PaginationService,
  QueryParamPaginationService,
} from '@csirtmu-orion/microframework/pagination-services';
import { SentinelControlItem } from '@sentinel/components/controls';
import { EntityPaginableFilterableSmartOverviewDirective } from '@csirtmu-orion/microframework/entity-smart-directives';
import { Observable } from 'rxjs';
import { CaseFilterChipsService, CaseFilterService } from '../filters';
import { CaseControlsService } from './case-controls.service';
import { CaseOverviewService } from './case-overview.service';

@Component({
  selector: 'orion-case-overview-page',
  templateUrl: './case-overview-page.component.html',
  styleUrls: ['./case-overview-page.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [
    CaseOverviewService,
    CaseFilterChipsService,
    CaseFilterService,
    CaseControlsService,
    { provide: PaginationService, useClass: QueryParamPaginationService },
    {
      provide: INIT_PAGINATION_EVENT_BASE_TOKEN,
      useValue: new PaginationBaseInit(10, CaseOrdEnum.STATE, 'asc'),
    },
  ],
})
export class CaseOverviewPageComponent
  extends EntityPaginableFilterableSmartOverviewDirective<CaseOverviewElementFragment, CaseClientFilter>
  implements OnInit
{
  controls$?: Observable<SentinelControlItem[]>;

  constructor(
    protected casesPaginationService: PaginationService,
    protected casesService: CaseOverviewService,
    protected filterService: CaseFilterService,
    protected filterChipsService: CaseFilterChipsService,
    private controlsService: CaseControlsService
  ) {
    super(casesService, filterService, casesPaginationService, filterChipsService);
  }

  ngOnInit(): void {
    super.ngOnInit();
    this.controls$ = this.controlsService.controls$;
  }
}
