import { Injectable } from '@angular/core';
import { CaseOverviewElementFragment } from '@orion/case-components/overview';
import { CaseClientFilter, CaseFilterConverter } from '@orion/case-types';
import { CaseFilter1AndFilterEntry, CaseOrdEnum } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import { GetCaseOverviewQuery, GetCaseOverviewQueryService, GetCaseOverviewQueryVariables } from './graphql';
import { ApolloPaginatedFilterablePollingService } from '@orion/shared-services';

@Injectable()
export class CaseOverviewService extends ApolloPaginatedFilterablePollingService<
  GetCaseOverviewQuery,
  GetCaseOverviewQueryVariables,
  CaseOverviewElementFragment,
  CaseOrdEnum,
  CaseClientFilter,
  CaseFilter1AndFilterEntry
> {
  constructor(public getQuery: GetCaseOverviewQueryService) {
    super(getQuery, 'Fetching cases');
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: CaseClientFilter
  ): GetCaseOverviewQueryVariables {
    const orderVar = this.createOrderVariables(paginationEvent.sort, paginationEvent.sortDir);
    orderVar.order?.push({ o: CaseOrdEnum.LAST_UPDATED, desc: true });
    return {
      ...this.createPaginationVariables(paginationEvent),
      ...this.createFilterVariables(clientFilter),
      ...orderVar,
    };
  }

  protected createFilterConverter(): FilterConverter<CaseClientFilter, CaseFilter1AndFilterEntry[]> {
    return new CaseFilterConverter();
  }

  protected getQueryResponse(query: GetCaseOverviewQuery): CursorPaginatedResponse<CaseOverviewElementFragment> {
    return query.getCaseList;
  }

  protected strToOrderable(sort: string): Optional<CaseOrdEnum> {
    return enumFromValue(CaseOrdEnum, sort);
  }
}
