import * as SchemaTypes from '../../../../graphql/generated/base-types/base-types';

import * as Apollo from 'apollo-angular';
import { gql } from 'apollo-angular';
import { CaseOverviewElementFragmentDoc } from '../../overview/case-overview-element.fragment.generated';
import { CaseTableFragmentDoc } from '../../shared/case-table/case-table.generated';
import { UserNameAndIconFragmentDoc } from '../../../../user/components/shared/graphql/user-icon.fragment.generated';
import { CaseNameRowFragmentDoc } from '../../shared/case-table/table-rows/name-row/case-name-row.fragment.generated';
import { CaseNameFragmentDoc } from '../../shared/case-name/case-name.fragment.generated';
import { LabelChipFragmentDoc } from '../../../../label/components/shared/label/label-chip.fragment.generated';
import { Injectable } from '@angular/core';

export type GetCaseOverviewQueryVariables = SchemaTypes.Exact<{
  filter?: SchemaTypes.InputMaybe<Array<SchemaTypes.CaseFilter1AndFilterEntry>>;
  order?: SchemaTypes.InputMaybe<Array<SchemaTypes.CaseOrdEnumOrderingEntry>>;
  cursor?: SchemaTypes.InputMaybe<SchemaTypes.Scalars['String']>;
  limit?: SchemaTypes.InputMaybe<SchemaTypes.Scalars['Int']>;
}>;

export type GetCaseOverviewQuery = {
  __typename?: 'Query';
  getCaseList: {
    __typename?: 'CasePaginated';
    previous?: string | undefined;
    next?: string | undefined;
    totalCount: number;
    data: Array<{
      __typename?: 'Case';
      lastUpdated?: any | undefined;
      dueDate?: any | undefined;
      priority: SchemaTypes.CasePriorityEnum;
      state?: SchemaTypes.CaseStateEnum | undefined;
      id: string;
      name: string;
      created?: any | undefined;
      assignees?:
        | {
            __typename?: 'CaseDBUserNestedList';
            totalCount: number;
            data: Array<{ __typename?: 'CaseDBUser'; id: string; name: string; iconSrc?: string | undefined }>;
          }
        | undefined;
      labels?:
        | {
            __typename?: 'LabelNestedList';
            totalCount: number;
            data: Array<{
              __typename?: 'Label';
              id: string;
              name: string;
              backgroundColor?: string | undefined;
              textColor?: string | undefined;
            }>;
          }
        | undefined;
      createdBy?: { __typename?: 'CaseDBUser'; id: string; name: string; iconSrc?: string | undefined } | undefined;
    }>;
  };
};

export const GetCaseOverviewDocument = gql`
  query getCaseOverview(
    $filter: [CaseFilter1ANDFilterEntry!]
    $order: [CaseOrdEnumOrderingEntry!]
    $cursor: String
    $limit: Int
  ) {
    getCaseList(filter: $filter, ordering: $order, cursor: $cursor, limit: $limit) {
      data {
        ...caseOverviewElement
      }
      previous
      next
      totalCount
    }
  }
  ${CaseOverviewElementFragmentDoc}
  ${CaseTableFragmentDoc}
  ${UserNameAndIconFragmentDoc}
  ${CaseNameRowFragmentDoc}
  ${CaseNameFragmentDoc}
  ${LabelChipFragmentDoc}
`;

@Injectable({
  providedIn: 'root',
})
export class GetCaseOverviewQueryService extends Apollo.Query<GetCaseOverviewQuery, GetCaseOverviewQueryVariables> {
  document = GetCaseOverviewDocument;
  client = 'graphApi';
  constructor(apollo: Apollo.Apollo) {
    super(apollo);
  }
}
