import { ChangeDetectionStrategy, Component } from '@angular/core';
import { WorkflowTemplateOrdEnum } from '@orion/graphql-types';
import {
  AddEntityControlsService,
  AddPaginableEntityDirective,
  CreateEntityAssociationService,
} from '@orion/shared-components/related-entity-overview';
import { EntityAddAssociationService } from '@orion/shared-services';
import {
  WorkflowTemplateListFragment,
  WorkflowTemplateListService,
} from '@orion/workflow-components/workflow-template-selection';
import { WorkflowTemplateClientFilter } from '@orion/workflow-template-types';
import {
  INIT_PAGINATION_EVENT_BASE_TOKEN,
  PaginationBaseInit,
  PaginationService,
} from '@csirtmu-orion/microframework/pagination-services';
import { CaseWorkflowTemplateFilterService } from '../services';

export interface WorkflowTemplateWithOptionalName {
  id: string;
  selectedName?: string;
}

@Component({
  selector: 'orion-add-workflow-from-template',
  templateUrl: './add-workflow-from-template.component.html',
  styleUrls: ['./add-workflow-from-template.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [
    PaginationService,
    AddEntityControlsService,
    WorkflowTemplateListService,
    CaseWorkflowTemplateFilterService,
    {
      provide: INIT_PAGINATION_EVENT_BASE_TOKEN,
      useValue: new PaginationBaseInit(50, WorkflowTemplateOrdEnum.NAME, 'asc'),
    },
  ],
})
export class AddWorkflowFromTemplateComponent extends AddPaginableEntityDirective<
  WorkflowTemplateListFragment,
  WorkflowTemplateClientFilter
> {
  name?: string;
  private lastSelection?: WorkflowTemplateListFragment;
  constructor(
    protected selectionService: EntityAddAssociationService<WorkflowTemplateWithOptionalName>,
    protected controlsService: AddEntityControlsService,
    protected paginationService: PaginationService,
    protected filterService: CaseWorkflowTemplateFilterService,
    protected workflowTemplatesService: WorkflowTemplateListService,
    protected addEntityService: CreateEntityAssociationService
  ) {
    super(
      selectionService,
      controlsService,
      paginationService,
      filterService,
      workflowTemplatesService,
      addEntityService
    );
  }

  onNameChanged(name?: string): void {
    this.name = name;
    if (this.lastSelection) {
      this.selectionService.select([{ id: this.lastSelection.id, selectedName: name }]);
    }
  }

  onSingleSelectionChange(selection?: WorkflowTemplateListFragment): void {
    this.lastSelection = selection;
    if (selection) {
      this.selectionService.select([{ id: selection.id, selectedName: this.name }]);
    } else {
      this.selectionService.select([]);
    }
  }

  protected createFilter(searchValue: string): WorkflowTemplateClientFilter {
    return { name: searchValue };
  }
}
