import { ChangeDetectionStrategy, Component, Input, OnInit, SimpleChanges } from '@angular/core';
import {
  CreateAssociationViewStateService,
  CreateEntityAssociationService,
} from '@orion/shared-components/related-entity-overview';
import { EntityAddAssociationService } from '@orion/shared-services';
import { Observable } from 'rxjs';
import { CaseWorkflowsPanelFragment } from './graphql';
import { CaseWorkflowFromTemplateService, WorkflowPanelControlsService } from './services';
import { SentinelControlItem } from '@sentinel/components/controls';

@Component({
  selector: 'orion-case-workflows-panel',
  templateUrl: './case-workflows-panel.component.html',
  styleUrls: ['./case-workflows-panel.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [
    CreateAssociationViewStateService,
    EntityAddAssociationService,
    WorkflowPanelControlsService,
    { provide: CreateEntityAssociationService, useClass: CaseWorkflowFromTemplateService },
  ],
})
export class CaseWorkflowsPanelComponent implements OnInit {
  @Input() case?: CaseWorkflowsPanelFragment;
  displayedAddComponent$?: Observable<boolean>;
  controls$?: Observable<SentinelControlItem[]>;
  isExpanded = false;
  progress?: number;

  constructor(
    private viewStateService: CreateAssociationViewStateService,
    private controlService: WorkflowPanelControlsService
  ) {}

  ngOnInit(): void {
    this.displayedAddComponent$ = this.viewStateService.displayedAddComponent$;
    this.controls$ = this.controlService.controls$;
  }

  ngOnChanges(changes: SimpleChanges): void {
    if ('case' in changes && this.case?.workflows) {
      this.controlService.setWorkflowParent(this.case);
      this.isExpanded = this.case.workflows.data.length > 0;
      this.progress = this.calculateProgress();
    }
  }

  private calculateProgress(): number {
    const totalProgress =
      this.case?.workflows?.data
        .map((workflow) => workflow.progress ?? 0)
        .reduce((progressA, progressB) => progressA + progressB, 0) ?? 0;
    const workflowCount = this.case?.workflows?.data?.length ?? 0;
    if (workflowCount === 0) {
      return 0;
    } else {
      return Math.floor(totalProgress / workflowCount);
    }
  }
}
