import { Injectable } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { namedOperations } from '@orion/named-operations';
import {
  CreateAssociationViewStateService,
  CreateAssociationWithCaseService,
} from '@orion/shared-components/related-entity-overview';
import { EntityAddAssociationService } from '@orion/shared-services';
import {
  ApolloOperationResultResolver,
  ApolloResult,
  ApolloResultType,
  createApolloContextErrorTitle,
} from '@csirtmu-orion/microframework/graphql';
import { Observable, of } from 'rxjs';
import { catchError, map, tap } from 'rxjs/operators';
import { WorkflowTemplateWithOptionalName } from '../add-workflow-from-template';
import { CreateWorkflowFromTemplateMutationService, CreateWorkflowFromTemplateMutationVariables } from '../graphql';

@Injectable()
export class CaseWorkflowFromTemplateService extends CreateAssociationWithCaseService {
  constructor(
    protected viewService: CreateAssociationViewStateService,
    protected activatedRoute: ActivatedRoute,

    private selectionService: EntityAddAssociationService<WorkflowTemplateWithOptionalName>,
    private createFromTemplateMutation: CreateWorkflowFromTemplateMutationService
  ) {
    super(viewService, activatedRoute);
    this.operationName = 'Creating workflow from template';
  }

  protected createAssociation(relatedCaseId: string): Observable<ApolloResult> {
    const selection = this.selectionService.save().add;
    if (selection.length === 0 || selection.length > 1) {
      return of(new ApolloResult(ApolloResultType.ERROR));
    } else {
      const workflowTemplateId = selection[0].id;
      const workflowName = selection[0].selectedName;
      const vars: CreateWorkflowFromTemplateMutationVariables = {
        caseId: relatedCaseId,
        workflowTemplateId: workflowTemplateId,
        workflowName: workflowName,
      };
      return this.createFromTemplateMutation
        .mutate(vars, {
          refetchQueries: [namedOperations.Query.getCaseDetail],
          awaitRefetchQueries: true,
          context: createApolloContextErrorTitle('Creating workflow from template'),
        })
        .pipe(
          map((res) => ApolloOperationResultResolver.resolve(res)),
          tap((res) => this.handleLinkResult(res)),
          catchError((err) => ApolloOperationResultResolver.handleError(err))
        );
    }
  }
}
