import { ActivatedRoute, Router } from '@angular/router';
import { CaseNameFragment } from '@orion/case-components/shared';
import { CreateAssociationViewStateService } from '@orion/shared-components/related-entity-overview';
import { ControlsService } from '@orion/shared-services';
import { WorkflowNavigator } from '@orion/workflow-services';
import {
  SentinelControlItem,
  SentinelControlMenuItem,
  SentinelExpandableControlItem,
} from '@sentinel/components/controls';
import { defer, EMPTY, from, Observable, of } from 'rxjs';
import { Injectable } from '@angular/core';

@Injectable()
export class WorkflowPanelControlsService extends ControlsService {
  private workflowParent?: CaseNameFragment;

  constructor(
    protected workflowPanelView: CreateAssociationViewStateService,
    protected router: Router,
    protected activatedRoute: ActivatedRoute,
    protected workflowRouter: WorkflowNavigator
  ) {
    super();
    this.controls$ = of(this.createControls());
  }

  setWorkflowParent(parent: CaseNameFragment): void {
    this.workflowParent = parent;
  }

  protected createControls(): SentinelControlItem[] {
    return this.createSharedControls();
  }

  protected createWorkflow(): Observable<boolean> {
    if (this.workflowParent) {
      return from(
        this.router.navigate([this.workflowRouter.toCreate(this.workflowParent)], { relativeTo: this.activatedRoute })
      );
    }
    return EMPTY;
  }

  protected addWorkflow(): void {
    this.workflowPanelView.displayAddComponent();
  }

  private createSharedControls(): SentinelControlItem[] {
    return [
      new SentinelExpandableControlItem('ADD', 'Add', 'primary', of(false), [
        new SentinelControlMenuItem(
          'CREATE_WORKFLOW',
          'Create workflow',
          'primary',
          of(false),
          defer(() => this.createWorkflow()),
          'playlist_add'
        ),
        new SentinelControlMenuItem(
          'ADD_WORKFLOW',
          'Add workflow from template',
          'primary',
          of(false),
          defer(() => this.addWorkflow()),
          'post_add'
        ),
      ]),
    ];
  }
}
