import { ChangeDetectionStrategy, Component, Input, OnChanges, SimpleChanges } from '@angular/core';
import {
  CaseRelationshipControlsService,
  CaseRelationshipViewStateService,
} from '@orion/case-components/case-relationship';
import { SentinelControlItem } from '@sentinel/components/controls';
import { Observable } from 'rxjs';
import { CaseLinkedCasesPanelFragment } from './case-linked-cases-panel.fragment.generated';

@Component({
  selector: 'orion-linked-cases-panel',
  templateUrl: './linked-cases-panel.component.html',
  styleUrls: ['./linked-cases-panel.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [CaseRelationshipControlsService, CaseRelationshipViewStateService],
})
export class LinkedCasesPanelComponent implements OnChanges {
  @Input() case?: CaseLinkedCasesPanelFragment;
  linkedCasesCount = 0;
  controls$?: Observable<SentinelControlItem[]>;

  constructor(private controlsService: CaseRelationshipControlsService) {
    this.controls$ = this.controlsService.controls$;
  }

  ngOnChanges(changes: SimpleChanges): void {
    if ('case' in changes && this.case) {
      this.linkedCasesCount = this.resolveLinkedCasesCount(this.case);
    }
  }

  resolveLinkedCasesCount(caseToResolve: CaseLinkedCasesPanelFragment): number {
    const sourceRelCount = caseToResolve?.sourceRelationships?.totalCount ?? 0;
    const targetRelCount = caseToResolve?.targetRelationships?.totalCount ?? 0;
    return sourceRelCount + targetRelCount;
  }
}
