import { Injectable } from '@angular/core';
import { CaseOverviewElementFragment } from '@orion/case-components/overview';
import { RelatedCaseFilter, RelatedCaseFilterConverter } from '@orion/case-types';
import { CaseFilterAndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { GetRelatedCasesQuery, GetRelatedCasesQueryService, GetRelatedCasesQueryVariables } from './graphql';
import { ApolloFilterablePollingService } from '@orion/shared-services';

@Injectable()
export class RelatedCaseService extends ApolloFilterablePollingService<
  GetRelatedCasesQuery,
  GetRelatedCasesQueryVariables,
  CaseOverviewElementFragment,
  RelatedCaseFilter,
  CaseFilterAndFilterEntry[]
> {
  public constructor(public getQuery: GetRelatedCasesQueryService) {
    super(getQuery, 'Fetching related cases');
  }

  protected createFilterConverter(): FilterConverter<RelatedCaseFilter, CaseFilterAndFilterEntry[]> {
    return new RelatedCaseFilterConverter();
  }

  protected createVariables(clientFilter: RelatedCaseFilter): GetRelatedCasesQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected toFragments(query: GetRelatedCasesQuery): CaseOverviewElementFragment[] {
    return query?.getCaseByFederatedEntity?.data ?? [];
  }
}
