import { Injectable } from '@angular/core';
import { CaseClientFilter, CaseFilterConverter } from '@orion/case-types';
import { CaseFilter1AndFilterEntry, CaseOrdEnum } from '@orion/graphql-types';
import { ApolloPaginatedFilterableService } from '@csirtmu-orion/microframework/apollo-services';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import {
  CaseListElementFragment,
  GetCaseListQuery,
  GetCaseListQueryService,
  GetCaseListQueryVariables,
} from './graphql';

@Injectable()
export class CaseListService extends ApolloPaginatedFilterableService<
  GetCaseListQuery,
  GetCaseListQueryVariables,
  CaseListElementFragment,
  CaseOrdEnum,
  CaseClientFilter,
  CaseFilter1AndFilterEntry
> {
  constructor(public getQuery: GetCaseListQueryService) {
    super(getQuery, 'Fetching cases');
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: CaseClientFilter
  ): GetCaseListQueryVariables {
    return {
      ...this.createPaginationVariables(paginationEvent),
      ...this.createOrderVariables(paginationEvent.sort, paginationEvent.sortDir),
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected createFilterConverter(): FilterConverter<CaseClientFilter, CaseFilter1AndFilterEntry[]> {
    return new CaseFilterConverter();
  }

  protected getQueryResponse(query: GetCaseListQuery): CursorPaginatedResponse<CaseListElementFragment> {
    return query?.getCaseList;
  }

  protected strToOrderable(sort: string): Optional<CaseOrdEnum> {
    return enumFromValue(CaseOrdEnum, sort);
  }
}
