import { ChangeDetectionStrategy, Component, EventEmitter, Input, Output } from '@angular/core';
import { CasePriorityEnum, CaseStateEnum } from '@orion/graphql-types';
import { LabelChipFragment } from '@orion/label-components/shared';
import { TimeService } from '@orion/shared/services/global';
import { IPaginatedElements } from '@sentinel/common/pagination';
import { OptionallyPaginatedEntityTableDirective } from '@csirtmu-orion/microframework/entity-smart-directives';
import { trackByIdTableRow } from '@sentinel/components/table';
import { Observable } from 'rxjs';
import { CaseTable } from './case-table';
import { CaseTableFragment } from './case-table.generated';

@Component({
  selector: 'orion-case-table',
  templateUrl: './case-table.component.html',
  styleUrls: ['./case-table.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class CaseTableComponent extends OptionallyPaginatedEntityTableDirective<CaseTableFragment, CaseTable> {
  @Input() sortable = true;
  @Output() labelClicked: EventEmitter<LabelChipFragment> = new EventEmitter<LabelChipFragment>();
  @Output() priorityClicked: EventEmitter<CasePriorityEnum> = new EventEmitter<CasePriorityEnum>();
  @Output() stateClicked: EventEmitter<CaseStateEnum> = new EventEmitter<CaseStateEnum>();

  trackByFn = trackByIdTableRow;
  today$: Observable<Date>;
  tableData?: CaseTable;

  constructor(private timeService: TimeService) {
    super();
    this.today$ = this.timeService.today$;
  }

  protected createTable(entities: IPaginatedElements<CaseTableFragment> | CaseTableFragment[]): CaseTable {
    return new CaseTable(entities, this.sortable);
  }

  onLabelClicked(label: LabelChipFragment): void {
    this.labelClicked.emit(label);
  }

  onPriorityClicked(priority: CasePriorityEnum): void {
    this.priorityClicked.emit(priority);
  }

  onStateClicked(state: CaseStateEnum): void {
    this.stateClicked.emit(state);
  }
}
