import { Directive, EventEmitter, Input, OnChanges, Output, SimpleChanges } from '@angular/core';
import { EntityAssociationService } from '@orion/shared-services';
import { EntityOperationEvent, IResourceRef } from '@sentinel/common/entity';

@Directive()
export abstract class EditableSelectionDirective<T extends IResourceRef> implements OnChanges {
  @Input() isEditable = true;
  @Input() selectedEntities: T[] = [];
  @Input() entitiesToSelect: T[] = [];
  @Input() isLoading = false;
  @Input() hasError = false;
  @Output() search: EventEmitter<string> = new EventEmitter<string>();
  @Output() searchTryAgain: EventEmitter<void> = new EventEmitter<void>();
  @Output() save: EventEmitter<EntityOperationEvent<T>> = new EventEmitter<EntityOperationEvent<T>>();

  preselected: T[] = [];
  saveDisabled = true;

  protected constructor(public selectionService: EntityAssociationService<T>) {}

  ngOnChanges(changes: SimpleChanges): void {
    if ('selectedEntities' in changes && this.selectedEntities) {
      this.preselect(this.selectedEntities);
    }
  }

  onChangesSaved(): void {
    this.saveDisabled = true;
    const saveResult = this.selectionService.save();
    this.save.emit(saveResult);
  }

  onSelectionChange(selected: T[]): void {
    this.selectionService.select(selected);
    this.saveDisabled = false;
  }

  onChangesCancelled(): void {
    this.preselect(this.selectedEntities);
  }

  onSearch(value: string): void {
    this.search.emit(value);
  }

  onSearchTryAgain(): void {
    this.searchTryAgain.emit();
  }

  private preselect(resources: T[]): void {
    this.preselected = [...resources];
  }
}
