import { Injectable } from '@angular/core';
import { CaseDbUserFilter1AndFilterEntry, CaseDbUserOrdEnum } from '@orion/graphql-types';
import { UserClientFilter, UserFilterConverter } from '@orion/user-types';
import { ApolloPaginatedFilterableService } from '@csirtmu-orion/microframework/apollo-services';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import { AssigneeListElementFragment } from './assignee-list-element.fragment.generated';
import {
  GetAssigneeListQuery,
  GetAssigneeListQueryService,
  GetAssigneeListQueryVariables,
} from './assignee-list.operation.generated';

@Injectable()
export class AssigneesListService extends ApolloPaginatedFilterableService<
  GetAssigneeListQuery,
  GetAssigneeListQueryVariables,
  AssigneeListElementFragment,
  CaseDbUserOrdEnum,
  UserClientFilter,
  CaseDbUserFilter1AndFilterEntry
> {
  constructor(public getQuery: GetAssigneeListQueryService) {
    super(getQuery, 'Fetching assignees');
  }

  protected strToOrderable(sort: string): Optional<CaseDbUserOrdEnum> {
    return enumFromValue(CaseDbUserOrdEnum, sort);
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: UserClientFilter
  ): GetAssigneeListQueryVariables {
    return {
      ...this.createPaginationVariables(paginationEvent),
      ...this.createOrderVariables(paginationEvent.sort, paginationEvent.sortDir),
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected createFilterConverter(): FilterConverter<UserClientFilter, CaseDbUserFilter1AndFilterEntry[]> {
    return new UserFilterConverter();
  }

  protected getQueryResponse(query: GetAssigneeListQuery): CursorPaginatedResponse<AssigneeListElementFragment> {
    return query?.getCaseDbUserList;
  }
}
