import { FormControl, FormGroup } from '@angular/forms';
import { defaultEntityControls, EntityFormModel } from '@orion/common';
import { CasePriorityEnum, CaseTypeEnum } from '@orion/graphql-types';
import { BaseReactiveForm, SentinelValidators } from '@sentinel/common';
import { CreateCaseData, ImportWorkflowTemplate } from './create-case-data';

export interface CreateCaseFormModel extends EntityFormModel {
  priority: FormControl<CasePriorityEnum>;
  type: FormControl<CaseTypeEnum>;
  workflowTemplates: FormControl<ImportWorkflowTemplate[]>;
}

export class CreateCaseForm extends BaseReactiveForm<CreateCaseFormModel> {
  constructor() {
    const formGroup = new FormGroup<CreateCaseFormModel>({
      ...defaultEntityControls(),
      priority: new FormControl<CasePriorityEnum>(CasePriorityEnum.MEDIUM, {
        nonNullable: true,
        initialValueIsDefault: true,
      }),
      type: new FormControl<CaseTypeEnum>(CaseTypeEnum.INCIDENT, { nonNullable: true, initialValueIsDefault: true }),
      workflowTemplates: new FormControl<ImportWorkflowTemplate[]>([], {
        nonNullable: true,
        initialValueIsDefault: true,
      }),
    });
    formGroup.controls.priority.setValidators([SentinelValidators.required]);
    formGroup.controls.type.setValidators([SentinelValidators.required]);
    super(formGroup);
  }

  getData(): CreateCaseData {
    return {
      name: this.formGroup.controls.name.value,
      description: this.formGroup.controls.description.value,
      priority: this.formGroup.controls.priority.value,
      type: this.formGroup.controls.type.value,
      workflowTemplates: this.formGroup.controls.workflowTemplates.value,
    };
  }
}
