import { RelationOperation, RelationUpdate } from '@orion/graphql-types';
import {
  EntityOperationEvent,
  IResourceRef,
  isAdditionEvent,
  isRemovalEvent,
  isSetEvent,
} from '@sentinel/common/entity';

export class EntityOperationEventToRelationUpdateConverter {
  static convert(event: EntityOperationEvent<IResourceRef>): RelationUpdate {
    if (isSetEvent(event)) {
      return { ids: event.set.map((entity) => entity.id), op: RelationOperation.SET };
    } else if (isAdditionEvent(event)) {
      return { ids: event.add.map((entity) => entity.id), op: RelationOperation.ADD };
    } else if (isRemovalEvent(event)) {
      return { ids: event.remove.map((entity) => entity.id), op: RelationOperation.REM };
    } else {
      throw new Error('EntityOperationEvent of unsupported type');
    }
  }
}
