import { convertDateTimeFilter } from '@orion/common';
import { CaseFilter1, CaseFilter1AndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CaseClientFilter } from './case-client-filter';

export class CaseFilterConverter implements FilterConverter<CaseClientFilter, CaseFilter1AndFilterEntry[]> {
  convert(clientFilter?: CaseClientFilter): CaseFilter1AndFilterEntry[] {
    return CaseFilterConverter.toCaseFilter(clientFilter);
  }

  static toCaseFilter(clientFilter?: CaseClientFilter): CaseFilter1AndFilterEntry[] {
    const andFilter: CaseFilter1 = {};
    if (clientFilter?.id) {
      andFilter.id = { exact: clientFilter.id };
    }
    if (clientFilter?.name) {
      andFilter.name = { icontains: clientFilter.name };
    }
    if (clientFilter?.exceptId) {
      andFilter.id = { ...andFilter?.id, except_: clientFilter.exceptId };
    }
    if (clientFilter?.externalReferenceId) {
      andFilter.externalReferences = { id: { exact: clientFilter.externalReferenceId } };
    }
    if (clientFilter?.state) {
      andFilter.state = { exact: clientFilter.state };
    }
    if (clientFilter?.type) {
      andFilter.type = { exact: clientFilter.type };
    }
    if (clientFilter?.priority) {
      andFilter.priority = { exact: clientFilter.priority };
    }
    if (clientFilter?.from || clientFilter?.to) {
      andFilter.created = convertDateTimeFilter(clientFilter);
    }
    if (clientFilter?.dueDateUntil) {
      andFilter.dueDate = { lte: clientFilter.dueDateUntil.toISOString() };
    }
    if (clientFilter?.labels) {
      andFilter.labels = { id: { in_: clientFilter.labels.map((label) => label.id) } };
    }
    if (clientFilter?.assignees) {
      andFilter.assignees = { id: { in_: clientFilter.assignees.map((assignee) => assignee.id) } };
    }
    if (clientFilter?.idOrName) {
      const isNumber = !Number.isNaN(Number.parseInt(clientFilter.idOrName));
      if (isNumber) {
        return [
          {
            AND: [
              { OR: andFilter },
              { OR: { id: { exact: clientFilter.idOrName } } },
              { OR: { name: { icontains: clientFilter.idOrName } } },
            ],
          },
        ];
      } else {
        return [
          {
            AND: [{ OR: andFilter }, { OR: { name: { icontains: clientFilter.idOrName } } }],
          },
        ];
      }
    } else {
      return [{ AND: [{ OR: andFilter }] }];
    }
  }
}
