import { convertDateTimeFilter } from '@orion/common';
import {
  CaseManagementExternalReferenceFilter1,
  CaseManagementExternalReferenceFilter1AndFilterEntry,
} from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { ExternalReferenceClientFilter } from './external-reference-client-filter';

export class ExternalReferenceFilterConverter
  implements FilterConverter<ExternalReferenceClientFilter, CaseManagementExternalReferenceFilter1AndFilterEntry[]>
{
  convert(clientFilter: ExternalReferenceClientFilter): CaseManagementExternalReferenceFilter1AndFilterEntry[] {
    const mainAndFilter: CaseManagementExternalReferenceFilter1 = {};
    if (clientFilter.from || clientFilter.to) {
      mainAndFilter.created = convertDateTimeFilter(clientFilter);
    }
    if (clientFilter.category) {
      mainAndFilter.category = { exact: clientFilter.category };
    }
    if (clientFilter.url) {
      mainAndFilter.url = { icontains: clientFilter.url };
    }
    if (clientFilter.caseId && clientFilter.taskIds) {
      return [
        {
          AND: [
            { OR: { relatedCases: { id: { exact: clientFilter.caseId } }, ...mainAndFilter } },
            { OR: { relatedTasks: { id: { in_: clientFilter.taskIds } }, ...mainAndFilter } },
          ],
        },
      ];
    } else if (clientFilter.caseId) {
      mainAndFilter.relatedCases = { id: { exact: clientFilter.caseId } };
    } else if (clientFilter.taskIds) {
      mainAndFilter.relatedTasks = { id: { in_: clientFilter.taskIds } };
    }
    if (clientFilter?.idOrUrl) {
      const isNumber = !Number.isNaN(Number.parseInt(clientFilter.idOrUrl));
      if (isNumber) {
        return [
          {
            AND: [
              { OR: mainAndFilter },
              { OR: { id: { exact: clientFilter.idOrUrl } } },
              { OR: { url: { icontains: clientFilter.idOrUrl } } },
            ],
          },
        ];
      } else {
        return [
          {
            AND: [{ OR: mainAndFilter }, { OR: { url: { icontains: clientFilter.idOrUrl } } }],
          },
        ];
      }
    }
    return [
      {
        AND: [{ OR: mainAndFilter }],
      },
    ];
  }
}
