import { ChangeDetectionStrategy, Component } from '@angular/core';
import { AssetListService } from '@orion/asset-components/related-assets';
import { AssetSelectionFragment } from '@orion/asset-components/selection';
import { AssetClientFilter } from '@orion/asset-types';
import { KnownAssetsEnum } from '@orion/graphql-types';
import { enumFromValue } from '@sentinel/common/utils';
import { TagPopupDirectiveSansPagination } from '../tag-popup.directive';

@Component({
  selector: 'orion-asset-tag-popup',
  templateUrl: './asset-tag-popup.component.html',
  styleUrls: ['./asset-tag-popup.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [AssetListService],
})
export class AssetTagPopupComponent extends TagPopupDirectiveSansPagination<AssetSelectionFragment, AssetClientFilter> {
  constructor(protected assetListService: AssetListService) {
    super(assetListService);
  }

  protected createFilter(value: string): AssetClientFilter {
    if (value.includes('/')) {
      const splitOnTypeKeyChar = value.split('/');
      const maybeType = splitOnTypeKeyChar[0];
      const maybeIdOrName = splitOnTypeKeyChar[1];
      const type = enumFromValue(KnownAssetsEnum, maybeType);
      if (type) {
        return {
          type: type,
          idOrTermSearch: maybeIdOrName,
        };
      }
    }
    return { idOrTermSearch: value };
  }
}
