import { Directive, EventEmitter, Input, OnChanges, OnInit, Output, SimpleChanges } from '@angular/core';
import {
  ApolloFilterableService,
  ApolloPaginatedFilterableBaseService,
} from '@csirtmu-orion/microframework/apollo-services';
import { ICursorPaginationEvent } from '@sentinel/common/pagination';
import { Observable } from 'rxjs';
import { map } from 'rxjs/operators';

@Directive()
export abstract class TagPopupDirective<Fragment, Filter> implements OnInit, OnChanges {
  @Input() searchValue?: string;
  @Output() tagSelected: EventEmitter<string> = new EventEmitter<string>();
  sortBy?: string;
  sortDir?: 'asc' | 'desc' = 'asc';
  searchResults$?: Observable<Fragment[]>;

  protected abstract createFilter(value: string): Filter;

  protected constructor(
    // No point in introducing a generic for query, query variables, orderable, and api filter in this component
    // as the types context doesn't matter to this component.
    // eslint-disable-next-line
    protected entityService: ApolloPaginatedFilterableBaseService<any, any, Fragment, any, Filter, any>
  ) {}

  ngOnInit(): void {
    this.searchResults$ = this.entityService.data$.pipe(map((paginated) => paginated.elements));
    this.onSearch('');
  }

  ngOnChanges(changes: SimpleChanges): void {
    if ('searchValue' in changes && this.searchValue) {
      this.onSearch(this.searchValue);
    }
  }

  onSelected(value: string): void {
    this.tagSelected.emit(value);
  }

  onSearch(value: string): void {
    const pagination: ICursorPaginationEvent = { size: 20, sort: this.sortBy, sortDir: this.sortDir, cursor: null };
    const filter = this.createFilter(value);
    this.entityService.update(pagination, filter);
  }
}

@Directive()
export abstract class TagPopupDirectiveSansPagination<Fragment, Filter> implements OnInit, OnChanges {
  @Input() searchValue?: string;
  @Output() tagSelected: EventEmitter<string> = new EventEmitter<string>();
  searchResults$?: Observable<Fragment[]>;

  protected abstract createFilter(value: string): Filter;

  protected constructor(
    // No point in introducing a generic for query, query variables, and api filter in this component
    // as the types context doesn't matter to this component.
    // eslint-disable-next-line
    protected entityService: ApolloFilterableService<any, any, Fragment, Filter, any>
  ) {}

  ngOnInit(): void {
    this.searchResults$ = this.entityService.data$;
    this.onSearch('');
  }

  ngOnChanges(changes: SimpleChanges): void {
    if ('searchValue' in changes && this.searchValue) {
      this.onSearch(this.searchValue);
    }
  }

  onSelected(value: string): void {
    this.tagSelected.emit(value);
  }

  onSearch(value: string): void {
    const filter = this.createFilter(value);
    this.entityService.update(filter);
  }
}
