import { ChangeDetectionStrategy, Component, EventEmitter, Input, Output } from '@angular/core';
import { AddCommentEvent, CommentEvent } from '@orion/comment-types';
import { ENTITY_NOT_LOADING_STATE, EntityLoadingState, trackById } from '@sentinel/common/utils';
import { TopLevelCommentFragment } from './top-level-comment';

@Component({
  selector: 'orion-comment-list',
  templateUrl: './comment-list.component.html',
  styleUrls: ['./comment-list.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class CommentListComponent {
  @Input() comments?: TopLevelCommentFragment[];
  @Input() currUserId?: string;
  @Input() canWriteComment = false;
  @Input() showMoreDisplayed = false;
  @Input() isLoading = false;
  @Input() addingInProgress = false;
  @Input() updatingInProgress: EntityLoadingState = ENTITY_NOT_LOADING_STATE;
  @Input() deletingInProgress: EntityLoadingState = ENTITY_NOT_LOADING_STATE;
  @Output() commentEvent: EventEmitter<CommentEvent> = new EventEmitter<CommentEvent>();
  @Output() showMore: EventEmitter<void> = new EventEmitter<void>();

  trackByFn = trackById;

  onCommentEvent(event: CommentEvent): void {
    this.commentEvent.emit(event);
  }

  onAddComment(content: string): void {
    this.onCommentEvent(new AddCommentEvent(content));
  }

  onShowMore(): void {
    this.showMore.emit();
  }
}
