import { ChangeDetectionStrategy, Component, EventEmitter, Input, Output } from '@angular/core';
import { AddCommentEvent, CommentEvent } from '@orion/comment-types';
import { ENTITY_NOT_LOADING_STATE, EntityLoadingState, trackById } from '@sentinel/common/utils';
import { CommentReplyFragment } from './comment-reply';

@Component({
  selector: 'orion-comment-replies',
  templateUrl: './comment-replies.component.html',
  styleUrls: ['./comment-replies.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class CommentRepliesComponent {
  @Input() currUserId?: string;
  @Input() autosaveIdToken?: string;
  @Input() comments?: CommentReplyFragment[];
  @Input() updatingInProgress: EntityLoadingState = ENTITY_NOT_LOADING_STATE;
  @Input() deletingInProgress: EntityLoadingState = ENTITY_NOT_LOADING_STATE;
  @Output() commentEvent: EventEmitter<CommentEvent> = new EventEmitter<CommentEvent>();
  @Output() addReply: EventEmitter<AddCommentEvent> = new EventEmitter<AddCommentEvent>();
  displayFullReplyInput = false;
  trackByFn = trackById;

  onReplyInputClicked(): void {
    this.displayFullReplyInput = true;
  }

  onCancelReply(): void {
    this.displayFullReplyInput = false;
  }

  onAddComment(content: string): void {
    this.addReply.emit(new AddCommentEvent(content));
  }

  onCommentEvent(event: CommentEvent): void {
    this.commentEvent.emit(event);
  }
}
