import { ChangeDetectionStrategy, Component, Input } from '@angular/core';
import { CommentActionType, CommentEvent } from '@orion/comment-types';
import { ENTITY_NOT_LOADING_STATE, EntityLoadingState } from '@sentinel/common/utils';
import { SmartCommentDirective } from './shared';
import { TopLevelCommentFragment } from './top-level-comment.fragment.generated';

@Component({
  selector: 'orion-top-level-comment',
  templateUrl: './top-level-comment.component.html',
  styleUrls: ['./top-level-comment.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class TopLevelCommentComponent extends SmartCommentDirective<TopLevelCommentFragment> {
  @Input() updatingInProgress: EntityLoadingState = ENTITY_NOT_LOADING_STATE;
  @Input() deletingInProgress: EntityLoadingState = ENTITY_NOT_LOADING_STATE;

  resolveActions(comment: TopLevelCommentFragment): CommentActionType[] {
    const authorId = comment.author.id;
    if (comment?.replies && comment.replies.totalCount > 0) {
      return this.resolveSharedActionTypes(authorId, this.currUserId);
    } else {
      return [CommentActionType.REPLY, ...this.resolveSharedActionTypes(authorId, this.currUserId)];
    }
  }

  onCommentEvent(event: CommentEvent): void {
    this.commentEvent.emit(event);
  }
}
