import { Injectable } from '@angular/core';
import { TopLevelCommentFragment } from '@orion/comment-components';
import { CommentClientFilter, CommentFilterConverter } from '@orion/comment-types';
import { CommentFilter1AndFilterEntry, CommentOrdEnum } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import { GetCommentsQuery, GetCommentsQueryService, GetCommentsQueryVariables } from './graphql';
import { ApolloPaginatedFilterablePollingService } from '@orion/shared-services';

@Injectable()
export class CommentsService extends ApolloPaginatedFilterablePollingService<
  GetCommentsQuery,
  GetCommentsQueryVariables,
  TopLevelCommentFragment,
  CommentOrdEnum,
  CommentClientFilter,
  CommentFilter1AndFilterEntry
> {
  constructor(public getQuery: GetCommentsQueryService) {
    super(getQuery, 'Fetching comments');
  }

  protected createFilterConverter(): FilterConverter<CommentClientFilter, CommentFilter1AndFilterEntry[]> {
    return new CommentFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: CommentClientFilter
  ): GetCommentsQueryVariables {
    return {
      ...this.createPaginationVariables(paginationEvent),
      ...this.createOrderVariables(paginationEvent.sort, paginationEvent.sortDir),
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected getQueryResponse(query: GetCommentsQuery): CursorPaginatedResponse<TopLevelCommentFragment> {
    return query?.getCommentList;
  }

  protected strToOrderable(sort: string): Optional<CommentOrdEnum> {
    return enumFromValue(CommentOrdEnum, sort);
  }
}
