import { FormControl, FormGroup } from '@angular/forms';
import { BaseReactiveForm, SentinelValidators } from '@sentinel/common';

export interface CommentFormModel {
  content: FormControl<string>;
}

export class CommentForm extends BaseReactiveForm<CommentFormModel> {
  constructor(content?: string) {
    const formGroup = new FormGroup<CommentFormModel>({
      content: new FormControl<string>(content ?? '', { nonNullable: true, initialValueIsDefault: true }),
    });
    formGroup.controls.content.setValidators([SentinelValidators.noWhitespace]);
    formGroup.controls.content.updateValueAndValidity();
    super(formGroup);
  }

  getContent(): string {
    return this.formGroup.controls.content.value;
  }

  setContent(value: string): void {
    this.formGroup.setValue({ content: value });
  }

  reset(): void {
    this.formGroup.reset();
  }
}
