import { CommentCreate } from '@orion/graphql-types';

export interface CommentRefs {
  authorId: string;
  replyToId?: string;
}

export interface CaseCommentRefs extends CommentRefs {
  caseId: string;
}

export interface TaskCommentRefs extends CommentRefs {
  taskId: string;
}

export type EntityCommentRefs = CaseCommentRefs | TaskCommentRefs;

export function isCaseRefs(refs: EntityCommentRefs): refs is CaseCommentRefs {
  return refs.hasOwnProperty('caseId');
}

export class CreateCommentDTO implements CommentCreate {
  content: string;
  author: string;
  case?: string;
  task?: string;
  replyTo?: string;

  constructor(content: string, refs: EntityCommentRefs) {
    this.content = content;
    this.author = refs.authorId;
    this.replyTo = refs.replyToId;
    if (isCaseRefs(refs)) {
      this.case = refs.caseId;
    } else {
      this.task = refs.taskId;
    }
  }
}
