import { ChangeDetectionStrategy, Component, ViewChild } from '@angular/core';
import { combineLatest, Observable } from 'rxjs';
import { DashboardQueryResult, DashboardService } from './dashboard.service';
import { SidebarStateService } from '@sentinel/layout/sidebar';
import { FullWidthPageContentService } from '@orion/shared/services/global';
import { delay, takeUntil } from 'rxjs/operators';
import { Destroyable } from '@sentinel/common';
import { NumberCardComponent } from '@swimlane/ngx-charts/lib/number-card/number-card.component';

@Component({
  selector: 'orion-dashboard-page',
  templateUrl: './dashboard-page.component.html',
  styleUrls: ['./dashboard-page.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [DashboardService],
})
export class DashboardPageComponent extends Destroyable() {
  dashboard$?: Observable<DashboardQueryResult>;
  @ViewChild('chart', { static: false }) chartComponent?: NumberCardComponent;

  constructor(
    private dashboardService: DashboardService,
    private sidebarStatus: SidebarStateService,
    private widthService: FullWidthPageContentService
  ) {
    super();
    combineLatest([this.sidebarStatus.state$, this.widthService.fullWidth$])
      .pipe(takeUntil(this.destroy$), delay(500)) // delay circa by animation it takes to expand and hide the sidebar
      .subscribe(() => {
        if (this.chartComponent) {
          this.chartComponent.update();
        }
      });
  }

  ngOnInit(): void {
    this.dashboard$ = this.dashboardService.data$;
    this.dashboardService.update();
  }
}
