import * as SchemaTypes from '../../graphql/generated/base-types/base-types';

import * as Apollo from 'apollo-angular';
import { gql } from 'apollo-angular';
import { CaseTableFragmentDoc } from '../../case/components/shared/case-table/case-table.generated';
import { UserNameAndIconFragmentDoc } from '../../user/components/shared/graphql/user-icon.fragment.generated';
import { CaseNameRowFragmentDoc } from '../../case/components/shared/case-table/table-rows/name-row/case-name-row.fragment.generated';
import { CaseNameFragmentDoc } from '../../case/components/shared/case-name/case-name.fragment.generated';
import { LabelChipFragmentDoc } from '../../label/components/shared/label/label-chip.fragment.generated';
import { TaskTableFragmentDoc } from '../../task/components/overview/task-table/task-table.fragment.generated';
import { TaskNameRowFragmentDoc } from '../../task/components/overview/task-table/task-name-row/task-name-row.fragment.generated';
import { TaskNameFragmentDoc } from '../../task/components/shared/task-name/graphql/task-name.fragment.generated';
import { TaskStateFragmentDoc } from '../../task/components/shared/task-state/task-state.fragment.generated';
import { TaskFlagsFragmentDoc } from '../../task/components/shared/task-flags/task-flags.fragment.generated';
import { Injectable } from '@angular/core';

export type DashboardQueryVariables = SchemaTypes.Exact<{
  userId: SchemaTypes.Scalars['ID'];
  lastWeek: SchemaTypes.Scalars['DateTime'];
  today: SchemaTypes.Scalars['DateTime'];
}>;

export type DashboardQuery = {
  __typename?: 'Query';
  caseOpenInTimeRange: { __typename?: 'CasePaginated'; totalCount: number };
  taskOpenInTimeRange: { __typename?: 'TaskPaginated'; totalCount: number };
  caseClosedInTimeRange: { __typename?: 'CasePaginated'; totalCount: number };
  taskClosedInTimeRange: { __typename?: 'TaskPaginated'; totalCount: number };
  casesPastDueDate: { __typename?: 'CasePaginated'; totalCount: number };
  tasksPastDueDate: { __typename?: 'TaskPaginated'; totalCount: number };
  caseTodo: {
    __typename?: 'CasePaginated';
    data: Array<{
      __typename?: 'Case';
      lastUpdated?: any | undefined;
      dueDate?: any | undefined;
      priority: SchemaTypes.CasePriorityEnum;
      state?: SchemaTypes.CaseStateEnum | undefined;
      id: string;
      name: string;
      created?: any | undefined;
      assignees?:
        | {
            __typename?: 'CaseDBUserNestedList';
            totalCount: number;
            data: Array<{ __typename?: 'CaseDBUser'; id: string; name: string; iconSrc?: string | undefined }>;
          }
        | undefined;
      labels?:
        | {
            __typename?: 'LabelNestedList';
            totalCount: number;
            data: Array<{
              __typename?: 'Label';
              id: string;
              name: string;
              backgroundColor?: string | undefined;
              textColor?: string | undefined;
            }>;
          }
        | undefined;
      createdBy?: { __typename?: 'CaseDBUser'; id: string; name: string; iconSrc?: string | undefined } | undefined;
    }>;
  };
  taskTodo: {
    __typename?: 'TaskPaginated';
    data: Array<{
      __typename?: 'Task';
      dueDate?: any | undefined;
      lastUpdated?: any | undefined;
      state?: SchemaTypes.TaskStateEnum | undefined;
      isDecision?: boolean | undefined;
      decision?: boolean | undefined;
      autotrigger?: boolean | undefined;
      isAutomated?: boolean | undefined;
      aggregatesResults?: boolean | undefined;
      id: string;
      name: string;
      created?: any | undefined;
      stage: {
        __typename?: 'Stage';
        id: string;
        workflow: { __typename?: 'Workflow'; id: string; case: { __typename?: 'Case'; id: string } };
      };
      assignees?:
        | {
            __typename?: 'CaseDBUserNestedList';
            totalCount: number;
            data: Array<{ __typename?: 'CaseDBUser'; id: string; name: string; iconSrc?: string | undefined }>;
          }
        | undefined;
      labels?:
        | {
            __typename?: 'LabelNestedList';
            totalCount: number;
            data: Array<{
              __typename?: 'Label';
              id: string;
              name: string;
              backgroundColor?: string | undefined;
              textColor?: string | undefined;
            }>;
          }
        | undefined;
      createdBy?: { __typename?: 'CaseDBUser'; id: string; name: string; iconSrc?: string | undefined } | undefined;
    }>;
  };
};

export const DashboardDocument = gql`
  query dashboard($userId: ID!, $lastWeek: DateTime!, $today: DateTime!) {
    caseOpenInTimeRange: getCaseList(filter: [{ AND: [{ OR: { created: { gte: $lastWeek } } }] }], limit: 1) {
      totalCount
    }
    taskOpenInTimeRange: getTaskList(filter: [{ AND: [{ OR: { created: { gte: $lastWeek } } }] }], limit: 1) {
      totalCount
    }
    caseClosedInTimeRange: getCaseList(
      filter: [{ AND: [{ OR: { state: { in_: [REJECTED, RESOLVED] }, lastUpdated: { gte: $lastWeek } } }] }]
      limit: 1
    ) {
      totalCount
    }
    taskClosedInTimeRange: getTaskList(
      filter: [{ AND: [{ OR: { state: { in_: [REJECTED, RESOLVED, SKIPPED] }, lastUpdated: { gte: $lastWeek } } }] }]
      limit: 1
    ) {
      totalCount
    }
    casesPastDueDate: getCaseList(
      filter: [{ AND: [{ OR: { state: { in_: [OPEN, IN_PROGRESS] }, dueDate: { lte: $today } } }] }]
      limit: 1
    ) {
      totalCount
    }
    tasksPastDueDate: getTaskList(
      filter: [{ AND: [{ OR: { state: { in_: [OPEN, PENDING, RUNNING] }, dueDate: { lte: $today } } }] }]
      limit: 1
    ) {
      totalCount
    }
    caseTodo: getCaseList(
      filter: [{ AND: [{ OR: { assignees: { id: { in_: [$userId] } }, state: { in_: [IN_PROGRESS, OPEN] } } }] }]
      ordering: [{ desc: true, o: DUE_DATE }, { desc: true, o: STATE }]
      limit: 10
    ) {
      data {
        ...caseTable
      }
    }
    taskTodo: getTaskList(
      filter: [{ AND: [{ OR: { assignees: { id: { in_: [$userId] } }, state: { in_: [PENDING, RUNNING, OPEN] } } }] }]
      ordering: [{ desc: true, o: DUE_DATE }, { desc: true, o: STATE }]
      limit: 10
    ) {
      data {
        ...taskTable
      }
    }
  }
  ${CaseTableFragmentDoc}
  ${UserNameAndIconFragmentDoc}
  ${CaseNameRowFragmentDoc}
  ${CaseNameFragmentDoc}
  ${LabelChipFragmentDoc}
  ${TaskTableFragmentDoc}
  ${TaskNameRowFragmentDoc}
  ${TaskNameFragmentDoc}
  ${TaskStateFragmentDoc}
  ${TaskFlagsFragmentDoc}
`;

@Injectable({
  providedIn: 'root',
})
export class DashboardQueryService extends Apollo.Query<DashboardQuery, DashboardQueryVariables> {
  document = DashboardDocument;
  client = 'graphApi';
  constructor(apollo: Apollo.Apollo) {
    super(apollo);
  }
}
