import { Injectable } from '@angular/core';
import { IpFixClientFilter } from '@orion/data-platform-types';
import { FilterChip, StringValueChip } from '@csirtmu-orion/microframework/filter';
import { FilterChipsService } from '@csirtmu-orion/microframework/filter-services';
import { DateValueChip } from '@csirtmu-orion/microframework/filters';
import { IpFixFilterService } from './ip-fix-filter.service';

@Injectable()
export class IpFixFilterChipsService extends FilterChipsService<IpFixClientFilter> {
  private readonly IP_ADDRESS_CHIP_ID = 'ipAddress';
  private readonly PORT_CHIP_ID = 'port';
  constructor(protected filterService: IpFixFilterService) {
    super(filterService);
  }

  protected createChips(filter?: IpFixClientFilter): FilterChip[] {
    if (filter === undefined || filter === this.filterService.EMPTY_FILTER) {
      return [];
    } else {
      const chips = [];
      if (filter.ipAddress) {
        chips.push(new StringValueChip(filter.ipAddress, this.IP_ADDRESS_CHIP_ID));
      }
      if (filter.port) {
        chips.push(new StringValueChip(filter.port.toString(), this.PORT_CHIP_ID));
      }
      if (filter.from) {
        chips.push(new DateValueChip(filter.from, 'from'));
      }
      if (filter.to) {
        chips.push(new DateValueChip(filter.to, 'to'));
      }
      return chips;
    }
  }

  removeChip(removedChip: FilterChip): void {
    if (removedChip instanceof StringValueChip && removedChip.id === this.IP_ADDRESS_CHIP_ID) {
      this.filterService.updateAndSubmit({ ipAddress: undefined });
    }
    if (removedChip instanceof StringValueChip && removedChip.id === this.PORT_CHIP_ID) {
      this.filterService.updateAndSubmit({ port: undefined });
    }
    if (removedChip instanceof DateValueChip && removedChip.direction === 'from') {
      this.filterService.updateAndSubmit({ from: undefined });
    }
    if (removedChip instanceof DateValueChip && removedChip.direction === 'to') {
      this.filterService.updateAndSubmit({ to: undefined });
    }
  }
}
