import { Injectable } from '@angular/core';
import { ActivatedRoute, Data, ParamMap, Params, Router } from '@angular/router';
import { IpFixClientFilter } from '@orion/data-platform-types';
import { QueryParamFilterService } from '@csirtmu-orion/microframework/filter-services';
import { Observable, of } from 'rxjs';

@Injectable()
export class IpFixFilterService extends QueryParamFilterService<IpFixClientFilter> {
  constructor(protected router: Router, protected activatedRoute: ActivatedRoute) {
    super(router, activatedRoute);
  }

  protected toQueryParams(filter: IpFixClientFilter): Params {
    const params = super.toQueryParams(filter);
    if (filter.from) {
      params.from = filter.from.valueOf();
    }
    if (filter.to) {
      params.to = filter.to.valueOf();
    }
    return params;
  }

  protected createEmptyFilter(): IpFixClientFilter {
    return {
      from: undefined,
      to: undefined,
      ipAddress: undefined,
      port: undefined,
    };
  }

  protected createFilterFromRoute(
    queryParamMap: ParamMap,
    paramMap: ParamMap,
    data: Data
  ): Observable<IpFixClientFilter> {
    const ipParam = queryParamMap.get('ipAddress');
    const portParam = queryParamMap.get('port');
    const from = this.deslugifyTimestamp(queryParamMap.get('from'));
    const to = this.deslugifyTimestamp(queryParamMap.get('to'));
    const ip = this.deslugify(ipParam);
    const port: number = Number.parseInt(this.deslugify(portParam) ?? '');
    if (from === undefined && to === undefined && (port === undefined || Number.isNaN(port)) && ip === undefined) {
      return of(this.EMPTY_FILTER);
    }
    return of({
      ipAddress: ip,
      from: from,
      to: to,
      port: Number.isNaN(port) ? undefined : port,
    });
  }
}
