import { ChangeDetectionStrategy, Component } from '@angular/core';
import { IpFixFilterChipsService, IpFixFilterService } from '@orion/data-platform-components-filters';
import { IpFixClientFilter } from '@orion/data-platform-types';
import { DataPlatformServiceIpFixOrdEnum } from '@orion/graphql-types';
import {
  INIT_PAGINATION_EVENT_BASE_TOKEN,
  PaginationBaseInit,
  PaginationService,
  QueryParamPaginationService,
} from '@csirtmu-orion/microframework/pagination-services';
import { EntityPaginableFilterableSmartOverviewDirective } from '@csirtmu-orion/microframework/entity-smart-directives';
import { IpFixOverviewFragment } from './graphql';
import { IpFixOverviewService } from './ip-fix-overview.service';

@Component({
  selector: 'orion-ip-fix-overview-page',
  templateUrl: './ip-fix-overview-page.component.html',
  styleUrls: ['./ip-fix-overview-page.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [
    IpFixOverviewService,
    IpFixFilterService,
    IpFixFilterChipsService,
    {
      provide: PaginationService,
      useClass: QueryParamPaginationService,
    },
    {
      provide: INIT_PAGINATION_EVENT_BASE_TOKEN,
      useValue: new PaginationBaseInit(50, DataPlatformServiceIpFixOrdEnum.TIMESTAMP, 'desc'),
    },
  ],
})
export class IpFixOverviewPageComponent extends EntityPaginableFilterableSmartOverviewDirective<
  IpFixOverviewFragment,
  IpFixClientFilter
> {
  constructor(
    protected ipFixService: IpFixOverviewService,
    protected paginationService: PaginationService,
    protected filterService: IpFixFilterService,
    protected filterChipsService: IpFixFilterChipsService
  ) {
    super(ipFixService, filterService, paginationService, filterChipsService);
  }
}
