import { Injectable } from '@angular/core';
import { IpFixClientFilter, IpFixFilterConverter } from '@orion/data-platform-types';
import { DataPlatformServiceIpFixFilter1AndFilterEntry, DataPlatformServiceIpFixOrdEnum } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import {
  GetIpFixOverviewQuery,
  GetIpFixOverviewQueryService,
  GetIpFixOverviewQueryVariables,
  IpFixOverviewFragment,
} from './graphql';
import { ApolloPaginatedFilterablePollingService } from '@orion/shared-services';

@Injectable()
export class IpFixOverviewService extends ApolloPaginatedFilterablePollingService<
  GetIpFixOverviewQuery,
  GetIpFixOverviewQueryVariables,
  IpFixOverviewFragment,
  DataPlatformServiceIpFixOrdEnum,
  IpFixClientFilter,
  DataPlatformServiceIpFixFilter1AndFilterEntry
> {
  constructor(public getQuery: GetIpFixOverviewQueryService) {
    super(getQuery, 'Fetching IPFIX data');
  }

  protected createFilterConverter(): FilterConverter<
    IpFixClientFilter,
    DataPlatformServiceIpFixFilter1AndFilterEntry[]
  > {
    return new IpFixFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: IpFixClientFilter
  ): GetIpFixOverviewQueryVariables {
    return {
      ...this.createPaginationVariables(paginationEvent),
      ...this.createOrderVariables(paginationEvent.sort, paginationEvent.sortDir),
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected getQueryResponse(query: GetIpFixOverviewQuery): CursorPaginatedResponse<IpFixOverviewFragment> {
    return query.getDataPlatformServiceIpFixList;
  }

  protected strToOrderable(sort: string): Optional<DataPlatformServiceIpFixOrdEnum> {
    return enumFromValue(DataPlatformServiceIpFixOrdEnum, sort);
  }
}
