import { convertDateTimeFilter, isIPv4, isIPv6 } from '@orion/common';
import {
  DataPlatformServiceIpFixFilter1AndFilterEntry,
  DataPlatformServiceIpFixFilter1OrFilterEntry,
} from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { IpFixClientFilter } from './ip-fix-client-filter';

export class IpFixFilterConverter
  implements FilterConverter<IpFixClientFilter, DataPlatformServiceIpFixFilter1AndFilterEntry[]>
{
  convert(source?: IpFixClientFilter): DataPlatformServiceIpFixFilter1AndFilterEntry[] {
    if (source) {
      const filters: DataPlatformServiceIpFixFilter1OrFilterEntry[] = [];
      if (source.from || source.to) {
        filters.push({ OR: { timestamp: convertDateTimeFilter(source) } });
      }
      if (source.ipAddress) {
        if (isIPv4(source.ipAddress)) {
          filters.push(
            ...[
              { OR: { sourceipv4address: { icontains: source.ipAddress } } },
              { OR: { destinationipv4address: { icontains: source.ipAddress } } },
            ]
          );
        } else if (isIPv6(source.ipAddress)) {
          filters.push(
            ...[
              { OR: { sourceipv6address: { icontains: source.ipAddress } } },
              { OR: { destinationipv6address: { icontains: source.ipAddress } } },
            ]
          );
        }
      }
      if (source.port !== undefined) {
        filters.push(
          ...[
            { OR: { sourcetransportport: { exact: source.port } } },
            { OR: { destinationtransportport: { exact: source.port } } },
          ]
        );
      }
      return [{ AND: filters }];
    } else {
      return [];
    }
  }
}
