import { Injectable } from '@angular/core';
import { FlowEventClientFilter } from '@orion/event-types';
import { FilterChip, StringValueChip } from '@csirtmu-orion/microframework/filter';
import { FilterChipsService } from '@csirtmu-orion/microframework/filter-services';
import { DateValueChip } from '@csirtmu-orion/microframework/filters';
import { FlowEventsFilterService } from './flow-events-filter.service';

@Injectable()
export class EventsFilterChipsService extends FilterChipsService<FlowEventClientFilter> {
  constructor(protected filterService: FlowEventsFilterService) {
    super(filterService);
  }
  protected createChips(filter?: FlowEventClientFilter): FilterChip[] {
    const chips = [];
    if (filter?.keyword) {
      chips.push(new StringValueChip(filter.keyword));
    }
    if (filter?.from) {
      chips.push(new DateValueChip(filter.from, 'from'));
    }
    if (filter?.to) {
      chips.push(new DateValueChip(filter.to, 'to'));
    }
    return chips;
  }

  removeChip(removedChip: FilterChip): void {
    if (removedChip instanceof StringValueChip) {
      this.filterService.updateAndSubmit({ keyword: undefined });
    }
    if (removedChip instanceof DateValueChip && removedChip.direction === 'from') {
      this.filterService.updateAndSubmit({ from: undefined });
    }
    if (removedChip instanceof DateValueChip && removedChip.direction === 'to') {
      this.filterService.updateAndSubmit({ to: undefined });
    }
  }
}
