import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap, Params, Router } from '@angular/router';
import { FlowEventClientFilter } from '@orion/event-types';
import { QueryParamFilterService } from '@csirtmu-orion/microframework/filter-services';
import { Observable, of } from 'rxjs';

@Injectable()
export class FlowEventsFilterService extends QueryParamFilterService<FlowEventClientFilter> {
  constructor(protected router: Router, protected activatedRoute: ActivatedRoute) {
    super(router, activatedRoute);
  }

  protected toQueryParams(filter: FlowEventClientFilter): Params {
    const params = super.toQueryParams(filter);
    if (filter.from) {
      params.from = filter.from.valueOf();
    }
    if (filter.to) {
      params.to = filter.to.valueOf();
    }
    delete params.taskIds;
    delete params.caseId;
    return params;
  }

  protected createEmptyFilter(): FlowEventClientFilter {
    return { keyword: undefined, from: undefined, to: undefined };
  }

  protected createFilterFromRoute(queryParamMap: ParamMap, paramMap: ParamMap): Observable<FlowEventClientFilter> {
    const keyword = this.deslugify(queryParamMap.get('keyword'));
    const from = this.deslugifyTimestamp(queryParamMap.get('from'));
    const to = this.deslugifyTimestamp(queryParamMap.get('to'));
    return of({ ipAddress: keyword, from, to });
  }
}
