import { ChangeDetectionStrategy, Component, Input, OnInit } from '@angular/core';
import { FlowEventDataOrdEnum } from '@orion/graphql-types';
import {
  INIT_PAGINATION_EVENT_BASE_TOKEN,
  PaginationBaseInit,
  PaginationService,
} from '@csirtmu-orion/microframework/pagination-services';
import { EntityPaginableFilterableSmartOverviewDirective } from '@csirtmu-orion/microframework/entity-smart-directives';
import { takeUntil } from 'rxjs/operators';
import { FlowEventTableElementFlowEventFragment } from '../flow-event-table.fragment.generated';
import { FlowEventNestedFlowsFragment } from './flow-event-nested-flows.fragment.generated';
import { FlowEventNestedFlowsService, NestedFlowsFilter } from './flow-event-nested-flows.service';
import { FlowEventsFilterService } from './flow-events-filter.service';

@Component({
  selector: 'orion-flow-event-nested-flows',
  templateUrl: './flow-event-nested-flows.component.html',
  styleUrls: ['./flow-event-nested-flows.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [
    FlowEventNestedFlowsService,
    FlowEventsFilterService,
    PaginationService,
    {
      provide: INIT_PAGINATION_EVENT_BASE_TOKEN,
      useValue: new PaginationBaseInit(50, FlowEventDataOrdEnum.TIMESTAMP, 'desc'),
    },
  ],
})
export class FlowEventNestedFlowsComponent
  extends EntityPaginableFilterableSmartOverviewDirective<FlowEventNestedFlowsFragment, NestedFlowsFilter>
  implements OnInit
{
  @Input() data?: FlowEventTableElementFlowEventFragment;

  constructor(
    protected paginationService: PaginationService,
    protected casesService: FlowEventNestedFlowsService,
    protected filterService: FlowEventsFilterService
  ) {
    super(casesService, filterService, paginationService);
    filterService.filter$.pipe(takeUntil(this.destroy$)).subscribe();
  }

  ngOnInit(): void {
    super.ngOnInit();
    if (this.data) {
      this.filterService.updateAndSubmit({ eventId: this.data?.id });
    }
  }
}
