import { Injectable } from '@angular/core';
import { FlowEventDataFilter1, FlowEventDataFilter1AndFilterEntry, FlowEventDataOrdEnum } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import { FlowEventNestedFlowsFragment } from './flow-event-nested-flows.fragment.generated';
import {
  GetFlowEventNestedFlowsQuery,
  GetFlowEventNestedFlowsQueryService,
  GetFlowEventNestedFlowsQueryVariables,
} from './flow-event-nested-flows.operation.generated';
import { ApolloPaginatedFilterablePollingService } from '@orion/shared-services';

export interface NestedFlowsFilter {
  eventId?: string;
}

export class NestedFlowsFilterConverter
  implements FilterConverter<NestedFlowsFilter, FlowEventDataFilter1AndFilterEntry[]>
{
  convert(source?: NestedFlowsFilter): FlowEventDataFilter1AndFilterEntry[] {
    const mainAndFilter: FlowEventDataFilter1 = {};
    if (source?.eventId) {
      mainAndFilter.flowEvent = { id: { exact: source.eventId } };
    }
    return [
      {
        AND: [{ OR: mainAndFilter }],
      },
    ];
  }
}

@Injectable()
export class FlowEventNestedFlowsService extends ApolloPaginatedFilterablePollingService<
  GetFlowEventNestedFlowsQuery,
  GetFlowEventNestedFlowsQueryVariables,
  FlowEventNestedFlowsFragment,
  FlowEventDataOrdEnum,
  NestedFlowsFilter,
  FlowEventDataFilter1AndFilterEntry
> {
  public constructor(public getQuery: GetFlowEventNestedFlowsQueryService) {
    super(getQuery, 'Fetching flows');
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: NestedFlowsFilter
  ): GetFlowEventNestedFlowsQueryVariables {
    return {
      ...this.createPaginationVariables(paginationEvent),
      ...this.createOrderVariables(paginationEvent.sort, paginationEvent.sortDir),
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected createFilterConverter(): FilterConverter<NestedFlowsFilter, FlowEventDataFilter1AndFilterEntry[]> {
    return new NestedFlowsFilterConverter();
  }

  protected getQueryResponse(
    query: GetFlowEventNestedFlowsQuery
  ): CursorPaginatedResponse<FlowEventNestedFlowsFragment> {
    return query.getFlowEventDataList;
  }

  protected strToOrderable(sort: string): Optional<FlowEventDataOrdEnum> {
    return enumFromValue(FlowEventDataOrdEnum, sort);
  }
}
