import { Injectable } from '@angular/core';
import { FlowEventClientFilter, FlowEventFilterConverter } from '@orion/event-types';
import { EventFilter1AndFilterEntry, FlowEventOrdEnum } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import {
  FlowEventFragment,
  GetFlowEventsQuery,
  GetFlowEventsQueryService,
  GetFlowEventsQueryVariables,
} from './graphql';
import { ApolloPaginatedFilterablePollingService } from '@orion/shared-services';

@Injectable()
export class RelatedFlowEventsService extends ApolloPaginatedFilterablePollingService<
  GetFlowEventsQuery,
  GetFlowEventsQueryVariables,
  FlowEventFragment,
  FlowEventOrdEnum,
  FlowEventClientFilter,
  EventFilter1AndFilterEntry
> {
  public constructor(public getQuery: GetFlowEventsQueryService) {
    super(getQuery, 'Fetching related flow events');
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: FlowEventClientFilter
  ): GetFlowEventsQueryVariables {
    return {
      ...this.createPaginationVariables(paginationEvent),
      ...this.createOrderVariables(paginationEvent.sort, paginationEvent.sortDir),
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected createFilterConverter(): FilterConverter<FlowEventClientFilter, EventFilter1AndFilterEntry[]> {
    return new FlowEventFilterConverter();
  }

  protected strToOrderable(sort: string): Optional<FlowEventOrdEnum> {
    return enumFromValue(FlowEventOrdEnum, sort);
  }

  protected getQueryResponse(query: GetFlowEventsQuery): CursorPaginatedResponse<FlowEventFragment> {
    return query.getFlowEventList;
  }
}
