import { convertDateTimeFilter } from '@orion/common';
import { EventFilter1, FlowEventFilter1AndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { FlowEventClientFilter } from './index';

export class FlowEventFilterConverter
  implements FilterConverter<FlowEventClientFilter, FlowEventFilter1AndFilterEntry[]>
{
  convert(clientFilter?: FlowEventClientFilter): FlowEventFilter1AndFilterEntry[] {
    const mainAndFilter: EventFilter1 = {};
    if (clientFilter?.from || clientFilter?.to) {
      mainAndFilter.eventTime = convertDateTimeFilter(clientFilter);
    }
    if (clientFilter?.keyword) {
      mainAndFilter.name = { icontains: clientFilter.keyword };
    }
    if (clientFilter?.caseId && clientFilter?.taskIds) {
      return [
        {
          AND: [
            { OR: { relatedCases: { id: { exact: clientFilter.caseId } }, ...mainAndFilter } },
            { OR: { relatedTasks: { id: { in_: clientFilter.taskIds } }, ...mainAndFilter } },
          ],
        },
      ];
    } else if (clientFilter?.caseId) {
      mainAndFilter.relatedCases = { id: { exact: clientFilter.caseId } };
    } else if (clientFilter?.taskIds) {
      mainAndFilter.relatedTasks = { id: { in_: clientFilter.taskIds } };
    }
    return [
      {
        AND: [{ OR: mainAndFilter }],
      },
    ];
  }
}
