import { ChangeDetectionStrategy, Component, Input, OnChanges, SimpleChanges } from '@angular/core';
import { LabelForm } from '@orion/label-types';
import { Destroyable } from '@sentinel/common';
import { Observable } from 'rxjs';
import { map, startWith, takeUntil } from 'rxjs/operators';
import { LabelPreview } from './label-preview';

@Component({
  selector: 'orion-create-edit-label',
  templateUrl: './create-edit-label.component.html',
  styleUrls: ['./create-edit-label.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class CreateEditLabelComponent extends Destroyable() implements OnChanges {
  @Input() form?: LabelForm;
  labelPreview$?: Observable<LabelPreview>;
  readonly BCG_RECOMMENDED = [
    '#009966',
    '#8fbc8f',
    '#3cb371',
    '#00b140',
    '#013220',
    '#6699cc',
    '#0000ff',
    '#e6e6fa',
    '#9400d3',
    '#330066',
    '#808080',
    '#36454f',
    '#f7e7ce',
    '#c21e56',
    '#cc338b',
    '#dc143c',
    '#ff0000',
    '#cd5b45',
    '#eee600',
    '#ed9121',
    '#c39953',
  ];
  readonly TEXT_RECOMMENDED = ['black', 'white'];

  ngOnChanges(changes: SimpleChanges): void {
    if ('form' in changes && this.form) {
      this.labelPreview$ = this.form.formGroup.valueChanges.pipe(
        takeUntil(this.destroy$),
        map(() => this.createLabelPreview()),
        startWith(this.createLabelPreview())
      );
    }
  }

  private createLabelPreview(): LabelPreview {
    return new LabelPreview(this.form?.getData());
  }
}
