import * as SchemaTypes from '../../../../graphql/generated/base-types/base-types';

import * as Apollo from 'apollo-angular';
import { gql } from 'apollo-angular';
import { LabelOverviewFragmentDoc } from './label-overview.fragment.generated';
import { LabelTableFragmentDoc } from '../label-table/label-table.fragment.generated';
import { LabelChipFragmentDoc } from '../../shared/label/label-chip.fragment.generated';
import { Injectable } from '@angular/core';

export type GetLabelOverviewQueryVariables = SchemaTypes.Exact<{
  filter?: SchemaTypes.InputMaybe<Array<SchemaTypes.LabelFilter1AndFilterEntry>>;
  order?: SchemaTypes.InputMaybe<Array<SchemaTypes.LabelOrdEnumOrderingEntry>>;
  cursor?: SchemaTypes.InputMaybe<SchemaTypes.Scalars['String']>;
  limit?: SchemaTypes.InputMaybe<SchemaTypes.Scalars['Int']>;
}>;

export type GetLabelOverviewQuery = {
  __typename?: 'Query';
  getLabelList: {
    __typename?: 'LabelPaginated';
    previous?: string | undefined;
    next?: string | undefined;
    totalCount: number;
    data: Array<{
      __typename?: 'Label';
      id: string;
      name: string;
      backgroundColor?: string | undefined;
      textColor?: string | undefined;
    }>;
  };
};

export type DeleteLabelsMutationVariables = SchemaTypes.Exact<{
  ids: Array<SchemaTypes.Scalars['ID']>;
}>;

export type DeleteLabelsMutation = {
  __typename?: 'Mutation';
  deleteLabelBulk: Array<{ __typename?: 'MutateResult'; id?: string | undefined }>;
};

export const GetLabelOverviewDocument = gql`
  query getLabelOverview(
    $filter: [LabelFilter1ANDFilterEntry!]
    $order: [LabelOrdEnumOrderingEntry!]
    $cursor: String
    $limit: Int
  ) {
    getLabelList(filter: $filter, ordering: $order, cursor: $cursor, limit: $limit) {
      data {
        ...labelOverview
      }
      previous
      next
      totalCount
    }
  }
  ${LabelOverviewFragmentDoc}
  ${LabelTableFragmentDoc}
  ${LabelChipFragmentDoc}
`;

@Injectable({
  providedIn: 'root',
})
export class GetLabelOverviewQueryService extends Apollo.Query<GetLabelOverviewQuery, GetLabelOverviewQueryVariables> {
  document = GetLabelOverviewDocument;
  client = 'graphApi';
  constructor(apollo: Apollo.Apollo) {
    super(apollo);
  }
}
export const DeleteLabelsDocument = gql`
  mutation deleteLabels($ids: [ID!]!) {
    deleteLabelBulk(ids: $ids) {
      id
    }
  }
`;

@Injectable({
  providedIn: 'root',
})
export class DeleteLabelsMutationService extends Apollo.Mutation<DeleteLabelsMutation, DeleteLabelsMutationVariables> {
  document = DeleteLabelsDocument;
  client = 'graphApi';
  constructor(apollo: Apollo.Apollo) {
    super(apollo);
  }
}
