import { ChangeDetectionStrategy, Component } from '@angular/core';
import { LabelOrdEnum } from '@orion/graphql-types';
import { LabelOverviewActionsService } from '@orion/label-services';
import { LabelClientFilter } from '@orion/label-types';
import {
  INIT_PAGINATION_EVENT_BASE_TOKEN,
  PaginationBaseInit,
  PaginationService,
  QueryParamPaginationService,
} from '@csirtmu-orion/microframework/pagination-services';
import { SentinelControlItem } from '@sentinel/components/controls';
import { EntityPaginableFilterableSmartOverviewDirective } from '@csirtmu-orion/microframework/entity-smart-directives';
import { defer, of } from 'rxjs';
import { take } from 'rxjs/operators';
import { LabelFilterChipsService, LabelFilterService } from './filters';
import { LabelOverviewFragment } from './graphql';
import { LabelOverviewService } from './label-overview.service';

@Component({
  selector: 'orion-label-overview-page',
  templateUrl: './label-overview-page.component.html',
  styleUrls: ['./label-overview-page.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [
    LabelOverviewService,
    LabelOverviewActionsService,
    LabelFilterService,
    LabelFilterChipsService,
    { provide: PaginationService, useClass: QueryParamPaginationService },
    {
      provide: INIT_PAGINATION_EVENT_BASE_TOKEN,
      useValue: new PaginationBaseInit(10, LabelOrdEnum.NAME, 'asc'),
    },
  ],
})
export class LabelOverviewPageComponent extends EntityPaginableFilterableSmartOverviewDirective<
  LabelOverviewFragment,
  LabelClientFilter
> {
  controls: SentinelControlItem[] = [
    new SentinelControlItem(
      'create',
      'Create',
      'primary',
      of(false),
      defer(() => this.labelActionsService.create())
    ),
  ];
  constructor(
    protected labelsService: LabelOverviewService,
    protected filterService: LabelFilterService,
    protected filterChipsService: LabelFilterChipsService,
    private labelActionsService: LabelOverviewActionsService,
    protected paginationService: PaginationService
  ) {
    super(labelsService, filterService, paginationService, filterChipsService);
  }

  onControlsEvent(clickedItem: SentinelControlItem): void {
    clickedItem.result$?.pipe(take(1)).subscribe();
  }
}
