import { Injectable } from '@angular/core';
import { LabelFilter1AndFilterEntry, LabelOrdEnum } from '@orion/graphql-types';
import { LabelClientFilter, LabelFilterConverter } from '@orion/label-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import {
  GetLabelOverviewQuery,
  GetLabelOverviewQueryService,
  GetLabelOverviewQueryVariables,
  LabelOverviewFragment,
} from './graphql';
import { ApolloPaginatedFilterablePollingService } from '@orion/shared-services';

@Injectable()
export class LabelOverviewService extends ApolloPaginatedFilterablePollingService<
  GetLabelOverviewQuery,
  GetLabelOverviewQueryVariables,
  LabelOverviewFragment,
  LabelOrdEnum,
  LabelClientFilter,
  LabelFilter1AndFilterEntry
> {
  constructor(public getQuery: GetLabelOverviewQueryService) {
    super(getQuery, 'Fetching labels');
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: LabelClientFilter
  ): GetLabelOverviewQueryVariables {
    return {
      ...this.createPaginationVariables(paginationEvent),
      ...this.createOrderVariables(paginationEvent.sort, paginationEvent.sortDir),
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected createFilterConverter(): FilterConverter<LabelClientFilter, LabelFilter1AndFilterEntry[]> {
    return new LabelFilterConverter();
  }

  protected getQueryResponse(query: GetLabelOverviewQuery): CursorPaginatedResponse<LabelOverviewFragment> {
    return query.getLabelList;
  }

  protected strToOrderable(sort: string): Optional<LabelOrdEnum> {
    return enumFromValue(LabelOrdEnum, sort);
  }
}
