import { ChangeDetectionStrategy, Component, Input } from '@angular/core';
import { Router } from '@angular/router';
import { CASES_PATH } from '@orion/case-paths';
import { toAuthPath } from '@orion/common';
import { NotificationService } from '@orion/shared/services/global';

@Component({
  selector: 'orion-label-cases',
  templateUrl: './label-cases-row.component.html',
  styleUrls: ['./label-cases-row.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class LabelCasesRowComponent {
  @Input() labelId?: string;

  constructor(private router: Router, private notificationService: NotificationService) {}

  navigateToCases(): void {
    if (this.labelId) {
      this.router
        .navigate([toAuthPath(CASES_PATH)], { queryParams: { labelIds: this.labelId } })
        .then((navSuccessful) => {
          if (!navSuccessful) {
            this.notificationService.emit('success', 'Navigation to cases failed');
          }
        })
        .catch(() => this.notificationService.emit('error', 'Navigation to cases failed'));
    }
  }
}
