import { LabelOrdEnum } from '@orion/graphql-types';
import { LabelOverviewActionsService } from '@orion/label-services';
import { IPaginatedElements } from '@sentinel/common/pagination';
import { isLoading } from '@sentinel/common/utils';
import { Column, Row, RowAction, SentinelTable } from '@sentinel/components/table';
import { defer, of } from 'rxjs';
import { map } from 'rxjs/operators';
import { LabelTableFragment } from './label-table.fragment.generated';

export class LabelsTable extends SentinelTable<LabelTableFragment> {
  constructor(resources: IPaginatedElements<LabelTableFragment>, service: LabelOverviewActionsService) {
    const columns = [new Column('label', 'Label', true, LabelOrdEnum.NAME), new Column('cases', '', false)];
    const rows = resources.elements.map((label) => new Row(label, LabelsTable.createActions(label, service)));
    super(rows, columns);
    this.pagination = resources.pagination;
  }

  private static createActions(label: LabelTableFragment, service: LabelOverviewActionsService): RowAction[] {
    const editAction = new RowAction(
      'edit',
      'Edit',
      'create',
      'primary',
      'Edit',
      of(false),
      defer(() => service.edit(label))
    );
    const deleteAction = new RowAction(
      'delete',
      'Delete',
      'delete',
      'warn',
      'Delete',
      of(false),
      defer(() => service.delete([label])),
      service.deletingInProgress$.pipe(map((state) => isLoading(state, label.id)))
    );
    return [editAction, deleteAction];
  }
}
