import { ChangeDetectionStrategy, Component } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { EditableSelectionDirective } from '@orion/case-components/shared';
import { EntitySetAssociationService } from '@orion/shared-services';
import { NotificationService } from '@orion/shared/services/global';
import { LabelChipFragment } from '../../label';
import { LabelSelectionFragment } from '../../labels-selection';

@Component({
  selector: 'orion-labels-expanded-sidebar-element',
  templateUrl: './labels-expanded-sidebar-element.component.html',
  styleUrls: ['./labels-expanded-sidebar-element.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [EntitySetAssociationService],
})
export class LabelsExpandedSidebarElementComponent extends EditableSelectionDirective<LabelChipFragment> {
  constructor(
    public selectionService: EntitySetAssociationService<LabelSelectionFragment>,
    private router: Router,
    private notificationService: NotificationService,
    private activatedRoute: ActivatedRoute
  ) {
    super(selectionService);
  }

  onLabelClicked(label: LabelChipFragment): void {
    void this.router
      .navigate(['../'], {
        queryParams: { labelIds: label.id },
        relativeTo: this.activatedRoute,
      })
      .then((navSuccessful) => {
        if (!navSuccessful) {
          this.notificationService.emit('success', 'Navigation to label failed');
        }
      })
      .catch(() => this.notificationService.emit('error', 'Navigation to label failed'));
  }

  onLabelRemoved(label: LabelSelectionFragment): void {
    this.save.emit({ remove: [label] });
  }
}
