import { Injectable } from '@angular/core';
import { LabelFilter1AndFilterEntry, LabelOrdEnum } from '@orion/graphql-types';
import { LabelClientFilter, LabelFilterConverter } from '@orion/label-types';
import { ApolloPaginatedFilterableService } from '@csirtmu-orion/microframework/apollo-services';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import {
  GetLabelListQuery,
  GetLabelListQueryService,
  GetLabelListQueryVariables,
  LabelListElementFragment,
} from './graphql';

@Injectable()
export class LabelListService extends ApolloPaginatedFilterableService<
  GetLabelListQuery,
  GetLabelListQueryVariables,
  LabelListElementFragment,
  LabelOrdEnum,
  LabelClientFilter,
  LabelFilter1AndFilterEntry
> {
  constructor(public getQuery: GetLabelListQueryService) {
    super(getQuery, 'Fetching labels');
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: LabelClientFilter
  ): GetLabelListQueryVariables {
    return {
      ...this.createPaginationVariables(paginationEvent),
      ...this.createOrderVariables(paginationEvent.sort, paginationEvent.sortDir),
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected createFilterConverter(): FilterConverter<LabelClientFilter, LabelFilter1AndFilterEntry[]> {
    return new LabelFilterConverter();
  }

  protected getQueryResponse(query: GetLabelListQuery): CursorPaginatedResponse<LabelListElementFragment> {
    return query.getLabelList;
  }

  protected strToOrderable(sort: string): Optional<LabelOrdEnum> {
    return enumFromValue(LabelOrdEnum, sort);
  }
}
