import { FormControl, FormGroup } from '@angular/forms';
import { LabelChipFragment } from '@orion/label-components/shared';
import { BaseReactiveForm, SentinelValidators } from '@sentinel/common';
import { CreateEditLabelData } from './create-edit-label-data';

export interface LabelFormModel {
  name: FormControl<string>;
  backgroundColor: FormControl<string>;
  textColor: FormControl<string>;
}

export class LabelForm extends BaseReactiveForm<LabelFormModel> {
  constructor(label?: LabelChipFragment) {
    const formGroup = new FormGroup<LabelFormModel>({
      name: new FormControl<string>(label?.name ?? '', { nonNullable: true, initialValueIsDefault: true }),
      backgroundColor: new FormControl<string>(label?.backgroundColor ?? 'black', {
        nonNullable: true,
        initialValueIsDefault: true,
      }),
      textColor: new FormControl<string>(label?.textColor ?? 'white', {
        nonNullable: true,
        initialValueIsDefault: true,
      }),
    });
    formGroup.controls.name.setValidators([SentinelValidators.noWhitespace]);
    formGroup.controls.backgroundColor.setValidators([SentinelValidators.noWhitespace]);
    formGroup.controls.textColor.setValidators([SentinelValidators.noWhitespace]);
    formGroup.controls.name.updateValueAndValidity();
    super(formGroup);
  }

  setValues(label: LabelChipFragment): void {
    if (label.name && label.textColor && label.backgroundColor) {
      this.formGroup.controls.name.setValue(label.name);
      this.formGroup.controls.backgroundColor.setValue(label.backgroundColor);
      this.formGroup.controls.textColor.setValue(label.textColor);
    }
  }

  getData(): CreateEditLabelData {
    return {
      name: this.formGroup.controls.name.value,
      backgroundColor: this.formGroup.controls.backgroundColor.value,
      textColor: this.formGroup.controls.textColor.value,
    };
  }
}
