import { Injectable } from '@angular/core';
import { ObservableCtiEntryClientFilter } from '@orion/observable-types';
import { FilterChip, StringValueChip } from '@csirtmu-orion/microframework/filter';
import { FilterChipsService } from '@csirtmu-orion/microframework/filter-services';
import { DateValueChip } from '@csirtmu-orion/microframework/filters';
import { ObservableCtiEntryFilterService } from './observable-cti-entry-filter.service';

@Injectable()
export class ObservableCtiEntryFilterChipsService extends FilterChipsService<ObservableCtiEntryClientFilter> {
  public constructor(protected filterService: ObservableCtiEntryFilterService) {
    super(filterService);
  }

  protected createChips(filter: ObservableCtiEntryClientFilter | undefined): FilterChip[] {
    const chips = [];
    if (filter?.from) {
      chips.push(new DateValueChip(filter.from, 'from'));
    }
    if (filter?.to) {
      chips.push(new DateValueChip(filter.to, 'to'));
    }
    if (filter?.externalReference) {
      chips.push(new StringValueChip(filter.externalReference, 'externalReference'));
    }
    return chips;
  }

  removeChip(removedChip: FilterChip): void {
    if (removedChip instanceof DateValueChip && removedChip.direction === 'from') {
      this.filterService.updateAndSubmit({ from: undefined });
    }
    if (removedChip instanceof DateValueChip && removedChip.direction === 'to') {
      this.filterService.updateAndSubmit({ to: undefined });
    }
    if (removedChip instanceof StringValueChip && removedChip.id === 'externalReference') {
      this.filterService.updateAndSubmit({ externalReference: undefined });
    }
  }
}
