import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap, Params, Router } from '@angular/router';
import { OBSERVABLE_ID_PARAM_SELECTOR } from '@orion/observable-paths';
import { ObservableCtiEntryClientFilter } from '@orion/observable-types';
import { QueryParamFilterService } from '@csirtmu-orion/microframework/filter-services';
import { Observable, of } from 'rxjs';

@Injectable()
export class ObservableCtiEntryFilterService extends QueryParamFilterService<ObservableCtiEntryClientFilter> {
  constructor(protected router: Router, protected activatedRoute: ActivatedRoute) {
    super(router, activatedRoute);
  }

  protected toQueryParams(filter: ObservableCtiEntryClientFilter): Params {
    const params = super.toQueryParams(filter);
    if (filter.from) {
      params.from = filter.from.valueOf();
    }
    if (filter.to) {
      params.to = filter.to.valueOf();
    }
    params.externalReference = filter.externalReference;
    delete params.observableId;
    return params;
  }

  protected createEmptyFilter(): ObservableCtiEntryClientFilter {
    return {
      observableId: undefined,
      from: undefined,
      to: undefined,
      externalReference: undefined,
    };
  }

  protected createFilterFromRoute(
    queryParamMap: ParamMap,
    paramMap: ParamMap
  ): Observable<ObservableCtiEntryClientFilter> {
    const from = this.deslugifyTimestamp(queryParamMap.get('from'));
    const to = this.deslugifyTimestamp(queryParamMap.get('to'));
    const externalReference = queryParamMap.get('externalReference') ?? '';
    const idParam = paramMap.get(OBSERVABLE_ID_PARAM_SELECTOR) ?? undefined;
    return of({
      observableId: idParam,
      from: from,
      to: to,
      externalReference: externalReference,
    });
  }
}
