import { Injectable } from '@angular/core';
import { CtiEntryFilter1AndFilterEntry, CtiEntryOrdEnum } from '@orion/graphql-types';
import { ObservableCtiEntryClientFilter, ObservableCTIEntryFilterConverter } from '@orion/observable-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import {
  GetObservableCtiEntriesQuery,
  GetObservableCtiEntriesQueryService,
  GetObservableCtiEntriesQueryVariables,
  ObservableCtiEntryFragment,
} from './graphql';
import { ApolloPaginatedFilterablePollingService } from '@orion/shared-services';

@Injectable()
export class ObservableCtiEntriesService extends ApolloPaginatedFilterablePollingService<
  GetObservableCtiEntriesQuery,
  GetObservableCtiEntriesQueryVariables,
  ObservableCtiEntryFragment,
  CtiEntryOrdEnum,
  ObservableCtiEntryClientFilter,
  CtiEntryFilter1AndFilterEntry
> {
  constructor(public getQuery: GetObservableCtiEntriesQueryService) {
    super(getQuery, 'Fetching CTI entries');
  }

  protected createFilterConverter(): FilterConverter<ObservableCtiEntryClientFilter, CtiEntryFilter1AndFilterEntry[]> {
    return new ObservableCTIEntryFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: ObservableCtiEntryClientFilter
  ): GetObservableCtiEntriesQueryVariables {
    return {
      ...this.createPaginationVariables(paginationEvent),
      ...this.createOrderVariables(paginationEvent.sort, paginationEvent.sortDir),
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected getQueryResponse(query: GetObservableCtiEntriesQuery): CursorPaginatedResponse<ObservableCtiEntryFragment> {
    return query?.getCtiEntryList;
  }

  protected strToOrderable(sort: string): Optional<CtiEntryOrdEnum> {
    return enumFromValue(CtiEntryOrdEnum, sort);
  }
}
