import { ChangeDetectionStrategy, Component, OnInit } from '@angular/core';
import { ctiEntryToExternalUrl } from '@orion/observable-components/shared-cti-entry-external-url';
import { EntityDetailPageBaseDirective } from '@orion/shared-components/entity-base';
import { SentinelControlItem } from '@sentinel/components/controls';
import { defer, Observable, of } from 'rxjs';
import { map } from 'rxjs/operators';
import { CtiEntryDetailService } from './cti-entry-detail.service';
import { CtiEntryDetailFragment } from './graphql';

@Component({
  selector: 'orion-cti-entry-detail-page',
  templateUrl: './cti-entry-detail-page.component.html',
  styleUrls: ['./cti-entry-detail-page.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [CtiEntryDetailService],
})
export class CtiEntryDetailPageComponent
  extends EntityDetailPageBaseDirective<CtiEntryDetailFragment>
  implements OnInit
{
  controls$?: Observable<SentinelControlItem[]>;

  constructor(protected ctiEntryService: CtiEntryDetailService) {
    super(ctiEntryService);
  }

  ngOnInit(): void {
    super.ngOnInit();
    this.controls$ = this.entity$?.pipe(
      map((entity) => {
        return [
          new SentinelControlItem(
            'externalLink',
            'Open in External Data Source',
            'primary',
            of(false),
            defer(() => this.openInExternalDataSource(entity))
          ),
        ];
      })
    );
  }

  private openInExternalDataSource(ctiEntry?: CtiEntryDetailFragment): void {
    window.open(ctiEntryToExternalUrl(ctiEntry), '_blank');
  }
}
