import { Injectable } from '@angular/core';
import { ObservableLinkFilter1AndFilterEntry, ObservableLinkOrdEnum } from '@orion/graphql-types';
import { ObservableLinkClientFilter, ObservableLinkFilterConverter } from '@orion/observable-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import {
  CtiEntryDetailTabObservablesFragment,
  GetObservableLinkOverviewQuery,
  GetObservableLinkOverviewQueryService,
  GetObservableLinkOverviewQueryVariables,
} from './graphql';
import { ApolloPaginatedFilterablePollingService } from '@orion/shared-services';

@Injectable()
export class ObservableLinkOverviewService extends ApolloPaginatedFilterablePollingService<
  GetObservableLinkOverviewQuery,
  GetObservableLinkOverviewQueryVariables,
  CtiEntryDetailTabObservablesFragment,
  ObservableLinkOrdEnum,
  ObservableLinkClientFilter,
  ObservableLinkFilter1AndFilterEntry
> {
  constructor(getQuery: GetObservableLinkOverviewQueryService) {
    super(getQuery, 'Fetching observable links');
  }

  protected createFilterConverter(): FilterConverter<
    ObservableLinkClientFilter,
    ObservableLinkFilter1AndFilterEntry[]
  > {
    return new ObservableLinkFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: ObservableLinkClientFilter
  ): GetObservableLinkOverviewQueryVariables {
    return {
      ...this.createPaginationVariables(paginationEvent),
      ...this.createOrderVariables(paginationEvent.sort, paginationEvent.sortDir),
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected getQueryResponse(
    query: GetObservableLinkOverviewQuery
  ): CursorPaginatedResponse<CtiEntryDetailTabObservablesFragment> {
    return query.getObservableLinkList;
  }

  protected strToOrderable(sort: string): Optional<ObservableLinkOrdEnum> {
    return enumFromValue(ObservableLinkOrdEnum, sort);
  }
}
