import { Injectable } from '@angular/core';
import { TtpLinkFilter1AndFilterEntry, TtpLinkOrdEnum } from '@orion/graphql-types';
import { TtpLinkClientFilter, TtpLinkFilterConverter } from '@orion/observable-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import {
  CtiEntryDetailTabTtpsFragment,
  GetTttpLinkOverviewQuery,
  GetTttpLinkOverviewQueryService,
  GetTttpLinkOverviewQueryVariables,
} from './graphql';
import { ApolloPaginatedFilterablePollingService } from '@orion/shared-services';

@Injectable()
export class TtpLinkOverviewService extends ApolloPaginatedFilterablePollingService<
  GetTttpLinkOverviewQuery,
  GetTttpLinkOverviewQueryVariables,
  CtiEntryDetailTabTtpsFragment,
  TtpLinkOrdEnum,
  TtpLinkClientFilter,
  TtpLinkFilter1AndFilterEntry
> {
  constructor(getQuery: GetTttpLinkOverviewQueryService) {
    super(getQuery, 'Fetching TTP links');
  }

  protected createFilterConverter(): FilterConverter<TtpLinkClientFilter, TtpLinkFilter1AndFilterEntry[]> {
    return new TtpLinkFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: TtpLinkClientFilter
  ): GetTttpLinkOverviewQueryVariables {
    return {
      ...this.createPaginationVariables(paginationEvent),
      ...this.createOrderVariables(paginationEvent.sort, paginationEvent.sortDir),
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected getQueryResponse(query: GetTttpLinkOverviewQuery): CursorPaginatedResponse<CtiEntryDetailTabTtpsFragment> {
    return query.getTtpLinkList;
  }

  protected strToOrderable(sort: string): Optional<TtpLinkOrdEnum> {
    return enumFromValue(TtpLinkOrdEnum, sort);
  }
}
