import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  CtiEntryDetailFragment,
  GetCtiEntryDetailQuery,
  GetCtiEntryDetailQueryService,
  GetCtiEntryDetailQueryVariables,
} from './graphql';
import { CTI_ENTRY_ID_PARAM_SELECTOR } from '@orion/observable-paths';

@Injectable()
export class CtiEntryDetailService extends ApolloRoutedEntityService<
  GetCtiEntryDetailQuery,
  GetCtiEntryDetailQueryVariables,
  CtiEntryDetailFragment
> {
  constructor(getQuery: GetCtiEntryDetailQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching CTI entry');
  }

  protected createVariables(entityId: string): GetCtiEntryDetailQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(CTI_ENTRY_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetCtiEntryDetailQuery): Optional<CtiEntryDetailFragment> {
    return query?.getCtiEntry;
  }
}
