import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import {
  GetUrlObservableQuery,
  GetUrlObservableQueryService,
  GetUrlObservableQueryVariables,
  UrlObservableDetailFragment,
} from '@orion/observable-components/detail-url-graphql';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import { OBSERVABLE_ID_PARAM_SELECTOR } from '@orion/observable-paths';

@Injectable()
export class UrlObservableDetailService extends ApolloRoutedEntityService<
  GetUrlObservableQuery,
  GetUrlObservableQueryVariables,
  UrlObservableDetailFragment
> {
  constructor(getQuery: GetUrlObservableQueryService, activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching URL');
  }

  protected createVariables(entityId: string): GetUrlObservableQueryVariables {
    return { id: entityId };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(OBSERVABLE_ID_PARAM_SELECTOR);
  }

  protected toFragment(query: GetUrlObservableQuery): Optional<UrlObservableDetailFragment> {
    return query?.getUrl;
  }
}
