import { Injectable } from '@angular/core';
import {
  ObservableLinkClientFilter,
  ObservableLinkTypeFilterChip,
  ObservableTypeFilterChip,
} from '@orion/observable-types';
import { FilterChip } from '@csirtmu-orion/microframework/filter';
import { FilterChipsService } from '@csirtmu-orion/microframework/filter-services';
import { ObservableLinkFilterService } from './observable-link-filter.service';

@Injectable()
export class ObservableLinkFilterChipsService extends FilterChipsService<ObservableLinkClientFilter> {
  constructor(protected filterService: ObservableLinkFilterService) {
    super(filterService);
  }

  protected createChips(filter: ObservableLinkClientFilter | undefined): FilterChip[] {
    if (filter === undefined || filter === this.filterService.EMPTY_FILTER) {
      return [];
    } else {
      const chips = [];
      if (filter.type) {
        chips.push(new ObservableTypeFilterChip(filter.type));
      }
      if (filter.observableLinkType) {
        chips.push(new ObservableLinkTypeFilterChip(filter.observableLinkType));
      }
      return chips;
    }
  }

  removeChip(removedChip: FilterChip): void {
    if (removedChip instanceof ObservableTypeFilterChip) {
      this.filterService.updateAndSubmit({ type: undefined });
    }
    if (removedChip instanceof ObservableLinkTypeFilterChip) {
      this.filterService.updateAndSubmit({ observableLinkType: undefined });
    }
  }
}
