import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap, Params, Router } from '@angular/router';
import { KnownObservablesEnum, ObservableLinkTypeEnum } from '@orion/graphql-types';
import { CTI_ENTRY_ID_PARAM_SELECTOR } from '@orion/observable-paths';
import { ObservableLinkClientFilter } from '@orion/observable-types';
import { QueryParamFilterService } from '@csirtmu-orion/microframework/filter-services';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import { Observable, of } from 'rxjs';

@Injectable()
export class ObservableLinkFilterService extends QueryParamFilterService<ObservableLinkClientFilter> {
  constructor(protected router: Router, protected activatedRoute: ActivatedRoute) {
    super(router, activatedRoute);
  }

  protected createEmptyFilter(): ObservableLinkClientFilter {
    return { type: undefined, observableLinkType: undefined, ctiEntryId: undefined };
  }

  protected toQueryParams(filter: ObservableLinkClientFilter): Params {
    const params = super.toQueryParams(filter);
    delete params.ctiEntryId;
    return params;
  }

  protected createFilterFromRoute(queryParamMap: ParamMap, paramMap: ParamMap): Observable<ObservableLinkClientFilter> {
    const typeParam = queryParamMap.get('type');
    const observableLinkTypeParam = queryParamMap.get('observableLinkType');
    const ctiEntryIdParam = paramMap.get(CTI_ENTRY_ID_PARAM_SELECTOR);
    const type = this.resolveObservableType(this.deslugify(typeParam));
    const observableLinkType = this.resolveObservableLinkType(this.deslugify(observableLinkTypeParam));
    return of({ observableLinkType: observableLinkType, type: type, ctiEntryId: ctiEntryIdParam ?? undefined });
  }

  private resolveObservableType(value?: string): Optional<KnownObservablesEnum> {
    return value ? enumFromValue(KnownObservablesEnum, value) : undefined;
  }

  private resolveObservableLinkType(value?: string): Optional<ObservableLinkTypeEnum> {
    return value ? enumFromValue(ObservableLinkTypeEnum, value) : undefined;
  }
}
