import { Injectable } from '@angular/core';
import { ObservableClientFilter, ObservableTypeFilterChip } from '@orion/observable-types';
import { FilterChip, StringValueChip } from '@csirtmu-orion/microframework/filter';
import { FilterChipsService } from '@csirtmu-orion/microframework/filter-services';
import { ObservableFilterService } from './observable-filter.service';

@Injectable()
export class ObservableFilterChipsService extends FilterChipsService<ObservableClientFilter> {
  constructor(protected filterService: ObservableFilterService) {
    super(filterService);
  }

  protected createChips(filter: ObservableClientFilter | undefined): FilterChip[] {
    if (filter === undefined || filter === this.filterService.EMPTY_FILTER) {
      return [];
    } else {
      const chips = [];
      if (filter.type) {
        chips.push(new ObservableTypeFilterChip(filter.type));
      }
      if (filter.termSearch) {
        chips.push(new StringValueChip(filter.termSearch));
      }
      return chips;
    }
  }

  removeChip(removedChip: FilterChip): void {
    if (removedChip instanceof ObservableTypeFilterChip) {
      this.filterService.updateAndSubmit({ type: undefined });
    }
    if (removedChip instanceof StringValueChip) {
      this.filterService.updateAndSubmit({ termSearch: undefined });
    }
  }
}
