import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap, Router } from '@angular/router';
import { KnownObservablesEnum } from '@orion/graphql-types';
import { ObservableClientFilter } from '@orion/observable-types';
import { QueryParamFilterService } from '@csirtmu-orion/microframework/filter-services';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import { Observable, of } from 'rxjs';

@Injectable()
export class ObservableFilterService extends QueryParamFilterService<ObservableClientFilter> {
  constructor(protected router: Router, protected activatedRoute: ActivatedRoute) {
    super(router, activatedRoute);
  }

  protected createEmptyFilter(): ObservableClientFilter {
    return { type: undefined, termSearch: undefined };
  }

  protected createFilterFromRoute(queryParamMap: ParamMap, paramMap: ParamMap): Observable<ObservableClientFilter> {
    const typeParam = queryParamMap.get('type');
    const searchTermParam = queryParamMap.get('termSearch');
    if (typeParam === null && searchTermParam === null) {
      return of(this.EMPTY_FILTER);
    }
    const type = this.resolveType(this.deslugify(typeParam));
    const termSearch = this.deslugify(searchTermParam);
    return of({ type, termSearch });
  }

  private resolveType(value?: string): Optional<KnownObservablesEnum> {
    return value ? enumFromValue(KnownObservablesEnum, value) : undefined;
  }
}
