import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap, Params, Router } from '@angular/router';
import { KnownObservablesEnum } from '@orion/graphql-types';
import { RelatedObservableClientFilter } from '@orion/observable-types';
import { QueryParamFilterService } from '@csirtmu-orion/microframework/filter-services';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import { Observable, of } from 'rxjs';

@Injectable()
export class RelatedObservableFilterService extends QueryParamFilterService<RelatedObservableClientFilter> {
  constructor(protected router: Router, protected activatedRoute: ActivatedRoute) {
    super(router, activatedRoute);
  }

  protected toQueryParams(filter: RelatedObservableClientFilter): Params {
    const params = super.toQueryParams(filter);
    delete params.taskIds;
    delete params.caseId;
    return params;
  }

  protected createEmptyFilter(): RelatedObservableClientFilter {
    return { observableType: undefined };
  }

  protected createFilterFromRoute(
    queryParamMap: ParamMap,
    paramMap: ParamMap
  ): Observable<RelatedObservableClientFilter> {
    const observableTypeParam = queryParamMap.get('observableType');
    if (observableTypeParam === null) {
      return of(this.EMPTY_FILTER);
    }
    const observableType = this.resolveObservableType(this.deslugify(observableTypeParam));
    return of({ observableType });
  }

  private resolveObservableType(value?: string): Optional<KnownObservablesEnum> {
    return value ? enumFromValue(KnownObservablesEnum, value) : undefined;
  }
}
