import { Injectable } from '@angular/core';
import { ObservableFilter1AndFilterEntry, ObservableOrdEnum } from '@orion/graphql-types';
import { ObservableClientFilter, ObservableFilterConverter } from '@orion/observable-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import {
  GetObservableOverviewQuery,
  GetObservableOverviewQueryService,
  GetObservableOverviewQueryVariables,
  ObservableOverviewElementFragment,
} from './graphql';
import { ApolloPaginatedFilterablePollingService } from '@orion/shared-services';

@Injectable()
export class ObservablesOverviewService extends ApolloPaginatedFilterablePollingService<
  GetObservableOverviewQuery,
  GetObservableOverviewQueryVariables,
  ObservableOverviewElementFragment,
  ObservableOrdEnum,
  ObservableClientFilter,
  ObservableFilter1AndFilterEntry
> {
  constructor(public getQuery: GetObservableOverviewQueryService) {
    super(getQuery, 'Fetching observables');
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: ObservableClientFilter
  ): GetObservableOverviewQueryVariables {
    return {
      ...this.createPaginationVariables(paginationEvent),
      ...this.createOrderVariables(paginationEvent.sort, paginationEvent.sortDir),
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected createFilterConverter(): FilterConverter<ObservableClientFilter, ObservableFilter1AndFilterEntry[]> {
    return new ObservableFilterConverter();
  }

  protected getQueryResponse(
    query: GetObservableOverviewQuery
  ): CursorPaginatedResponse<ObservableOverviewElementFragment> {
    return query.getObservableList;
  }

  protected strToOrderable(sort: string): Optional<ObservableOrdEnum> {
    return enumFromValue(ObservableOrdEnum, sort);
  }
}
