import { ChangeDetectionStrategy, Component } from '@angular/core';
import { ObservableOrdEnum } from '@orion/graphql-types';
import { ObservableSelectionFragment } from '@orion/observable-components/observable-selection';
import { ObservableClientFilter } from '@orion/observable-types';
import {
  AddEntityControlsService,
  AddPaginableEntityDirective,
  CreateEntityAssociationService,
} from '@orion/shared-components/related-entity-overview';
import { EntityAddAssociationService } from '@orion/shared-services';
import {
  INIT_PAGINATION_EVENT_BASE_TOKEN,
  PaginationBaseInit,
  PaginationService,
} from '@csirtmu-orion/microframework/pagination-services';
import { EntityAddObservablesFilterService } from './entity-add-observables-filter.service';
import { ObservablesListService } from './observables-list.service';

@Component({
  selector: 'orion-add-related-observables',
  templateUrl: './add-related-observables.component.html',
  styleUrls: ['./add-related-observables.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [
    PaginationService,
    AddEntityControlsService,
    ObservablesListService,
    {
      provide: INIT_PAGINATION_EVENT_BASE_TOKEN,
      useValue: new PaginationBaseInit(50, ObservableOrdEnum.OBSERVABLE_TYPE, 'asc'),
    },
  ],
})
export class AddRelatedObservablesComponent extends AddPaginableEntityDirective<
  ObservableSelectionFragment,
  ObservableClientFilter
> {
  constructor(
    protected selectionService: EntityAddAssociationService<ObservableSelectionFragment>,
    protected controlsService: AddEntityControlsService,
    protected paginationService: PaginationService,
    protected filterService: EntityAddObservablesFilterService,
    protected observablesService: ObservablesListService,
    protected addEntityService: CreateEntityAssociationService
  ) {
    super(selectionService, controlsService, paginationService, filterService, observablesService, addEntityService);
  }

  protected createFilter(searchValue: string): ObservableClientFilter {
    return { termSearch: searchValue };
  }
}
