import { Injectable } from '@angular/core';
import { ObservableFilter1AndFilterEntry, ObservableOrdEnum } from '@orion/graphql-types';
import { ObservableSelectionFragment } from '@orion/observable-components/observable-selection';
import { ObservableClientFilter, ObservableFilterConverter } from '@orion/observable-types';
import { ApolloPaginatedFilterableService } from '@csirtmu-orion/microframework/apollo-services';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import { GetObservableListQuery, GetObservableListQueryService, GetObservableListQueryVariables } from './graphql';

@Injectable()
export class ObservablesListService extends ApolloPaginatedFilterableService<
  GetObservableListQuery,
  GetObservableListQueryVariables,
  ObservableSelectionFragment,
  ObservableOrdEnum,
  ObservableClientFilter,
  ObservableFilter1AndFilterEntry
> {
  constructor(public getQuery: GetObservableListQueryService) {
    super(getQuery, 'Fetching observables');
  }

  protected createFilterConverter(): FilterConverter<ObservableClientFilter, ObservableFilter1AndFilterEntry[]> {
    return new ObservableFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: ObservableClientFilter
  ): GetObservableListQueryVariables {
    return {
      ...this.createPaginationVariables(paginationEvent),
      ...this.createOrderVariables(paginationEvent.sort, paginationEvent.sortDir),
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected getQueryResponse(query: GetObservableListQuery): CursorPaginatedResponse<ObservableSelectionFragment> {
    return query?.getObservableList;
  }

  protected strToOrderable(sort: string): Optional<ObservableOrdEnum> {
    return enumFromValue(ObservableOrdEnum, sort);
  }
}
