import { Injectable } from '@angular/core';
import { ObservableFederationBaseFilterAndFilterEntry } from '@orion/graphql-types';
import { RelatedObservableClientFilter, RelatedObservableFilterConverter } from '@orion/observable-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import {
  GetRelatedObservablesQuery,
  GetRelatedObservablesQueryService,
  GetRelatedObservablesQueryVariables,
  RelatedObservableFragment,
} from './graphql';
import { ApolloFilterablePollingService } from '@orion/shared-services';

@Injectable()
export class RelatedObservableService extends ApolloFilterablePollingService<
  GetRelatedObservablesQuery,
  GetRelatedObservablesQueryVariables,
  RelatedObservableFragment,
  RelatedObservableClientFilter,
  ObservableFederationBaseFilterAndFilterEntry[]
> {
  public constructor(public getQuery: GetRelatedObservablesQueryService) {
    super(getQuery, 'Fetching related observables');
  }

  protected createFilterConverter(): FilterConverter<
    RelatedObservableClientFilter,
    ObservableFederationBaseFilterAndFilterEntry[]
  > {
    return new RelatedObservableFilterConverter();
  }

  protected createVariables(clientFilter: RelatedObservableClientFilter): GetRelatedObservablesQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected toFragments(query: GetRelatedObservablesQuery): RelatedObservableFragment[] {
    return query?.getFederatedObservableList?.data;
  }
}
