import { ChangeDetectionStrategy, Component, OnChanges, Optional, SimpleChanges } from '@angular/core';
import { KnownObservablesEnum } from '@orion/graphql-types';
import { RelatedObservableClientFilter } from '@orion/observable-types';
import {
  CreateAssociationViewStateService,
  RelatedEntityControlsService,
  RelatedEntityOverviewDirective,
} from '@orion/shared-components/related-entity-overview';
import { enumFromValue } from '@sentinel/common/utils';
import { EntityAddObservablesFilterService } from './add-related-observables';
import { RelatedObservableFragment } from './graphql';

@Component({
  selector: 'orion-related-observables-overview',
  templateUrl: './related-observables-overview.component.html',
  styleUrls: ['./related-observables-overview.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [EntityAddObservablesFilterService],
})
export class RelatedObservablesOverviewComponent
  extends RelatedEntityOverviewDirective<RelatedObservableFragment, RelatedObservableClientFilter>
  implements OnChanges
{
  constructor(
    @Optional() protected controlsService: RelatedEntityControlsService,
    @Optional() protected viewStateService: CreateAssociationViewStateService,
    private filterService: EntityAddObservablesFilterService
  ) {
    super(controlsService, viewStateService);
  }

  ngOnChanges(changes: SimpleChanges): void {
    super.ngOnChanges(changes);
    if ('entities' in changes && this.entities && this.entities.length > 0) {
      const relatedObservables = this.entities.map((entity) => {
        const type = entity.observableType
          ? enumFromValue(KnownObservablesEnum, entity.observableType)
          : KnownObservablesEnum.OBSERVABLE;
        return {
          id: entity.id,
          type: type ?? KnownObservablesEnum.OBSERVABLE,
        };
      });
      this.filterService.exclude(relatedObservables);
    }
  }
}
