import { ChangeDetectionStrategy, Component, Input, OnChanges, SimpleChanges } from '@angular/core';
import { IpNetworkAddressType } from '@orion/graphql-types';
import { trackByIndex } from '@sentinel/common/utils';
import { NetworkTypeInfoFragment } from '../network-type-info';
import { AddressTypeInfoFragment } from './address-type-info.fragment.generated';

@Component({
  selector: 'orion-address-type-info',
  templateUrl: './address-type-info.component.html',
  styleUrls: ['./address-type-info.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class AddressTypeInfoComponent implements OnChanges {
  @Input() address?: AddressTypeInfoFragment | NetworkTypeInfoFragment | IpNetworkAddressType;
  reversePointer?: string;
  addressAttributes: string[] = [];
  trackByFn = trackByIndex;

  ngOnChanges(changes: SimpleChanges): void {
    if ('address' in changes && this.address) {
      this.addressAttributes = this.resolveAttributes(this.address);
      if (this.hasReversePointer(this.address)) {
        this.reversePointer = this.address.reversePointer;
      }
    }
  }

  private resolveAttributes(
    address: AddressTypeInfoFragment | NetworkTypeInfoFragment | IpNetworkAddressType
  ): string[] {
    const attributes: string[] = [];
    if (address.isGlobal) {
      attributes.push('global');
    }
    if (address.isLinkLocal) {
      attributes.push('link local');
    }
    if (address.isLoopback) {
      attributes.push('loopback');
    }
    if (address.isMulticast) {
      attributes.push('multicast');
    }
    if (address.isPrivate) {
      attributes.push('private');
    }
    if (address.isReserved) {
      attributes.push('reserved');
    }
    if (address.isUnspecified) {
      attributes.push('unspecified');
    }
    return attributes;
  }

  private hasReversePointer(
    address: AddressTypeInfoFragment | NetworkTypeInfoFragment | IpNetworkAddressType
  ): address is AddressTypeInfoFragment | IpNetworkAddressType {
    return address?.__typename === 'AddressType' || address?.__typename === 'IPNetworkAddressType';
  }
}
