import { ChangeDetectionStrategy, Component, Input, OnChanges, SimpleChanges } from '@angular/core';
import {
  DomainToIPv4Resolution,
  DomainToIPv4ResolutionNestedList,
  DomainToIPv6Resolution,
  DomainToIPv6ResolutionNestedList,
} from '@orion/graphql-types';
import { Ipv6AddressObservableDetailFragment } from '@orion/observable-components/detail-ipv6-address-graphql';
import { ObservableTableFragment } from '@orion/observable-components/shared-observable-table';
import { Ipv4AddressRelatedObservablesFragment } from './ipv4-address-related-observables.fragment.generated';

@Component({
  selector: 'orion-ip-address-related-observables',
  templateUrl: './ip-address-related-observables.component.html',
  styleUrls: ['./ip-address-related-observables.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class IpAddressRelatedObservablesComponent implements OnChanges {
  @Input() ipAddress?: Ipv4AddressRelatedObservablesFragment | Ipv6AddressObservableDetailFragment;
  isResolutionFor: ObservableTableFragment[] = [];

  ngOnChanges(changes: SimpleChanges): void {
    if (
      'ipAddress' in changes &&
      this.ipAddress &&
      this.ipAddress.isResolutionFor?.data &&
      this.ipAddress.isResolutionFor.data.length > 0
    ) {
      this.isResolutionFor = this.mapDomains(
        this.ipAddress.isResolutionFor as DomainToIPv4ResolutionNestedList | DomainToIPv6ResolutionNestedList
      );
    }
  }

  private mapDomains(
    domains: DomainToIPv4ResolutionNestedList | DomainToIPv6ResolutionNestedList
  ): ObservableTableFragment[] {
    const resolutionFor: ObservableTableFragment[] = [];
    if (domains.data.length > 0) {
      resolutionFor.push(
        ...domains.data.map((domain: DomainToIPv4Resolution | DomainToIPv6Resolution) => domain.sourceDomain)
      );
    }
    return resolutionFor;
  }
}
