import { Injectable } from '@angular/core';
import { CanLoad, Route, Router, UrlSegment, UrlTree } from '@angular/router';
import { ObservableBaseViewFragment } from '@orion/observable-components/base-view';
import { from, Observable, of } from 'rxjs';
import { concatMap, map } from 'rxjs/operators';
import { ObservableNavigator } from '../observable-navigator.service';
import { GetObservableQueryService } from './graphql';

@Injectable()
export class ObservableRedirectService implements CanLoad {
  constructor(
    private query: GetObservableQueryService,
    private router: Router,
    private observableNavigator: ObservableNavigator
  ) {}

  canLoad(
    route: Route,
    segments: UrlSegment[]
  ): Observable<boolean | UrlTree> | Promise<boolean | UrlTree> | boolean | UrlTree {
    const id = segments[segments.length - 1]?.path;
    if (id !== null && id !== undefined) {
      return this.getObservable(id).pipe(
        concatMap((observable) => {
          if (observable && observable.observableType) {
            return from(
              this.router.navigate([this.observableNavigator.toDetail(observable.id, observable.observableType)])
            );
          } else {
            return of(false);
          }
        })
      );
    } else {
      return false;
    }
  }

  private getObservable(id: string): Observable<ObservableBaseViewFragment | undefined> {
    return this.query
      .fetch({ id: id }, { fetchPolicy: 'cache-first' })
      .pipe(map((queryResult) => queryResult.data.getObservable));
  }
}
