import { ObservableFilter1, ObservableFilter1AndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { ObservableClientFilter, ObservableIdentification } from './observable-client-filter';

export class ObservableFilterConverter
  implements FilterConverter<ObservableClientFilter, ObservableFilter1AndFilterEntry[]>
{
  convert(source?: ObservableClientFilter): ObservableFilter1AndFilterEntry[] {
    const mainAndFilter: ObservableFilter1 = {};
    const otherFilters: ObservableFilter1AndFilterEntry[] = [];

    if (source?.id !== undefined && source.id !== '') {
      mainAndFilter.id = { exact: source.id };
    }
    if (source?.type !== undefined) {
      mainAndFilter.observableType = { iexact: source.type };
    }
    if (source?.termSearch !== undefined && source?.termSearch !== '') {
      otherFilters.push(this.createTermFilter(source?.termSearch));
    }
    if (source?.notIn && source.notIn.length > 0) {
      otherFilters.push(...this.createNotInFilter(source.notIn));
    }
    if (source?.termSearchOrId) {
      const isNumber = !Number.isNaN(Number.parseInt(source.termSearchOrId));
      if (isNumber) {
        return [
          {
            AND: [
              { OR: mainAndFilter },
              { OR: { id: { exact: source.termSearchOrId } } },
              { OR: { name: { icontains: source.termSearchOrId } } },
            ],
          },
        ];
      } else {
        return [
          {
            AND: [{ OR: mainAndFilter }, { OR: { name: { icontains: source.termSearchOrId } } }],
          },
        ];
      }
    }
    return [{ AND: [{ OR: mainAndFilter }] }, ...otherFilters];
  }

  private createTermFilter(term: string): ObservableFilter1AndFilterEntry {
    return {
      AND: [
        // {
        //   OR: {
        //     address: { netContainsOrEquals: term },
        //   },
        // },
        {
          OR: {
            domainName: { icontains: term },
          },
        },
        {
          OR: {
            resolvedDomain: { domainName: { icontains: term } },
          },
        },
        {
          OR: {
            resolutionDomain: { domainName: { icontains: term } },
          },
        },
        {
          OR: {
            originalDomain: { domainName: { icontains: term } },
          },
        },
        {
          OR: {
            sourceDomain: { domainName: { icontains: term } },
          },
        },
        {
          OR: {
            hashes: { value: { icontains: term } },
          },
        },
        {
          OR: {
            name: { icontains: term },
          },
        },
        {
          OR: {
            rawUrl: { icontains: term },
          },
        },
        {
          OR: {
            reference: { icontains: term },
          },
        },
        {
          OR: {
            rawEmailAddress: { icontains: term },
          },
        },
        {
          OR: {
            rawReference: { icontains: term },
          },
        },
        {
          OR: {
            subject: { icontains: term },
          },
        },
        {
          OR: {
            observableType: { icontains: term },
          },
        },
        {
          OR: {
            username: { icontains: term },
          },
        },
        {
          OR: {
            emailAddresses: { emailAddress: { rawEmailAddress: { icontains: term } } },
          },
        },
        {
          OR: {
            sourceEmailMessage: { subject: { icontains: term } },
          },
        },
        {
          OR: {
            emailAddress: { rawEmailAddress: { icontains: term } },
          },
        },
      ],
    };
  }

  // creating list of AND filters that filter out observables. A bit complex because Observables are identified by its id AND type.
  private createNotInFilter(notIn: ObservableIdentification[]): ObservableFilter1AndFilterEntry[] {
    return notIn.map((observable) => {
      return {
        AND: [{ negate: true, OR: { id: { exact: observable.id }, observableType: { iexact: observable.type } } }],
      };
    });
  }
}
