import { FragmentTypes, PossibleTypesResultData } from '@orion/fragment-matcher';

export type ObservableTypename = PossibleTypesResultData['possibleTypes']['Observable'][number];
const OBSERVABLE_TYPENAMES: ObservableTypename[] = FragmentTypes.possibleTypes.Observable;

export class ObservableIconResolver {
  private static map: Map<ObservableTypename, string> = ObservableIconResolver.createMap();

  private static createMap(): Map<ObservableTypename, string> {
    const map = new Map<ObservableTypename, string>([
      ['BaseHashableObservable', ''],
      ['BaseHost', ''],
      ['BaseObservable', ''],
      ['DomainName', 'domain'],
      ['DomainToDomainResolution', 'account_tree'],
      ['DomainToIPAddressResolution', 'account_tree'],
      ['EmailAddress', 'alternate_email'],
      ['EmailMessage', 'email'],
      ['EmailMessageEmailAddressRelationship', 'account_tree'],
      ['EmailMessagePartsRelationship', 'account_tree'],
      ['FileReference', 'description'],
      ['IPAddress', 'public'],
      ['IPAddressToDomainResolution', 'account_tree'],
      ['URL', 'link'],
    ]);
    if (map.size < OBSERVABLE_TYPENAMES.length) {
      console.warn(
        'ObservableIconMap is not properly initiated. There are Observable types missing an icon. These types will fallback to default icon'
      );
    }
    return map;
  }

  static resolve(typename?: ObservableTypename): string {
    const fallbackIcon = 'help_outline';
    if (typename) {
      return this.map.get(typename) ?? fallbackIcon;
    } else {
      return fallbackIcon;
    }
  }
}
