import {
  AllObservableFragments,
  isDomainNameObservable,
  isDomainToDomainObservable,
  isDomainToIpAddressResolutionObservable,
  isEmailAddressObservable,
  isEmailMessageObservable,
  isFileReferenceObservable,
  isIPAddressObservable,
  isIPAddressToDomainResolutionObservable,
  isURLObservable,
} from '@orion/observable-components/base-view';
import { formatObservableType } from './utils';

export class ObservableNameResolver {
  static resolve(observable?: AllObservableFragments, withTypename = false): string {
    if (observable === undefined) {
      return '';
    }
    const typename = formatObservableType(observable?.observableType ?? '');
    if (isIPAddressObservable(observable)) {
      return withTypename ? `${typename}: ${observable.address?.compressed}` : observable.address?.compressed;
    }
    if (isDomainNameObservable(observable)) {
      return withTypename ? `${typename}: ${observable.domainName}` : observable.domainName;
    }
    if (isDomainToDomainObservable(observable)) {
      const name = `${observable?.originalDomain?.domainName} to ${observable?.resolutionDomain?.domainName}` ?? '';
      return withTypename ? `${typename}: ${name}` : name;
    }
    if (isDomainToIpAddressResolutionObservable(observable)) {
      const name =
        `${observable?.sourceDomain?.domainName} to ${observable?.resolvedIpAddress?.address?.compressed}` ?? '';
      return withTypename ? `${typename}: ${name}` : name;
    }
    if (isIPAddressToDomainResolutionObservable(observable)) {
      const name =
        `${observable?.sourceIpAddress?.address?.compressed} to ${observable?.resolvedDomain?.domainName}` ?? '';
      return withTypename ? `${typename}: ${name}` : name;
    }
    if (isURLObservable(observable)) {
      return withTypename ? `${typename}: ${observable?.rawUrl}` : observable?.rawUrl;
    }
    if (isFileReferenceObservable(observable)) {
      return withTypename ? `${typename}: ${observable?.name}` : observable?.name;
    }
    if (isEmailAddressObservable(observable)) {
      return withTypename ? `${typename}: ${observable?.rawEmailAddress}` : observable?.rawEmailAddress;
    }
    if (isEmailMessageObservable(observable)) {
      const name = observable?.subject ? `${observable?.subject}` : observable?.id;
      return withTypename ? `${typename}: ${name}` : name;
    }
    return withTypename ? `${typename}: ${observable?.id}` : observable?.id;
  }
}
