import { Injectable } from '@angular/core';
import { OAuthService } from 'angular-oauth2-oidc';
import { filter } from 'rxjs/operators';
import { OrionDynamicEnvironment } from '@orion/env';
import { SentinelAuthContext } from '@sentinel/auth';

@Injectable({
  providedIn: 'root',
})
/**
 * This service listens to events indicating oidc init or receiving new access token and
 * sends token and other auth data to service worker intercepting browser fetch requests.
 * It allows browser to fetch images through <img src=""> tags from protected endpoints.
 */
export class OrionServiceWorkerConfigMessengerService {
  constructor(private oAuthService: OAuthService, private sentinelAuthContext: SentinelAuthContext) {
    this.oAuthService.events
      .pipe(
        filter(
          (event) =>
            event.type === 'discovery_document_loaded' ||
            event.type === 'token_received' ||
            event.type === 'token_refreshed'
        )
      )
      .subscribe(() => {
        const config = OrionDynamicEnvironment.getConfig();
        navigator.serviceWorker.controller?.postMessage({
          accessToken: this.oAuthService.getAccessToken(),
          interceptedUrl: config.apiConfig.caseFileStorageUrl,
          oidcProviderHeaderName: config.authConfig.oidcProviderHeaderName,
          oidcProviderHeaderValue:
            this.sentinelAuthContext.selectedProviderConfig?.oidcConfig?.options?.oidcProviderHeaderValue,
        });
      });
  }
}
