import { NgModule } from '@angular/core';
import { RouterModule, Routes } from '@angular/router';
import { AssetOverviewPageComponent } from '@orion/asset-components/overview';
import { ASSET_ICON, enumToPath } from '@orion/common';
import { KnownAssetsEnum } from '@orion/graphql-types';

const routes: Routes = [
  {
    path: '',
    title: 'Assets Overview',
    component: AssetOverviewPageComponent,
    data: {
      headline: 'Assets Overview',
      headlineIcon: ASSET_ICON,
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.AGGREGATE),
    loadChildren: () =>
      import('./type-overview/ipam/aggregate-overview/aggregate-overview.module').then(
        (m) => m.AggregateOverviewModule
      ),
    data: {
      breadcrumb: 'Aggregates',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.ASN),
    loadChildren: () =>
      import('./type-overview/ipam/asn-overview/asn-overview.module').then((m) => m.AsnOverviewModule),
    data: {
      breadcrumb: 'ASNs',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.FHRP_GROUP),
    loadChildren: () =>
      import('./type-overview/ipam/fhrp-group-overview/fhrp-group-overview.module').then(
        (m) => m.FhrpGroupOverviewModule
      ),
    data: {
      breadcrumb: 'FHRP Groups',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.IP_ADDRESS),
    loadChildren: () =>
      import('./type-overview/ipam/ip-address-overview/ip-address-overview.module').then(
        (m) => m.IpAddressOverviewModule
      ),
    data: {
      breadcrumb: 'IP Addresses',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.IP_RANGE),
    loadChildren: () =>
      import('./type-overview/ipam/ip-range-overview/ip-range-overview.module').then((m) => m.IpRangeOverviewModule),
    data: {
      breadcrumb: 'IP Ranges',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.PREFIX),
    loadChildren: () =>
      import('./type-overview/ipam/prefix-overview/prefix-overview.module').then((m) => m.PrefixOverviewModule),
    data: {
      breadcrumb: 'Prefixes',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.ROLE),
    loadChildren: () =>
      import('./type-overview/ipam/prefix-and-vlan-role-overview/prefix-and-vlan-role-overview.module').then(
        (m) => m.PrefixAndVlanRoleOverviewModule
      ),
    data: {
      breadcrumb: 'Prefix & VLAN Roles',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.RIR),
    loadChildren: () =>
      import('./type-overview/ipam/rir-overview/rir-overview.module').then((m) => m.RirOverviewModule),
    data: {
      breadcrumb: 'RIRs',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.ROUTE_TARGET),
    loadChildren: () =>
      import('./type-overview/ipam/route-target-overview/route-target-overview.module').then(
        (m) => m.RouteTargetOverviewModule
      ),
    data: {
      breadcrumb: 'Route Targets',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.SERVICE),
    loadChildren: () =>
      import('./type-overview/ipam/service-overview/service-overview.module').then((m) => m.ServiceOverviewModule),
    data: {
      breadcrumb: 'Services',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.VLAN),
    loadChildren: () =>
      import('./type-overview/ipam/vlan-overview/vlan-overview.module').then((m) => m.VlanOverviewModule),
    data: {
      breadcrumb: 'VLANs',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.VLAN_GROUP),
    loadChildren: () =>
      import('./type-overview/ipam/vlan-group-overview/vlan-group-overview.module').then(
        (m) => m.VlanGroupOverviewModule
      ),
    data: {
      breadcrumb: 'VLAN Groups',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.VRF),
    loadChildren: () =>
      import('./type-overview/ipam/vrf-overview/vrf-overview.module').then((m) => m.VrfOverviewModule),
    data: {
      breadcrumb: 'VRFs',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.LOCATION),
    loadChildren: () =>
      import('./type-overview/organization/location-overview/location-overview.module').then(
        (m) => m.LocationOverviewModule
      ),
    data: {
      breadcrumb: 'Locations',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.RACK),
    loadChildren: () =>
      import('./type-overview/organization/rack-overview/rack-overview.module').then((m) => m.RackOverviewModule),
    data: {
      breadcrumb: 'Racks',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.RACK_RESERVATION),
    loadChildren: () =>
      import('./type-overview/organization/rack-reservation-overview/rack-reservation-overview.module').then(
        (m) => m.RackReservationOverviewModule
      ),
    data: {
      breadcrumb: 'Rack Reservations',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.RACK_ROLE),
    loadChildren: () =>
      import('./type-overview/organization/rack-role-overview/rack-role-overview.module').then(
        (m) => m.RackRoleOverviewModule
      ),
    data: {
      breadcrumb: 'Rack Roles',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.REGION),
    loadChildren: () =>
      import('./type-overview/organization/region-overview/region-overview.module').then((m) => m.RegionOverviewModule),
    data: {
      breadcrumb: 'Regions',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.SITE_GROUP),
    loadChildren: () =>
      import('./type-overview/organization/site-group-overview/site-group-overview.module').then(
        (m) => m.SiteGroupOverviewModule
      ),
    data: {
      breadcrumb: 'Site Groups',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.SITE),
    loadChildren: () =>
      import('./type-overview/organization/site-overview/site-overview.module').then((m) => m.SiteOverviewModule),
    data: {
      breadcrumb: 'Sites',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.TENANT_GROUP),
    loadChildren: () =>
      import('./type-overview/organization/tenant-group-overview/tenant-group-overview.module').then(
        (m) => m.TenantGroupOverviewModule
      ),
    data: {
      breadcrumb: 'Tenant Groups',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.TENANT),
    loadChildren: () =>
      import('./type-overview/organization/tenant-overview/tenant-overview.module').then((m) => m.TenantOverviewModule),
    data: {
      breadcrumb: 'Tenants',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.CLUSTER_GROUP),
    loadChildren: () =>
      import('./type-overview/virtualization/cluster-group-overview/cluster-group-overview.module').then(
        (m) => m.ClusterGroupOverviewModule
      ),
    data: {
      breadcrumb: 'Cluster Groups',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.CLUSTER),
    loadChildren: () =>
      import('./type-overview/virtualization/cluster-overview/cluster-overview.module').then(
        (m) => m.ClusterOverviewModule
      ),
    data: {
      breadcrumb: 'Clusters',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.CLUSTER_TYPE),
    loadChildren: () =>
      import('./type-overview/virtualization/cluster-type-overview/cluster-type-overview.module').then(
        (m) => m.ClusterTypeOverviewModule
      ),
    data: {
      breadcrumb: 'Cluster Types',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.VM_INTERFACE),
    loadChildren: () =>
      import('./type-overview/virtualization/vm-interface-overview/vm-interface-overview.module').then(
        (m) => m.VmInterfaceOverviewModule
      ),
    data: {
      breadcrumb: 'VM Interfaces',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.VIRTUAL_MACHINE),
    loadChildren: () =>
      import('./type-overview/virtualization/vm-overview/vm-overview.module').then((m) => m.VmOverviewModule),
    data: {
      breadcrumb: 'Virtual Machines',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.CONSOLE_PORT),
    loadChildren: () =>
      import('./type-overview/devices/console-port-overview/console-port-overview.module').then(
        (m) => m.ConsolePortOverviewModule
      ),
    data: {
      breadcrumb: 'Console Ports',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.CONSOLE_SERVER_PORT),
    loadChildren: () =>
      import('./type-overview/devices/console-server-port-overview/console-server-port-overview.module').then(
        (m) => m.ConsoleServerPortOverviewModule
      ),
    data: {
      breadcrumb: 'Console Server Ports',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.DEVICE_BAY),
    loadChildren: () =>
      import('./type-overview/devices/device-bay-overview/device-bay-overview.module').then(
        (m) => m.DeviceBayOverviewModule
      ),
    data: {
      breadcrumb: 'Device Bays',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.DEVICE),
    loadChildren: () =>
      import('./type-overview/devices/device-overview/device-overview.module').then((m) => m.DeviceOverviewModule),
    data: {
      breadcrumb: 'Devices',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.DEVICE_ROLE),
    loadChildren: () =>
      import('./type-overview/devices/device-role-overview/device-role-overview.module').then(
        (m) => m.DeviceRoleOverviewModule
      ),
    data: {
      breadcrumb: 'Device Roles',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.DEVICE_TYPE),
    loadChildren: () =>
      import('./type-overview/devices/device-type-overview/device-type-overview.module').then(
        (m) => m.DeviceTypeOverviewModule
      ),
    data: {
      breadcrumb: 'Device Types',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.FRONT_PORT),
    loadChildren: () =>
      import('./type-overview/devices/front-port-overview/front-port-overview.module').then(
        (m) => m.FrontPortOverviewModule
      ),
    data: {
      breadcrumb: 'Front Ports',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.INTERFACE),
    loadChildren: () =>
      import('./type-overview/devices/interface-overview/interface-overview.module').then(
        (m) => m.InterfaceOverviewModule
      ),
    data: {
      breadcrumb: 'Interfaces',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.INVENTORY_ITEM),
    loadChildren: () =>
      import('./type-overview/devices/inventory-item-overview/inventory-item-overview.module').then(
        (m) => m.InventoryItemOverviewModule
      ),
    data: {
      breadcrumb: 'Inventory Items',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.MANUFACTURER),
    loadChildren: () =>
      import('./type-overview/devices/manufacturer-overview/manufacturer-overview.module').then(
        (m) => m.ManufacturerOverviewModule
      ),
    data: {
      breadcrumb: 'Manufacturers',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.PLATFORM),
    loadChildren: () =>
      import('./type-overview/devices/platform-overview/platform-asset-overview.module').then(
        (m) => m.PlatformAssetOverviewModule
      ),
    data: {
      breadcrumb: 'Platforms',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.POWER_OUTLET),
    loadChildren: () =>
      import('./type-overview/devices/power-outlet-overview/power-outlet-overview.module').then(
        (m) => m.PowerOutletOverviewModule
      ),
    data: {
      breadcrumb: 'Power Outlets',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.POWER_PORT),
    loadChildren: () =>
      import('./type-overview/devices/power-port-overview/power-port-overview.module').then(
        (m) => m.PowerPortOverviewModule
      ),
    data: {
      breadcrumb: 'Power Ports',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.REAR_PORT),
    loadChildren: () =>
      import('./type-overview/devices/rear-port-overview/rear-port-overview.module').then(
        (m) => m.RearPortOverviewModule
      ),
    data: {
      breadcrumb: 'Rear Ports',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.VIRTUAL_CHASSIS),
    loadChildren: () =>
      import('./type-overview/devices/virtual-chassis-overview/virtual-chassis-overview.module').then(
        (m) => m.VirtualChassisOverviewModule
      ),
    data: {
      breadcrumb: 'Virtual Chassis',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.CIRCUIT),
    loadChildren: () =>
      import('./type-overview/circuits/circuit-overview/circuit-overview.module').then((m) => m.CircuitOverviewModule),
    data: {
      breadcrumb: 'Circuits',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.CIRCUIT_TERMINATION),
    loadChildren: () =>
      import('./type-overview/circuits/circuit-termination-overview/circuit-termination-overview.module').then(
        (m) => m.CircuitTerminationOverviewModule
      ),
    data: {
      breadcrumb: 'Circuit Terminations',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.CIRCUIT_TYPE),
    loadChildren: () =>
      import('./type-overview/circuits/circuit-type-overview/circuit-type-overview.module').then(
        (m) => m.CircuitTypeOverviewModule
      ),
    data: {
      breadcrumb: 'Circuit Types',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.PROVIDER_NETWORK),
    loadChildren: () =>
      import('./type-overview/circuits/provider-network-overview/provider-network-overview.module').then(
        (m) => m.ProviderNetworkOverviewModule
      ),
    data: {
      breadcrumb: 'Provider Networks',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.PROVIDER),
    loadChildren: () =>
      import('./type-overview/circuits/provider-overview/provider-overview.module').then(
        (m) => m.ProviderOverviewModule
      ),
    data: {
      breadcrumb: 'Providers',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.CABLE),
    loadChildren: () =>
      import('./type-overview/connection/cable-overview/cable-overview.module').then((m) => m.CableOverviewModule),
    data: {
      breadcrumb: 'Cables',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.WIRELESS_LINK),
    loadChildren: () =>
      import('./type-overview/connection/wireless-link-overview/wireless-link-overview.module').then(
        (m) => m.WirelessLinkOverviewModule
      ),
    data: {
      breadcrumb: 'Wireless Links',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.POWER_FEED),
    loadChildren: () =>
      import('./type-overview/power/power-feed-overview/power-feed-overview.module').then(
        (m) => m.PowerFeedOverviewModule
      ),
    data: {
      breadcrumb: 'Power Feeds',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.POWER_PANEL),
    loadChildren: () =>
      import('./type-overview/power/power-panel-overview/power-panel-overview.module').then(
        (m) => m.PowerPanelOverviewModule
      ),
    data: {
      breadcrumb: 'Power Panels',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.WIRELESS_LAN),
    loadChildren: () =>
      import('./type-overview/wireless/wireless-lan-overview/wireless-lan-overview.module').then(
        (m) => m.WirelessLanOverviewModule
      ),
    data: {
      breadcrumb: 'Wireless LANs',
    },
  },
  {
    path: enumToPath(KnownAssetsEnum.WIRELESS_LAN_GROUP),
    loadChildren: () =>
      import('./type-overview/wireless/wireless-lan-group-overview/wireless-lan-group-overview.module').then(
        (m) => m.WirelessLanGroupOverviewModule
      ),
    data: {
      breadcrumb: 'Wireless LAN Groups',
    },
  },
];
@NgModule({
  imports: [RouterModule.forChild(routes)],
  exports: [RouterModule],
})
export class AssetOverviewRoutingModule {}
