import { NgModule } from '@angular/core';
import { RouterModule, Routes } from '@angular/router';
import { ConfirmationGuard } from '@orion/shared-services';
import { WorkflowDetailPageComponent } from '@orion/workflow-components/detail';
import { WorkflowTitleResolver } from '@orion/workflow-services';
import { StageBreadcrumbResolver } from '@orion/stage-services';
import { WORKFLOW_ICON } from '@orion/common';

const routes: Routes = [
  {
    path: '',
    title: WorkflowTitleResolver,
    component: WorkflowDetailPageComponent,
    canDeactivate: [ConfirmationGuard],
    data: {
      headline: 'Workflow Detail',
      headlineIcon: WORKFLOW_ICON,
    },
  },
  {
    path: `stage/create`,
    loadChildren: () => import('../stage/create/create-stage.module').then((m) => m.CreateStageModule),
  },
  {
    path: `stage/:stageId`,
    loadChildren: () => import('../stage/detail/stage-detail.module').then((m) => m.StageDetailModule),
    resolve: {
      breadcrumb: StageBreadcrumbResolver,
    },
  },
];

@NgModule({
  imports: [RouterModule.forChild(routes)],
  exports: [RouterModule],
})
export class WorkflowDetailRoutingModule {}
