import { NgModule } from '@angular/core';
import { RouterModule, Routes } from '@angular/router';
import { enumToPath, OBSERVABLE_ICON } from '@orion/common';
import { KnownObservablesEnum } from '@orion/graphql-types';
import { ObservableOverviewPageComponent } from '@orion/observable-components/overview';
import { CTI_ENTRIES_PATH, CTI_ENTRY_ID_PARAM_SELECTOR, OBSERVABLE_ID_PARAM_SELECTOR } from '@orion/observable-paths';
import {
  CtiEntryBreadcrumbResolver,
  DomainObservableBreadcrumbResolver,
  DomainToDomainObservableBreadcrumbResolver,
  DomainToIpAddressObservableBreadcrumbResolver,
  EmailAddressObservableBreadcrumbResolver,
  EmailMessageObservableBreadcrumbResolver,
  FileReferenceObservableBreadcrumbResolver,
  IpAddressObservableBreadcrumbResolver,
  IpAddressToDomainObservableBreadcrumbResolver,
  UrlObservableBreadcrumbResolver,
} from '@orion/observable-services';

const routes: Routes = [
  {
    path: '',
    title: 'Observables Overview',
    component: ObservableOverviewPageComponent,
    data: {
      headline: 'Observables Overview',
      headlineIcon: OBSERVABLE_ICON,
    },
  },
  {
    path: `${CTI_ENTRIES_PATH}/:${CTI_ENTRY_ID_PARAM_SELECTOR}`,
    loadChildren: () =>
      import('./cti-entry/cti-entry-detail/cti-entry-detail.module').then((m) => m.CtiEntryDetailModule),
    resolve: {
      breadcrumb: CtiEntryBreadcrumbResolver,
    },
  },
  {
    path: `${enumToPath(KnownObservablesEnum.DOMAIN_NAME)}/:${OBSERVABLE_ID_PARAM_SELECTOR}`,
    loadChildren: () => import('./detail/domain-detail/domain-detail.module').then((m) => m.DomainDetailModule),
    resolve: {
      breadcrumb: DomainObservableBreadcrumbResolver,
    },
  },
  {
    path: `${enumToPath(KnownObservablesEnum.DOMAIN_TO_DOMAIN_RESOLUTION)}/:${OBSERVABLE_ID_PARAM_SELECTOR}`,
    loadChildren: () =>
      import('./detail/domain-to-domain-resolution-detail/domain-to-domain-resolution-detail.module').then(
        (m) => m.DomainToDomainResolutionDetailModule
      ),
    resolve: {
      breadcrumb: DomainToDomainObservableBreadcrumbResolver,
    },
  },
  {
    path: `${enumToPath(KnownObservablesEnum.DOMAIN_TO_IP_ADDRESS_RESOLUTION)}/:${OBSERVABLE_ID_PARAM_SELECTOR}`,
    loadChildren: () =>
      import('./detail/domain-to-ip-address-resolution-detail/domain-to-ip-address-resolution-detail.module').then(
        (m) => m.DomainToIpAddressResolutionDetailModule
      ),
    resolve: {
      breadcrumb: DomainToIpAddressObservableBreadcrumbResolver,
    },
  },
  {
    path: `${enumToPath(KnownObservablesEnum.EMAIL_ADDRESS)}/:${OBSERVABLE_ID_PARAM_SELECTOR}`,
    loadChildren: () =>
      import('./detail/email-address-detail/email-address-detail.module').then((m) => m.EmailAddressDetailModule),
    resolve: {
      breadcrumb: EmailAddressObservableBreadcrumbResolver,
    },
  },
  {
    path: `${enumToPath(KnownObservablesEnum.EMAIL_MESSAGE)}/:${OBSERVABLE_ID_PARAM_SELECTOR}`,
    loadChildren: () =>
      import('./detail/email-message-detail/email-message-detail.module').then((m) => m.EmailMessageDetailModule),
    resolve: {
      breadcrumb: EmailMessageObservableBreadcrumbResolver,
    },
  },
  {
    path: `${enumToPath(KnownObservablesEnum.FILE_REFERENCE)}/:${OBSERVABLE_ID_PARAM_SELECTOR}`,
    loadChildren: () =>
      import('./detail/file-reference-detail/file-reference-detail.module').then((m) => m.FileReferenceDetailModule),
    resolve: {
      breadcrumb: FileReferenceObservableBreadcrumbResolver,
    },
  },
  {
    path: `${enumToPath(KnownObservablesEnum.IP_ADDRESS)}/:${OBSERVABLE_ID_PARAM_SELECTOR}`,
    loadChildren: () =>
      import('./detail/ip-address-detail/ip-address-detail.module').then((m) => m.IpAddressDetailModule),
    resolve: {
      breadcrumb: IpAddressObservableBreadcrumbResolver,
    },
  },
  {
    path: `${enumToPath(KnownObservablesEnum.IP_ADDRESS_TO_DOMAIN_RESOLUTION)}/:${OBSERVABLE_ID_PARAM_SELECTOR}`,
    loadChildren: () =>
      import('./detail/ip-address-to-domain-resolution-detail/ip-address-to-domain-resolution-detail.module').then(
        (m) => m.IpAddressToDomainResolutionDetailModule
      ),
    resolve: {
      breadcrumb: IpAddressToDomainObservableBreadcrumbResolver,
    },
  },
  {
    path: `${enumToPath(KnownObservablesEnum.URL)}/:${OBSERVABLE_ID_PARAM_SELECTOR}`,
    loadChildren: () => import('./detail/url-detail/url-detail.module').then((m) => m.UrlDetailModule),
    resolve: {
      breadcrumb: UrlObservableBreadcrumbResolver,
    },
  },
];

@NgModule({
  imports: [RouterModule.forChild(routes)],
  exports: [RouterModule],
})
export class ObservableOverviewRoutingModule {}
