import { NgModule } from '@angular/core';
import { RouterModule, Routes } from '@angular/router';
import { enumToPath, TTP_ICON } from '@orion/common';
import { KnownTtPsTypesEnum } from '@orion/graphql-types';
import { TTPsOverviewPageComponent } from '@orion/ttps-components/ttps-overview';
import {
  ALIAS_PARAM_SELECTOR,
  ALIAS_PATH,
  GROUP_PARAM_SELECTOR,
  GROUP_PATH,
  MALWARE_PARAM_SELECTOR,
  MALWARE_PATH,
  MITIGATION_PATH,
  PLATFORM_PATH,
  TOOL_PARAM_SELECTOR,
  TOOL_PATH,
} from '@orion/ttps-paths';
import {
  AliasBreadcrumbResolver,
  GroupBreadcrumbResolver,
  MalwareBreadcrumbResolver,
  ToolBreadcrumbResolver,
} from '@orion/ttps-services';

const routes: Routes = [
  {
    path: '',
    title: 'TTPs Overview',
    component: TTPsOverviewPageComponent,
    data: {
      headline: 'TTPs Overview',
      headlineIcon: TTP_ICON,
    },
  },
  {
    path: `${ALIAS_PATH}/:${ALIAS_PARAM_SELECTOR}`,
    loadChildren: () => import('../detail/alias/alias-detail.module').then((m) => m.AliasDetailModule),
    resolve: {
      breadcrumb: AliasBreadcrumbResolver,
    },
  },
  {
    path: `${GROUP_PATH}/:${GROUP_PARAM_SELECTOR}`,
    loadChildren: () => import('../detail/group/group-detail.module').then((m) => m.GroupDetailModule),
    resolve: {
      breadcrumb: GroupBreadcrumbResolver,
    },
  },
  {
    path: `${MALWARE_PATH}/:${MALWARE_PARAM_SELECTOR}`,
    loadChildren: () => import('../detail/malware/malware-detail.module').then((m) => m.MalwareDetailModule),
    resolve: {
      breadcrumb: MalwareBreadcrumbResolver,
    },
  },
  {
    path: `${TOOL_PATH}/:${TOOL_PARAM_SELECTOR}`,
    loadChildren: () => import('../detail/tool/tool-detail.module').then((m) => m.ToolDetailModule),
    resolve: {
      breadcrumb: ToolBreadcrumbResolver,
    },
  },
  {
    path: MITIGATION_PATH,
    loadChildren: () =>
      import('./mitigation-overview/mitigation-overview.module').then((m) => m.MitigationOverviewModule),
    data: {
      breadcrumb: 'Mitigations',
    },
  },
  {
    path: PLATFORM_PATH,
    loadChildren: () => import('./platform-overview/platform-overview.module').then((m) => m.PlatformOverviewModule),
    data: {
      breadcrumb: 'Platforms',
    },
  },
  {
    path: enumToPath(KnownTtPsTypesEnum.TACTIC),
    loadChildren: () => import('./tactic-overview/tactic-overview.module').then((m) => m.TacticOverviewModule),
    data: {
      breadcrumb: 'Tactics',
    },
  },
  {
    path: enumToPath(KnownTtPsTypesEnum.TECHNIQUE),
    loadChildren: () => import('./technique-overview/technique-overview.module').then((m) => m.TechniqueOverviewModule),
    data: {
      breadcrumb: 'Techniques',
    },
  },
  {
    path: enumToPath(KnownTtPsTypesEnum.GROUP_PROCEDURE),
    loadChildren: () =>
      import('./group-procedure-overview/group-procedure-overview.module').then((m) => m.GroupProcedureOverviewModule),
    data: {
      breadcrumb: 'Group Procedures',
    },
  },
  {
    path: enumToPath(KnownTtPsTypesEnum.TOOL_PROCEDURE),
    loadChildren: () =>
      import('./tool-procedure-overview/tool-procedure-overview.module').then((m) => m.ToolProcedureOverviewModule),
    data: {
      breadcrumb: 'Tool Procedures',
    },
  },
  {
    path: enumToPath(KnownTtPsTypesEnum.MALWARE_PROCEDURE),
    loadChildren: () =>
      import('./malware-procedure-overview/malware-procedure-overview.module').then(
        (m) => m.MalwareProcedureOverviewModule
      ),
    data: {
      breadcrumb: 'Malware Procedures',
    },
  },
];

@NgModule({ imports: [RouterModule.forChild(routes)], exports: [RouterModule] })
export class TTPsOverviewRoutingModule {}
