import { convertDateTimeFilter, DateClientFilter } from '@orion/common';
import { DateTimeFieldFilter } from '@orion/graphql-types';

describe('FilterConverterUtils', () => {
  it('should convert to close interval date range filter', () => {
    const clientFilter: DateClientFilter = {
      from: new Date(1646377144000),
      to: new Date(1646549944000),
    };
    const expected: DateTimeFieldFilter = { in_: ['2022-03-04T06:59:04.000Z', '2022-03-06T06:59:04.000Z'] };

    const converted = convertDateTimeFilter(clientFilter);

    expect(converted).toEqual(expected);
  });

  it('should convert to open interval (from) date range filter', () => {
    const clientFilter: DateClientFilter = {
      from: new Date(1646377144000),
    };
    const expected: DateTimeFieldFilter = { gt: '2022-03-04T06:59:04.000Z' };

    const converted = convertDateTimeFilter(clientFilter);

    expect(converted).toEqual(expected);
  });

  it('should convert to open interval (to) date range filter', () => {
    const clientFilter: DateClientFilter = {
      to: new Date(1646377144000),
    };
    const expected: DateTimeFieldFilter = { lt: '2022-03-04T06:59:04.000Z' };

    const converted = convertDateTimeFilter(clientFilter);

    expect(converted).toEqual(expected);
  });
});
