import { FormControl, FormGroup } from '@angular/forms';
import { BaseReactiveForm, SentinelValidators } from '@sentinel/common';

export interface EntityFormModel {
  name: FormControl<string>;
  description: FormControl<string>;
}

export interface EntityEditData {
  name: string;
  description: string;
}

export function defaultEntityControls(
  name?: string,
  description?: string,
  mandatoryDescription = false
): EntityFormModel {
  const formControls = {
    name: new FormControl<string>(name ?? '', { nonNullable: true, initialValueIsDefault: true }),
    description: new FormControl<string>(description ?? '', { nonNullable: true, initialValueIsDefault: true }),
  };
  formControls.name.setValidators([SentinelValidators.noWhitespace]);
  formControls.name.updateValueAndValidity();
  if (mandatoryDescription) {
    formControls.description.setValidators(SentinelValidators.noWhitespace);
    formControls.description.updateValueAndValidity();
  }
  return formControls;
}

export class EntityForm extends BaseReactiveForm<EntityFormModel> {
  constructor(name?: string, description?: string, mandatoryDescription = false) {
    super(new FormGroup<EntityFormModel>(defaultEntityControls(name, description, mandatoryDescription)));
  }

  setName(name: string): void {
    this.formGroup.controls.name.setValue(name);
  }

  setDescription(description: string): void {
    this.formGroup.controls.description.setValue(description);
  }

  getData(): EntityEditData {
    return {
      name: this.formGroup.controls.name.value,
      description: this.formGroup.controls.description.value,
    };
  }
}
