import { AbstractControl, ValidationErrors } from '@angular/forms';
import { Optional } from '@sentinel/common/utils';
import * as ipRegex from 'ip-regex';

export class IPValidators {
  static IPAddress(control: AbstractControl): ValidationErrors | null {
    const ipv4AddressErrors = IPValidators.IPV4Address(control);
    const ipv6AddressErrors = IPValidators.IPv6Address(control);
    if (
      ipv4AddressErrors !== null &&
      ipv4AddressErrors['ipv4'] &&
      ipv6AddressErrors !== null &&
      ipv6AddressErrors['ipv6']
    ) {
      return { ip: true };
    } else {
      return null;
    }
  }

  static IPV4Address(control: AbstractControl): ValidationErrors | null {
    const value: Optional<string> = control.value;
    if (!value) {
      return null;
    } else {
      if (value && isIPv4(value)) {
        return null;
      } else {
        return { ipv4: true };
      }
    }
  }

  static IPv6Address(control: AbstractControl): ValidationErrors | null {
    const value: Optional<string> = control.value;
    if (!value) {
      return null;
    } else {
      if (value && isIPv6(value)) {
        return null;
      } else {
        return { ipv6: true };
      }
    }
  }
}

export function isIPv4(value: string): boolean {
  return ipRegex.v4({ exact: true }).test(value);
}

export function isIPv6(value: string): boolean {
  return ipRegex.v6({ exact: true }).test(value);
}
