import { IPaginatedElements, isPaginatedElements } from '@sentinel/common/pagination';
import { Column, Row, SentinelTable } from '@sentinel/components/table';

export abstract class SimpleRowTable<T> extends SentinelTable<T> {
  protected constructor(resources: IPaginatedElements<T> | T[], columns: Column[]) {
    if (isPaginatedElements(resources)) {
      const rows = resources.elements.map((element) => new Row(element));
      super(rows, columns);
      this.pagination = resources.pagination;
    } else {
      const rows = resources.map((element) => new Row(element));
      super(rows, columns);
    }
  }
}

export function formatEnum(enumString: string, separator = ' '): string {
  return enumString.split('_').join(separator);
}

export function toAuthPath(path: string): string {
  return `/auth/${path}`;
}

export function resolveFromIdOrUrl(idOrUrl: string, idPath?: string): string | undefined {
  if (Number.isInteger(parseInt(idOrUrl))) {
    return idOrUrl;
  } else {
    if (!idPath) {
      return undefined;
    }
    const match = idOrUrl.match(new RegExp(`${idPath}\\/\\d+`));
    if (match && match.length > 0) {
      const matchedCasePathWithId = match[0];
      return matchedCasePathWithId.split(`${idPath}/`)[1];
    }
    return undefined;
  }
}

export interface FilenameWithExtension {
  name: string;
  extension: string;
}

export function fileToNameAndExtension(file: File): FilenameWithExtension {
  const splitFileName = file.name.split('.');
  const extension = splitFileName.pop() ?? '';
  const name = splitFileName.join('.');
  return { name, extension };
}

export function entityId(value?: string): string {
  if (value) {
    return `#${value}`;
  } else {
    return '';
  }
}
export const TITLE_SEPARATOR = '·';

export function entityTitle(id?: string, name?: string, entityType?: string): string {
  let title = '';
  if (id) {
    title += entityId(id);
  }
  if (name) {
    title += ` ${name}`;
  }
  if (entityType) {
    title += ` ${TITLE_SEPARATOR} ${entityType}`;
  }
  return title;
}
