import { ChangeDetectionStrategy, Component, Input, OnChanges, SimpleChanges } from '@angular/core';
import { SentinelControlItem } from '@sentinel/components/controls';
import { take } from 'rxjs/operators';

@Component({
  selector: 'orion-create-edit-entity-inline',
  templateUrl: './create-edit-entity-inline.component.html',
  styleUrls: ['./create-edit-entity-inline.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class CreateEditEntityInlineComponent implements OnChanges {
  @Input() controls: SentinelControlItem[] = [];
  @Input() isSaving = false;
  saveControl?: SentinelControlItem;
  cancelControl?: SentinelControlItem;

  ngOnChanges(changes: SimpleChanges): void {
    if ('controls' in changes && this.controls) {
      this.saveControl = this.controls.find((item) => item.id === 'save');
      this.cancelControl = this.controls.find((item) => item.id === 'cancel');
    }
  }

  onEditSaved(): void {
    this.saveControl?.result$?.pipe(take(1)).subscribe();
  }

  onEditCanceled(): void {
    this.cancelControl?.result$?.pipe(take(1)).subscribe();
  }
}
