import { Directive } from '@angular/core';
import {
  CanDeactivatePageDirective,
  EntityModifyBaseService,
  ModifyEntityControlsService,
} from '@orion/shared-services';
import { BaseReactiveForm } from '@sentinel/common';
import { SentinelControlItem } from '@sentinel/components/controls';
import { Observable } from 'rxjs';
import { takeUntil } from 'rxjs/operators';

@Directive()
export abstract class EntityModifyPageDirective<Form extends BaseReactiveForm<any>> extends CanDeactivatePageDirective {
  controls$?: Observable<SentinelControlItem[]>;
  isSaving$: Observable<boolean>;
  form$: Observable<Form>;
  canDeactivateSync = true;
  protected constructor(
    protected modifyEntityService: EntityModifyBaseService<Form>,
    protected controlsService: ModifyEntityControlsService
  ) {
    super();
    this.controls$ = this.controlsService.controls$;
    this.isSaving$ = this.modifyEntityService.isSaving$;
    this.form$ = this.modifyEntityService.form$;
    this.modifyEntityService.canDeactivate$
      .pipe(takeUntil(this.destroy$))
      .subscribe((canDeactivate) => (this.canDeactivateSync = canDeactivate));
  }

  canDeactivate(): boolean {
    return this.canDeactivateSync;
  }
}
