import { ChangeDetectionStrategy, Component, Input, OnChanges, SimpleChanges } from '@angular/core';
import { ThemePalette } from '@angular/material/core';

export enum TrendDirection {
  UP,
  DOWN,
  FLAT,
}

export interface DashboardCardTrend {
  value?: number;
  label?: string;
  direction: TrendDirection;
  positiveDirection: TrendDirection;
}

type TrendIcon = 'trending_up' | 'trending_down' | 'trending_flat';

@Component({
  selector: 'orion-dashboard-card-trend',
  templateUrl: './dashboard-card-trend.component.html',
  styleUrls: ['./dashboard-card-trend.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class DashboardCardTrendComponent implements OnChanges {
  @Input() trend?: DashboardCardTrend;
  trendIcon?: TrendIcon;
  trendIconColor?: ThemePalette;

  ngOnChanges(changes: SimpleChanges): void {
    if ('trend' in changes && this.trend) {
      this.resolveTrendView(this.trend);
    }
  }

  private resolveTrendView(trend: DashboardCardTrend): void {
    if (trend.direction === TrendDirection.UP) {
      this.trendIcon = 'trending_up';
      this.trendIconColor = trend.positiveDirection === TrendDirection.UP ? 'primary' : 'warn';
    } else if (trend.direction === TrendDirection.DOWN) {
      this.trendIcon = 'trending_down';
      this.trendIconColor = trend.positiveDirection === TrendDirection.DOWN ? 'primary' : 'warn';
    } else {
      this.trendIcon = 'trending_flat';
      this.trendIconColor = 'accent';
    }
  }
}
