import {
  ChangeDetectionStrategy,
  Component,
  EventEmitter,
  Input,
  OnChanges,
  Output,
  SimpleChanges,
} from '@angular/core';
import { EntityForm } from '@orion/common';
import { EntityEditService } from '@orion/shared-components/entity-edit';
import { ControlsService } from '@orion/shared-services';
import { SentinelControlItem } from '@sentinel/components/controls';
import { Observable } from 'rxjs';
import { take } from 'rxjs/operators';
import { EditableEntityPatchEvent } from './editable-entity-patch-event';
import { EntityEditControlsService } from './entity-edit-controls.service';
import { EntityEditEventService } from './entity-edit-event.service';
import { EntityEditModeService } from './entity-edit-mode.service';

@Component({
  selector: 'orion-editable-entity',
  templateUrl: './editable-entity.component.html',
  styleUrls: ['./editable-entity.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [{ provide: ControlsService, useClass: EntityEditControlsService }],
})
export class EditableEntityComponent implements OnChanges {
  @Input() name?: string;
  @Input() description?: string;
  @Input() displayName = true;
  @Input() displayDescription = true;
  @Input() disabled = false;
  @Output() save: EventEmitter<EditableEntityPatchEvent>;
  controls$?: Observable<SentinelControlItem[]>;
  editMode$: Observable<boolean>;
  form: EntityForm;

  constructor(
    private editModeService: EntityEditModeService,
    private entityEditEventService: EntityEditEventService,
    private editService: EntityEditService,
    private controlsService: ControlsService
  ) {
    this.editMode$ = this.editModeService.editMode$;
    this.controls$ = this.controlsService.controls$;
    this.form = this.editService.form;
    this.save = this.entityEditEventService.saveEmitter;
  }

  ngOnChanges(changes: SimpleChanges): void {
    if ('name' in changes && this.name) {
      this.form.setName(this.name);
    }
    if ('description' in changes && this.description) {
      this.form.setDescription(this.description);
    }
  }

  onEditClicked(): void {
    this.editModeService.set(true).pipe(take(1)).subscribe();
  }
}
