import { Injectable } from '@angular/core';
import { ControlsService } from '@orion/shared-services';
import { SentinelControlItem } from '@sentinel/components/controls';
import { defer, merge, of } from 'rxjs';
import { map } from 'rxjs/operators';
import { EntityEditService } from '../entity-edit';

@Injectable()
export class EntityEditControlsService extends ControlsService {
  constructor(private entityEditService: EntityEditService) {
    super();
    const saveDisabled$ = this.entityEditService.form.valid$.pipe(map((valid) => !valid));
    this.controls$ = of([
      new SentinelControlItem(
        'cancel',
        'Cancel',
        'warn',
        this.entityEditService.isSaving$,
        defer(() => this.entityEditService.cancel()),
        this.entityEditService.isSaving$
      ),
      new SentinelControlItem(
        'save',
        'Save',
        'primary',
        merge(saveDisabled$, this.entityEditService.isSaving$),
        defer(() => this.entityEditService.save()),
        this.entityEditService.isSaving$
      ),
    ]);
  }
}
