import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap, Router } from '@angular/router';
import { from, merge, Observable, Subject } from 'rxjs';
import { map, take } from 'rxjs/operators';

@Injectable()
export class EntityEditModeService {
  readonly EDIT_MODE_PARAM = 'edit';
  private editModeSubject$: Subject<boolean> = new Subject<boolean>();
  editMode$: Observable<boolean>;

  constructor(private router: Router, private activatedRoute: ActivatedRoute) {
    const modeFromRoute$ = this.resolveModeFromRoute();
    const modeFromSubject$ = this.editModeSubject$.asObservable();
    this.editMode$ = merge(modeFromRoute$, modeFromSubject$);
  }

  set(value: boolean): Observable<boolean> {
    this.editModeSubject$.next(value);
    return this.updateQueryParams(value);
  }

  private updateQueryParams(editMode: boolean): Observable<boolean> {
    const params = editMode ? { [this.EDIT_MODE_PARAM]: editMode } : { [this.EDIT_MODE_PARAM]: undefined };
    return from(
      this.router.navigate([], {
        relativeTo: this.activatedRoute,
        queryParams: { ...params },
        queryParamsHandling: 'merge',
        replaceUrl: true,
      })
    );
  }

  private resolveModeFromRoute(): Observable<boolean> {
    return this.activatedRoute.queryParamMap.pipe(
      take(1),
      map((queryParamMap) => this.resolveModeFromParamMap(queryParamMap))
    );
  }

  private resolveModeFromParamMap(paramMap: ParamMap): boolean {
    const editMode = paramMap.get(this.EDIT_MODE_PARAM);
    return editMode === 'true';
  }
}
