import { Directive, OnInit } from '@angular/core';
import { EditableEntityPageCanDeactivateService } from '@orion/shared-components/editable-entity';
import { CanDeactivatePageDirective } from '@orion/shared-services';
import { ApolloEntityPatchService, ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Identifiable } from '@sentinel/common/entity';
import { EntityUpdateEvent } from '@csirtmu-orion/microframework/graphql';
import { Optional } from '@sentinel/common/utils';
import { Observable } from 'rxjs';
import { take } from 'rxjs/operators';

@Directive()
export abstract class EditableEntityDetailPageBaseDirective<Entity extends Identifiable, EntityPatch>
  extends CanDeactivatePageDirective
  implements OnInit
{
  entity$?: Observable<Optional<Entity>>;
  isLoading$?: Observable<boolean>;
  hasError$?: Observable<boolean>;
  protected constructor(
    // No point in introducing a generic for query and query variables in this component
    // as the types context doesn't matter to this component.
    // eslint-disable-next-line
    protected entityService: ApolloRoutedEntityService<any, any, Entity>,
    // No point in introducing a generic for mutation and mutation variables in this component
    // as the types context doesn't matter to this component.
    // eslint-disable-next-line
    protected entityPatchService: ApolloEntityPatchService<EntityPatch, any, any>,
    protected canDeactivateService: EditableEntityPageCanDeactivateService
  ) {
    super();
  }

  ngOnInit(): void {
    this.entity$ = this.entityService.data$;
    this.hasError$ = this.entityService.hasError$;
    this.isLoading$ = this.entityService.isLoading$;
  }

  onPatch(event: EntityUpdateEvent<EntityPatch>): void {
    this.entityPatchService.patch(event).pipe(take(1)).subscribe();
  }

  canDeactivate(): boolean {
    return this.canDeactivateService.canDeactivate();
  }

  onRefetch(): void {
    this.entityService.recoverAfterError();
  }
}
