import { Directive, OnInit } from '@angular/core';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Identifiable } from '@sentinel/common/entity';
import { Optional } from '@sentinel/common/utils';
import { Observable } from 'rxjs';

@Directive()
export abstract class EntityDetailPageBaseDirective<Entity extends Identifiable> implements OnInit {
  entity$?: Observable<Optional<Entity>>;
  isLoading$?: Observable<boolean>;
  hasError$?: Observable<boolean>;

  // No point in introducing a generic for query and query variables in this component
  // as the types context doesn't matter to this component.
  // eslint-disable-next-line
  protected constructor(protected entityService: ApolloRoutedEntityService<any, any, Entity>) {}

  ngOnInit(): void {
    this.entity$ = this.entityService.data$;
    this.hasError$ = this.entityService.hasError$;
    this.isLoading$ = this.entityService.isLoading$;
  }

  onRefetch(): void {
    this.entityService.recoverAfterError();
  }
}
