import { EntityForm } from '@orion/common';
import { BehaviorSubject, Observable } from 'rxjs';
import { tap } from 'rxjs/operators';

export abstract class EntityEditService {
  form: EntityForm;
  private isSavingSubject$: BehaviorSubject<boolean> = new BehaviorSubject<boolean>(false);
  isSaving$: Observable<boolean> = this.isSavingSubject$.asObservable();

  protected constructor(mandatoryDescription?: boolean) {
    this.form = new EntityForm(undefined, undefined, mandatoryDescription);
  }

  abstract cancel(): Observable<boolean>;

  abstract onSave(): Observable<boolean>;

  save(): Observable<boolean> {
    this.isSavingSubject$.next(true);
    return this.onSave().pipe(
      tap({
        next: () => this.isSavingSubject$.next(false),
        error: () => this.isSavingSubject$.next(false),
      })
    );
  }

  canDeactivate(): boolean {
    return !this.form.dirty;
  }
}
