import { ChangeDetectionStrategy, Component, Input, OnChanges, SimpleChanges } from '@angular/core';
import { FormControl } from '@angular/forms';
import { Destroyable } from '@sentinel/common';
import { BehaviorSubject } from 'rxjs';
import { map, takeUntil } from 'rxjs/operators';

@Component({
  selector: 'orion-json-editor',
  templateUrl: './json-editor.component.html',
  styleUrls: ['./json-editor.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class JsonEditorComponent extends Destroyable() implements OnChanges {
  @Input() control?: FormControl<string | null>;
  @Input() disabled?: boolean;
  @Input() size: 'small' | 'medium' | 'large' = 'medium';
  @Input() withToolbar = true;
  actionsDisabled$: BehaviorSubject<boolean> = new BehaviorSubject<boolean>(true);

  ngOnChanges(changes: SimpleChanges): void {
    if ('disabled' in changes && this.disabled !== undefined) {
      this.actionsDisabled$.next(this.disabled || (this.control?.status === 'INVALID' ?? false));
    }
    if ('control' in changes && this.control) {
      this.control.statusChanges
        .pipe(
          map((status) => status === 'INVALID'),
          takeUntil(this.destroy$)
        )
        .subscribe((invalid) => this.actionsDisabled$.next((this.disabled ?? false) || invalid));
    }
  }

  indent(): void {
    if (this.control && this.control.value) {
      const curr = JSON.parse(this.control.value);
      this.control.setValue(JSON.stringify(curr, null, '\t'));
    }
  }

  compact(): void {
    if (this.control && this.control.value) {
      const curr = JSON.parse(this.control.value);
      this.control.setValue(JSON.stringify(curr, null, ''));
    }
  }
}
