import { Directive, OnInit } from '@angular/core';
import { EntityAddAssociationService } from '@orion/shared-services';
import { Destroyable } from '@sentinel/common';
import { ApolloPaginatedFilterableService } from '@csirtmu-orion/microframework/apollo-services';
import { IResourceRef } from '@sentinel/common/entity';

import { FilterService } from '@csirtmu-orion/microframework/filter-services';
import { PaginationService } from '@csirtmu-orion/microframework/pagination-services';
import { SentinelControlItem } from '@sentinel/components/controls';
import { Observable } from 'rxjs';
import { map, takeUntil, tap } from 'rxjs/operators';
import { AddEntityControlsService } from './add-entity-controls.service';
import { CreateEntityAssociationService } from './create-entity-association.service';

@Directive()
export abstract class AddPaginableEntityDirective<ListFragment extends IResourceRef, ClientFilter>
  extends Destroyable()
  implements OnInit
{
  controls$?: Observable<SentinelControlItem[]>;
  entitiesToSelect$?: Observable<ListFragment[]>;
  isLoading$?: Observable<boolean>;
  hasError$?: Observable<boolean>;
  isSaving$?: Observable<boolean>;

  protected constructor(
    protected selectionService: EntityAddAssociationService<IResourceRef>,
    protected controlsService: AddEntityControlsService,
    protected paginationService: PaginationService,
    protected filterService: FilterService<ClientFilter>,
    protected listService: ApolloPaginatedFilterableService<any, any, ListFragment, any, ClientFilter, any>,
    protected addEntityService: CreateEntityAssociationService
  ) {
    super();
  }

  protected abstract createFilter(searchValue: string): ClientFilter;

  ngOnInit(): void {
    this.controls$ = this.controlsService.controls$;
    this.isLoading$ = this.listService.isLoading$;
    this.hasError$ = this.listService.hasError$;
    this.isSaving$ = this.addEntityService.isSaving$;
    this.entitiesToSelect$ = this.listService.data$?.pipe(map((paginated) => paginated.elements));
    this.filterService.filter$
      .pipe(
        takeUntil(this.destroy$),
        tap((filter) => this.listService.update(this.paginationService.get(), filter))
      )
      .subscribe();
  }

  onSelectionChange(selection: ListFragment[]): void {
    this.selectionService.select(selection);
  }

  onSingleSelectionChange(selection: ListFragment): void {
    this.selectionService.select([selection]);
  }

  onSearch(value: string): void {
    this.filterService.updateAndSubmit(this.createFilter(value));
  }

  onTryAgain(): void {
    this.listService.recoverAfterError();
  }
}
