import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloResult } from '@csirtmu-orion/microframework/graphql';
import { Observable } from 'rxjs';
import { concatMap, map, skipWhile, take } from 'rxjs/operators';
import { CreateAssociationViewStateService } from './create-association-view-state.service';
import { CreateEntityAssociationService } from './create-entity-association.service';
import { TASK_PARAM_SELECTOR } from '@orion/case-paths';

export abstract class AddTaskToEntityService extends CreateEntityAssociationService {
  protected constructor(
    protected viewService: CreateAssociationViewStateService,
    protected activatedRoute: ActivatedRoute
  ) {
    super(viewService);
  }

  protected abstract linkToEntity(relatedTaskId: string): Observable<ApolloResult>;

  requestAndHandleAssociation(): Observable<ApolloResult> {
    return this.getTaskId().pipe(concatMap((relatedTask) => this.linkToEntity(relatedTask)));
  }

  private getTaskId(): Observable<string> {
    return this.activatedRoute.paramMap.pipe(take(1)).pipe(
      map((paramMap) => this.taskIdFromRoute(paramMap)),
      skipWhile((relatedTaskId) => relatedTaskId === null || relatedTaskId === undefined)
    );
  }

  private taskIdFromRoute(paramMap: ParamMap): string {
    const taskId = paramMap.get(TASK_PARAM_SELECTOR);
    if (taskId === null) {
      throw new Error('Task ID param is null');
    } else {
      return taskId;
    }
  }
}
