import { ActivatedRoute } from '@angular/router';
import { ApolloResult } from '@csirtmu-orion/microframework/graphql';
import { Observable } from 'rxjs';
import { concatMap, map, take } from 'rxjs/operators';
import { CreateAssociationViewStateService } from './create-association-view-state.service';
import { CreateEntityAssociationService } from './create-entity-association.service';
import { CASE_PARAM_SELECTOR } from '@orion/case-paths';

export abstract class CreateAssociationWithCaseService extends CreateEntityAssociationService {
  protected constructor(
    protected viewService: CreateAssociationViewStateService,
    protected activatedRoute: ActivatedRoute
  ) {
    super(viewService);
  }

  protected abstract createAssociation(caseId: string): Observable<ApolloResult>;

  requestAndHandleAssociation(): Observable<ApolloResult> {
    return this.getCaseId().pipe(concatMap((caseId) => this.createAssociation(caseId)));
  }

  private getCaseId(): Observable<string> {
    return this.activatedRoute.paramMap.pipe(
      take(1),
      map((paramMap) => {
        const id = paramMap.get(CASE_PARAM_SELECTOR);
        if (id === null) {
          throw new Error('Case id param is null');
        } else {
          return id;
        }
      })
    );
  }
}
