import { ApolloResult, ApolloResultType } from '@csirtmu-orion/microframework/graphql';
import { BehaviorSubject, Observable, of } from 'rxjs';
import { tap } from 'rxjs/operators';
import { CreateAssociationViewStateService } from './create-association-view-state.service';

export abstract class CreateEntityAssociationService {
  protected operationName = 'Linking entity';
  protected isSavingSubject$: BehaviorSubject<boolean> = new BehaviorSubject<boolean>(false);
  isSaving$: Observable<boolean> = this.isSavingSubject$.asObservable();

  protected constructor(protected viewService: CreateAssociationViewStateService) {}

  abstract requestAndHandleAssociation(): Observable<ApolloResult>;

  save(): Observable<ApolloResult> {
    this.isSavingSubject$.next(true);
    return this.requestAndHandleAssociation().pipe(
      tap(
        () => this.isSavingSubject$.next(false),
        () => this.isSavingSubject$.next(false),
        () => this.isSavingSubject$.next(false)
      )
    );
  }

  cancel(): Observable<boolean> {
    this.viewService.hideAddComponent();
    return of(true);
  }

  protected handleLinkResult(res: ApolloResult): void {
    if (res.type === ApolloResultType.SUCCESS) {
      this.viewService.hideAddComponent();
    }
  }
}
