import { Directive, EventEmitter, Input, OnChanges, Output, SimpleChanges } from '@angular/core';
import { MatFormFieldAppearance } from '@angular/material/form-field';
import { Identifiable } from '@sentinel/common/entity';
import { trackById } from '@sentinel/common/utils';
import { defer } from 'rxjs';

@Directive()
export abstract class EntitySelectionDirective<Fragment extends Identifiable> implements OnChanges {
  @Input() label?: string;
  @Input() searchPlaceholder = 'Search';
  @Input() appearance: MatFormFieldAppearance = 'standard';
  @Input() multiple = true;
  @Input() required = false;
  @Input() compactMode = false;
  @Input() entitiesToSelect: Fragment[] = [];
  @Input() preselectedEntities: Fragment[] = [];
  @Input() isLoading = false;
  @Input() hasError = false;
  @Output() search: EventEmitter<string> = new EventEmitter<string>();
  @Output() selectionChange: EventEmitter<Fragment[]> = new EventEmitter<Fragment[]>();
  @Output() singleSelectionChange: EventEmitter<Fragment> = new EventEmitter<Fragment>();
  @Output() tryAgain: EventEmitter<void> = new EventEmitter<void>();
  onTryAgain$ = defer(() => this.tryAgain.emit());
  trackBy = trackById;
  private appearanceOverriden = false;

  ngOnChanges(changes: SimpleChanges): void {
    // setting up default appearance if not overriden by parent component
    if ('appearance' in changes) {
      this.appearanceOverriden = true;
    }
    if ('multiple' in changes && !this.appearanceOverriden) {
      this.appearance = this.multiple ? 'standard' : 'outline';
    }
  }

  onSelectionChange(selected: Fragment[]): void {
    this.selectionChange.emit(selected);
  }

  onSingleSelectionChange(selected: Fragment): void {
    this.selectionChange.emit([selected]);
    this.singleSelectionChange.emit(selected);
  }

  onSearch(value: string): void {
    this.search.emit(value);
  }
}
