import { Directive, Input, OnChanges, OnInit, Optional, SimpleChanges } from '@angular/core';
import { ControlsService } from '@orion/shared-services';
import { SentinelControlItem } from '@sentinel/components/controls';
import { EntityFilterableOverviewDirective } from '@csirtmu-orion/microframework/entity-smart-directives';
import { Observable } from 'rxjs';
import { take } from 'rxjs/operators';
import { CreateAssociationViewStateService } from './create-association-view-state.service';

@Directive()
export abstract class RelatedEntityOverviewDirective<Fragment, ClientFilter>
  extends EntityFilterableOverviewDirective<Fragment, ClientFilter>
  implements OnInit, OnChanges
{
  @Input() withActions = true;
  displayedAddComponent$?: Observable<boolean>;
  controls$?: Observable<SentinelControlItem[]>;

  protected constructor(
    @Optional() protected controlsService?: ControlsService,
    @Optional() protected viewStateService?: CreateAssociationViewStateService
  ) {
    super();
  }

  ngOnInit(): void {
    this.initViewState();
  }

  ngOnChanges(changes: SimpleChanges): void {
    if ('withActions' in changes && this.withActions) {
      this.initViewState();
    }
  }

  onControlsClicked(item: SentinelControlItem): void {
    item.result$?.pipe(take(1)).subscribe();
  }

  private initViewState(): void {
    if (this.viewStateService) {
      this.displayedAddComponent$ = this.viewStateService.displayedAddComponent$;
    }
    if (this.controlsService) {
      this.controls$ = this.controlsService.controls$;
    }
  }
}
