import { Injectable } from '@angular/core';
import * as Apollo from 'apollo-angular';
import { APOLLO_CLIENT_NAME } from '@orion/common';
import { from, Observable } from 'rxjs';
import { LoadingService } from './loading.service';
import { catchError, tap } from 'rxjs/operators';
import { ApolloOperationResultResolver } from '@csirtmu-orion/microframework/graphql';

@Injectable({ providedIn: 'root' })
export class ApolloRefreshPageDataService {
  constructor(private apollo: Apollo.Apollo, private loadingService: LoadingService) {}
  refreshData(): Observable<any> {
    this.loadingService.setLoading(true);
    return from(this.apollo.use(APOLLO_CLIENT_NAME).client.reFetchObservableQueries()).pipe(
      catchError((err) => ApolloOperationResultResolver.handleError(err)),
      tap({
        next: () => this.loadingService.setLoading(false),
        error: () => this.loadingService.setLoading(false),
        complete: () => this.loadingService.setLoading(false),
      })
    );
  }
}
