import { Injectable } from '@angular/core';
import { Event, NavigationCancel, NavigationEnd, NavigationError, NavigationStart, Router } from '@angular/router';
import { BehaviorSubject, combineLatest, Observable } from 'rxjs';
import { distinctUntilChanged, filter, map, startWith } from 'rxjs/operators';

@Injectable({ providedIn: 'root' })
export class LoadingService {
  isLoading$: Observable<boolean>;
  private loadingSubject$: BehaviorSubject<boolean> = new BehaviorSubject<boolean>(false);

  constructor(private router: Router) {
    this.isLoading$ = combineLatest([this.createLoadingObsFromRouter(), this.loadingSubject$.asObservable()]).pipe(
      map((loadings) => loadings.some((loading) => loading), distinctUntilChanged())
    );
  }

  setLoading(value: boolean): void {
    this.loadingSubject$.next(value);
  }

  private createLoadingObsFromRouter(): Observable<boolean> {
    return this.router.events.pipe(
      filter((routerEvent) => this.isChangeOfLoadingEvent(routerEvent)),
      map((routerEvent) => routerEvent instanceof NavigationStart),
      startWith(false)
    );
  }

  private isChangeOfLoadingEvent(event: Event): boolean {
    return (
      event instanceof NavigationEnd ||
      event instanceof NavigationStart ||
      event instanceof NavigationCancel ||
      event instanceof NavigationError
    );
  }
}
