import { Injectable } from '@angular/core';
import { NotificationType } from '@sentinel/common/utils';
import {
  SentinelNotification,
  SentinelNotificationResult,
  SentinelNotificationService,
  SentinelNotificationTypeEnum,
} from '@sentinel/layout/notification';
import { Observable } from 'rxjs';
import { map } from 'rxjs/operators';

@Injectable({ providedIn: 'root' })
export class NotificationService {
  constructor(private sentinelNotificationService: SentinelNotificationService) {}

  private static convertToSentinelType(type: NotificationType): SentinelNotificationTypeEnum {
    switch (type) {
      case 'error':
        return SentinelNotificationTypeEnum.Error;
      case 'success':
        return SentinelNotificationTypeEnum.Success;
      case 'info':
        return SentinelNotificationTypeEnum.Info;
      case 'warning':
        return SentinelNotificationTypeEnum.Warning;
    }
  }

  emit(type: NotificationType, title: string, message?: string, action?: string): Observable<boolean> {
    const sentinelNotification: SentinelNotification = {
      type: NotificationService.convertToSentinelType(type),
      title: title,
      additionalInfo: message ? [message] : [],
    };
    if (action) {
      sentinelNotification.action = action;
    }
    return this.sentinelNotificationService
      .emit(sentinelNotification)
      .pipe(map((result) => result === SentinelNotificationResult.CONFIRMED));
  }
}
