import {
  ActivatedRouteSnapshot,
  BaseRouteReuseStrategy,
  DetachedRouteHandle,
  RouteReuseStrategy,
} from '@angular/router';
import { Injectable } from '@angular/core';
import { TASK_PARAM_SELECTOR } from '@orion/case-paths';

@Injectable()
export class OrionRouteReuseStrategy extends BaseRouteReuseStrategy implements RouteReuseStrategy {
  shouldDetach(route: ActivatedRouteSnapshot): boolean {
    return super.shouldDetach(route);
  }
  store(route: ActivatedRouteSnapshot, detachedTree: DetachedRouteHandle): void {
    return super.store(route, detachedTree);
  }
  shouldAttach(route: ActivatedRouteSnapshot): boolean {
    return super.shouldAttach(route);
  }
  retrieve(route: ActivatedRouteSnapshot): DetachedRouteHandle | null {
    return super.retrieve(route);
  }

  /**
   *  Blocks reusing route when navigating between task detail pages because it does not work well with
   *  apollo polling. For all other routes it uses default Angular strategy.
   * @param future route snapshot
   * @param curr curr route snapshot
   */
  shouldReuseRoute(future: ActivatedRouteSnapshot, curr: ActivatedRouteSnapshot): boolean {
    const currTaskParam = curr.paramMap.get(TASK_PARAM_SELECTOR);
    const futureTaskParam = future.paramMap.get(TASK_PARAM_SELECTOR);
    if (currTaskParam !== futureTaskParam) {
      return false;
    } else {
      return super.shouldReuseRoute(future, curr);
    }
  }
}
