import { Inject, Injectable } from '@angular/core';
import { DOCUMENT } from '@angular/common';
import { UserSettingsService } from './user-settings.service';

type PresentationModeTheme = 'regular-typography-mode' | 'presentation-typography-mode';

function swapThemes(document: Document, theme: PresentationModeTheme): void {
  const regularMode: PresentationModeTheme = 'regular-typography-mode';
  const presentationMode: PresentationModeTheme = 'presentation-typography-mode';

  if (document.body.classList.contains(theme)) {
    return;
  } else if (theme === regularMode && document.body.classList.contains(presentationMode)) {
    document.body.classList.replace(presentationMode, regularMode);
  } else if (theme === presentationMode && document.body.classList.contains(regularMode)) {
    document.body.classList.replace(regularMode, presentationMode);
  } else {
    document.body.classList.add(theme);
  }
}

@Injectable({ providedIn: 'root' })
export class PresentationModeThemeService {
  constructor(@Inject(DOCUMENT) private document: Document, private userSettingsService: UserSettingsService) {
    this.userSettingsService.stateSubject$.asObservable().subscribe({
      next: (state) => {
        const newTheme: PresentationModeTheme = state.presentationMode
          ? 'presentation-typography-mode'
          : 'regular-typography-mode';
        swapThemes(this.document, newTheme);
      },
    });
  }
}
