import { Injectable } from '@angular/core';
import { BehaviorSubject } from 'rxjs';

export interface UserSettingsState {
  presentationMode: boolean;
  fullWidthMode: boolean;
}

const DEFAULT_USER_SETTINGS_STATE: UserSettingsState = {
  presentationMode: false,
  fullWidthMode: true,
};

const PRESENTATION_MODE_LOCAL_STORAGE_KEY = 'orion-user-settings-presentation-mode';
const FULL_WIDTH_LOCAL_STORAGE_KEY = 'orion-user-settings-full-width';

@Injectable({ providedIn: 'root' })
export class UserSettingsService {
  stateSubject$: BehaviorSubject<UserSettingsState>;

  constructor() {
    this.stateSubject$ = new BehaviorSubject<UserSettingsState>({
      presentationMode: this.initPresentationMode(),
      fullWidthMode: this.initFullWidthMode(),
    });
  }

  setState(newState: UserSettingsState): void {
    const currState = this.stateSubject$.getValue();
    if (newState.presentationMode !== currState.presentationMode) {
      this.onChangePresentationMode(newState.presentationMode);
    }
    if (newState.fullWidthMode !== currState.fullWidthMode) {
      this.onChangeFullWidthMode(newState.fullWidthMode);
    }
    this.stateSubject$.next(newState);
  }

  private initPresentationMode(): boolean {
    const maybeBrowserPresentationModeValue = localStorage.getItem(PRESENTATION_MODE_LOCAL_STORAGE_KEY);
    const initPresentationModeValue =
      maybeBrowserPresentationModeValue === null
        ? DEFAULT_USER_SETTINGS_STATE.presentationMode.toString()
        : maybeBrowserPresentationModeValue;
    return initPresentationModeValue === 'true';
  }

  private onChangePresentationMode(value: boolean): void {
    localStorage.setItem(PRESENTATION_MODE_LOCAL_STORAGE_KEY, value.toString());
  }

  private initFullWidthMode(): boolean {
    const maybeFullWidthModeValue = localStorage.getItem(FULL_WIDTH_LOCAL_STORAGE_KEY);
    const initFullWidthModeValue =
      maybeFullWidthModeValue === null ? DEFAULT_USER_SETTINGS_STATE.fullWidthMode.toString() : maybeFullWidthModeValue;
    return initFullWidthModeValue === 'true';
  }

  private onChangeFullWidthMode(value: boolean): void {
    localStorage.setItem(FULL_WIDTH_LOCAL_STORAGE_KEY, value.toString());
  }
}
