import { HttpEvent, HttpHandler, HttpInterceptor, HttpRequest } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { OrionDynamicEnvironment } from '@orion/env';
import { SentinelAuthContext } from '@sentinel/auth';
import { Observable } from 'rxjs';

@Injectable()
export class OidcProviderHeaderInterceptor implements HttpInterceptor {
  constructor(private authContext: SentinelAuthContext) {}

  intercept(req: HttpRequest<any>, next: HttpHandler): Observable<HttpEvent<any>> {
    const headerName = OrionDynamicEnvironment.getConfig()?.authConfig?.oidcProviderHeaderName;
    const selectedOidcProviderHeaderValue =
      this.authContext.getProviderFromStorage()?.oidcConfig?.options?.oidcProviderHeaderValue;
    const interceptorAllowedUrls =
      OrionDynamicEnvironment.getConfig().authConfig.oidcProviderHeaderNameInterceptorAllowedUrls ?? [];

    if (this.shouldBeIntercepted(req.url, interceptorAllowedUrls) && headerName && selectedOidcProviderHeaderValue) {
      const reqWithOidcProviderClientIdHeader = req.clone({
        headers: req.headers.set(headerName, selectedOidcProviderHeaderValue),
      });
      return next.handle(reqWithOidcProviderClientIdHeader);
    }
    return next.handle(req);
  }

  private shouldBeIntercepted(url: string, interceptorAllowedUrls: string[]): boolean {
    return interceptorAllowedUrls.some((allowedUrl) => url.startsWith(allowedUrl));
  }
}
