import {
  HttpErrorResponse,
  HttpEvent,
  HttpHandler,
  HttpInterceptor,
  HttpRequest,
  HttpResponse,
  HttpStatusCode,
} from '@angular/common/http';
import { Injectable } from '@angular/core';
import { NotificationService, OrionLogoutService } from '@orion/shared/services/global';
import { Observable, of, throwError } from 'rxjs';
import { catchError, mapTo, switchMap, switchMapTo, tap } from 'rxjs/operators';

@Injectable()
export class UnauthorizedInterceptor implements HttpInterceptor {
  constructor(private auth: OrionLogoutService, private notificationService: NotificationService) {}

  intercept(req: HttpRequest<any>, next: HttpHandler): Observable<HttpEvent<any>> {
    return next.handle(req).pipe(
      switchMap((response) => {
        if (response instanceof HttpResponse && response.status === HttpStatusCode.Unauthorized) {
          return this.displayNotification().pipe(mapTo(response));
        } else {
          return of(response);
        }
      }),
      catchError((err) => {
        if (err instanceof HttpErrorResponse && err.status === HttpStatusCode.Unauthorized) {
          return this.displayNotification().pipe(switchMapTo(throwError(err)));
        } else {
          return throwError(err);
        }
      })
    );
  }

  private displayNotification(): Observable<boolean> {
    return this.notificationService
      .emit('error', 'You are not authorized', 'You will be logged out')
      .pipe(tap(() => this.auth.logout()));
  }
}
