import { Injectable } from '@angular/core';
import { MatDialog } from '@angular/material/dialog';
import { CanDeactivate, UrlTree } from '@angular/router';
import {
  SentinelConfirmationDialogComponent,
  SentinelConfirmationDialogConfig,
  SentinelDialogResultEnum,
} from '@sentinel/components/dialogs';
import { Observable } from 'rxjs';
import { map } from 'rxjs/operators';
import { DeactivableComponent } from './deactivable-component';

@Injectable()
export class ConfirmationGuard implements CanDeactivate<DeactivableComponent> {
  constructor(private dialog: MatDialog) {}
  canDeactivate(
    component: DeactivableComponent
  ): Observable<boolean | UrlTree> | Promise<boolean | UrlTree> | boolean | UrlTree {
    if (component === null || component === undefined) {
      console.warn('ConfirmationGuard not set up properly, component is undefined or null.');
      return true;
    }
    return component.canDeactivate() ? true : this.confirm();
  }

  private confirm(): Observable<boolean> {
    const dialogRef = this.dialog.open(SentinelConfirmationDialogComponent, {
      data: new SentinelConfirmationDialogConfig(
        'Unsaved Changes',
        'There are unsaved changes in the edited form. Do you really want to leave without saving?',
        'Cancel',
        'Leave'
      ),
    });
    return dialogRef.afterClosed().pipe(map((result) => result === SentinelDialogResultEnum.CONFIRMED));
  }
}
