import { ActivatedRoute } from '@angular/router';
import { NotificationService } from '@orion/shared/services/global';
import { BaseReactiveForm } from '@sentinel/common';
import { ApolloResult } from '@csirtmu-orion/microframework/graphql';
import { Optional } from '@sentinel/common/utils';
import { EMPTY, Observable } from 'rxjs';
import { concatMap, tap } from 'rxjs/operators';
import { EntityModifyBaseService } from './entity-modify-base.service';

export abstract class CreateEditEntityService<
  Form extends BaseReactiveForm<any>
> extends EntityModifyBaseService<Form> {
  protected editMode = false;
  protected entityId$: Observable<Optional<string>>;

  protected constructor(
    entityName: string,
    protected notificationService: NotificationService,
    protected activatedRoute: ActivatedRoute
  ) {
    super(entityName, notificationService, activatedRoute);
    this.entityId$ = this.getEntityId();
  }

  protected abstract getEntityId(): Observable<Optional<string>>;

  protected abstract updateEntity(form: Form): Observable<ApolloResult>;

  protected abstract createEntity(form: Form): Observable<ApolloResult>;

  save(): Observable<boolean> {
    return this.form$.pipe(
      tap(() => this.isSavingSubject$.next(true)),
      concatMap((form) => (form.valid ? this.createOrUpdateEntity(form) : EMPTY)),
      tap(
        () => this.isSavingSubject$.next(false),
        () => this.isSavingSubject$.next(false)
      )
    );
  }

  private createOrUpdateEntity(form: Form): Observable<boolean> {
    const save$ = this.editMode ? this.updateEntity(form) : this.createEntity(form);
    return save$.pipe(concatMap((result) => this.handleSaveResult(form, result)));
  }

  protected createSuccessSaveMessage(): string {
    return this.editMode ? `${this.entityName} was updated` : `${this.entityName} was created`;
  }

  protected createErrorSaveMessage(): string {
    const lowerCasedEntity = this.entityName.toLowerCase();
    return this.editMode ? `Updating ${lowerCasedEntity}` : `Creating ${lowerCasedEntity}`;
  }
}
