import { ActivatedRoute } from '@angular/router';
import { NotificationService } from '@orion/shared/services/global';
import { BaseReactiveForm } from '@sentinel/common';
import { ApolloResult } from '@csirtmu-orion/microframework/graphql';
import { Observable, of } from 'rxjs';
import { concatMap, tap } from 'rxjs/operators';
import { EntityModifyBaseService } from './entity-modify-base.service';

export abstract class CreateEntityService<Form extends BaseReactiveForm<any>> extends EntityModifyBaseService<Form> {
  protected constructor(
    entityName: string,
    protected notificationService: NotificationService,
    protected activatedRoute: ActivatedRoute
  ) {
    super(entityName, notificationService, activatedRoute);
  }

  protected abstract createEntity(form: Form): Observable<ApolloResult>;

  save(): Observable<boolean> {
    return this.form$.pipe(concatMap((form) => (form.valid ? this.validFormSave() : of(false))));
  }

  protected createSuccessSaveMessage(): string {
    return `${this.entityName} was created`;
  }

  protected createErrorSaveMessage(): string {
    const lowerCasedEntity = this.entityName.toLowerCase();
    return `Creating ${lowerCasedEntity}`;
  }

  private validFormSave(): Observable<boolean> {
    return this.form$.pipe(
      tap(() => this.isSavingSubject$.next(true)),
      concatMap((form) => this.createEntity(form).pipe(concatMap((result) => this.handleSaveResult(form, result)))),
      tap(
        () => this.isSavingSubject$.next(false),
        () => this.isSavingSubject$.next(false)
      )
    );
  }
}
