import { ActivatedRoute } from '@angular/router';
import { NotificationService } from '@orion/shared/services/global';
import { BaseReactiveForm } from '@sentinel/common';
import { ApolloResult } from '@csirtmu-orion/microframework/graphql';
import { Observable, of } from 'rxjs';
import { concatMap, tap } from 'rxjs/operators';
import { EntityModifyBaseService } from './entity-modify-base.service';

export abstract class EditEntityService<Form extends BaseReactiveForm<any>> extends EntityModifyBaseService<Form> {
  protected entityId?: string;

  protected constructor(
    entityName: string,
    protected notificationService: NotificationService,
    protected activatedRoute: ActivatedRoute
  ) {
    super(entityName, notificationService, activatedRoute);
  }

  protected abstract updateEntity(form: Form): Observable<ApolloResult>;

  save(): Observable<boolean> {
    return this.form$.pipe(concatMap((form) => (form.valid ? this.validFormSave(form) : of(false))));
  }

  protected createSuccessSaveMessage(): string {
    return `${this.entityName} was updated`;
  }

  protected createErrorSaveMessage(): string {
    const lowerCasedEntity = this.entityName.toLowerCase();
    return `Updating ${lowerCasedEntity}`;
  }

  private validFormSave(form: Form): Observable<boolean> {
    this.isSavingSubject$.next(true);
    return this.updateEntity(form).pipe(
      concatMap((result) => this.handleSaveResult(form, result)),
      tap(
        () => this.isSavingSubject$.next(false),
        () => this.isSavingSubject$.next(false)
      )
    );
  }
}
