import { Injectable } from '@angular/core';
import { BaseReactiveForm } from '@sentinel/common';
import { SentinelControlItem } from '@sentinel/components/controls';
import { combineLatest, defer, Observable, of } from 'rxjs';
import { map, switchMap } from 'rxjs/operators';
import { ControlsService } from '../controls.service';
import { EntityModifyBaseService } from './entity-modify-base.service';

@Injectable()
export class ModifyEntityControlsService extends ControlsService {
  // No point in introducing a generic for form types in this service
  // eslint-disable-next-line
  constructor(private editEntityService: EntityModifyBaseService<BaseReactiveForm<any>>) {
    super();
    const saveDisabled$ = this.getSaveDisabled();
    this.controls$ = of([
      new SentinelControlItem(
        'cancel',
        'Cancel',
        'warn',
        this.editEntityService.isSaving$,
        defer(() => this.editEntityService.cancel())
      ),
      new SentinelControlItem(
        'save',
        'Save',
        'primary',
        saveDisabled$,
        defer(() => this.editEntityService.save()),
        this.editEntityService.isSaving$
      ),
    ]);
  }

  private getSaveDisabled(): Observable<boolean> {
    const invalid$ = this.editEntityService.form$.pipe(
      switchMap((form) => form.valid$),
      map((valid) => !valid)
    );
    const saving$ = this.editEntityService.isSaving$;
    return combineLatest([invalid$, saving$]).pipe(map((values) => values.some((value) => value)));
  }
}
