import { HttpClient } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { ApolloOperationResultResolver, ApolloResult, ApolloResultType } from '@csirtmu-orion/microframework/graphql';
import { saveAs } from 'file-saver';
import { Observable } from 'rxjs';
import { catchError, map, take, tap } from 'rxjs/operators';

@Injectable({ providedIn: 'root' })
export class FileDownloadService {
  constructor(private http: HttpClient) {}

  download(src: string, filename?: string): Observable<ApolloResult> {
    return this.http.get(src, { responseType: 'blob' }).pipe(
      take(1),
      tap((data) => saveAs(data, filename ?? data.type)),
      map(() => new ApolloResult(ApolloResultType.SUCCESS)),
      catchError((err) => ApolloOperationResultResolver.handleError(err))
    );
  }
}
