import { ChangeDetectionStrategy, Component, OnChanges, OnInit, SimpleChanges } from '@angular/core';
import { CurrentUserService } from '@orion/user-services';
import { Optional } from '@sentinel/common/utils';
import {
  EntityDetailTabsDirective,
  OrionQueryParamTabService,
  OrionTabService,
  TABS_TOKEN,
} from '@csirtmu-orion/microframework/tabs';
import { Observable } from 'rxjs';
import { map } from 'rxjs/operators';
import { StageDetailTabsFragment, WorkflowDetailTabsFragment } from './stage-or-workflow-detail-tabs.generated';
import { StageOrWorkflowNestedTasksService } from './stage-or-workflow-nested-tasks.service';

@Component({
  selector: 'orion-stage-or-workflow-detail-tabs',
  templateUrl: './stage-or-workflow-detail-tabs.component.html',
  styleUrls: ['./stage-or-workflow-detail-tabs.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [
    StageOrWorkflowNestedTasksService,
    { provide: OrionTabService, useClass: OrionQueryParamTabService },
    { provide: TABS_TOKEN, useValue: ['overview', 'users', 'observables', 'assets', 'events', 'references', 'ttps'] },
  ],
})
export class StageOrWorkflowDetailTabsComponent
  extends EntityDetailTabsDirective<StageDetailTabsFragment | WorkflowDetailTabsFragment>
  implements OnInit, OnChanges
{
  activeUserId$?: Observable<Optional<string>>;

  constructor(
    protected tabsService: OrionTabService,
    private activeUserService: CurrentUserService,
    private nestedTasksService: StageOrWorkflowNestedTasksService
  ) {
    super(tabsService);
  }

  ngOnInit(): void {
    this.activeUserId$ = this.activeUserService.data$.pipe(map((user) => user?.id));
  }

  ngOnChanges(changes: SimpleChanges): void {
    super.ngOnChanges(changes);
    if ('entity' in changes && this.entity) {
      this.nestedTasksService.update(this.entity);
    }
  }
}
