import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap, Router } from '@angular/router';
import { ExternalReferenceClientFilter } from '@orion/case-types';
import { ExternalReferenceFilterService } from '@orion/external-reference-components/overview';
import { Observable } from 'rxjs';
import { concatMap, map } from 'rxjs/operators';
import { StageOrWorkflowNestedTasksService } from '../stage-or-workflow-nested-tasks.service';

@Injectable()
export class StageOrWorkflowExternalReferenceFilterService extends ExternalReferenceFilterService {
  constructor(
    protected router: Router,
    protected activatedRoute: ActivatedRoute,
    private nestedTasksService: StageOrWorkflowNestedTasksService
  ) {
    super(router, activatedRoute);
  }

  protected createFilterFromRoute(
    queryParamMap: ParamMap,
    paramMap: ParamMap
  ): Observable<ExternalReferenceClientFilter> {
    return super.createFilterFromRoute(queryParamMap, paramMap).pipe(
      concatMap((filter) =>
        this.nestedTasksService.ids$.pipe(
          map((taskIds) => {
            filter.taskIds = taskIds;
            return filter;
          })
        )
      )
    );
  }
}
