import { ChangeDetectionStrategy, Component } from '@angular/core';
import { ExternalReferenceClientFilter } from '@orion/case-types';
import {
  ExternalReferenceFilterChipsService,
  ExternalReferenceFilterService,
  ExternalReferenceOverviewFragment,
} from '@orion/external-reference-components/overview';
import { ExternalReferenceOverviewService } from '@orion/external-reference-services/overview';
import { CaseManagementExternalReferenceOrdEnum } from '@orion/graphql-types';
import {
  INIT_PAGINATION_EVENT_BASE_TOKEN,
  PaginationBaseInit,
  PaginationService,
  QueryParamPaginationService,
} from '@csirtmu-orion/microframework/pagination-services';
import { EntityPaginableFilterableSmartOverviewDirective } from '@csirtmu-orion/microframework/entity-smart-directives';
import { StageOrWorkflowExternalReferenceFilterService } from './stage-or-workflow-external-reference-filter.service';

@Component({
  selector: 'orion-stage-or-workflow-external-references',
  templateUrl: './stage-or-workflow-external-references.component.html',
  styleUrls: ['./stage-or-workflow-external-references.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [
    ExternalReferenceOverviewService,
    ExternalReferenceFilterChipsService,
    { provide: ExternalReferenceFilterService, useClass: StageOrWorkflowExternalReferenceFilterService },
    { provide: PaginationService, useClass: QueryParamPaginationService },
    {
      provide: INIT_PAGINATION_EVENT_BASE_TOKEN,
      useValue: new PaginationBaseInit(10, CaseManagementExternalReferenceOrdEnum.CREATED, 'desc'),
    },
  ],
})
export class StageOrWorkflowExternalReferencesComponent extends EntityPaginableFilterableSmartOverviewDirective<
  ExternalReferenceOverviewFragment,
  ExternalReferenceClientFilter
> {
  constructor(
    protected externalTicketsService: ExternalReferenceOverviewService,
    protected filterService: ExternalReferenceFilterService,
    protected chipsService: ExternalReferenceFilterChipsService,
    protected paginationService: PaginationService
  ) {
    super(externalTicketsService, filterService, paginationService, chipsService);
  }
}
