import { Injectable } from '@angular/core';
import { Observable, ReplaySubject } from 'rxjs';
import { StageDetailTabsFragment, WorkflowDetailTabsFragment } from './stage-or-workflow-detail-tabs.generated';

@Injectable()
export class StageOrWorkflowNestedTasksService {
  private idsSubject$: ReplaySubject<string[]> = new ReplaySubject<string[]>();
  ids$: Observable<string[]> = this.idsSubject$.asObservable();

  update(stageOrWorkflow: StageDetailTabsFragment | WorkflowDetailTabsFragment): void {
    if (this.isWorkflow(stageOrWorkflow)) {
      this.updateWorkflow(stageOrWorkflow);
    } else {
      this.updateStage(stageOrWorkflow);
    }
  }

  private isWorkflow(
    stageOrWorkflow: StageDetailTabsFragment | WorkflowDetailTabsFragment
  ): stageOrWorkflow is WorkflowDetailTabsFragment {
    return stageOrWorkflow.__typename === 'Workflow';
  }

  private updateWorkflow(workflow: WorkflowDetailTabsFragment): void {
    const taskIds = this.getTaskIdsOfWorkflow(workflow);
    this.idsSubject$.next(taskIds);
  }

  private updateStage(stage: StageDetailTabsFragment): void {
    if (stage?.tasksIds?.data && stage.tasksIds.data.length > 0) {
      this.idsSubject$.next(stage.tasksIds.data.map((task) => task.id));
    } else {
      this.idsSubject$.next([]);
    }
  }

  private getTaskIdsOfWorkflow(workflow: WorkflowDetailTabsFragment): string[] {
    if (workflow?.stagesWithTasksIds?.data && workflow?.stagesWithTasksIds.data.length > 0) {
      let taskIds: string[] = [];
      workflow.stagesWithTasksIds.data.forEach((stage) => {
        if (stage?.tasksIds?.data && stage.tasksIds.data.length > 0) {
          stage.tasksIds.data.forEach((task) => taskIds.push(task.id));
        }
      });
      return taskIds;
    } else {
      return [];
    }
  }
}
