import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap, Router } from '@angular/router';
import { FlowEventsFilterService } from '@orion/event-components/filters';
import { FlowEventClientFilter } from '@orion/event-types';
import { Observable } from 'rxjs';
import { concatMap, map } from 'rxjs/operators';
import { StageOrWorkflowNestedTasksService } from '../stage-or-workflow-nested-tasks.service';

@Injectable()
export class StageOrWorkflowRelatedEventsFilterService extends FlowEventsFilterService {
  constructor(
    protected router: Router,
    protected activatedRoute: ActivatedRoute,
    private nestedTasksService: StageOrWorkflowNestedTasksService
  ) {
    super(router, activatedRoute);
  }

  protected createFilterFromRoute(queryParamMap: ParamMap, paramMap: ParamMap): Observable<FlowEventClientFilter> {
    return super.createFilterFromRoute(queryParamMap, paramMap).pipe(
      concatMap((filter) =>
        this.nestedTasksService.ids$.pipe(
          map((taskIds) => {
            filter.taskIds = taskIds;
            return filter;
          })
        )
      )
    );
  }
}
