import { Injectable } from '@angular/core';
import { ActivatedRoute, Data, ParamMap, Router } from '@angular/router';
import { StageOrWorkflowNestedTasksService } from '@orion/stage-workflow-shared-components/detail';
import { Observable } from 'rxjs';
import { concatMap, map } from 'rxjs/operators';
import { RelatedUsersClientFilter } from '@orion/user-accounting-types';
import { RelatedUsersFilterService } from '@orion/user-accounting-components/related-users';

@Injectable()
export class StageOrWorkflowRelatedUsersFilterService extends RelatedUsersFilterService {
  constructor(
    protected router: Router,
    protected activatedRoute: ActivatedRoute,
    private nestedTasksService: StageOrWorkflowNestedTasksService
  ) {
    super(router, activatedRoute);
  }

  protected createFilterFromRoute(
    queryParamMap: ParamMap,
    paramMap: ParamMap,
    data: Data
  ): Observable<RelatedUsersClientFilter> {
    return super.createFilterFromRoute(queryParamMap, paramMap, data).pipe(
      concatMap((filter) =>
        this.nestedTasksService.ids$.pipe(
          map((taskFilters) => {
            filter.taskIds = taskFilters;
            return filter;
          })
        )
      )
    );
  }
}
