import { ControlsService } from '@orion/shared-services';
import { Optional } from '@sentinel/common/utils';
import { SentinelControlItem } from '@sentinel/components/controls';
import { BehaviorSubject } from 'rxjs';
import { map } from 'rxjs/operators';
import { StageDetailMainContentFragment, WorkflowDetailMainContentFragment } from './graphql';

export abstract class StageOrWorkflowControlsService extends ControlsService {
  stageOrWorkflow$: BehaviorSubject<Optional<StageDetailMainContentFragment | WorkflowDetailMainContentFragment>> =
    new BehaviorSubject<Optional<StageDetailMainContentFragment | WorkflowDetailMainContentFragment>>(undefined);

  protected constructor() {
    super();
    this.controls$ = this.stageOrWorkflow$.pipe(
      map((stageOrWorkflow) => (stageOrWorkflow ? this.createControls(stageOrWorkflow) : []))
    );
  }

  protected abstract createControls(
    stageOrWorkflow: StageDetailMainContentFragment | WorkflowDetailMainContentFragment
  ): SentinelControlItem[];

  onStageOrWorkflowChanged(stageOrWorkflow: StageDetailMainContentFragment | WorkflowDetailMainContentFragment): void {
    this.stageOrWorkflow$.next(stageOrWorkflow);
  }
}
