import {
  ChangeDetectionStrategy,
  Component,
  EventEmitter,
  Input,
  OnChanges,
  OnInit,
  Output,
  SimpleChanges,
} from '@angular/core';
import { EditableEntityPatchEvent, EntityEditModeService } from '@orion/shared-components/editable-entity';
import { StageOrWorkflowUpdate } from '@orion/stage-workflow-types';
import { EntityUpdateEvent } from '@csirtmu-orion/microframework/graphql';
import { SentinelControlItem } from '@sentinel/components/controls';
import { Observable } from 'rxjs';
import { StageDetailMainContentFragment, WorkflowDetailMainContentFragment } from './graphql';
import { StageOrWorkflowControlsService } from './stage-or-workflow-controls.service';

@Component({
  selector: 'orion-stage-or-workflow-detail-main-content',
  templateUrl: './stage-or-workflow-detail-main-content.component.html',
  styleUrls: ['./stage-or-workflow-detail-main-content.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class StageOrWorkflowDetailMainContentComponent implements OnInit, OnChanges {
  @Input() stageOrWorkflow?: StageDetailMainContentFragment | WorkflowDetailMainContentFragment;
  @Output() patch: EventEmitter<EntityUpdateEvent<StageOrWorkflowUpdate>> = new EventEmitter<
    EntityUpdateEvent<StageOrWorkflowUpdate>
  >();
  editMode$: Observable<boolean>;
  controls$?: Observable<SentinelControlItem[]>;

  constructor(
    private editService: EntityEditModeService,
    private stageOrWorkflowControlService: StageOrWorkflowControlsService
  ) {
    this.editMode$ = this.editService.editMode$;
    this.controls$ = this.stageOrWorkflowControlService.controls$;
  }

  ngOnInit(): void {
    this.editMode$ = this.editService.editMode$;
  }

  ngOnChanges(changes: SimpleChanges): void {
    if ('stageOrWorkflow' in changes && this.stageOrWorkflow) {
      this.stageOrWorkflowControlService.onStageOrWorkflowChanged(this.stageOrWorkflow);
    }
  }

  onPatch(event: EditableEntityPatchEvent): void {
    if (this.stageOrWorkflow) {
      const patchEvent: EntityUpdateEvent<StageOrWorkflowUpdate> = {
        id: this.stageOrWorkflow.id,
        patch: {
          name: event.name,
          description: event.description,
        },
      };
      this.patch.emit(patchEvent);
    }
  }
}
