import { Injectable } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { CreateEntityService } from '@orion/shared-services';
import { NotificationService } from '@orion/shared/services/global';
import { CreateStageDTO, CreateStageForm, StageRefs } from '@orion/stage-types';
import { CurrentUserService } from '@orion/user-services';
import {
  ApolloOperationResultResolver,
  ApolloResult,
  createApolloContextErrorTitle,
} from '@csirtmu-orion/microframework/graphql';
import { from, Observable, of } from 'rxjs';
import { catchError, concatMap, map, take } from 'rxjs/operators';
import { CreateStageMutationService } from './graphql';
import { WORKFLOW_PARAM_SELECTOR } from '@orion/case-paths';

@Injectable()
export class CreateStageService extends CreateEntityService<CreateStageForm> {
  constructor(
    protected notificationService: NotificationService,
    protected activatedRoute: ActivatedRoute,
    private router: Router,
    private createStageMutation: CreateStageMutationService,
    private activeUser: CurrentUserService
  ) {
    super('Stage', notificationService, activatedRoute);
  }

  protected createForm(): Observable<CreateStageForm> {
    return of(new CreateStageForm());
  }

  protected createEntity(form: CreateStageForm): Observable<ApolloResult> {
    return this.createStageRefs().pipe(
      map((refs) => new CreateStageDTO(form.getData(), refs)),
      concatMap((dto) =>
        this.createStageMutation.mutate({ stage: dto }, { context: createApolloContextErrorTitle('Creating stage') })
      ),
      map((res) => ApolloOperationResultResolver.resolve(res)),
      catchError((err) => ApolloOperationResultResolver.handleError(err))
    );
  }

  protected handleCancel(): Observable<boolean> {
    return this.navigateToWorkflow();
  }

  protected onSaveError(): Observable<boolean> {
    return of(false);
  }

  protected onSaveSuccess(): Observable<boolean> {
    return this.navigateToWorkflow();
  }

  private createStageRefs(): Observable<StageRefs> {
    return this.activatedRoute.paramMap.pipe(
      take(1),
      map((paramMap) => {
        const workflowId = paramMap.get(WORKFLOW_PARAM_SELECTOR) ?? undefined;
        const authorId = this.activeUser.getCurrentUser()?.id;
        if (workflowId !== undefined && authorId !== undefined) {
          return { workflowId, authorId };
        } else {
          throw 'error';
        }
      })
    );
  }

  private navigateToWorkflow(): Observable<boolean> {
    return from(this.router.navigate(['../../'], { relativeTo: this.activatedRoute }));
  }
}
