import { Injectable } from '@angular/core';
import { FetchResult } from '@apollo/client/core';
import { namedOperations } from '@orion/named-operations';
import { NotificationService } from '@orion/shared/services/global';
import {
  ApolloOperationResultResolver,
  ApolloResult,
  ApolloResultType,
  createApolloContextErrorTitle,
} from '@csirtmu-orion/microframework/graphql';
import { BehaviorSubject, Observable } from 'rxjs';
import { catchError, map, tap } from 'rxjs/operators';
import { RejectStageMutationService } from './graphql';

@Injectable()
export class StageActionsService {
  private rejectInProgressSubject$: BehaviorSubject<boolean> = new BehaviorSubject<boolean>(false);
  rejectInProgress$: Observable<boolean> = this.rejectInProgressSubject$.asObservable();

  constructor(
    private rejectStageMutation: RejectStageMutationService,
    private notificationService: NotificationService
  ) {}

  reject(id: string): Observable<ApolloResult> {
    this.rejectInProgressSubject$.next(true);
    return this.rejectStageMutation
      .mutate(
        { stageId: id },
        {
          refetchQueries: [namedOperations.Query.getStageDetail],
          context: createApolloContextErrorTitle('Rejecting stage'),
          awaitRefetchQueries: true,
        }
      )
      .pipe(
        map((res) => this.handleActionResponse(res)),
        tap({
          next: () => this.rejectInProgressSubject$.next(false),
          error: () => this.rejectInProgressSubject$.next(false),
        }),
        catchError((err) => ApolloOperationResultResolver.handleError(err))
      );
  }

  private handleActionResponse(fetchResult: FetchResult): ApolloResult {
    const result = ApolloOperationResultResolver.resolve(fetchResult);
    if (result.type === ApolloResultType.SUCCESS) {
      this.notificationService.emit('success', `Stage was successfully rejected`);
    }
    return result;
  }
}
