import { ChangeDetectionStrategy, Component, OnInit } from '@angular/core';
import { StageUpdate } from '@orion/graphql-types';
import {
  EditableEntityPageCanDeactivateService,
  ENTITY_EDIT_FORM_MANDATORY_DESCRIPTION_TOKEN,
  EntityEditEventService,
  EntityEditModeService,
  PatchEntityEditService,
} from '@orion/shared-components/editable-entity';
import { EditableEntityDetailPageBaseDirective } from '@orion/shared-components/entity-base';
import { EntityEditService } from '@orion/shared-components/entity-edit';
import { StageOrWorkflowControlsService } from '@orion/stage-workflow-shared-components/detail';
import { SidebarState, SidebarStateService } from '@sentinel/layout/sidebar';
import { Observable } from 'rxjs';
import { StageDetailFragment } from './graphql';
import { StageActionsService } from './stage-actions.service';
import { StageControlsService } from './stage-controls.service';
import { StageDetailService } from './stage-detail.service';
import { StagePatchService } from './stage-patch.service';
import { AssignedTasksFilterService } from '@orion/task-components/shared';
import { StageAssignedTasksFilterService } from './stage-assigned-tasks-filter.service';

@Component({
  selector: 'orion-stage-detail',
  templateUrl: './stage-detail-page.component.html',
  styleUrls: ['./stage-detail-page.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [
    StageDetailService,
    StagePatchService,
    StageActionsService,
    EntityEditModeService,
    EntityEditEventService,
    EditableEntityPageCanDeactivateService,
    { provide: AssignedTasksFilterService, useClass: StageAssignedTasksFilterService },
    { provide: ENTITY_EDIT_FORM_MANDATORY_DESCRIPTION_TOKEN, useValue: true },
    { provide: StageOrWorkflowControlsService, useClass: StageControlsService },
    { provide: EntityEditService, useClass: PatchEntityEditService },
  ],
})
export class StageDetailPageComponent
  extends EditableEntityDetailPageBaseDirective<StageDetailFragment, StageUpdate>
  implements OnInit
{
  state$?: Observable<SidebarState>;

  constructor(
    protected stageService: StageDetailService,
    protected stagePatchService: StagePatchService,
    protected canDeactivateService: EditableEntityPageCanDeactivateService,
    private sidebarStateService: SidebarStateService
  ) {
    super(stageService, stagePatchService, canDeactivateService);
  }

  ngOnInit(): void {
    super.ngOnInit();
    this.state$ = this.sidebarStateService.state$;
  }

  onSidebarClick(): void {
    this.sidebarStateService.toggleState();
  }
}
