import { Injectable } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { ControlsService } from '@orion/shared-services';
import { StageNavigator } from '@orion/stage-services';
import { WorkflowNameFragment } from '@orion/workflow-components/workflow-name';
import { SentinelControlItem } from '@sentinel/components/controls';
import { defer, EMPTY, from, Observable, of } from 'rxjs';

@Injectable()
export class StagesOverviewControlsService extends ControlsService {
  stageParent?: WorkflowNameFragment;
  constructor(private router: Router, private activatedRoute: ActivatedRoute, private stageRouter: StageNavigator) {
    super();
    this.controls$ = of([
      new SentinelControlItem(
        'CREATE',
        'Add',
        'primary',
        of(false),
        defer(() => this.onAdd())
      ),
    ]);
  }

  private onAdd(): Observable<boolean> {
    if (this.stageParent) {
      return from(
        this.router.navigate([this.stageRouter.toCreate(this.stageParent)], { relativeTo: this.activatedRoute })
      );
    }
    return EMPTY;
  }

  setStageParent(workflow: WorkflowNameFragment): void {
    this.stageParent = workflow;
  }
}
