import { ChangeDetectionStrategy, Component, Input, OnChanges, SimpleChanges } from '@angular/core';
import { StagesOverviewControlsService } from '@orion/stage-components/overview';
import { SentinelControlItem } from '@sentinel/components/controls';
import { Observable } from 'rxjs';
import { StagePanelFragment } from './stage-panel.fragment.generated';

@Component({
  selector: 'orion-stage-panel',
  templateUrl: './stage-panel.component.html',
  styleUrls: ['./stage-panel.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [StagesOverviewControlsService],
})
export class StagePanelComponent implements OnChanges {
  @Input() workflow?: StagePanelFragment;
  controls$?: Observable<SentinelControlItem[]>;
  isExpanded = false;
  stagesCount = 0;

  constructor(private controlsService: StagesOverviewControlsService) {
    this.controls$ = this.controlsService.controls$;
  }

  ngOnChanges(changes: SimpleChanges): void {
    if ('workflow' in changes && this.workflow?.stages) {
      this.isExpanded = this.workflow?.stages?.totalCount > 0;
      this.stagesCount = this.workflow?.stages?.totalCount ?? 0;
      this.controlsService.setStageParent(this.workflow);
    }
  }
}
