import { ChangeDetectionStrategy, Component, Input, OnChanges, SimpleChanges } from '@angular/core';
import { CreateAssociationViewStateService } from '@orion/shared-components/related-entity-overview';
import { SentinelControlItem } from '@sentinel/components/controls';
import { Observable } from 'rxjs';
import { ParentOfTaskService } from './parent-of-task.service';
import { StageTaskPanelFragment } from './stage-task-panel.fragment.generated';
import { StageTasksControlsService } from './stage-tasks-controls.service';
import { TASK_ICON } from '@orion/common';

@Component({
  selector: 'orion-stage-task-panel',
  templateUrl: './stage-task-panel.component.html',
  styleUrls: ['./stage-task-panel.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [CreateAssociationViewStateService, StageTasksControlsService, ParentOfTaskService],
})
export class StageTaskPanelComponent implements OnChanges {
  @Input() stagePanel?: StageTaskPanelFragment;
  tasksCount = 0;
  controls$?: Observable<SentinelControlItem[]>;
  taskIcon = TASK_ICON;

  constructor(private controlsService: StageTasksControlsService, private parentOfTaskService: ParentOfTaskService) {
    this.controls$ = this.controlsService.controls$;
  }

  ngOnChanges(changes: SimpleChanges): void {
    if ('stagePanel' in changes && this.stagePanel?.tasksAggregate) {
      this.tasksCount = this.stagePanel.tasksAggregate.totalCount;
      this.parentOfTaskService.setParentStage(this.stagePanel);
    }
  }
}
