import { Injectable } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { ControlsService } from '@orion/shared-services';
import { TaskNavigator } from '@orion/task-services';
import { SentinelControlItem } from '@sentinel/components/controls';
import { defer, EMPTY, from, Observable, of } from 'rxjs';
import { ParentOfTaskService } from './parent-of-task.service';

@Injectable()
export class StageTasksControlsService extends ControlsService {
  constructor(
    private parentOfTaskService: ParentOfTaskService,
    private router: Router,
    private activatedRoute: ActivatedRoute,
    private taskRouter: TaskNavigator
  ) {
    super();
    this.controls$ = of([
      new SentinelControlItem(
        'CREATE',
        'Add',
        'primary',
        of(false),
        defer(() => this.onAddNew())
      ),
    ]);
  }

  private onAddNew(): Observable<boolean> {
    if (this.parentOfTaskService.parentStage) {
      return from(
        this.router.navigate([this.taskRouter.toCreate(this.parentOfTaskService.parentStage)], {
          relativeTo: this.activatedRoute,
        })
      );
    }
    return EMPTY;
  }
}
