import { Injectable } from '@angular/core';
import { ControlsService, EntityModifyBaseService } from '@orion/shared-services';
import { combineLatest, defer, Observable, of } from 'rxjs';
import { SentinelControlItem } from '@sentinel/components/controls';
import { distinctUntilChanged, map, startWith, switchMap } from 'rxjs/operators';
import { CreateTaskForm } from '@orion/task-types';
import { TaskFormStepperService } from './task-form-stepper.service';

@Injectable()
export class CreateTaskControlsService extends ControlsService {
  constructor(
    private editEntityService: EntityModifyBaseService<CreateTaskForm>,
    private formStepperService: TaskFormStepperService
  ) {
    super();
    const saveDisabled$ = this.getSaveDisabled();
    const nextDisabled$ = this.getNextStepDisabled();
    const previous = new SentinelControlItem(
      'previous',
      'Previous',
      'accent',
      of(false),
      defer(() => this.formStepperService.previous())
    );
    const next = new SentinelControlItem(
      'next',
      'Next',
      'accent',
      nextDisabled$,
      defer(() => this.formStepperService.next())
    );
    const cancel = new SentinelControlItem(
      'cancel',
      'Cancel',
      'warn',
      this.editEntityService.isSaving$,
      defer(() => this.editEntityService.cancel())
    );
    const save = new SentinelControlItem(
      'save',
      'Finish',
      'primary',
      saveDisabled$,
      defer(() => this.editEntityService.save()),
      this.editEntityService.isSaving$
    );
    this.controls$ = combineLatest([
      this.formStepperService.step$,
      this.editEntityService.form$.pipe(map((form) => form.steps)),
    ]).pipe(
      map(([step, maxSteps]) => {
        if (step === 0) {
          return [cancel, next];
        }
        if (step === 1) {
          return [cancel, previous, next];
        }
        if ((step === 2 && step === maxSteps - 1) || (step === 3 && step === maxSteps - 1)) {
          return [cancel, previous, save];
        } else {
          return [cancel, previous, next];
        }
      })
    );
  }

  private getSaveDisabled(): Observable<boolean> {
    const invalid$ = this.editEntityService.form$.pipe(
      switchMap((form) =>
        form.formGroup.statusChanges.pipe(
          map(() => form.formGroup.valid),
          distinctUntilChanged(),
          startWith(form.formGroup.valid)
        )
      ),
      map((valid) => !valid)
    );
    const saving$ = this.editEntityService.isSaving$;
    return combineLatest([invalid$, saving$]).pipe(map((values) => values.some((value) => value)));
  }

  private getNextStepDisabled(): Observable<boolean> {
    return combineLatest([this.editEntityService.form$, this.formStepperService.step$]).pipe(
      switchMap(([form, step]) => form.getStepValid(step)),
      map((valid) => !valid)
    );
  }
}
