import { TaskListElementFragment } from '@orion/task-components/shared';
import { TaskRelationshipTypeEnum } from '@orion/graphql-types';
import { PredecessorPossibleRelationshipResolver } from './predecessor-possible-relationship-resolver';

describe('PredecessorPossibleRelationshipResolver', () => {
  function createMockTaskFragment(): TaskListElementFragment {
    return {
      id: '1',
      name: '',
      stage: {
        id: '1',
        workflow: {
          id: '1',
          case: {
            id: '1',
          },
        },
      },
    };
  }

  it('should return correct relationships for task without flags', () => {
    const task = createMockTaskFragment();
    const expected = [TaskRelationshipTypeEnum.ON_COMPLETION];
    const actual = PredecessorPossibleRelationshipResolver.resolve(task);

    expect(actual.length).toEqual(expected.length);
    actual.forEach((rel) => expect(expected).toContain(rel));
  });

  it('should return correct relationships for task with aggregator flag', () => {
    const task = createMockTaskFragment();
    task.aggregatesResults = true;
    const expected = [TaskRelationshipTypeEnum.ON_COMPLETION, TaskRelationshipTypeEnum.BLOCKED_BY];
    const actual = PredecessorPossibleRelationshipResolver.resolve(task);

    expect(actual.length).toEqual(expected.length);
    actual.forEach((rel) => expect(expected).toContain(rel));
  });

  it('should return correct relationships for task with decision flag', () => {
    const task = createMockTaskFragment();
    task.isDecision = true;
    const expected = [
      TaskRelationshipTypeEnum.ON_COMPLETION,
      TaskRelationshipTypeEnum.ON_TRUE,
      TaskRelationshipTypeEnum.ON_FALSE,
    ];
    const actual = PredecessorPossibleRelationshipResolver.resolve(task);

    expect(actual.length).toEqual(expected.length);
    actual.forEach((rel) => expect(expected).toContain(rel));
  });

  it('should return correct relationships for task with decision and aggregator flag', () => {
    const task = createMockTaskFragment();
    task.isDecision = true;
    task.aggregatesResults = true;
    const expected = [
      TaskRelationshipTypeEnum.ON_COMPLETION,
      TaskRelationshipTypeEnum.ON_TRUE,
      TaskRelationshipTypeEnum.ON_FALSE,
      TaskRelationshipTypeEnum.BLOCKED_BY,
    ];
    const actual = PredecessorPossibleRelationshipResolver.resolve(task);

    expect(actual.length).toEqual(expected.length);
    actual.forEach((rel) => expect(expected).toContain(rel));
  });
});
