import { ChangeDetectionStrategy, Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { TaskOrdEnum, TaskStateEnum } from '@orion/graphql-types';
import { TaskListElementFragment, TaskListService } from '@orion/task-components/shared';
import {
  INIT_PAGINATION_EVENT_BASE_TOKEN,
  PaginationBaseInit,
  PaginationService,
} from '@csirtmu-orion/microframework/pagination-services';
import { Observable } from 'rxjs';
import { map } from 'rxjs/operators';

@Component({
  selector: 'orion-task-link-predecessor',
  templateUrl: './task-link-predecessor.component.html',
  styleUrls: ['./task-link-predecessor.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [
    TaskListService,
    PaginationService,
    {
      provide: INIT_PAGINATION_EVENT_BASE_TOKEN,
      useValue: new PaginationBaseInit(50, TaskOrdEnum.NAME, 'asc'),
    },
  ],
})
export class TaskLinkPredecessorComponent implements OnInit {
  readonly POSSIBLE_PREDECESSOR_STATES = [
    TaskStateEnum.OPEN,
    TaskStateEnum.PENDING,
    TaskStateEnum.RESOLVED,
    TaskStateEnum.RUNNING,
    TaskStateEnum.SKIPPED,
  ];
  @Input() stageId?: string;
  @Input() exceptIds?: string[];
  @Output() valueChange: EventEmitter<TaskListElementFragment> = new EventEmitter<TaskListElementFragment>();
  possiblePredecessors$?: Observable<TaskListElementFragment[]>;
  isLoading$?: Observable<boolean>;
  hasError$?: Observable<boolean>;

  constructor(private tasksService: TaskListService, private paginationService: PaginationService) {}

  ngOnInit(): void {
    this.possiblePredecessors$ = this.tasksService.data$.pipe(map((paginated) => paginated.elements));
    this.isLoading$ = this.tasksService.isLoading$;
    this.hasError$ = this.tasksService.hasError$;
  }

  onSelectionChange(selected: TaskListElementFragment): void {
    this.valueChange.emit(selected);
  }

  onSearchPredecessor(value: string): void {
    if (this.stageId) {
      this.tasksService.update(this.paginationService.get(), {
        states: this.POSSIBLE_PREDECESSOR_STATES,
        inStageIds: [this.stageId],
        exceptIds: this.exceptIds ?? [],
        name: value,
      });
    }
  }

  onPredecessorSearchTryAgain(): void {
    this.tasksService.recoverAfterError();
  }
}
