import { ChangeDetectionStrategy, Component, OnInit } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { CanDeactivatePageDirective, EntityModifyBaseService } from '@orion/shared-services';
import { CreateTaskForm } from '@orion/task-types';
import { Observable } from 'rxjs';
import { map, take, takeUntil } from 'rxjs/operators';
import { CreateTaskService } from './create-task.service';
import { STAGE_PARAM_SELECTOR } from '@orion/case-paths';
import { Optional } from '@sentinel/common/utils';
import { SentinelControlItem } from '@sentinel/components/controls';
import { TaskFormStepperService } from './task-form-stepper.service';
import { CreateTaskControlsService } from './create-task-controls.service';

@Component({
  selector: 'orion-create-task-page',
  templateUrl: './create-task-page.component.html',
  styleUrls: ['./create-task-page.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [
    { provide: EntityModifyBaseService, useClass: CreateTaskService },
    CreateTaskControlsService,
    TaskFormStepperService,
  ],
})
export class CreateTaskPageComponent extends CanDeactivatePageDirective implements OnInit {
  stageId$?: Observable<Optional<string>>;
  controls$?: Observable<SentinelControlItem[]>;
  isSaving$: Observable<boolean>;
  form$: Observable<CreateTaskForm>;
  canDeactivateSync = true;

  constructor(
    protected modifyEntityService: EntityModifyBaseService<CreateTaskForm>,
    protected controlsService: CreateTaskControlsService,
    private activatedRoute: ActivatedRoute
  ) {
    super();
    this.controls$ = this.controlsService.controls$;
    this.isSaving$ = this.modifyEntityService.isSaving$;
    this.form$ = this.modifyEntityService.form$;
    this.modifyEntityService.canDeactivate$
      .pipe(takeUntil(this.destroy$))
      .subscribe((canDeactivate) => (this.canDeactivateSync = canDeactivate));
  }

  ngOnInit(): void {
    this.stageId$ = this.activatedRoute.paramMap.pipe(
      take(1),
      map((paramMap) => paramMap.get(STAGE_PARAM_SELECTOR) ?? undefined)
    );
  }

  canDeactivate(): boolean {
    return this.canDeactivateSync;
  }
}
