import { Injectable } from '@angular/core';
import { MatDialog } from '@angular/material/dialog';
import { ActivatedRoute } from '@angular/router';
import { TASK_PARAM_SELECTOR } from '@orion/case-paths';
import {
  CreateCommentMutationService,
  DeleteCommentMutationService,
  EntityCommentsActionService,
  UpdateCommentMutationService,
} from '@orion/comment-services';
import { CommentRefs, EntityCommentRefs } from '@orion/comment-types';
import { NotificationService } from '@orion/shared/services/global';
import { Observable } from 'rxjs';
import { map, take } from 'rxjs/operators';

@Injectable()
export class TaskCommentsActionService extends EntityCommentsActionService {
  public constructor(
    protected dialog: MatDialog,
    protected notificationService: NotificationService,
    protected addCommentService: CreateCommentMutationService,
    protected updateCommentService: UpdateCommentMutationService,
    protected deleteCommentService: DeleteCommentMutationService,
    protected activatedRoute: ActivatedRoute
  ) {
    super(dialog, notificationService, addCommentService, updateCommentService, deleteCommentService);
  }
  createEntityRefs(refs: CommentRefs): Observable<EntityCommentRefs> {
    return this.activatedRoute.paramMap.pipe(
      take(1),
      map((paramMap) => {
        const taskId = paramMap.get(TASK_PARAM_SELECTOR);
        if (taskId) {
          return { ...refs, taskId: taskId };
        } else {
          throw Error('Failed to add comment to task. Task param is null');
        }
      })
    );
  }
}
