import {
  ChangeDetectionStrategy,
  Component,
  EventEmitter,
  Input,
  OnChanges,
  Output,
  SimpleChanges,
} from '@angular/core';
import { TaskInputOutputUpdate } from '@orion/task-types';
import { SentinelControlItem } from '@sentinel/components/controls';
import { TaskInputOutputPanelFragment } from '../../graphql';
import { CreateTaskInputOutputData, IOTaskFileSave, IOTaskSave, TaskMode } from './task-io';

@Component({
  selector: 'orion-task-input-output-panel',
  templateUrl: './task-input-output-panel.component.html',
  styleUrls: ['./task-input-output-panel.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class TaskInputOutputPanelComponent implements OnChanges {
  @Input() id?: string;
  @Input() mode?: TaskMode;
  @Input() edit?: boolean;
  @Input() canResolve?: boolean;
  @Input() canCreateInput = false;
  @Input() inputOrOutput?: TaskInputOutputPanelFragment;
  @Input() isLoading = false;
  @Input() disabled = false;
  @Input() isAutomated = false;

  @Input() hasAutotrigger = false;
  @Input() controls: SentinelControlItem[] = [];
  @Output() saveValue: EventEmitter<IOTaskSave> = new EventEmitter<IOTaskSave>();
  @Output() saveFile: EventEmitter<IOTaskFileSave> = new EventEmitter<IOTaskFileSave>();
  @Output() createInputOutput: EventEmitter<CreateTaskInputOutputData> = new EventEmitter<CreateTaskInputOutputData>();
  @Output() cancelEdit: EventEmitter<void> = new EventEmitter<void>();
  @Output() saveEdit: EventEmitter<TaskInputOutputUpdate> = new EventEmitter<TaskInputOutputUpdate>();

  initialValue?: string;

  ngOnChanges(changes: SimpleChanges): void {
    if ('inputOrOutput' in changes && this.inputOrOutput && this.inputOrOutput.__typename === 'JSONInputOutput') {
      this.initialValue = this.inputOrOutput.jsonInitialValue;
    } else {
      this.initialValue = undefined;
    }
  }

  setTaskInputOutputValue(value: IOTaskSave): void {
    this.saveValue.emit(value);
  }

  setTaskInputOutputFile(file: IOTaskFileSave): void {
    this.saveFile.emit(file);
  }

  onCreateInputOutput(inputOutput: CreateTaskInputOutputData): void {
    this.createInputOutput.emit(inputOutput);
  }

  onCancelEdit(): void {
    this.cancelEdit.emit();
  }

  onSaveEdit(data: TaskInputOutputUpdate): void {
    this.saveEdit.emit(data);
  }
}
