import { Pipe, PipeTransform } from '@angular/core';
import { KnownInputOutputTypes } from '@orion/graphql-types';
import { TaskIOTypenameOrEnum } from '@orion/task-types';
import { isAnyDateType, isBoolType, isDateType, isFileType, isStringLikeType, isStringType } from './utils';

@Pipe({
  name: 'isBoolForm',
})
export class IsBoolFormPipe implements PipeTransform {
  transform(typeOrEnum?: TaskIOTypenameOrEnum): boolean {
    return isBoolType(typeOrEnum);
  }
}

@Pipe({
  name: 'isAnyDateForm',
})
export class IsAnyDateFormPipe implements PipeTransform {
  transform(typeOrEnum?: TaskIOTypenameOrEnum): boolean {
    return isAnyDateType(typeOrEnum);
  }
}

@Pipe({
  name: 'isDateForm',
})
export class IsDateFormPipe implements PipeTransform {
  transform(typeOrEnum?: TaskIOTypenameOrEnum): boolean {
    return isDateType(typeOrEnum);
  }
}

@Pipe({
  name: 'isFileForm',
})
export class IsFileFormPipe implements PipeTransform {
  transform(typeOrEnum?: TaskIOTypenameOrEnum): boolean {
    return isFileType(typeOrEnum);
  }
}

@Pipe({
  name: 'isJSONForm',
})
export class IsJSONFormPipe implements PipeTransform {
  transform(typeOrEnum?: TaskIOTypenameOrEnum): boolean {
    return typeOrEnum === 'JSONInputOutput' || typeOrEnum === KnownInputOutputTypes.JSON;
  }
}

@Pipe({
  name: 'isStringLikeForm',
})
export class IsStringLikeFormPipe implements PipeTransform {
  transform(typeOrEnum?: TaskIOTypenameOrEnum): boolean {
    return isStringLikeType(typeOrEnum);
  }
}

@Pipe({
  name: 'isStringForm',
})
export class IsStringFormPipe implements PipeTransform {
  transform(typeOrEnum?: TaskIOTypenameOrEnum): boolean {
    return isStringType(typeOrEnum);
  }
}

@Pipe({
  name: 'toBoolValue',
})
export class ToBoolValuePipe implements PipeTransform {
  transform(value?: string): boolean {
    return value ? value.toLowerCase() === 'true' : false;
  }
}

@Pipe({
  name: 'toDateValue',
})
export class ToDateValuePipe implements PipeTransform {
  transform(value?: string): Date | undefined {
    return value ? new Date(value) : undefined;
  }
}
