import {
  ChangeDetectionStrategy,
  Component,
  EventEmitter,
  Input,
  OnChanges,
  OnDestroy,
  Output,
  SimpleChanges,
} from '@angular/core';
import { Destroyable } from '@sentinel/common';
import { SentinelControlItem } from '@sentinel/components/controls';
import { BehaviorSubject, defer, of } from 'rxjs';
import { map, take } from 'rxjs/operators';
import { TaskMode } from '../io-utils';
import { CreateInputOutputForm, CreateTaskInputOutputData } from './create-task-inpu-output-form';

@Component({
  selector: 'orion-task-input-output-create',
  templateUrl: './task-input-output-create.component.html',
  styleUrls: ['./task-input-output-create.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class TaskInputOutputCreateComponent extends Destroyable() implements OnChanges, OnDestroy {
  @Input() isLoading?: boolean;
  @Input() mode?: TaskMode;
  @Output() cancel: EventEmitter<void> = new EventEmitter<void>();
  @Output() createInputOutput: EventEmitter<CreateTaskInputOutputData> = new EventEmitter<CreateTaskInputOutputData>();

  form: CreateInputOutputForm;
  controls: SentinelControlItem[] = [];
  isLoadingSubject$: BehaviorSubject<boolean> = new BehaviorSubject<boolean>(false);

  constructor() {
    super();
    this.form = new CreateInputOutputForm();

    const disabled$ = this.form.valid$.pipe(map((valid) => !valid));
    this.controls = [
      new SentinelControlItem(
        'CANCEL',
        'Cancel',
        'warn',
        of(false),
        defer(() => this.onCancel())
      ),
      new SentinelControlItem(
        'SET',
        'Set',
        'primary',
        disabled$,
        defer(() => this.onSetInputOutput()),
        this.isLoadingSubject$
      ),
    ];
  }

  ngOnChanges(changes: SimpleChanges): void {
    if ('isLoading' in changes && this.isLoading !== undefined) {
      this.isLoadingSubject$.next(this.isLoading);
    }
  }

  onControlsItem(controlItem: SentinelControlItem): void {
    controlItem.result$?.pipe(take(1)).subscribe();
  }

  private onCancel(): void {
    this.cancel.emit();
  }

  private onSetInputOutput(): void {
    this.createInputOutput.emit(this.form.toData());
  }
}
