import { ChangeDetectionStrategy, Component, EventEmitter, Input, Output } from '@angular/core';
import { TaskIOTypenameOrEnum } from '@orion/task-types';

@Component({
  selector: 'orion-task-input-output-form',
  templateUrl: './task-input-output-form.component.html',
  styleUrls: ['./task-input-output-form.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class TaskInputOutputFormComponent {
  @Input() displayFileValue = true;
  @Input() initValue?: string;
  @Input() lastSavedValue?: string;
  @Input() validationValue?: string;
  @Input() type?: TaskIOTypenameOrEnum;
  @Input() disabled = false;
  @Input() required = false;
  @Output() valueChange: EventEmitter<string> = new EventEmitter<string>();
  @Output() fileChange: EventEmitter<File | undefined> = new EventEmitter<File | undefined>();
  @Output() validityChange: EventEmitter<boolean> = new EventEmitter<boolean>();

  onPrimitiveValueChanged(value: string | boolean): void {
    if (value !== undefined && value !== null) {
      this.valueChange.emit(value.toString());
    } else {
      this.valueChange.emit(value);
    }
  }

  onDateChanged(value: Date): void {
    if (value !== undefined && value !== null) {
      this.valueChange.emit(value.toISOString());
    } else {
      this.valueChange.emit(value);
    }
  }

  onFileSelected(file: File | undefined): void {
    this.fileChange.emit(file);
    this.validityChange.emit(file !== undefined);
  }

  onValidityChange(valid: boolean): void {
    this.validityChange.emit(valid);
  }
}
