import { ChangeDetectionStrategy, Component, Input, OnChanges, OnInit, SimpleChanges } from '@angular/core';
import { ValidatorFn } from '@angular/forms';
import { JSONSchemaValidator } from '@orion/common';
import { taskIOTypenameToValidators } from '../../../io-utils';
import { TaskInputOutputEditDirective } from '../../task-input-output-edit.directive';

@Component({
  selector: 'orion-task-raw-json-input-output-edit',
  templateUrl: './task-raw-json-input-output-edit.component.html',
  styleUrls: ['./task-raw-json-input-output-edit.component.scss'],
  changeDetection: ChangeDetectionStrategy.Default,
})
export class TaskRawJsonInputOutputEditComponent
  extends TaskInputOutputEditDirective<string>
  implements OnInit, OnChanges
{
  @Input() editorSize: 'small' | 'medium' | 'large' = 'medium';
  @Input() validationValue?: string;
  private schemaValidator?: ValidatorFn;

  ngOnInit(): void {
    super.ngOnInit();
    this.addValidators(taskIOTypenameToValidators('JSONInputOutput'));
  }

  ngOnChanges(changes: SimpleChanges): void {
    super.ngOnChanges(changes);
    if (
      'validationValue' in changes &&
      changes.validationValue.currentValue !== changes.validationValue.previousValue
    ) {
      const recompileSchema =
        !changes.validationValue.isFirstChange() &&
        changes.validationValue.previousValue !== null &&
        changes.validationValue.previousValue !== undefined &&
        changes.validationValue.previousValue !== '';
      this.changeSchemaValidator(this.validationValue, recompileSchema);
    }
  }

  /**
   * If schema changes during the component's life we need to add new validator and
   * remove previous validator
   */
  private changeSchemaValidator(value?: string, forceCompileSchema = false): void {
    if (value) {
      const newValidator = JSONSchemaValidator.validator(value, forceCompileSchema);
      this.addValidators(newValidator);
      if (this.schemaValidator) {
        this.removeValidators(this.schemaValidator);
      }
      this.schemaValidator = newValidator;
    } else if (this.schemaValidator) {
      this.removeValidators(this.schemaValidator);
      this.schemaValidator = undefined;
    }
  }
}
