import { ChangeDetectionStrategy, Component, Input, OnChanges, SimpleChanges } from '@angular/core';
import { ValidatorFn, Validators } from '@angular/forms';
import { TaskIOTypenameOrEnum } from '@orion/task-types';
import { taskIOTypenameToValidators } from '../../../io-utils';
import { TaskInputOutputEditDirective } from '../../task-input-output-edit.directive';

@Component({
  selector: 'orion-task-string-input-output-edit',
  templateUrl: './task-string-input-output-edit.component.html',
  styleUrls: ['./task-string-input-output-edit.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class TaskStringInputOutputEditComponent extends TaskInputOutputEditDirective<string> implements OnChanges {
  @Input() type?: TaskIOTypenameOrEnum;
  @Input() validationValue?: string;

  private patternValidator?: ValidatorFn;
  ngOnChanges(changes: SimpleChanges): void {
    super.ngOnChanges(changes);
    if ('type' in changes && this.type !== undefined) {
      const prevTypeValidators = taskIOTypenameToValidators(changes.type.previousValue);
      if (prevTypeValidators) {
        this.removeValidators(prevTypeValidators);
      }
      this.addValidators(taskIOTypenameToValidators(this.type));
    }
    if ('validationValue' in changes) {
      this.changePatternValidator(this.validationValue);
    }
  }

  private changePatternValidator(value?: string): void {
    if (value) {
      const newValidator = Validators.pattern(value);
      this.addValidators(newValidator);
      if (this.patternValidator) {
        this.removeValidators(this.patternValidator);
      }
      this.patternValidator = newValidator;
    } else if (this.patternValidator) {
      this.removeValidators(this.patternValidator);
      this.patternValidator = undefined;
    }
  }
}
