import {
  ChangeDetectionStrategy,
  Component,
  EventEmitter,
  Input,
  OnChanges,
  Output,
  SimpleChanges,
} from '@angular/core';
import { CreateInputOutputForm, TaskInputOutputPanelFragment } from '@orion/task-components/task-detail';
import { TaskInputOutputUpdate } from '@orion/task-types';
import { BehaviorSubject, combineLatest, Observable } from 'rxjs';
import { map } from 'rxjs/operators';
import { TaskMode } from '../../io-utils';

@Component({
  selector: 'orion-task-input-output-edit',
  templateUrl: './task-input-output-edit.component.html',
  styleUrls: ['./task-input-output-edit.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class TaskInputOutputEditComponent implements OnChanges {
  @Input() mode?: TaskMode;
  @Input() inputOrOutput?: TaskInputOutputPanelFragment;
  @Input() disabled?: boolean;
  @Output() cancel: EventEmitter<void> = new EventEmitter<void>();
  @Output() saveEdit: EventEmitter<TaskInputOutputUpdate> = new EventEmitter<TaskInputOutputUpdate>();
  basicTaskIOForm?: CreateInputOutputForm;
  ioEditOutput?: TaskInputOutputUpdate;
  private ioValueValid$: BehaviorSubject<boolean> = new BehaviorSubject<boolean>(true);
  canSave$?: Observable<boolean>;
  validationValue$?: Observable<string | null>;

  ngOnChanges(changes: SimpleChanges): void {
    if ('inputOrOutput' in changes && this.inputOrOutput) {
      this.basicTaskIOForm = new CreateInputOutputForm(this.inputOrOutput);
      this.ioEditOutput = {
        id: this.inputOrOutput.id,
        stringifiedValue: this.inputOrOutput.stringifiedValue,
        type: this.inputOrOutput.__typename ?? 'BaseTaskInputOutput',
      };
      this.canSave$ = combineLatest([this.basicTaskIOForm.valid$, this.ioValueValid$.asObservable()]).pipe(
        map((values) => values.every((value) => value))
      );
      this.validationValue$ = this.basicTaskIOForm.formGroup.controls.validation.valueChanges;
    }
  }

  onCancel(): void {
    this.cancel.emit();
  }

  onSave(): void {
    if (this.basicTaskIOForm && this.ioEditOutput) {
      const formData = this.basicTaskIOForm.toData();
      this.ioEditOutput.description = formData.description;
      this.ioEditOutput.validation = formData.validation;
      this.saveEdit.emit(this.ioEditOutput);
    }
  }

  onValueValidityChange(valid: boolean): void {
    this.ioValueValid$.next(valid);
  }

  onIOValueChange(ioValue: string): void {
    if (this.ioEditOutput) {
      this.ioEditOutput.stringifiedValue = ioValue;
    }
  }
}
