import { ChangeDetectionStrategy, Component, Input, OnInit } from '@angular/core';
import { EntityCommentFileUploadService } from '@orion/comment-components';
import { CommentFilterService, EntityCommentsActionService } from '@orion/comment-services';
import { CurrentUserService } from '@orion/user-services';
import { Optional } from '@sentinel/common/utils';
import { Observable } from 'rxjs';
import { map } from 'rxjs/operators';
import { TaskCommentsActionService } from './task-comments-action.service';
import { TaskCommentsFilterService } from './task-comments-filter.service';
import { TaskOverviewTabFragment } from './task-overview-tab.fragment.generated';
import { UploadTaskCommentFileService } from './upload-task-comment-file.service';

@Component({
  selector: 'orion-task-overview-tab',
  templateUrl: './task-overview-tab.component.html',
  styleUrls: ['./task-overview-tab.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [
    { provide: EntityCommentsActionService, useClass: TaskCommentsActionService },
    { provide: CommentFilterService, useClass: TaskCommentsFilterService },
    { provide: EntityCommentFileUploadService, useClass: UploadTaskCommentFileService },
  ],
})
export class TaskOverviewTabComponent implements OnInit {
  @Input() task?: TaskOverviewTabFragment;
  activeUserId$?: Observable<Optional<string>>;

  constructor(private activeUserService: CurrentUserService) {}

  ngOnInit(): void {
    this.activeUserId$ = this.activeUserService.data$.pipe(map((user) => user?.id));
  }
}
