import { isLoading } from '@sentinel/common/utils';
import { Column, Row, RowAction, SentinelTable } from '@sentinel/components/table';
import { defer, of } from 'rxjs';
import { map } from 'rxjs/operators';
import { TaskReferenceActionsService } from '../task-reference-actions.service';
import { TaskReferenceTableElementFragment } from './task-reference-table.fragment.generated';

export class TaskReferenceTable extends SentinelTable<TaskReferenceTableElementFragment> {
  constructor(references: TaskReferenceTableElementFragment[], service: TaskReferenceActionsService) {
    const columns = [new Column('task', 'Task', false), new Column('state', 'State', false)];
    const rows = references.map(
      (reference) => new Row(reference, TaskReferenceTable.createActions(reference, service))
    );
    super(rows, columns);
  }

  private static createActions(
    relationship: TaskReferenceTableElementFragment,
    service: TaskReferenceActionsService
  ): RowAction[] {
    return [
      new RowAction(
        'delete',
        'Delete',
        'clear',
        'warn',
        'Delete reference',
        of(false),
        defer(() => service.delete(relationship.id)),
        service.deletingInProgress$.pipe(map((state) => isLoading(state, relationship.id)))
      ),
    ];
  }
}
