import { ChangeDetectionStrategy, Component, Input, OnChanges, SimpleChanges } from '@angular/core';
import { SentinelControlItem } from '@sentinel/components/controls';
import { Observable } from 'rxjs';
import { take } from 'rxjs/operators';
import { CreateTaskReference } from './create-task-reference';
import { TaskReferenceActionsService } from './task-reference-actions.service';
import { TaskReferenceControlsService } from './task-reference-controls.service';
import { TaskReferenceViewStateService } from './task-reference-view-state.service';
import { TaskReferencesPanelFragment } from './task-references-panel.fragment.generated';

@Component({
  selector: 'orion-task-references-panel',
  templateUrl: './task-references-panel.component.html',
  styleUrls: ['./task-references-panel.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [TaskReferenceControlsService, TaskReferenceActionsService, TaskReferenceViewStateService],
})
export class TaskReferencesPanelComponent implements OnChanges {
  @Input() task?: TaskReferencesPanelFragment;
  referencesCount = 0;
  controls$?: Observable<SentinelControlItem[]>;
  addComponentDisplayed$?: Observable<boolean>;
  constructor(
    private controlsService: TaskReferenceControlsService,
    private actionService: TaskReferenceActionsService,
    private viewService: TaskReferenceViewStateService
  ) {
    this.controls$ = this.controlsService.controls$;
    this.addComponentDisplayed$ = this.viewService.displayedAddComponent$;
  }

  ngOnChanges(changes: SimpleChanges): void {
    if ('task' in changes && this.task) {
      const referencedByCount = this.task.referencedBy?.totalCount ?? 0;
      const refersToCount = this.task.refersTo?.totalCount ?? 0;
      this.referencesCount = referencedByCount + refersToCount;
    }
  }

  onSaveReferences(taskReferences: CreateTaskReference[]): void {
    this.actionService.create(taskReferences).pipe(take(1)).subscribe();
  }

  onCancelCreateReference(): void {
    this.viewService.hideAddComponent();
  }
}
