import { Injectable } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { TASK_PARAM_SELECTOR } from '@orion/case-paths';
import { CommentFileRefs, EntityCommentFileUploadService } from '@orion/comment-components';
import { FilenameWithExtension } from '@orion/common';
import { NotificationService } from '@orion/shared/services/global';
import { CurrentUserService } from '@orion/user-services';
import { Observable, of, throwError } from 'rxjs';
import { concatMap } from 'rxjs/operators';
import {
  UploadTaskCommentFileMutation,
  UploadTaskCommentFileMutationService,
  UploadTaskCommentFileMutationVariables,
} from './graphql';

@Injectable()
export class UploadTaskCommentFileService extends EntityCommentFileUploadService<
  UploadTaskCommentFileMutation,
  UploadTaskCommentFileMutationVariables
> {
  constructor(
    protected notificationService: NotificationService,
    protected uploadTaskMutation: UploadTaskCommentFileMutationService,
    private currUserService: CurrentUserService,
    private activatedRoute: ActivatedRoute
  ) {
    super(notificationService, uploadTaskMutation);
  }

  protected getRefs(): Observable<CommentFileRefs> {
    const userId = this.currUserService.getCurrentUser()?.id;
    return this.activatedRoute.paramMap.pipe(
      concatMap((paramMap) => {
        const taskId = paramMap.get(TASK_PARAM_SELECTOR);
        if (userId && taskId !== null) {
          return of({ authorId: userId, entityId: taskId });
        } else {
          return throwError('Could not retrieve author id or task id of comment');
        }
      })
    );
  }

  protected createVars(
    file: File,
    fileMeta: FilenameWithExtension,
    entityId: string,
    authorId: string
  ): UploadTaskCommentFileMutationVariables {
    return {
      taskId: entityId,
      authorId: authorId,
      file: file,
      filename: fileMeta.name,
      extension: fileMeta.extension,
    };
  }

  protected resolveUrlFromResponse(response: UploadTaskCommentFileMutation): string | undefined {
    return response.createFileFromCommentInTask?.url;
  }
}
