import { Injectable } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import {
  CreateExternalReferenceMutationService,
  CreateExternalReferenceService,
  ExternalReferenceViewStateService,
} from '@orion/external-reference-services/overview';
import { CreateExternalReference, CreateExternalReferenceForm } from '@orion/external-reference-types';
import { namedOperations } from '@orion/named-operations';
import { NotificationService } from '@orion/shared/services/global';
import {
  ApolloOperationResultResolver,
  ApolloResult,
  createApolloContextErrorTitle,
} from '@csirtmu-orion/microframework/graphql';
import { Observable } from 'rxjs';
import { catchError, concatMap, map, take } from 'rxjs/operators';
import { TASK_PARAM_SELECTOR } from '@orion/case-paths';

@Injectable()
export class CreateTaskExternalReferenceService extends CreateExternalReferenceService {
  constructor(
    protected notificationService: NotificationService,
    protected activatedRoute: ActivatedRoute,
    protected viewStateService: ExternalReferenceViewStateService,
    private createExternalReferenceMutation: CreateExternalReferenceMutationService
  ) {
    super(notificationService, activatedRoute, viewStateService);
  }

  protected createEntity(form: CreateExternalReferenceForm): Observable<ApolloResult> {
    return this.getTaskId().pipe(
      map((taskId) => new CreateExternalReference(form.getData(), { relatedTaskId: taskId })),
      concatMap((reference) =>
        this.createExternalReferenceMutation.mutate(
          { reference: reference },
          {
            refetchQueries: [namedOperations.Query.getExternalReferences],
            awaitRefetchQueries: true,
            context: createApolloContextErrorTitle('Creating external references'),
          }
        )
      ),
      map((res) => ApolloOperationResultResolver.resolve(res)),
      catchError((err) => ApolloOperationResultResolver.handleError(err))
    );
  }

  private getTaskId(): Observable<string> {
    return this.activatedRoute.paramMap.pipe(
      take(1),
      map((paramMap) => {
        const id = paramMap.get(TASK_PARAM_SELECTOR);
        if (id === null) {
          throw new Error('Task id param is null');
        } else {
          return id;
        }
      })
    );
  }
}
