import { Injectable } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import {
  ExternalReferenceActionsService,
  UpdateExternalReferenceMutationService,
  UpdateExternalReferenceMutationVariables,
} from '@orion/external-reference-services/overview';
import { RelationOperation } from '@orion/graphql-types';
import { NotificationService } from '@orion/shared/services/global';
import { Observable } from 'rxjs';
import { map, take } from 'rxjs/operators';
import { TASK_PARAM_SELECTOR } from '@orion/case-paths';

@Injectable()
export class TaskExternalReferenceActionsService extends ExternalReferenceActionsService {
  constructor(
    protected notificationService: NotificationService,
    protected updateMutation: UpdateExternalReferenceMutationService,
    private activatedRoute: ActivatedRoute
  ) {
    super(notificationService, updateMutation);
  }

  protected createVars(ticketId: string, op: RelationOperation): Observable<UpdateExternalReferenceMutationVariables> {
    return this.getTaskId().pipe(
      map((taskId) => {
        return {
          id: ticketId,
          patch: {
            relatedTasks: { ids: [taskId], op: op },
          },
        };
      })
    );
  }

  private getTaskId(): Observable<string> {
    return this.activatedRoute.paramMap.pipe(
      take(1),
      map((paramMap) => {
        const id = paramMap.get(TASK_PARAM_SELECTOR);
        if (id === null) {
          throw new Error('Task id param is null');
        } else {
          return id;
        }
      })
    );
  }
}
