import { ChangeDetectionStrategy, Component } from '@angular/core';
import { ExternalReferenceClientFilter } from '@orion/case-types';
import {
  EXTERNAL_REFERENCE_PROVIDERS,
  ExternalReferenceFilterChipsService,
  ExternalReferenceFilterService,
  ExternalReferenceOverviewFragment,
} from '@orion/external-reference-components/overview';
import {
  ExternalReferenceActionsService,
  ExternalReferenceOverviewService,
} from '@orion/external-reference-services/overview';
import { CaseManagementExternalReferenceOrdEnum } from '@orion/graphql-types';
import { EntityModifyBaseService } from '@orion/shared-services';
import {
  INIT_PAGINATION_EVENT_BASE_TOKEN,
  PaginationBaseInit,
  PaginationService,
  QueryParamPaginationService,
} from '@csirtmu-orion/microframework/pagination-services';
import { EntityPaginableFilterableSmartOverviewDirective } from '@csirtmu-orion/microframework/entity-smart-directives';
import { CreateTaskExternalReferenceService } from './create-task-external-reference.service';
import { TaskExternalReferenceActionsService } from './task-external-reference-actions.service';
import { TaskExternalReferenceFilterService } from './task-external-reference-filter.service';

@Component({
  selector: 'orion-task-external-references',
  templateUrl: './task-external-references.component.html',
  styleUrls: ['./task-external-references.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [
    ExternalReferenceFilterChipsService,
    ExternalReferenceOverviewService,
    ...EXTERNAL_REFERENCE_PROVIDERS,
    { provide: ExternalReferenceActionsService, useClass: TaskExternalReferenceActionsService },
    { provide: ExternalReferenceFilterService, useClass: TaskExternalReferenceFilterService },
    { provide: PaginationService, useClass: QueryParamPaginationService },
    {
      provide: INIT_PAGINATION_EVENT_BASE_TOKEN,
      useValue: new PaginationBaseInit(10, CaseManagementExternalReferenceOrdEnum.CREATED, 'desc'),
    },
    { provide: EntityModifyBaseService, useClass: CreateTaskExternalReferenceService },
  ],
})
export class TaskExternalReferencesComponent extends EntityPaginableFilterableSmartOverviewDirective<
  ExternalReferenceOverviewFragment,
  ExternalReferenceClientFilter
> {
  constructor(
    protected externalTicketsService: ExternalReferenceOverviewService,
    protected filterService: ExternalReferenceFilterService,
    protected chipsService: ExternalReferenceFilterChipsService,
    protected paginationService: PaginationService
  ) {
    super(externalTicketsService, filterService, paginationService, chipsService);
  }
}
