import { Injectable } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { AssetSelectionFragment } from '@orion/asset-components/selection';
import { AssetInput } from '@orion/graphql-types';
import { namedOperations } from '@orion/named-operations';
import {
  AddTaskToEntityService,
  CreateAssociationViewStateService,
} from '@orion/shared-components/related-entity-overview';
import { EntityAddAssociationService } from '@orion/shared-services';
import {
  ApolloOperationResultResolver,
  ApolloResult,
  ApolloResultType,
  createApolloContextErrorTitle,
} from '@csirtmu-orion/microframework/graphql';
import { Observable, of } from 'rxjs';
import { catchError, map, tap } from 'rxjs/operators';
import { AddAssetsToTaskMutationService, AddAssetsToTaskMutationVariables } from './graphql';

@Injectable()
export class AddTaskAssetsService extends AddTaskToEntityService {
  constructor(
    protected viewService: CreateAssociationViewStateService,
    protected activatedRoute: ActivatedRoute,
    private selectionService: EntityAddAssociationService<AssetSelectionFragment>,
    private updateMutation: AddAssetsToTaskMutationService
  ) {
    super(viewService, activatedRoute);
    this.operationName = 'Linking assets';
  }

  protected linkToEntity(relatedTaskId: string): Observable<ApolloResult> {
    const selection = this.selectionService.save().add;
    if (selection.length === 0) {
      return of(new ApolloResult(ApolloResultType.ERROR));
    } else {
      const assetInputs: AssetInput[] = selection.map((asset) => {
        return { id: asset.id, assetType: asset.assetType };
      });
      const vars: AddAssetsToTaskMutationVariables = {
        task: { id: relatedTaskId },
        assets: assetInputs,
      };
      return this.updateMutation
        .mutate(vars, {
          refetchQueries: [namedOperations.Query.getRelatedAssets],
          awaitRefetchQueries: true,
          context: createApolloContextErrorTitle('Adding asset to task'),
        })
        .pipe(
          map((res) => ApolloOperationResultResolver.resolve(res)),
          tap((res) => this.handleLinkResult(res)),
          catchError((err) => ApolloOperationResultResolver.handleError(err))
        );
    }
  }
}
