import { Injectable } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { ObservableInput } from '@orion/graphql-types';
import { namedOperations } from '@orion/named-operations';
import { ObservableSelectionFragment } from '@orion/observable-components/observable-selection';
import { strToObservableTypeEnum } from '@orion/observable-types';
import {
  AddTaskToEntityService,
  CreateAssociationViewStateService,
} from '@orion/shared-components/related-entity-overview';
import { EntityAddAssociationService } from '@orion/shared-services';
import {
  ApolloOperationResultResolver,
  ApolloResult,
  ApolloResultType,
  createApolloContextErrorTitle,
} from '@csirtmu-orion/microframework/graphql';
import { Observable, of } from 'rxjs';
import { catchError, map, tap } from 'rxjs/operators';
import { AddObservablesToTaskMutationService, AddObservablesToTaskMutationVariables } from './graphql';

@Injectable()
export class AddTaskObservablesService extends AddTaskToEntityService {
  constructor(
    protected viewService: CreateAssociationViewStateService,
    protected activatedRoute: ActivatedRoute,
    private selectionService: EntityAddAssociationService<ObservableSelectionFragment>,
    private updateMutation: AddObservablesToTaskMutationService
  ) {
    super(viewService, activatedRoute);
    this.operationName = 'Linking observables';
  }

  protected linkToEntity(relatedTaskId: string): Observable<ApolloResult> {
    const selection = this.selectionService.save().add;
    if (selection.length === 0) {
      return of(new ApolloResult(ApolloResultType.ERROR));
    } else {
      const observableInputs: ObservableInput[] = selection.map((observable) => {
        const type = strToObservableTypeEnum(observable.observableType);
        return { id: observable?.id, observableType: type };
      });
      const vars: AddObservablesToTaskMutationVariables = {
        task: { id: relatedTaskId },
        observables: observableInputs,
      };
      return this.updateMutation
        .mutate(vars, {
          refetchQueries: [namedOperations.Query.getRelatedObservables],
          awaitRefetchQueries: true,
          context: createApolloContextErrorTitle('Adding observable to task'),
        })
        .pipe(
          map((res) => ApolloOperationResultResolver.resolve(res)),
          tap((res) => this.handleLinkResult(res)),
          catchError((err) => ApolloOperationResultResolver.handleError(err))
        );
    }
  }
}
