import { Injectable } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { TtpInput } from '@orion/graphql-types';
import { namedOperations } from '@orion/named-operations';
import {
  AddTaskToEntityService,
  CreateAssociationViewStateService,
} from '@orion/shared-components/related-entity-overview';
import { EntityAddAssociationService } from '@orion/shared-services';
import { TtpSelectionFragment } from '@orion/ttps-components/shared';
import { strToTTPTypeEnum } from '@orion/ttps-types';
import {
  ApolloOperationResultResolver,
  ApolloResult,
  ApolloResultType,
  createApolloContextErrorTitle,
} from '@csirtmu-orion/microframework/graphql';
import { Observable, of } from 'rxjs';
import { catchError, map, tap } from 'rxjs/operators';
import { AddTtPsToTaskMutationService, AddTtPsToTaskMutationVariables } from './graphql';

@Injectable()
export class AddTaskTTPsService extends AddTaskToEntityService {
  constructor(
    protected viewService: CreateAssociationViewStateService,
    protected activatedRoute: ActivatedRoute,
    private selectionService: EntityAddAssociationService<TtpSelectionFragment>,
    private updateMutation: AddTtPsToTaskMutationService
  ) {
    super(viewService, activatedRoute);
    this.operationName = 'Linking TTPs';
  }

  protected linkToEntity(relatedTaskId: string): Observable<ApolloResult> {
    const selection = this.selectionService.save().add;
    if (selection.length === 0) {
      return of(new ApolloResult(ApolloResultType.ERROR));
    } else {
      const ttpInputs: TtpInput[] = selection.map((ttp) => {
        return { id: ttp.id, ttpType: strToTTPTypeEnum(ttp.ttpType) };
      });
      const vars: AddTtPsToTaskMutationVariables = {
        task: { id: relatedTaskId },
        ttps: ttpInputs,
      };
      return this.updateMutation
        .mutate(vars, {
          refetchQueries: [namedOperations.Query.getRelatedTTPs],
          awaitRefetchQueries: true,
          context: createApolloContextErrorTitle('Adding TTP to task'),
        })
        .pipe(
          map((res) => ApolloOperationResultResolver.resolve(res)),
          tap((res) => this.handleLinkResult(res)),
          catchError((err) => ApolloOperationResultResolver.handleError(err))
        );
    }
  }
}
