import {
  ChangeDetectionStrategy,
  Component,
  EventEmitter,
  Input,
  OnChanges,
  OnInit,
  Output,
  SimpleChanges,
} from '@angular/core';
import { EditableEntityPatchEvent, EntityEditModeService } from '@orion/shared-components/editable-entity';
import { EntityUpdateEvent } from '@csirtmu-orion/microframework/graphql';
import { SentinelControlItem } from '@sentinel/components/controls';
import { Observable } from 'rxjs';
import { TaskDetailMainContentFragment } from './task-detail-main-content.fragment.generated';
import { TaskControls } from '../task-controls.service';
import { TaskUpdate } from '@orion/graphql-types';

@Component({
  selector: 'orion-task-detail-main-content',
  templateUrl: './task-detail-main-content.component.html',
  styleUrls: ['./task-detail-main-content.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class TaskDetailMainContentComponent implements OnInit, OnChanges {
  @Input() task?: TaskDetailMainContentFragment;
  @Output() patch: EventEmitter<EntityUpdateEvent<TaskUpdate>> = new EventEmitter<EntityUpdateEvent<TaskUpdate>>();
  controls$?: Observable<SentinelControlItem[]>;
  editMode$?: Observable<boolean>;

  constructor(private editService: EntityEditModeService, private controlService: TaskControls) {}

  ngOnInit(): void {
    this.controls$ = this.controlService.controls$;
    this.editMode$ = this.editService.editMode$;
  }

  ngOnChanges(changes: SimpleChanges): void {
    if ('task' in changes && this.task) {
      this.controlService.onTaskChanged(this.task);
    }
  }

  onPatch(event: EditableEntityPatchEvent): void {
    if (this.task) {
      const patchEvent: EntityUpdateEvent<TaskUpdate> = {
        id: this.task.id,
        patch: {
          name: event.name,
          description: event.description,
        },
      };
      this.patch.emit(patchEvent);
    }
  }
}
