import { ChangeDetectionStrategy, Component, OnDestroy, OnInit } from '@angular/core';
import { TaskUpdate } from '@orion/graphql-types';
import {
  EditableEntityPageCanDeactivateService,
  ENTITY_EDIT_FORM_MANDATORY_DESCRIPTION_TOKEN,
  EntityEditEventService,
  EntityEditModeService,
  PatchEntityEditService,
} from '@orion/shared-components/editable-entity';
import { EntityEditService } from '@orion/shared-components/entity-edit';
import { TaskInputOutputEditCanDeactivateService } from '@orion/task-services';
import { TaskPatchService } from './task-patch.service';
import { TaskService } from './task.service';
import { TaskDetailFragment } from './graphql';
import { EditableEntityDetailPageBaseDirective } from '@orion/shared-components/entity-base';
import { TaskControls } from './task-controls.service';
import { TaskActionsService } from './task-actions.service';
import { combineLatest } from 'rxjs';
import { distinctUntilChanged, map, takeUntil } from 'rxjs/operators';
import { LoadingService } from '@orion/shared/services/global';

@Component({
  selector: 'orion-task-detail-page',
  templateUrl: './task-detail-page.component.html',
  styleUrls: ['./task-detail-page.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [
    TaskService,
    TaskPatchService,
    TaskControls,
    TaskActionsService,
    EntityEditModeService,
    EntityEditEventService,
    EditableEntityPageCanDeactivateService,
    TaskInputOutputEditCanDeactivateService,
    { provide: EntityEditService, useClass: PatchEntityEditService },
    { provide: ENTITY_EDIT_FORM_MANDATORY_DESCRIPTION_TOKEN, useValue: true },
  ],
})
export class TaskDetailPageComponent
  extends EditableEntityDetailPageBaseDirective<TaskDetailFragment, TaskUpdate>
  implements OnInit, OnDestroy
{
  constructor(
    protected taskService: TaskService,
    protected patchService: TaskPatchService,
    protected editTaskCanDeactivateService: EditableEntityPageCanDeactivateService,
    private inputOutputEditCanDeactivateService: TaskInputOutputEditCanDeactivateService,
    private loadingService: LoadingService
  ) {
    super(taskService, patchService, editTaskCanDeactivateService);
  }

  ngOnInit() {
    super.ngOnInit();
    // main loading for displaying skeleton loading instead of task detail page content
    this.isLoading$ = combineLatest([this.taskService.isLoading$, this.taskService.isPolling$]).pipe(
      map(([isLoading, isPolling]) => isLoading && !isPolling),
      distinctUntilChanged()
    );

    // subtle loading bar when task is polled if task is automated
    combineLatest([this.taskService.isLoading$, this.taskService.isPolling$])
      .pipe(
        map(([isLoading, isPolling]) => isLoading && isPolling),
        distinctUntilChanged(),
        takeUntil(this.destroy$)
      )
      .subscribe((isRefreshingPoll) => this.loadingService.setLoading(isRefreshingPoll));
  }

  ngOnDestroy(): void {
    super.ngOnDestroy();
    this.loadingService.setLoading(false);
  }

  canDeactivate(): boolean {
    const canDeactivateEdit = super.canDeactivate();
    return canDeactivateEdit && this.inputOutputEditCanDeactivateService.canDeactivate();
  }
}
