import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import { TASK_PARAM_SELECTOR } from '@orion/case-paths';
import {
  GetTaskDetailQuery,
  GetTaskDetailQueryService,
  GetTaskDetailQueryVariables,
  TaskDetailFragment,
} from './graphql';
import { TaskStateEnum } from '@orion/graphql-types';
import { BehaviorSubject, Observable } from 'rxjs';

@Injectable()
export class TaskService extends ApolloRoutedEntityService<
  GetTaskDetailQuery,
  GetTaskDetailQueryVariables,
  TaskDetailFragment
> {
  private isPollingSubject$: BehaviorSubject<boolean> = new BehaviorSubject<boolean>(false);

  isPolling$: Observable<boolean> = this.isPollingSubject$.asObservable();

  constructor(public getQuery: GetTaskDetailQueryService, protected activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching task');
  }

  protected createVariables(id: string): GetTaskDetailQueryVariables {
    return { id: id };
  }

  protected toFragment(queryRes: GetTaskDetailQuery): Optional<TaskDetailFragment> {
    const fragment = queryRes.getTask;
    if (fragment) {
      if (TaskService.shouldStartPolling(fragment)) {
        this.startPolling();
      }
      if (TaskService.shouldStopPolling(fragment)) {
        this.stopPolling();
      }
    }
    return fragment;
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(TASK_PARAM_SELECTOR);
  }

  private stopPolling(): void {
    this.queryRef?.stopPolling();
    this.isPollingSubject$.next(false);
  }

  private startPolling(): void {
    this.queryRef?.startPolling(5000);
    this.isPollingSubject$.next(true);
  }

  static shouldStartPolling(task: TaskDetailFragment): boolean {
    return (task.isAutomated ?? false) && TaskService.isActiveState(task.state);
  }

  static shouldStopPolling(task?: TaskDetailFragment): boolean {
    return task === undefined || TaskService.isInactiveState(task.state);
  }

  static isActiveState(state?: TaskStateEnum): boolean {
    return state === TaskStateEnum.RUNNING || state === TaskStateEnum.PENDING || state === TaskStateEnum.OPEN;
  }

  static isInactiveState(state?: TaskStateEnum): boolean {
    return (
      state === undefined ||
      state === TaskStateEnum.RESOLVED ||
      state === TaskStateEnum.REJECTED ||
      state === TaskStateEnum.SKIPPED
    );
  }
}
