import { ChangeDetectionStrategy, Component, Input } from '@angular/core';
import { TimeService } from '@orion/shared/services/global';
import { IPaginatedElements } from '@sentinel/common/pagination';
import { OptionallyPaginatedEntityTableDirective } from '@csirtmu-orion/microframework/entity-smart-directives';
import { Observable } from 'rxjs';
import { TaskTableFragment } from './task-table.fragment.generated';
import { TasksTable } from './tasks-table';

@Component({
  selector: 'orion-task-table',
  templateUrl: './task-table.component.html',
  styleUrls: ['./task-table.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class TaskTableComponent extends OptionallyPaginatedEntityTableDirective<TaskTableFragment, TasksTable> {
  @Input() sortable = false;
  @Input() fullSubtitlePath = false;
  today$: Observable<Date>;

  constructor(private timeService: TimeService) {
    super();
    this.today$ = this.timeService.today$;
  }

  protected createTable(entities: IPaginatedElements<TaskTableFragment> | TaskTableFragment[]): TasksTable {
    return new TasksTable(entities, this.sortable, this.selectable);
  }
}
