import { Injectable } from '@angular/core';
import { AssigneeFilterChip } from '@orion/shared-components/filters';
import { TaskClientFilter, TaskStateFilterChip } from '@orion/task-types';
import { FilterChip, StringValueChip } from '@csirtmu-orion/microframework/filter';
import { FilterChipsService } from '@csirtmu-orion/microframework/filter-services';
import { DateValueChip } from '@csirtmu-orion/microframework/filters';
import { TaskFilterService } from './task-filter.service';

@Injectable()
export class TaskFilterChipsService extends FilterChipsService<TaskClientFilter> {
  private readonly DUE_DATE_CHIP_NAME = 'Due date';

  constructor(protected filterService: TaskFilterService) {
    super(filterService);
  }

  removeChip(removedChip: FilterChip): void {
    if (removedChip instanceof StringValueChip) {
      this.filterService.updateAndSubmit({ name: undefined });
    }
    if (removedChip instanceof DateValueChip && removedChip.direction === 'from') {
      this.filterService.updateAndSubmit({ from: undefined });
    }
    if (removedChip instanceof DateValueChip && removedChip.direction === 'to') {
      this.filterService.updateAndSubmit({ to: undefined });
    }
    if (
      removedChip instanceof DateValueChip &&
      removedChip.direction === 'to' &&
      removedChip.name === this.DUE_DATE_CHIP_NAME
    ) {
      this.filterService.updateAndSubmit({ dueDateUntil: undefined });
    }
    if (removedChip instanceof AssigneeFilterChip) {
      this.filterService.removeAssignee(removedChip.assignee);
    }
    if (removedChip instanceof TaskStateFilterChip) {
      this.filterService.removeState(removedChip.state);
    }
  }

  protected createChips(filter: TaskClientFilter | undefined): FilterChip[] {
    if (filter === undefined || filter === this.filterService.EMPTY_FILTER) {
      return [];
    } else {
      const chips = [];
      if (filter?.name) {
        chips.push(new StringValueChip(filter?.name));
      }
      if (filter?.from) {
        chips.push(new DateValueChip(filter.from, 'from'));
      }
      if (filter?.to) {
        chips.push(new DateValueChip(filter.to, 'to'));
      }
      if (filter?.dueDateUntil) {
        chips.push(new DateValueChip(filter.dueDateUntil, 'to', this.DUE_DATE_CHIP_NAME));
      }
      if (filter.assignees && filter.assignees.length > 0) {
        chips.push(...filter.assignees.map((assignee) => new AssigneeFilterChip(assignee)));
      }
      if (filter.states && filter.states.length > 0) {
        chips.push(...filter.states.map((state) => new TaskStateFilterChip(state)));
      }
      return chips;
    }
  }
}
