import {
  ChangeDetectionStrategy,
  Component,
  EventEmitter,
  Input,
  OnChanges,
  Output,
  SimpleChanges,
} from '@angular/core';
import { AssigneeListElementFragment } from '@orion/case-services';
import { TaskStateEnum } from '@orion/graphql-types';
import { TaskClientFilter } from '@orion/task-types';
import { trackById } from '@sentinel/common/utils';
import { OrionFilterDirective } from '@csirtmu-orion/microframework/filters';
import { TaskFilterService } from './task-filter.service';

@Component({
  selector: 'orion-tasks-filters',
  templateUrl: './tasks-filters.component.html',
  styleUrls: ['./tasks-filters.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class TasksFiltersComponent extends OrionFilterDirective implements OnChanges {
  @Input() activeFilter?: TaskClientFilter;
  @Input() possibleAssignees?: AssigneeListElementFragment[];
  @Output() searchAssignees: EventEmitter<string> = new EventEmitter<string>();
  preselectedAssignees: AssigneeListElementFragment[] = [];
  selectedState?: TaskStateEnum;
  trackByFn = trackById;
  possibleStates: TaskStateEnum[] = Object.values(TaskStateEnum);

  constructor(protected filterService: TaskFilterService) {
    super(filterService);
  }

  ngOnChanges(changes: SimpleChanges): void {
    if ('activeFilter' in changes && this.activeFilter) {
      if (this.activeFilter.assignees) {
        this.preselectedAssignees = [...this.activeFilter.assignees];
      }
      if (this.activeFilter.states) {
        this.selectedState = this.activeFilter?.states.length > 0 ? this.activeFilter.states[0] : undefined;
      }
    }
  }
  onNameChange(value?: string): void {
    this.filterService.update({ name: value });
  }

  onStateChange(state?: TaskStateEnum): void {
    this.filterService.update({ states: state ? [state] : [] });
  }

  onDateChange(date: Date): void {
    this.filterService.update({ dueDateUntil: date });
  }

  onAssigneesChange(assignees: AssigneeListElementFragment[]): void {
    this.filterService.update({ assignees: [...assignees] });
  }

  onSearchAssignees(value: string): void {
    this.searchAssignees.emit(value);
  }
}
