import { QueryParamFilterService } from '@csirtmu-orion/microframework/filter-services';
import { TaskClientFilter } from '@orion/task-types';
import { TaskStateEnum } from '@orion/graphql-types';
import { ActivatedRoute, Data, ParamMap, Params, Router } from '@angular/router';
import { CurrentUserService } from '@orion/user-services';
import { Observable, throwError } from 'rxjs';
import { map } from 'rxjs/operators';

export abstract class AssignedTasksFilterService extends QueryParamFilterService<TaskClientFilter> {
  readonly RELEVANT_STATES = [TaskStateEnum.OPEN, TaskStateEnum.PENDING, TaskStateEnum.RUNNING];

  protected constructor(
    protected router: Router,
    protected activatedRoute: ActivatedRoute,
    protected currUserService: CurrentUserService
  ) {
    super(router, activatedRoute);
  }

  protected abstract getStageIds(paramMap: ParamMap): Observable<string[]>;

  protected toQueryParams(filter: TaskClientFilter): Params {
    return {};
  }

  protected createEmptyFilter(): TaskClientFilter {
    return { assignees: [], inStageIds: [], states: this.RELEVANT_STATES };
  }

  protected createFilterFromRoute(
    queryParamMap: ParamMap,
    paramMap: ParamMap,
    data: Data
  ): Observable<TaskClientFilter> {
    const user = this.currUserService.getCurrentUser();
    if (user) {
      return this.getStageIds(paramMap).pipe(
        map((stageIds) => {
          return { inStageIds: stageIds, assignees: [user], states: this.RELEVANT_STATES };
        })
      );
    } else {
      return throwError('Failed to load current user');
    }
  }
}
