import { ChangeDetectionStrategy, Component } from '@angular/core';
import { TaskOrdEnum } from '@orion/graphql-types';
import { TaskOverviewElementFragment } from '@orion/task-components/overview';
import { TaskOverviewService } from '@orion/task-services';
import { TaskClientFilter } from '@orion/task-types';
import {
  INIT_PAGINATION_EVENT_BASE_TOKEN,
  PaginationBaseInit,
  PaginationService,
} from '@csirtmu-orion/microframework/pagination-services';
import { EntityPaginableFilterableSmartOverviewDirective } from '@csirtmu-orion/microframework/entity-smart-directives';
import { Observable } from 'rxjs';
import { map, startWith } from 'rxjs/operators';
import { AssignedTasksFilterService } from './assigned-tasks-filter.service';
import { TASK_ICON } from '@orion/common';

@Component({
  selector: 'orion-assigned-tasks-panel',
  templateUrl: './assigned-tasks-panel.component.html',
  styleUrls: ['./assigned-tasks-panel.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [
    TaskOverviewService,
    { provide: PaginationService },
    {
      provide: INIT_PAGINATION_EVENT_BASE_TOKEN,
      useValue: new PaginationBaseInit(10, TaskOrdEnum.STATE, 'asc'),
    },
  ],
})
export class AssignedTasksPanelComponent extends EntityPaginableFilterableSmartOverviewDirective<
  TaskOverviewElementFragment,
  TaskClientFilter
> {
  tasksCount$?: Observable<number>;
  isExpanded$?: Observable<boolean>;
  taskIcon = TASK_ICON;

  constructor(
    protected taskService: TaskOverviewService,
    protected filterService: AssignedTasksFilterService,
    protected paginationService: PaginationService
  ) {
    super(taskService, filterService, paginationService);
  }

  ngOnInit(): void {
    super.ngOnInit();
    this.tasksCount$ = this.entities$?.pipe(
      map((taskDataList) => taskDataList.pagination.totalElements),
      startWith(0)
    );
    this.isExpanded$ = this.tasksCount$?.pipe(map((count) => count > 0));
  }
}
