import { ChangeDetectionStrategy, Component, Input, OnChanges, SimpleChanges } from '@angular/core';
import { TaskFlagsFragment } from './task-flags.fragment.generated';

export interface Flag {
  name: string;
  icon: string;
}

@Component({
  selector: 'orion-task-flags',
  templateUrl: './task-flags.component.html',
  styleUrls: ['./task-flags.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class TaskFlagsComponent implements OnChanges {
  @Input() maxLength: number = 2;
  @Input() taskFlags?: TaskFlagsFragment;
  uiFlags: Flag[] = [];

  ngOnChanges(changes: SimpleChanges): void {
    if ('taskFlags' in changes && this.taskFlags) {
      this.uiFlags = [];
      if (this.taskFlags.isDecision) {
        this.uiFlags.push({ name: 'Decision', icon: 'balance' });
      }
      if (this.taskFlags.isAutomated) {
        this.uiFlags.push({ name: 'Automated', icon: 'miscellaneous_services' });
      }
      if (this.taskFlags.aggregatesResults) {
        this.uiFlags.push({ name: 'Aggregator', icon: 'merge' });
      }
      if (this.taskFlags.autotrigger) {
        this.uiFlags.push({ name: 'Autotrigger', icon: 'restart_alt' });
      }
    }
  }

  onExpandFlags(): void {
    this.maxLength = 100;
  }
}
