import { Injectable } from '@angular/core';
import { TaskFilter1AndFilterEntry, TaskOrdEnum } from '@orion/graphql-types';
import { TaskClientFilter, TaskFilterConverter } from '@orion/task-types';
import { ApolloPaginatedFilterableService } from '@csirtmu-orion/microframework/apollo-services';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import { TaskListElementFragment } from '../task-selection';
import { GetTaskListQuery, GetTaskListQueryService, GetTaskListQueryVariables } from './task-list.operation.generated';

@Injectable()
export class TaskListService extends ApolloPaginatedFilterableService<
  GetTaskListQuery,
  GetTaskListQueryVariables,
  TaskListElementFragment,
  TaskOrdEnum,
  TaskClientFilter,
  TaskFilter1AndFilterEntry
> {
  constructor(public getQuery: GetTaskListQueryService) {
    super(getQuery, 'Fetching tasks');
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: TaskClientFilter
  ): GetTaskListQueryVariables {
    return {
      ...this.createPaginationVariables(paginationEvent),
      ...this.createOrderVariables(paginationEvent.sort, paginationEvent.sortDir),
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected createFilterConverter(): FilterConverter<TaskClientFilter, TaskFilter1AndFilterEntry[]> {
    return new TaskFilterConverter();
  }

  protected strToOrderable(sort: string): Optional<TaskOrdEnum> {
    return enumFromValue(TaskOrdEnum, sort);
  }

  protected getQueryResponse(query: GetTaskListQuery): CursorPaginatedResponse<TaskListElementFragment> {
    return query.getTaskList;
  }
}
