import * as SchemaTypes from '../../../graphql/generated/base-types/base-types';

import * as Apollo from 'apollo-angular';
import { gql } from 'apollo-angular';
import { TaskOverviewElementFragmentDoc } from '../../components/overview/task-overview-element.fragment.generated';
import { TaskTableFragmentDoc } from '../../components/overview/task-table/task-table.fragment.generated';
import { TaskNameRowFragmentDoc } from '../../components/overview/task-table/task-name-row/task-name-row.fragment.generated';
import { TaskNameFragmentDoc } from '../../components/shared/task-name/graphql/task-name.fragment.generated';
import { UserNameAndIconFragmentDoc } from '../../../user/components/shared/graphql/user-icon.fragment.generated';
import { LabelChipFragmentDoc } from '../../../label/components/shared/label/label-chip.fragment.generated';
import { TaskStateFragmentDoc } from '../../components/shared/task-state/task-state.fragment.generated';
import { TaskFlagsFragmentDoc } from '../../components/shared/task-flags/task-flags.fragment.generated';
import { Injectable } from '@angular/core';

export type GetTaskOverviewQueryVariables = SchemaTypes.Exact<{
  filter?: SchemaTypes.InputMaybe<Array<SchemaTypes.TaskFilter1AndFilterEntry>>;
  order?: SchemaTypes.InputMaybe<Array<SchemaTypes.TaskOrdEnumOrderingEntry>>;
  cursor?: SchemaTypes.InputMaybe<SchemaTypes.Scalars['String']>;
  limit?: SchemaTypes.InputMaybe<SchemaTypes.Scalars['Int']>;
}>;

export type GetTaskOverviewQuery = {
  __typename?: 'Query';
  getTaskList: {
    __typename?: 'TaskPaginated';
    previous?: string | undefined;
    next?: string | undefined;
    totalCount: number;
    data: Array<{
      __typename?: 'Task';
      dueDate?: any | undefined;
      lastUpdated?: any | undefined;
      state?: SchemaTypes.TaskStateEnum | undefined;
      isDecision?: boolean | undefined;
      decision?: boolean | undefined;
      autotrigger?: boolean | undefined;
      isAutomated?: boolean | undefined;
      aggregatesResults?: boolean | undefined;
      id: string;
      name: string;
      created?: any | undefined;
      stage: {
        __typename?: 'Stage';
        id: string;
        workflow: { __typename?: 'Workflow'; id: string; case: { __typename?: 'Case'; id: string } };
      };
      assignees?:
        | {
            __typename?: 'CaseDBUserNestedList';
            totalCount: number;
            data: Array<{ __typename?: 'CaseDBUser'; id: string; name: string; iconSrc?: string | undefined }>;
          }
        | undefined;
      labels?:
        | {
            __typename?: 'LabelNestedList';
            totalCount: number;
            data: Array<{
              __typename?: 'Label';
              id: string;
              name: string;
              backgroundColor?: string | undefined;
              textColor?: string | undefined;
            }>;
          }
        | undefined;
      createdBy?: { __typename?: 'CaseDBUser'; id: string; name: string; iconSrc?: string | undefined } | undefined;
    }>;
  };
};

export const GetTaskOverviewDocument = gql`
  query getTaskOverview(
    $filter: [TaskFilter1ANDFilterEntry!]
    $order: [TaskOrdEnumOrderingEntry!]
    $cursor: String
    $limit: Int
  ) {
    getTaskList(filter: $filter, ordering: $order, cursor: $cursor, limit: $limit) {
      data {
        ...taskOverviewElement
      }
      previous
      next
      totalCount
    }
  }
  ${TaskOverviewElementFragmentDoc}
  ${TaskTableFragmentDoc}
  ${TaskNameRowFragmentDoc}
  ${TaskNameFragmentDoc}
  ${UserNameAndIconFragmentDoc}
  ${LabelChipFragmentDoc}
  ${TaskStateFragmentDoc}
  ${TaskFlagsFragmentDoc}
`;

@Injectable({
  providedIn: 'root',
})
export class GetTaskOverviewQueryService extends Apollo.Query<GetTaskOverviewQuery, GetTaskOverviewQueryVariables> {
  document = GetTaskOverviewDocument;
  client = 'graphApi';
  constructor(apollo: Apollo.Apollo) {
    super(apollo);
  }
}
