import { Injectable } from '@angular/core';
import { CanLoad, Route, Router, UrlSegment, UrlTree } from '@angular/router';
import { TaskNameFragment } from '@orion/task-components/shared';
import { from, Observable, of } from 'rxjs';
import { concatMap, map } from 'rxjs/operators';
import { TaskNavigator } from '../routers';
import { GetTaskNameQueryService } from '../graphql';

@Injectable()
export class TaskRedirectService implements CanLoad {
  constructor(private query: GetTaskNameQueryService, private router: Router, private taskNavigator: TaskNavigator) {}

  canLoad(
    route: Route,
    segments: UrlSegment[]
  ): Observable<boolean | UrlTree> | Promise<boolean | UrlTree> | boolean | UrlTree {
    const id = segments[segments.length - 1]?.path;
    if (id !== null && id !== undefined) {
      return this.getTask(id).pipe(
        concatMap((task) => {
          if (task) {
            return from(this.router.navigate([this.taskNavigator.toDetail(task)]));
          } else {
            return of(false);
          }
        })
      );
    } else {
      return false;
    }
  }

  private getTask(id: string): Observable<TaskNameFragment | undefined> {
    return this.query
      .fetch({ id: id }, { fetchPolicy: 'cache-first' })
      .pipe(map((queryResult) => queryResult.data.getTask));
  }
}
