import { Injectable } from '@angular/core';
import { TaskFilter1AndFilterEntry, TaskOrdEnum } from '@orion/graphql-types';
import { TaskTableFragment } from '@orion/task-components/overview';
import { TaskClientFilter, TaskFilterConverter } from '@orion/task-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import { GetTaskOverviewQuery, GetTaskOverviewQueryService, GetTaskOverviewQueryVariables } from './graphql';
import { ApolloPaginatedFilterablePollingService } from '@orion/shared-services';

@Injectable()
export class TaskOverviewService extends ApolloPaginatedFilterablePollingService<
  GetTaskOverviewQuery,
  GetTaskOverviewQueryVariables,
  TaskTableFragment,
  TaskOrdEnum,
  TaskClientFilter,
  TaskFilter1AndFilterEntry
> {
  constructor(public getQuery: GetTaskOverviewQueryService) {
    super(getQuery, 'Fetching tasks');
  }

  protected createFilterConverter(): FilterConverter<TaskClientFilter, TaskFilter1AndFilterEntry[]> {
    return new TaskFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: TaskClientFilter
  ): GetTaskOverviewQueryVariables {
    return {
      ...this.createPaginationVariables(paginationEvent),
      ...this.createOrderVariables(paginationEvent.sort, paginationEvent.sortDir),
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected getQueryResponse(query: GetTaskOverviewQuery): CursorPaginatedResponse<TaskTableFragment> {
    return query.getTaskList;
  }

  protected strToOrderable(sort: string): Optional<TaskOrdEnum> {
    return enumFromValue(TaskOrdEnum, sort);
  }
}
