import { KnownInputOutputTypes, PredecessorInput, TaskCreate } from '@orion/graphql-types';
import { CreateParentlessTaskData, CreateTaskBaseData, CreateTaskWithParentData } from './create-task-data';

export interface TaskRefs {
  stageId: string;
  authorId?: string;
}

abstract class BaseCreateTask {
  aggregatesResults: boolean;
  isDecision: boolean;
  name: string;
  description: string;
  stage: string;
  input?: string;
  inputType?: KnownInputOutputTypes;
  inputDescription?: string;
  inputFormat?: string;
  outputType?: KnownInputOutputTypes;
  outputFormat?: string;
  outputDescription?: string;
  createdBy?: string;

  protected constructor(data: CreateTaskBaseData, refs: TaskRefs) {
    this.aggregatesResults = data.aggregatesResults;
    this.isDecision = data.isDecision;
    this.name = data.name;
    this.description = data.description;
    this.stage = refs.stageId;
    this.createdBy = refs.authorId;
    this.inputType = data.inputType;
    this.inputFormat = data.inputFormat;
    if (typeof data.input === 'string') {
      this.input = data.input;
    }
    this.inputDescription = data.inputDescription;
    this.outputDescription = data.outputDescription;
    this.outputType = data.outputType;
    this.outputFormat = data.outputFormat;
  }
}

export class CreateParentlessTask extends BaseCreateTask {
  constructor(data: CreateParentlessTaskData, refs: TaskRefs) {
    super(data, refs);
  }
}

export class CreateTask extends BaseCreateTask implements TaskCreate {
  predecessors: PredecessorInput[];

  constructor(data: CreateTaskWithParentData, refs: TaskRefs) {
    super(data, refs);
    this.predecessors = data.predecessors.map((predecessorData) => {
      return {
        predecessor: predecessorData.id,
        predecessorCondition: predecessorData.condition,
      };
    });
  }
}
