import { convertDateTimeFilter } from '@orion/common';
import { TaskFilter1, TaskFilter1AndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { TaskClientFilter } from './task-client-filter';

export class TaskFilterConverter implements FilterConverter<TaskClientFilter, TaskFilter1AndFilterEntry[]> {
  convert(clientFilter?: TaskClientFilter): TaskFilter1AndFilterEntry[] {
    const andFilter: TaskFilter1 = {};
    if (clientFilter && clientFilter.id) {
      andFilter.id = { exact: clientFilter.id };
    }
    if (clientFilter && clientFilter.name && clientFilter.name.length > 0) {
      andFilter.name = { icontains: clientFilter.name };
    }
    if (clientFilter?.inStageIds) {
      andFilter.stage = { id: { in_: clientFilter.inStageIds } };
    }
    if (clientFilter?.from || clientFilter?.to) {
      andFilter.created = convertDateTimeFilter(clientFilter);
    }
    if (clientFilter?.dueDateUntil) {
      andFilter.dueDate = { lte: clientFilter.dueDateUntil.toISOString() };
    }
    if (clientFilter?.externalReferenceId) {
      andFilter.externalReferences = { id: { exact: clientFilter.externalReferenceId } };
    }
    if (clientFilter?.assignees) {
      andFilter.assignees = { id: { in_: clientFilter.assignees.map((assignee) => assignee.id) } };
    }
    if (clientFilter?.states) {
      andFilter.state = { in_: clientFilter.states };
    }
    if (clientFilter && clientFilter.exceptIds && clientFilter.exceptIds.length > 0) {
      return [
        {
          AND: [{ negate: true, OR: { id: { in_: clientFilter.exceptIds } } }],
        },
        {
          AND: [{ OR: andFilter }],
        },
      ];
    }
    if (clientFilter?.idOrName) {
      const isNumber = !Number.isNaN(Number.parseInt(clientFilter.idOrName));
      if (isNumber) {
        return [
          {
            AND: [
              { OR: andFilter },
              { OR: { id: { exact: clientFilter.idOrName } } },
              { OR: { name: { icontains: clientFilter.idOrName } } },
            ],
          },
        ];
      } else {
        return [
          {
            AND: [{ OR: andFilter }, { OR: { name: { icontains: clientFilter.idOrName } } }],
          },
        ];
      }
    } else {
      return [{ AND: [{ OR: andFilter }] }];
    }
  }
}
