import { ChangeDetectionStrategy, Component, Input, OnChanges, OnInit, SimpleChanges } from '@angular/core';
import {
  OrionNestedTreeControl,
  OrionNestedTreeDataSource,
  OrionTreeDataService,
} from '@csirtmu-orion/microframework/nested-tree';
import { SidebarState, SidebarStateService } from '@sentinel/layout/sidebar';
import { Observable } from 'rxjs';
import { take } from 'rxjs/operators';
import { SelectedTtpFragment, TtpNodeFragment } from './graphql';
import { TTPTreeExpanderService } from './ttp-tree-expander.service';
import { TTPTreeNodeManagerService } from './ttp-tree-node-manager.service';
import { TTPTreeService } from './ttp-tree.service';

@Component({
  selector: 'orion-ttp-detail-sidebar',
  templateUrl: './ttp-detail-sidebar.component.html',
  styleUrls: ['./ttp-detail-sidebar.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [
    TTPTreeNodeManagerService,
    TTPTreeExpanderService,
    { provide: OrionTreeDataService, useClass: TTPTreeService },
  ],
})
export class TTPDetailSidebarComponent implements OnInit, OnChanges {
  @Input() selectedTTP?: SelectedTtpFragment;
  state$?: Observable<SidebarState>;
  treeDataSource?: OrionNestedTreeDataSource<TtpNodeFragment, string>;
  treeControl?: OrionNestedTreeControl<TtpNodeFragment, string>;
  private alreadyExpanded = false;

  constructor(
    private ttpNodeManager: TTPTreeNodeManagerService,
    private ttpTreeExpander: TTPTreeExpanderService,
    private sidebarStateService: SidebarStateService
  ) {}

  ngOnInit(): void {
    this.treeControl = new OrionNestedTreeControl<TtpNodeFragment, string>({ trackBy: (node) => node.data.id });
    this.treeDataSource = new OrionNestedTreeDataSource<TtpNodeFragment, string>(this.treeControl, this.ttpNodeManager);
    this.state$ = this.sidebarStateService.state$;
    this.expandTreeToSelectedTTP();
  }

  ngOnChanges(changes: SimpleChanges): void {
    if ('selectedTTP' in changes) {
      this.expandTreeToSelectedTTP();
    }
  }

  onSidebarClick(): void {
    this.sidebarStateService.toggleState();
  }

  isSelected(node: TtpNodeFragment): boolean {
    return node.id === this.selectedTTP?.id && node.ttpType === this.selectedTTP?.ttpType;
  }

  private expandTreeToSelectedTTP(): void {
    if (this.selectedTTP && this.treeControl && !this.alreadyExpanded) {
      this.ttpTreeExpander.expand(this.selectedTTP, this.treeControl)?.pipe(take(1)).subscribe();
      this.alreadyExpanded = true;
    }
  }
}
