import { Injectable } from '@angular/core';
import { OrionTreeDataService, OrionTreeNodeManagerService, TreeNode } from '@csirtmu-orion/microframework/nested-tree';
import { TtpNodeFragment } from './graphql';
import { isTacticNode, isTechniqueNode, TTPTreeNode } from './model';

@Injectable()
export class TTPTreeNodeManagerService extends OrionTreeNodeManagerService<TtpNodeFragment> {
  constructor(protected techniqueService: OrionTreeDataService<TtpNodeFragment>) {
    super(techniqueService);
  }

  protected createNodeInstance(data: TtpNodeFragment): TreeNode<TtpNodeFragment> {
    return new TTPTreeNode(data);
  }

  protected getTotalChildrenCount(parentNode: TreeNode<TtpNodeFragment>): number {
    if (isTacticNode(parentNode.data)) {
      return parentNode.data.techniques?.totalCount ?? 0;
    }
    if (isTechniqueNode(parentNode.data)) {
      return parentNode.data.subTechniques?.totalCount ?? 0;
    } else {
      return 0;
    }
  }
}
