import { Injectable } from '@angular/core';
import { ApolloQueryResult } from '@apollo/client/core';
import { RootNodes, OrionTreeDataService } from '@csirtmu-orion/microframework/nested-tree';
import { Observable } from 'rxjs';
import { map } from 'rxjs/operators';
import {
  GetSubTechniqueNodesQuery,
  GetSubTechniqueNodesQueryService,
  GetTacticNodesQuery,
  GetTacticNodesQueryService,
  GetTechniqueNodesQuery,
  GetTechniqueNodesQueryService,
  TacticNodeFragment,
  TechniqueNodeFragment,
  TtpNodeFragment,
} from './graphql';
import { isTacticNode, TTPTreeNode } from './model';

@Injectable()
export class TTPTreeService extends OrionTreeDataService<TtpNodeFragment> {
  constructor(
    private getTactics: GetTacticNodesQueryService,
    private getTechniques: GetTechniqueNodesQueryService,
    private getSubTechniques: GetSubTechniqueNodesQueryService
  ) {
    super();
  }

  getRoots(): Observable<RootNodes<TtpNodeFragment>> {
    return this.getTactics.fetch().pipe(map((result) => this.mapToRoots(result)));
  }

  getChildren(parentNode: TTPTreeNode): Observable<TtpNodeFragment[]> {
    if (isTacticNode(parentNode.data)) {
      return this.getTechniques
        .fetch({ tacticId: parentNode.data.id })
        .pipe(map((result) => this.mapToTechniques(result)));
    } else {
      return this.getSubTechniques
        .fetch({ techniqueId: parentNode.data.id })
        .pipe(map((result) => this.mapToSubTechniques(result)));
    }
  }

  private mapToRoots(result: ApolloQueryResult<GetTacticNodesQuery>): RootNodes<TacticNodeFragment> {
    let tactics: TacticNodeFragment[] = [];
    if (result.data.getTacticList) {
      tactics = result.data.getTacticList.data;
    }
    return { nodes: tactics, totalCount: tactics.length };
  }

  private mapToTechniques(result: ApolloQueryResult<GetTechniqueNodesQuery>): TechniqueNodeFragment[] {
    return result?.data?.getTactic?.techniques?.data ?? [];
  }

  private mapToSubTechniques(result: ApolloQueryResult<GetSubTechniqueNodesQuery>): TechniqueNodeFragment[] {
    return result?.data?.getTechnique?.subTechniques?.data ?? [];
  }
}
