import { TtpSharedClientFilter } from '@orion/ttps-types';
import { FilterChip, StringValueChip } from '@csirtmu-orion/microframework/filter';
import { FilterChipsService, FilterService } from '@csirtmu-orion/microframework/filter-services';
import { DateValueChip } from '@csirtmu-orion/microframework/filters';

export abstract class ProcedureSharedFilterChipsService<T extends TtpSharedClientFilter> extends FilterChipsService<T> {
  protected constructor(protected filterService: FilterService<any>) {
    super(filterService);
  }

  protected createChips(filter?: TtpSharedClientFilter): FilterChip[] {
    const chips = [];
    if (filter?.name) {
      chips.push(new StringValueChip(filter.name));
    }
    if (filter?.from) {
      chips.push(new DateValueChip(filter.from, 'from'));
    }
    if (filter?.to) {
      chips.push(new DateValueChip(filter.to, 'to'));
    }
    return chips;
  }

  removeChip(removedChip: FilterChip): void {
    if (removedChip instanceof StringValueChip) {
      this.filterService.updateAndSubmit({ name: undefined });
    }
    if (removedChip instanceof DateValueChip && removedChip.direction === 'from') {
      this.filterService.updateAndSubmit({ from: undefined });
    }
    if (removedChip instanceof DateValueChip && removedChip.direction === 'to') {
      this.filterService.updateAndSubmit({ to: undefined });
    }
  }
}
