import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap, Params, Router } from '@angular/router';
import { KnownTtPsTypesEnum } from '@orion/graphql-types';
import { RelatedTTPClientFilter } from '@orion/ttps-types';
import { QueryParamFilterService } from '@csirtmu-orion/microframework/filter-services';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import { Observable, of } from 'rxjs';

@Injectable()
export class RelatedTTPsFilterService extends QueryParamFilterService<RelatedTTPClientFilter> {
  constructor(protected router: Router, protected activatedRoute: ActivatedRoute) {
    super(router, activatedRoute);
  }

  protected createEmptyFilter(): RelatedTTPClientFilter {
    return { ttpType: undefined };
  }

  protected toQueryParams(filter: RelatedTTPClientFilter): Params {
    const params = super.toQueryParams(filter);
    delete params.taskIds;
    delete params.caseId;
    return params;
  }

  protected createFilterFromRoute(queryParamMap: ParamMap, paramMap: ParamMap): Observable<RelatedTTPClientFilter> {
    const ttpTypeParam = queryParamMap.get('ttpType');
    if (ttpTypeParam === null) {
      return of(this.EMPTY_FILTER);
    }
    const ttpType = this.resolveTTPType(this.deslugify(ttpTypeParam));
    return of({ ttpType: ttpType });
  }

  private resolveTTPType(value?: string): Optional<KnownTtPsTypesEnum> {
    return value ? enumFromValue(KnownTtPsTypesEnum, value) : undefined;
  }
}
