import { Injectable } from '@angular/core';
import { TechniqueClientFilter } from '@orion/ttps-types';
import { FilterChip, StringValueChip } from '@csirtmu-orion/microframework/filter';
import { FilterChipsService } from '@csirtmu-orion/microframework/filter-services';
import { DateValueChip } from '@csirtmu-orion/microframework/filters';
import { TechniqueFilterService } from './technique-filter.service';

@Injectable()
export class TechniqueFilterChipsService extends FilterChipsService<TechniqueClientFilter> {
  constructor(protected filterService: TechniqueFilterService) {
    super(filterService);
  }

  protected createChips(filter?: TechniqueClientFilter): FilterChip[] {
    const chips = [];
    if (filter?.name) {
      chips.push(new StringValueChip(filter.name));
    }
    if (filter?.from) {
      chips.push(new DateValueChip(filter.from, 'from'));
    }
    if (filter?.to) {
      chips.push(new DateValueChip(filter.to, 'to'));
    }
    return chips;
  }

  removeChip(removedChip: FilterChip): void {
    if (removedChip instanceof StringValueChip) {
      this.filterService.updateAndSubmit({ name: undefined });
    }
    if (removedChip instanceof DateValueChip && removedChip.direction === 'from') {
      this.filterService.updateAndSubmit({ from: undefined });
    }
    if (removedChip instanceof DateValueChip && removedChip.direction === 'to') {
      this.filterService.updateAndSubmit({ to: undefined });
    }
  }
}
