import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap, Params, Router } from '@angular/router';
import { TechniqueClientFilter } from '@orion/ttps-types';
import { QueryParamFilterService } from '@csirtmu-orion/microframework/filter-services';
import { Observable, of } from 'rxjs';

@Injectable()
export class TechniqueFilterService extends QueryParamFilterService<TechniqueClientFilter> {
  constructor(protected router: Router, protected activatedRoute: ActivatedRoute) {
    super(router, activatedRoute);
  }

  protected toQueryParams(filter: TechniqueClientFilter): Params {
    const params = super.toQueryParams(filter);
    if (filter.from) {
      params.from = filter.from.valueOf();
    }
    if (filter.to) {
      params.to = filter.to.valueOf();
    }
    return params;
  }

  protected createEmptyFilter(): TechniqueClientFilter {
    return { name: undefined, from: undefined, to: undefined };
  }

  protected createFilterFromRoute(queryParamMap: ParamMap, paramMap: ParamMap): Observable<TechniqueClientFilter> {
    const name = this.deslugify(queryParamMap.get('name'));
    const from = this.deslugifyTimestamp(queryParamMap.get('from'));
    const to = this.deslugifyTimestamp(queryParamMap.get('to'));
    return of({ name, from, to });
  }
}
