import { Injectable } from '@angular/core';
import { GroupProcedureFilter1AndFilterEntry, GroupProcedureOrdEnum } from '@orion/graphql-types';
import { GroupProcedureClientFilter, GroupProcedureFilterConverter } from '@orion/ttps-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import {
  GroupProcedureOverviewElementFragment,
  GroupProcedureOverviewQuery,
  GroupProcedureOverviewQueryService,
  GroupProcedureOverviewQueryVariables,
} from './graphql';
import { ApolloPaginatedFilterablePollingService } from '@orion/shared-services';

@Injectable()
export class GroupProcedureOverviewService extends ApolloPaginatedFilterablePollingService<
  GroupProcedureOverviewQuery,
  GroupProcedureOverviewQueryVariables,
  GroupProcedureOverviewElementFragment,
  GroupProcedureOrdEnum,
  GroupProcedureClientFilter,
  GroupProcedureFilter1AndFilterEntry
> {
  constructor(public getQuery: GroupProcedureOverviewQueryService) {
    super(getQuery, 'Fetching group procedures');
  }

  protected createFilterConverter(): FilterConverter<
    GroupProcedureClientFilter,
    GroupProcedureFilter1AndFilterEntry[]
  > {
    return new GroupProcedureFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: GroupProcedureClientFilter
  ): GroupProcedureOverviewQueryVariables {
    return {
      ...this.createPaginationVariables(paginationEvent),
      ...this.createOrderVariables(paginationEvent.sort, paginationEvent.sortDir),
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected getQueryResponse(
    query: GroupProcedureOverviewQuery
  ): CursorPaginatedResponse<GroupProcedureOverviewElementFragment> {
    return query?.getGroupProcedureList;
  }

  protected strToOrderable(sort: string): Optional<GroupProcedureOrdEnum> {
    return enumFromValue(GroupProcedureOrdEnum, sort);
  }
}
