import { Injectable } from '@angular/core';
import { MitigationFilter1AndFilterEntry, MitigationOrdEnum } from '@orion/graphql-types';
import { MitigationClientFilter, MitigationFilterConverter } from '@orion/ttps-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import {
  MitigationOverviewElementFragment,
  MitigationOverviewQuery,
  MitigationOverviewQueryService,
  MitigationOverviewQueryVariables,
} from './graphql';
import { ApolloPaginatedFilterablePollingService } from '@orion/shared-services';

@Injectable()
export class MitigationOverviewService extends ApolloPaginatedFilterablePollingService<
  MitigationOverviewQuery,
  MitigationOverviewQueryVariables,
  MitigationOverviewElementFragment,
  MitigationOrdEnum,
  MitigationClientFilter,
  MitigationFilter1AndFilterEntry
> {
  constructor(public getQuery: MitigationOverviewQueryService) {
    super(getQuery, 'Fetching mitigations');
  }

  protected createFilterConverter(): FilterConverter<MitigationClientFilter, MitigationFilter1AndFilterEntry[]> {
    return new MitigationFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: MitigationClientFilter
  ): MitigationOverviewQueryVariables {
    return {
      ...this.createPaginationVariables(paginationEvent),
      ...this.createOrderVariables(paginationEvent.sort, paginationEvent.sortDir),
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected getQueryResponse(
    query: MitigationOverviewQuery
  ): CursorPaginatedResponse<MitigationOverviewElementFragment> {
    return query?.getMitigationList;
  }

  protected strToOrderable(sort: string): Optional<MitigationOrdEnum> {
    return enumFromValue(MitigationOrdEnum, sort);
  }
}
