import { Injectable } from '@angular/core';
import { TtpPlatformFilter1AndFilterEntry, TtpPlatformOrdEnum } from '@orion/graphql-types';
import { PlatformClientFilter, PlatformFilterConverter } from '@orion/ttps-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import {
  PlatformOverviewElementFragment,
  PlatformOverviewQuery,
  PlatformOverviewQueryService,
  PlatformOverviewQueryVariables,
} from './graphql';
import { ApolloPaginatedFilterablePollingService } from '@orion/shared-services';

@Injectable()
export class PlatformOverviewService extends ApolloPaginatedFilterablePollingService<
  PlatformOverviewQuery,
  PlatformOverviewQueryVariables,
  PlatformOverviewElementFragment,
  TtpPlatformOrdEnum,
  PlatformClientFilter,
  TtpPlatformFilter1AndFilterEntry
> {
  constructor(public getQuery: PlatformOverviewQueryService) {
    super(getQuery, 'Fetching platforms');
  }

  protected createFilterConverter(): FilterConverter<PlatformClientFilter, TtpPlatformFilter1AndFilterEntry[]> {
    return new PlatformFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: PlatformClientFilter
  ): PlatformOverviewQueryVariables {
    return {
      ...this.createPaginationVariables(paginationEvent),
      ...this.createOrderVariables(paginationEvent.sort, paginationEvent.sortDir),
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected getQueryResponse(query: PlatformOverviewQuery): CursorPaginatedResponse<PlatformOverviewElementFragment> {
    return query.getTtpPlatformList;
  }

  protected strToOrderable(sort: string): Optional<TtpPlatformOrdEnum> {
    return enumFromValue(TtpPlatformOrdEnum, sort);
  }
}
