import { ChangeDetectionStrategy, Component, Input, OnChanges, SimpleChanges } from '@angular/core';
import { TechniqueOrdEnum } from '@orion/graphql-types';
import { TechniqueFilterService } from '@orion/ttps-components/filters-technique';
import { TechniqueClientFilter } from '@orion/ttps-types';
import { INIT_SORT_TOKEN, QueryParamSortService, SortService } from '@csirtmu-orion/microframework/sort-services';
import { EntityFilterableOrderableSmartOverviewDirective } from '@csirtmu-orion/microframework/entity-smart-directives';
import { TechniqueListItemFragment } from './graphql';
import { TechniquesOfTacticFilterService } from './techniques-of-tactic-filter.service';
import { TechniquesOfTacticService } from './techniques-of-tactic.service';

@Component({
  selector: 'orion-techniques-of-tactic',
  templateUrl: './techniques-of-tactic.component.html',
  styleUrls: ['./techniques-of-tactic.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [
    TechniquesOfTacticService,
    { provide: TechniqueFilterService, useClass: TechniquesOfTacticFilterService },
    { provide: SortService, useClass: QueryParamSortService },
    { provide: INIT_SORT_TOKEN, useValue: { sort: TechniqueOrdEnum.TECHNIQUE_NAME, sortDir: 'asc' } },
  ],
})
export class TechniquesOfTacticComponent
  extends EntityFilterableOrderableSmartOverviewDirective<TechniqueListItemFragment, TechniqueClientFilter>
  implements OnChanges
{
  @Input() expectedCount?: number;
  placeholdersCount = 5;

  constructor(
    protected techniquesService: TechniquesOfTacticService,
    protected filterService: TechniqueFilterService,
    protected sortService: SortService
  ) {
    super(techniquesService, filterService, sortService);
  }

  ngOnChanges(changes: SimpleChanges): void {
    if ('expectedCount' in changes && this.expectedCount) {
      this.placeholdersCount = Math.min(this.expectedCount, 5);
    }
  }
}
