import { Injectable } from '@angular/core';
import { TechniqueFilter1AndFilterEntry, TechniqueOrdEnum } from '@orion/graphql-types';
import { TechniqueClientFilter, TechniqueFilterConverter } from '@orion/ttps-types';
import { ApolloFilterableOrderableService } from '@csirtmu-orion/microframework/apollo-services';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { SortEvent } from '@csirtmu-orion/microframework/sort-services';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import {
  GetTechniqueListQuery,
  GetTechniqueListQueryService,
  GetTechniqueListQueryVariables,
  TechniqueListItemFragment,
} from './graphql';

@Injectable()
export class TechniquesOfTacticService extends ApolloFilterableOrderableService<
  GetTechniqueListQuery,
  GetTechniqueListQueryVariables,
  TechniqueListItemFragment,
  TechniqueOrdEnum,
  TechniqueClientFilter,
  TechniqueFilter1AndFilterEntry
> {
  constructor(public getQuery: GetTechniqueListQueryService) {
    super(getQuery, 'Fetching techniques');
  }

  protected toFragments(query: GetTechniqueListQuery): TechniqueListItemFragment[] {
    return query.getTechniqueList?.data ?? [];
  }

  protected createFilterConverter(): FilterConverter<TechniqueClientFilter, TechniqueFilter1AndFilterEntry[]> {
    return new TechniqueFilterConverter();
  }

  protected createVariables(clientFilter: TechniqueClientFilter, order: SortEvent): GetTechniqueListQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
      ...this.createOrderVariables(order),
    };
  }

  protected strToOrderable(sort: string): Optional<TechniqueOrdEnum> {
    return enumFromValue(TechniqueOrdEnum, sort);
  }
}
