import { ChangeDetectionStrategy, Component } from '@angular/core';
import { TechniqueOrdEnum } from '@orion/graphql-types';
import { TechniqueFilterChipsService, TechniqueFilterService } from '@orion/ttps-components/filters-technique';
import { TechniqueClientFilter } from '@orion/ttps-types';
import {
  INIT_PAGINATION_EVENT_BASE_TOKEN,
  PaginationBaseInit,
  PaginationService,
  QueryParamPaginationService,
} from '@csirtmu-orion/microframework/pagination-services';
import { EntityPaginableFilterableSmartOverviewDirective } from '@csirtmu-orion/microframework/entity-smart-directives';
import { TechniqueOverviewElementFragment } from './graphql';
import { TechniqueOverviewService } from './technique-overview.service';

@Component({
  selector: 'orion-technique-overview-page',
  templateUrl: './technique-overview-page.component.html',
  styleUrls: ['./technique-overview-page.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [
    TechniqueOverviewService,
    TechniqueFilterService,
    TechniqueFilterChipsService,
    { provide: PaginationService, useClass: QueryParamPaginationService },
    {
      provide: INIT_PAGINATION_EVENT_BASE_TOKEN,
      useValue: new PaginationBaseInit(10, TechniqueOrdEnum.TECHNIQUE_NAME, 'asc'),
    },
  ],
})
export class TechniqueOverviewPageComponent extends EntityPaginableFilterableSmartOverviewDirective<
  TechniqueOverviewElementFragment,
  TechniqueClientFilter
> {
  constructor(
    protected paginationService: PaginationService,
    protected techniqueService: TechniqueOverviewService,
    protected filterService: TechniqueFilterService,
    protected filterChipsService: TechniqueFilterChipsService
  ) {
    super(techniqueService, filterService, paginationService, filterChipsService);
  }
}
