import { Injectable } from '@angular/core';
import { TechniqueFilter1AndFilterEntry, TechniqueOrdEnum } from '@orion/graphql-types';
import { TechniqueClientFilter, TechniqueFilterConverter } from '@orion/ttps-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import {
  TechniqueOverviewElementFragment,
  TechniqueOverviewQuery,
  TechniqueOverviewQueryService,
  TechniqueOverviewQueryVariables,
} from './graphql';
import { ApolloPaginatedFilterablePollingService } from '@orion/shared-services';

@Injectable()
export class TechniqueOverviewService extends ApolloPaginatedFilterablePollingService<
  TechniqueOverviewQuery,
  TechniqueOverviewQueryVariables,
  TechniqueOverviewElementFragment,
  TechniqueOrdEnum,
  TechniqueClientFilter,
  TechniqueFilter1AndFilterEntry
> {
  constructor(public getQuery: TechniqueOverviewQueryService) {
    super(getQuery, 'Fetching techniques');
  }

  protected createFilterConverter(): FilterConverter<TechniqueClientFilter, TechniqueFilter1AndFilterEntry[]> {
    return new TechniqueFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: TechniqueClientFilter
  ): TechniqueOverviewQueryVariables {
    return {
      ...this.createPaginationVariables(paginationEvent),
      ...this.createOrderVariables(paginationEvent.sort, paginationEvent.sortDir),
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected getQueryResponse(query: TechniqueOverviewQuery): CursorPaginatedResponse<TechniqueOverviewElementFragment> {
    return query.getTechniqueList;
  }

  protected strToOrderable(sort: string): Optional<TechniqueOrdEnum> {
    return enumFromValue(TechniqueOrdEnum, sort);
  }
}
