import { ChangeDetectionStrategy, Component } from '@angular/core';
import { ToolProcedureOrdEnum } from '@orion/graphql-types';
import {
  ToolProcedureFilterChipsService,
  ToolProcedureFilterService,
} from '@orion/ttps-components/filters-tool-procedure';
import { ToolProcedureClientFilter } from '@orion/ttps-types';
import { FilterService } from '@csirtmu-orion/microframework/filter-services';
import {
  INIT_PAGINATION_EVENT_BASE_TOKEN,
  PaginationBaseInit,
  PaginationService,
  QueryParamPaginationService,
} from '@csirtmu-orion/microframework/pagination-services';
import { EntityPaginableFilterableSmartOverviewDirective } from '@csirtmu-orion/microframework/entity-smart-directives';
import { ToolProcedureOverviewElementFragment } from './graphql';
import { ToolProcedureOverviewService } from './tool-procedure-overview.service';

@Component({
  selector: 'orion-tool-procedure-overview-page',
  templateUrl: './tool-procedure-overview-page.component.html',
  styleUrls: ['./tool-procedure-overview-page.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [
    ToolProcedureOverviewService,
    ToolProcedureFilterChipsService,
    { provide: FilterService, useClass: ToolProcedureFilterService },
    {
      provide: PaginationService,
      useClass: QueryParamPaginationService,
    },
    {
      provide: INIT_PAGINATION_EVENT_BASE_TOKEN,
      useValue: new PaginationBaseInit(10, ToolProcedureOrdEnum.TOOL_PROCEDURE_NAME, 'asc'),
    },
  ],
})
export class ToolProcedureOverviewPageComponent extends EntityPaginableFilterableSmartOverviewDirective<
  ToolProcedureOverviewElementFragment,
  ToolProcedureClientFilter
> {
  constructor(
    protected paginationService: PaginationService,
    protected toolService: ToolProcedureOverviewService,
    protected filterService: FilterService<ToolProcedureClientFilter>,
    protected filterChipsService: ToolProcedureFilterChipsService
  ) {
    super(toolService, filterService, paginationService, filterChipsService);
  }
}
