import { Injectable } from '@angular/core';
import { ToolProcedureFilter1AndFilterEntry, ToolProcedureOrdEnum } from '@orion/graphql-types';
import { ToolProcedureClientFilter, ToolProcedureFilterConverter } from '@orion/ttps-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import {
  ToolProcedureOverviewElementFragment,
  ToolProcedureOverviewQuery,
  ToolProcedureOverviewQueryService,
  ToolProcedureOverviewQueryVariables,
} from './graphql';
import { ApolloPaginatedFilterablePollingService } from '@orion/shared-services';

@Injectable()
export class ToolProcedureOverviewService extends ApolloPaginatedFilterablePollingService<
  ToolProcedureOverviewQuery,
  ToolProcedureOverviewQueryVariables,
  ToolProcedureOverviewElementFragment,
  ToolProcedureOrdEnum,
  ToolProcedureClientFilter,
  ToolProcedureFilter1AndFilterEntry
> {
  constructor(public getQuery: ToolProcedureOverviewQueryService) {
    super(getQuery, 'Fetching tool procedures');
  }

  protected createFilterConverter(): FilterConverter<ToolProcedureClientFilter, ToolProcedureFilter1AndFilterEntry[]> {
    return new ToolProcedureFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: ToolProcedureClientFilter
  ): ToolProcedureOverviewQueryVariables {
    return {
      ...this.createPaginationVariables(paginationEvent),
      ...this.createOrderVariables(paginationEvent.sort, paginationEvent.sortDir),
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected getQueryResponse(
    query: ToolProcedureOverviewQuery
  ): CursorPaginatedResponse<ToolProcedureOverviewElementFragment> {
    return query?.getToolProcedureList;
  }

  protected strToOrderable(sort: string): Optional<ToolProcedureOrdEnum> {
    return enumFromValue(ToolProcedureOrdEnum, sort);
  }
}
