import { enumToPath } from '@orion/common';
import { KnownTtPsTypesEnum } from '@orion/graphql-types';
import { MITIGATION_PATH, PLATFORM_PATH } from '@orion/ttps-paths';

export type TTPsCards = TTPCard[];
export interface TTPCard {
  title: string;
  content: string;
  imgSrc: string;
  link: string;
}

export const TTPS_CARDS_CONTENT: TTPsCards = [
  {
    title: 'Tactics',
    content:
      'Tactics represent the "why" of an ATT&CK technique or sub-technique. It is the adversary\'s tactical goal: the reason for performing an action. For example, an adversary may want to achieve credential access.',
    imgSrc: '/assets/ttps/tactic.jpg',
    link: enumToPath(KnownTtPsTypesEnum.TACTIC),
  },
  {
    title: 'Techniques',
    content:
      "Techniques represent 'how' an adversary achieves a tactical goal by performing an action. For example, an adversary may dump credentials to achieve credential access.",
    imgSrc: '/assets/ttps/technique.jpg',
    link: enumToPath(KnownTtPsTypesEnum.TECHNIQUE),
  },
  {
    title: 'Group Procedures',
    content:
      'Groups are sets of related intrusion activity that are tracked by a common name in the security community. Analysts track clusters of activities using various analytic methodologies and terms such as threat groups, activity groups, threat actors, intrusion sets, and campaigns.',
    imgSrc: '/assets/ttps/ttp-stock.png',
    link: enumToPath(KnownTtPsTypesEnum.GROUP_PROCEDURE),
  },
  {
    title: 'Malware Procedures',
    content:
      'Commercial, custom closed source, or open source software intended to be used for malicious purposes by adversaries. Examples include PlugX, CHOPSTICK, etc.',
    imgSrc: '/assets/ttps/malware.jpg',
    link: enumToPath(KnownTtPsTypesEnum.MALWARE_PROCEDURE),
  },
  {
    title: 'Tool Procedures',
    content:
      'Commercial, open-source, built-in, or publicly available software that could be used by a defender, pen tester, red teamer, or an adversary. This category includes both software that generally is not found on an enterprise system as well as software generally available as part of an operating system that is already present in an environment.',
    imgSrc: '/assets/ttps/tool.jpg',
    link: enumToPath(KnownTtPsTypesEnum.TOOL_PROCEDURE),
  },
  {
    title: 'Mitigations',
    content:
      'Mitigations represent security concepts and classes of technologies that can be used to prevent a technique or sub-technique from being successfully executed.',
    imgSrc: '/assets/ttps/mitigations.jpg',
    link: MITIGATION_PATH,
  },
  {
    title: 'Platforms',
    content:
      'Platform is an environment in which a piece of software is executed. Relates to techniques and malware or tools which could be used on a specific platform. Can be an operating system or an application',
    imgSrc: '/assets/ttps/platform.jpg',
    link: PLATFORM_PATH,
  },
];
