import { ChangeDetectionStrategy, Component } from '@angular/core';
import { IttpOrdEnum } from '@orion/graphql-types';
import {
  AddEntityControlsService,
  AddPaginableEntityDirective,
  CreateEntityAssociationService,
} from '@orion/shared-components/related-entity-overview';
import { EntityAddAssociationService } from '@orion/shared-services';
import { TtpSelectionFragment } from '@orion/ttps-components/shared';
import { TTPClientFilter } from '@orion/ttps-types';
import {
  INIT_PAGINATION_EVENT_BASE_TOKEN,
  PaginationBaseInit,
  PaginationService,
} from '@csirtmu-orion/microframework/pagination-services';
import { EntityAddTTPsFilterService } from './entity-add-ttps-filter.service';
import { TTPsListService } from './ttps-list.service';

@Component({
  selector: 'orion-add-related-ttps',
  templateUrl: './add-related-ttps.component.html',
  styleUrls: ['./add-related-ttps.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [
    PaginationService,
    AddEntityControlsService,
    TTPsListService,
    {
      provide: INIT_PAGINATION_EVENT_BASE_TOKEN,
      useValue: new PaginationBaseInit(50, IttpOrdEnum.CREATED, 'asc'),
    },
  ],
})
export class AddRelatedTTPsComponent extends AddPaginableEntityDirective<TtpSelectionFragment, TTPClientFilter> {
  constructor(
    protected selectionService: EntityAddAssociationService<TtpSelectionFragment>,
    protected controlsService: AddEntityControlsService,
    protected paginationService: PaginationService,
    protected filterService: EntityAddTTPsFilterService,
    protected TTPsService: TTPsListService,
    protected addEntityService: CreateEntityAssociationService
  ) {
    super(selectionService, controlsService, paginationService, filterService, TTPsService, addEntityService);
  }

  protected createFilter(searchValue: string): TTPClientFilter {
    return { name: searchValue };
  }
}
