import { Injectable } from '@angular/core';
import { IttpFilter1AndFilterEntry, IttpOrdEnum } from '@orion/graphql-types';
import { TtpSelectionFragment } from '@orion/ttps-components/shared';
import { TTPClientFilter, TTPFilterConverter } from '@orion/ttps-types';
import { ApolloPaginatedFilterableService } from '@csirtmu-orion/microframework/apollo-services';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import { GetTtpListQuery, GetTtpListQueryService, GetTtpListQueryVariables } from './graphql';

@Injectable()
export class TTPsListService extends ApolloPaginatedFilterableService<
  GetTtpListQuery,
  GetTtpListQueryVariables,
  TtpSelectionFragment,
  IttpOrdEnum,
  TTPClientFilter,
  IttpFilter1AndFilterEntry
> {
  constructor(public getQuery: GetTtpListQueryService) {
    super(getQuery, 'Fetching TTPs');
  }

  protected createFilterConverter(): FilterConverter<TTPClientFilter, IttpFilter1AndFilterEntry[]> {
    return new TTPFilterConverter();
  }

  protected getQueryResponse(query: GetTtpListQuery): CursorPaginatedResponse<TtpSelectionFragment> {
    return query?.getIttpList;
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: TTPClientFilter
  ): GetTtpListQueryVariables {
    return {
      ...this.createPaginationVariables(paginationEvent),
      ...this.createOrderVariables(paginationEvent.sort, paginationEvent.sortDir),
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected strToOrderable(sort: string): Optional<IttpOrdEnum> {
    return enumFromValue(IttpOrdEnum, sort);
  }
}
