import { ChangeDetectionStrategy, Component, Optional, SimpleChanges } from '@angular/core';
import {
  CreateAssociationViewStateService,
  RelatedEntityControlsService,
  RelatedEntityOverviewDirective,
} from '@orion/shared-components/related-entity-overview';
import { RelatedTTPClientFilter, strToTTPTypeEnum } from '@orion/ttps-types';
import { EntityAddTTPsFilterService } from './add-related-ttps';
import { RelatedTtpTableElementFragment } from './ttps-table';

@Component({
  selector: 'orion-related-ttps-overview',
  templateUrl: './related-ttps-overview.component.html',
  styleUrls: ['./related-ttps-overview.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [EntityAddTTPsFilterService],
})
export class RelatedTTPsOverviewComponent extends RelatedEntityOverviewDirective<
  RelatedTtpTableElementFragment,
  RelatedTTPClientFilter
> {
  constructor(
    @Optional() protected controlsService: RelatedEntityControlsService,
    @Optional() protected viewStateService: CreateAssociationViewStateService,
    private filterService: EntityAddTTPsFilterService
  ) {
    super(controlsService, viewStateService);
  }

  ngOnChanges(changes: SimpleChanges): void {
    super.ngOnChanges(changes);
    if ('entities' in changes && this.entities && this.entities.length > 0) {
      const relatedTTPs = this.entities.map((entity) => {
        return { id: entity.id, type: strToTTPTypeEnum(entity.ttpType) };
      });
      this.filterService.exclude(relatedTTPs);
    }
  }
}
