import { Injectable } from '@angular/core';
import { TtpFederationBaseFilterAndFilterEntry } from '@orion/graphql-types';
import { RelatedTTPClientFilter, RelatedTTPFilterConverter } from '@orion/ttps-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import {
  GetRelatedTtPsQuery,
  GetRelatedTtPsQueryService,
  GetRelatedTtPsQueryVariables,
  RelatedTtpFragment,
} from './graphql';
import { ApolloFilterablePollingService } from '@orion/shared-services';

@Injectable()
export class RelatedTTPsService extends ApolloFilterablePollingService<
  GetRelatedTtPsQuery,
  GetRelatedTtPsQueryVariables,
  RelatedTtpFragment,
  RelatedTTPClientFilter,
  TtpFederationBaseFilterAndFilterEntry[]
> {
  public constructor(public getQuery: GetRelatedTtPsQueryService) {
    super(getQuery, 'Fetching related TTPs');
  }

  protected createFilterConverter(): FilterConverter<RelatedTTPClientFilter, TtpFederationBaseFilterAndFilterEntry[]> {
    return new RelatedTTPFilterConverter();
  }

  protected createVariables(clientFilter: RelatedTTPClientFilter): GetRelatedTtPsQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected toFragments(query: GetRelatedTtPsQuery): RelatedTtpFragment[] {
    return query?.getFederatedTtpList?.data ?? [];
  }
}
