import { TechniqueOrdEnum } from '@orion/graphql-types';
import { IPaginatedElements, isPaginatedElements } from '@sentinel/common/pagination';
import { Column, Row, SentinelTable } from '@sentinel/components/table';
import {
  SubTechniqueRowFragment,
  TechniqueAndSubTechniqueTableFragment,
  TechniqueRowFragment,
  TechniqueTableFragment,
} from './technique-and-sub-technique-table.fragment.generated';

export class TechniquesAndSubTechniquesTable extends SentinelTable<TechniqueRowFragment | SubTechniqueRowFragment> {
  constructor(
    techniques:
      | IPaginatedElements<TechniqueAndSubTechniqueTableFragment | TechniqueTableFragment>
      | TechniqueAndSubTechniqueTableFragment[]
      | TechniqueTableFragment[]
  ) {
    const isPaginated = isPaginatedElements(techniques);
    const columns = [
      new Column('name', 'Name', isPaginated, TechniqueOrdEnum.TECHNIQUE_NAME),
      new Column('description', 'Description', false),
    ];
    const rows = TechniquesAndSubTechniquesTable.createRows(techniques);
    super(rows, columns);
    if (isPaginatedElements(techniques)) {
      this.pagination = techniques.pagination;
    }
  }

  protected static createRows(
    input:
      | IPaginatedElements<TechniqueAndSubTechniqueTableFragment | TechniqueTableFragment>
      | TechniqueAndSubTechniqueTableFragment[]
      | TechniqueTableFragment[]
  ): Row<TechniqueRowFragment | SubTechniqueRowFragment>[] {
    const rows: Row<TechniqueRowFragment | SubTechniqueRowFragment>[] = [];
    let techniques: TechniqueAndSubTechniqueTableFragment[];
    if (isPaginatedElements(input)) {
      techniques = input.elements;
    } else {
      techniques = input;
    }
    techniques.forEach((technique) => {
      rows.push(new Row(technique));
      if (technique?.subTechniques && technique.subTechniques.data.length > 0) {
        const subTechniques = technique.subTechniques.data as SubTechniqueRowFragment[];
        subTechniques.forEach((subTechnique) => rows.push(new Row(subTechnique)));
      }
    });
    return rows;
  }
}
