import { Injectable } from '@angular/core';
import { CanLoad, Route, Router, UrlSegment, UrlTree } from '@angular/router';
import { TtpNameFragment } from '@orion/ttps-components/shared';
import { TTPNavigator } from '@orion/ttps-services';
import { from, Observable, of } from 'rxjs';
import { concatMap, map } from 'rxjs/operators';
import { GetIttpQueryService } from './graphql';

@Injectable()
export class TtpRedirectService implements CanLoad {
  constructor(private query: GetIttpQueryService, private router: Router, private ttpNavigator: TTPNavigator) {}

  canLoad(
    route: Route,
    segments: UrlSegment[]
  ): Observable<boolean | UrlTree> | Promise<boolean | UrlTree> | boolean | UrlTree {
    const id = segments[segments.length - 1]?.path;
    if (id !== null && id !== undefined) {
      return this.getTtp(id).pipe(
        concatMap((ttp) => {
          if (ttp) {
            return from(this.router.navigate([this.ttpNavigator.toDetail(ttp)]));
          } else {
            return of(false);
          }
        })
      );
    } else {
      return false;
    }
  }

  private getTtp(id: string): Observable<TtpNameFragment | undefined> {
    return this.query.fetch({ id: id }, { fetchPolicy: 'cache-first' }).pipe(map((result) => result.data.getIttp));
  }
}
