import { IttpFilter1AndFilterEntry, IttpFilter1OrFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { TTPClientFilter } from './ttp-client-filter';

export class TTPFilterConverter implements FilterConverter<TTPClientFilter, IttpFilter1AndFilterEntry[]> {
  convert(clientFilter?: TTPClientFilter): IttpFilter1AndFilterEntry[] {
    const convertedFilter: IttpFilter1AndFilterEntry[] = [];
    if (clientFilter?.name) {
      convertedFilter.push({
        AND: [...this.createNameFilter(clientFilter.name)],
      });
    }
    if (clientFilter?.notIn && clientFilter.notIn.length > 0) {
      // creating list of AND filters that filter out ttps. A bit complex because TTPs are identified by its id AND type.
      convertedFilter.push(
        ...clientFilter.notIn.map((ttp) => {
          return {
            AND: [{ negate: true, OR: { id: { exact: ttp.id }, ttpType: { exact: ttp.type } } }],
          };
        })
      );
    }
    if (clientFilter?.idOrName) {
      const isNumber = !Number.isNaN(Number.parseInt(clientFilter.idOrName));
      if (isNumber) {
        convertedFilter.push({
          AND: [{ OR: { id: { exact: clientFilter.idOrName } } }, ...this.createNameFilter(clientFilter.idOrName)],
        });
      } else {
        convertedFilter.push({
          AND: this.createNameFilter(clientFilter.idOrName),
        });
      }
    }
    return convertedFilter;
  }

  private createNameFilter(name: string): IttpFilter1OrFilterEntry[] {
    return [
      { OR: { groupProcedureName: { icontains: name } } },
      { OR: { malwareProcedureName: { icontains: name } } },
      { OR: { tacticName: { icontains: name } } },
      { OR: { techniqueName: { icontains: name } } },
      { OR: { techniqueName: { icontains: name } } },
      { OR: { toolProcedureName: { icontains: name } } },
    ];
  }
}
