import { ChangeDetectionStrategy, Component } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { Observable } from 'rxjs';
import { map } from 'rxjs/operators';
import { USER_ID_PARAM_SELECTOR, USER_NAME_PARAM_SELECTOR } from '@orion/user-accounting-paths';

export interface UsernameAndId {
  id: string;
  username: string;
}

@Component({
  selector: 'orion-user-accounting-detail-page',
  templateUrl: './user-accounting-detail-page.component.html',
  styleUrls: ['./user-accounting-detail-page.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class UserAccountingDetailPageComponent {
  usernameAndId$: Observable<UsernameAndId | undefined>;

  constructor(private activatedRoute: ActivatedRoute) {
    this.usernameAndId$ = this.activatedRoute.paramMap.pipe(
      map((paramMap) => {
        const userIdParam = paramMap.get(USER_ID_PARAM_SELECTOR) ?? undefined;
        const userNameParam = paramMap.get(USER_NAME_PARAM_SELECTOR) ?? undefined;
        if (userIdParam !== undefined && userNameParam !== undefined) {
          return { id: userIdParam, username: userNameParam };
        } else {
          return undefined;
        }
      })
    );
  }
}
