import { Injectable } from '@angular/core';
import { UserFlowsClientFilter } from '@orion/user-accounting-types';
import { FilterChip } from '@csirtmu-orion/microframework/filter';
import { FilterChipsService } from '@csirtmu-orion/microframework/filter-services';
import { DateValueChip } from '@csirtmu-orion/microframework/filters';
import { UserFlowsFilterService } from './user-flows-filter.service';

@Injectable()
export class UserFlowsFilterChipsService extends FilterChipsService<UserFlowsClientFilter> {
  constructor(protected filterService: UserFlowsFilterService) {
    super(filterService);
  }

  protected createChips(filter?: UserFlowsClientFilter): FilterChip[] {
    if (filter === undefined || filter === this.filterService.EMPTY_FILTER) {
      return [];
    } else {
      const chips = [];
      if (filter.from) {
        chips.push(new DateValueChip(filter.from, 'from'));
      }
      if (filter.to) {
        chips.push(new DateValueChip(filter.to, 'to'));
      }
      return chips;
    }
  }

  removeChip(removedChip: FilterChip): void {
    if (removedChip instanceof DateValueChip && removedChip.direction === 'from') {
      this.filterService.updateAndSubmit({ from: undefined });
    }
    if (removedChip instanceof DateValueChip && removedChip.direction === 'to') {
      this.filterService.updateAndSubmit({ to: undefined });
    }
  }
}
