import { Injectable } from '@angular/core';
import { ActivatedRoute, Data, ParamMap, Params, Router } from '@angular/router';
import { UserFlowsClientFilter } from '@orion/user-accounting-types';
import { QueryParamFilterService } from '@csirtmu-orion/microframework/filter-services';
import { Observable, of } from 'rxjs';
import { USER_NAME_PARAM_SELECTOR } from '@orion/user-accounting-paths';

@Injectable()
export class UserFlowsFilterService extends QueryParamFilterService<UserFlowsClientFilter> {
  constructor(protected router: Router, protected activatedRoute: ActivatedRoute) {
    super(router, activatedRoute);
  }

  protected toQueryParams(filter: UserFlowsClientFilter): Params {
    const params = super.toQueryParams(filter);
    if (filter.from) {
      params.from = filter.from.valueOf();
    }
    if (filter.to) {
      params.to = filter.to.valueOf();
    }
    delete params.username;
    return params;
  }

  protected createEmptyFilter(): UserFlowsClientFilter {
    return { username: undefined, from: undefined, to: undefined };
  }

  protected createFilterFromRoute(
    queryParamMap: ParamMap,
    paramMap: ParamMap,
    data: Data
  ): Observable<UserFlowsClientFilter> {
    const nameParam = paramMap.get(USER_NAME_PARAM_SELECTOR);
    const from = this.deslugifyTimestamp(queryParamMap.get('from'));
    const to = this.deslugifyTimestamp(queryParamMap.get('to'));
    const name = this.deslugify(nameParam);

    if (name === undefined && from === undefined && to === undefined) {
      return of(this.EMPTY_FILTER);
    } else {
      return of({ username: name, from: from, to: to });
    }
  }
}
