import { Injectable } from '@angular/core';
import { toIsoDateFormat } from '@orion/common';
import { UserFlowsClientFilter } from '@orion/user-accounting-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { GetUserFlowsQuery, GetUserFlowsQueryService, GetUserFlowsQueryVariables, UserFlowsFragment } from './graphql';
import { ApolloFilterablePollingService } from '@orion/shared-services';

class UserFlowsFilterConverter implements FilterConverter<UserFlowsClientFilter, UserFlowsClientFilter> {
  convert(source?: UserFlowsClientFilter): UserFlowsClientFilter {
    return source ?? {};
  }
}

@Injectable()
export class UserFlowsService extends ApolloFilterablePollingService<
  GetUserFlowsQuery,
  GetUserFlowsQueryVariables,
  UserFlowsFragment,
  UserFlowsClientFilter,
  UserFlowsClientFilter
> {
  constructor(public query: GetUserFlowsQueryService) {
    super(query, 'Fetching user flows');
  }

  protected createFilterConverter(): FilterConverter<UserFlowsClientFilter, UserFlowsClientFilter> {
    return new UserFlowsFilterConverter();
  }

  protected createVariables(clientFilter: UserFlowsClientFilter): GetUserFlowsQueryVariables {
    const filter: GetUserFlowsQueryVariables = { username: clientFilter.username ?? '' };
    if (clientFilter.from) {
      filter.from = toIsoDateFormat(clientFilter.from, true);
    }
    if (clientFilter.to) {
      filter.to = toIsoDateFormat(clientFilter.to, true);
    }
    return filter;
  }

  protected toFragments(query: GetUserFlowsQuery): UserFlowsFragment[] {
    return query.getUserFlows;
  }
}
