import { Injectable } from '@angular/core';
import { UserAccountingClientFilter } from '@orion/user-accounting-types';
import { FilterChip, StringValueChip } from '@csirtmu-orion/microframework/filter';
import { FilterChipsService } from '@csirtmu-orion/microframework/filter-services';
import { DateValueChip } from '@csirtmu-orion/microframework/filters';
import { UserAccountingFilterService } from './user-accounting-filter.service';

@Injectable()
export class UserAccountingFilterChipsService extends FilterChipsService<UserAccountingClientFilter> {
  private readonly IP_ADDRESS_CHIP_ID = 'ipAddress';
  private readonly USERNAME_CHIP_ID = 'username';
  constructor(filterService: UserAccountingFilterService) {
    super(filterService);
  }

  protected createChips(filter?: UserAccountingClientFilter): FilterChip[] {
    if (filter === undefined || filter === this.filterService.EMPTY_FILTER) {
      return [];
    } else {
      const chips = [];
      if (filter.ipAddress) {
        chips.push(new StringValueChip(filter.ipAddress, this.IP_ADDRESS_CHIP_ID));
      }
      if (filter.username) {
        chips.push(new StringValueChip(filter.username, this.USERNAME_CHIP_ID));
      }
      if (filter.from) {
        chips.push(new DateValueChip(filter.from, 'from'));
      }
      if (filter.to) {
        chips.push(new DateValueChip(filter.to, 'to'));
      }
      return chips;
    }
  }

  removeChip(removedChip: FilterChip): void {
    if (removedChip instanceof StringValueChip && removedChip.id === this.IP_ADDRESS_CHIP_ID) {
      this.filterService.updateAndSubmit({ ipAddress: undefined });
    }
    if (removedChip instanceof StringValueChip && removedChip.id === this.USERNAME_CHIP_ID) {
      this.filterService.updateAndSubmit({ username: undefined });
    }
    if (removedChip instanceof DateValueChip && removedChip.direction === 'from') {
      this.filterService.updateAndSubmit({ from: undefined });
    }
    if (removedChip instanceof DateValueChip && removedChip.direction === 'to') {
      this.filterService.updateAndSubmit({ to: undefined });
    }
  }
}
