import { Injectable } from '@angular/core';
import { ActivatedRoute, Data, ParamMap, Params, Router } from '@angular/router';
import { UserAccountingClientFilter } from '@orion/user-accounting-types';
import { QueryParamFilterService } from '@csirtmu-orion/microframework/filter-services';
import { Observable, of } from 'rxjs';

@Injectable()
export class UserAccountingFilterService extends QueryParamFilterService<UserAccountingClientFilter> {
  constructor(protected router: Router, protected activatedRoute: ActivatedRoute) {
    super(router, activatedRoute);
  }

  protected toQueryParams(filter: UserAccountingClientFilter): Params {
    const params = super.toQueryParams(filter);
    if (filter.from) {
      params.from = filter.from.valueOf();
    }
    if (filter.to) {
      params.to = filter.to.valueOf();
    }
    return params;
  }

  protected createEmptyFilter(): UserAccountingClientFilter {
    return { from: undefined, to: undefined, username: undefined, ipAddress: undefined };
  }

  protected createFilterFromRoute(
    queryParamMap: ParamMap,
    paramMap: ParamMap,
    data: Data
  ): Observable<UserAccountingClientFilter> {
    const ipParam = queryParamMap.get('ipAddress');
    const usernameParam = queryParamMap.get('username');
    const from = this.deslugifyTimestamp(queryParamMap.get('from'));
    const to = this.deslugifyTimestamp(queryParamMap.get('to'));
    const ip = this.deslugify(ipParam);
    const username = this.deslugify(usernameParam);
    if (from === undefined && to === undefined && username === undefined && ip === undefined) {
      return of(this.EMPTY_FILTER);
    }
    return of({
      ipAddress: ip,
      from: from,
      to: to,
      username: username,
    });
  }
}
