import { ChangeDetectionStrategy, Component } from '@angular/core';
import { UserIpAccountingModelOrdEnum } from '@orion/graphql-types';
import {
  UserAccountingFilterChipsService,
  UserAccountingFilterService,
} from '@orion/user-accounting-components/filters';
import { UserAccountingClientFilter } from '@orion/user-accounting-types';
import {
  INIT_PAGINATION_EVENT_BASE_TOKEN,
  PaginationBaseInit,
  PaginationService,
  QueryParamPaginationService,
} from '@csirtmu-orion/microframework/pagination-services';
import { EntityPaginableFilterableSmartOverviewDirective } from '@csirtmu-orion/microframework/entity-smart-directives';
import { UserAccountingOverviewFragment } from './graphql';
import { UserAccountingOverviewService } from './user-accounting-overview.service';

@Component({
  selector: 'orion-user-accounting-overview-page',
  templateUrl: './user-accounting-overview-page.component.html',
  styleUrls: ['./user-accounting-overview-page.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [
    UserAccountingOverviewService,
    UserAccountingFilterService,
    UserAccountingFilterChipsService,
    {
      provide: PaginationService,
      useClass: QueryParamPaginationService,
    },
    {
      provide: INIT_PAGINATION_EVENT_BASE_TOKEN,
      useValue: new PaginationBaseInit(50, UserIpAccountingModelOrdEnum.ACCTSTARTTIME, 'desc'),
    },
  ],
})
export class UserAccountingOverviewPageComponent extends EntityPaginableFilterableSmartOverviewDirective<
  UserAccountingOverviewFragment,
  UserAccountingClientFilter
> {
  constructor(
    protected userAccountingService: UserAccountingOverviewService,
    protected paginationService: PaginationService,
    protected filterService: UserAccountingFilterService,
    protected filterChipsService: UserAccountingFilterChipsService
  ) {
    super(userAccountingService, filterService, paginationService, filterChipsService);
  }
}
