import { Injectable } from '@angular/core';
import { UserIpAccountingModelFilter1AndFilterEntry, UserIpAccountingModelOrdEnum } from '@orion/graphql-types';
import { UserAccountingClientFilter, UserAccountingFilterConverter } from '@orion/user-accounting-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import {
  GetUserAccountingOverviewQuery,
  GetUserAccountingOverviewQueryService,
  GetUserAccountingOverviewQueryVariables,
  UserAccountingOverviewFragment,
} from './graphql';
import { ApolloPaginatedFilterablePollingService } from '@orion/shared-services';

@Injectable()
export class UserAccountingOverviewService extends ApolloPaginatedFilterablePollingService<
  GetUserAccountingOverviewQuery,
  GetUserAccountingOverviewQueryVariables,
  UserAccountingOverviewFragment,
  UserIpAccountingModelOrdEnum,
  UserAccountingClientFilter,
  UserIpAccountingModelFilter1AndFilterEntry
> {
  constructor(public getQuery: GetUserAccountingOverviewQueryService) {
    super(getQuery, 'Fetching user accounting data');
  }

  protected createFilterConverter(): FilterConverter<
    UserAccountingClientFilter,
    UserIpAccountingModelFilter1AndFilterEntry[]
  > {
    return new UserAccountingFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: UserAccountingClientFilter
  ): GetUserAccountingOverviewQueryVariables {
    return {
      ...this.createPaginationVariables(paginationEvent),
      ...this.createOrderVariables(paginationEvent.sort, paginationEvent.sortDir),
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected getQueryResponse(
    query: GetUserAccountingOverviewQuery
  ): CursorPaginatedResponse<UserAccountingOverviewFragment> {
    return query.getUserIpAccountingModelList;
  }

  protected strToOrderable(sort: string): Optional<UserIpAccountingModelOrdEnum> {
    return enumFromValue(UserIpAccountingModelOrdEnum, sort);
  }
}
