import { Injectable } from '@angular/core';
import { RelatedUserFederationBaseFilterAndFilterEntry } from '@orion/graphql-types';
import { RelatedUsersClientFilter, RelatedUsersFilterConverter } from '@orion/user-accounting-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import {
  GetRelatedUsersOverviewQuery,
  GetRelatedUsersOverviewQueryService,
  GetRelatedUsersOverviewQueryVariables,
  RelatedUsersOverviewFragment,
} from './graphql';
import { ApolloFilterablePollingService } from '@orion/shared-services';

@Injectable()
export class RelatedUsersOverviewService extends ApolloFilterablePollingService<
  GetRelatedUsersOverviewQuery,
  GetRelatedUsersOverviewQueryVariables,
  RelatedUsersOverviewFragment,
  RelatedUsersClientFilter,
  RelatedUserFederationBaseFilterAndFilterEntry[]
> {
  public constructor(public getQuery: GetRelatedUsersOverviewQueryService) {
    super(getQuery, 'Fetching related users');
  }

  protected createFilterConverter(): FilterConverter<
    RelatedUsersClientFilter,
    RelatedUserFederationBaseFilterAndFilterEntry[]
  > {
    return new RelatedUsersFilterConverter();
  }

  protected createVariables(clientFilter: RelatedUsersClientFilter): GetRelatedUsersOverviewQueryVariables {
    return {
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected toFragments(query: GetRelatedUsersOverviewQuery): RelatedUsersOverviewFragment[] {
    return query?.getFederatedRelatedUserList?.data;
  }
}
