import { ChangeDetectionStrategy, Component, Input } from '@angular/core';
import { UserAccountingWithIntrospectionTableElement } from '@orion/user-accounting-types';
import { UserAccountingTableElementFragment } from '../user-accounting-table-element.fragment.generated';
import { UserFlowsService } from './user-flows.service';
import { combineLatest, Observable, of } from 'rxjs';
import { UserAccountingWithFlowsTableDetailFragment } from './user-accounting-with-flows-table-detail.fragment.generated';
import { Optional } from '@sentinel/common/utils';
import { map, startWith, takeWhile } from 'rxjs/operators';

@Component({
  selector: 'orion-user-accounting-flow-table-detail',
  templateUrl: './user-accounting-flow-table-detail.component.html',
  styleUrls: ['./user-accounting-flow-table-detail.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [UserFlowsService],
})
export class UserAccountingFlowTableDetailComponent {
  @Input() data?: UserAccountingWithIntrospectionTableElement | UserAccountingTableElementFragment;
  accountingData$?: Observable<Optional<UserAccountingWithFlowsTableDetailFragment>>;
  isLoading$?: Observable<boolean>;
  initLoading$?: Observable<boolean>;
  hasError$?: Observable<boolean>;

  constructor(protected flowsService: UserFlowsService) {}

  ngOnInit(): void {
    if (this.data && this.data.id) {
      this.flowsService.updateVars(this.data.id);
    }
    this.accountingData$ = this.flowsService.data$;
    this.hasError$ = this.flowsService.hasError$;
    this.isLoading$ = this.flowsService.isLoading$;
    const firstDataLoading$ = this.flowsService.data$.pipe(
      takeWhile((data) => data === undefined, true),
      map((data) => data === undefined),
      startWith(true)
    );
    this.initLoading$ = combineLatest([firstDataLoading$, this.hasError$ ?? of(false)]).pipe(
      map(([loading, error]) => loading && !error)
    );
  }

  onRefetch(): void {
    this.flowsService.recoverAfterError();
  }
}
