import { ChangeDetectionStrategy, Component, Input } from '@angular/core';
import { toAuthPath } from '@orion/common';
import { USER_ACCOUNTING_PATH } from '@orion/user-accounting-paths';
import { UserAccountingWithIntrospectionTableElement } from '@orion/user-accounting-types';
import { IPaginatedElements } from '@sentinel/common/pagination';
import { trackByIndex } from '@sentinel/common/utils';
import { OptionallyPaginatedEntityTableDirective } from '@csirtmu-orion/microframework/entity-smart-directives';
import { UserAccountingTable } from './user-accounting-table';
import { UserAccountingTableElementFragment } from './user-accounting-table-element.fragment.generated';

@Component({
  selector: 'orion-user-accounting-table',
  templateUrl: './user-accounting-table.component.html',
  styleUrls: ['./user-accounting-table.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class UserAccountingTableComponent extends OptionallyPaginatedEntityTableDirective<
  UserAccountingWithIntrospectionTableElement | UserAccountingTableElementFragment,
  UserAccountingTable
> {
  @Input() withIntrospection = false;
  trackByFn = trackByIndex;
  ipAddressPath = toAuthPath(USER_ACCOUNTING_PATH);

  protected createTable(
    entities:
      | IPaginatedElements<UserAccountingWithIntrospectionTableElement>
      | IPaginatedElements<UserAccountingTableElementFragment>
      | UserAccountingWithIntrospectionTableElement[]
      | UserAccountingTableElementFragment[]
  ): UserAccountingTable {
    return new UserAccountingTable(entities, this.withIntrospection);
  }
}
