import { toIsoDateFormat } from '@orion/common';
import { UserIpAccountingModelFilter1, UserIpAccountingModelFilter1AndFilterEntry } from '@orion/graphql-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { UserAccountingClientFilter } from './user-accounting-client-filter';

export class UserAccountingFilterConverter
  implements FilterConverter<UserAccountingClientFilter, UserIpAccountingModelFilter1AndFilterEntry[]>
{
  convert(source?: UserAccountingClientFilter): UserIpAccountingModelFilter1AndFilterEntry[] {
    if (source) {
      const filter: UserIpAccountingModelFilter1 = {};
      if (source.from) {
        filter.acctstarttime = { gte: toIsoDateFormat(source.from, true) };
      }
      if (source.to) {
        filter.acctstoptime = { lte: toIsoDateFormat(source.to, true) };
      }
      if (source.ipAddress) {
        filter.framedipaddress = { icontains: source.ipAddress };
      }
      if (source.username) {
        filter.username = { icontains: source.username };
      }
      return [{ AND: [{ OR: filter }] }];
    } else {
      return [];
    }
  }
}
