import { ChangeDetectionStrategy, Component } from '@angular/core';
import { UserSettingsForm } from './user-settings-form';
import { take, takeUntil } from 'rxjs/operators';
import { Destroyable } from '@sentinel/common';
import { UserSettingsService } from '@orion/shared/services/global';

@Component({
  selector: 'orion-user-settings-menu',
  templateUrl: './user-settings-menu.component.html',
  styleUrls: ['./user-settings-menu.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class UserSettingsMenuComponent extends Destroyable() {
  form?: UserSettingsForm;

  constructor(private settingsService: UserSettingsService) {
    super();
    this.settingsService.stateSubject$.pipe(take(1)).subscribe({
      next: (state) => {
        this.form = new UserSettingsForm(state);
        this.form.formGroup.valueChanges.pipe(takeUntil(this.destroy$)).subscribe(() => {
          if (this.form) {
            this.settingsService.setState(this.form.toData());
          }
        });
      },
    });
  }
}
