import { ChangeDetectionStrategy, Component } from '@angular/core';
import { CaseOverviewElementFragment } from '@orion/case-components/overview';
import { CaseOverviewService } from '@orion/case-components/overview-page';
import { CaseClientFilter } from '@orion/case-types';
import { CaseOrdEnum } from '@orion/graphql-types';
import {
  INIT_PAGINATION_EVENT_BASE_TOKEN,
  PaginationBaseInit,
  PaginationService,
  QueryParamPaginationService,
} from '@csirtmu-orion/microframework/pagination-services';
import { EntityPaginableFilterableSmartOverviewDirective } from '@csirtmu-orion/microframework/entity-smart-directives';
import { takeUntil } from 'rxjs/operators';
import { UserCasesFilterService } from './user-cases-filter.service';

@Component({
  selector: 'orion-user-cases',
  templateUrl: './user-cases.component.html',
  styleUrls: ['./user-cases.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [
    CaseOverviewService,
    UserCasesFilterService,
    { provide: PaginationService, useClass: QueryParamPaginationService },
    {
      provide: INIT_PAGINATION_EVENT_BASE_TOKEN,
      useValue: new PaginationBaseInit(20, CaseOrdEnum.LAST_UPDATED, 'desc'),
    },
  ],
})
export class UserCasesComponent extends EntityPaginableFilterableSmartOverviewDirective<
  CaseOverviewElementFragment,
  CaseClientFilter
> {
  constructor(
    protected paginationService: PaginationService,
    protected casesService: CaseOverviewService,
    protected filterService: UserCasesFilterService
  ) {
    super(casesService, filterService, paginationService);
    filterService.filter$.pipe(takeUntil(this.destroy$)).subscribe();
  }
}
