import { Injectable } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ApolloRoutedEntityService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import {
  GetUserDetailQuery,
  GetUserDetailQueryService,
  GetUserDetailQueryVariables,
  UserDetailFragment,
} from './graphql';
import { USER_PARAM_SELECTOR } from '@orion/user-paths';

@Injectable()
export class UserDetailService extends ApolloRoutedEntityService<
  GetUserDetailQuery,
  GetUserDetailQueryVariables,
  UserDetailFragment
> {
  constructor(public getQuery: GetUserDetailQueryService, protected activatedRoute: ActivatedRoute) {
    super(getQuery, activatedRoute, 'Fetching user');
  }

  protected createVariables(id: string): GetUserDetailQueryVariables {
    return { id: id };
  }

  protected idFromParamMap(paramMap: ParamMap): string | null {
    return paramMap.get(USER_PARAM_SELECTOR);
  }

  protected toFragment(query: GetUserDetailQuery): Optional<UserDetailFragment> {
    return query.getCaseDbUser;
  }
}
