import { Injectable } from '@angular/core';
import { ActivatedRoute, Data, ParamMap, Params, Router } from '@angular/router';
import { TaskClientFilter } from '@orion/task-types';
import { USER_ID_PARAM_SELECTOR } from '@orion/user-accounting-paths';
import { QueryParamFilterService } from '@csirtmu-orion/microframework/filter-services';
import { Observable, of } from 'rxjs';

@Injectable()
export class UserTasksFilterService extends QueryParamFilterService<TaskClientFilter> {
  constructor(protected router: Router, protected activatedRoute: ActivatedRoute) {
    super(router, activatedRoute);
  }

  protected toQueryParams(filter: TaskClientFilter): Params {
    const params = super.toQueryParams(filter);
    delete params.assignees;
    return params;
  }

  protected createEmptyFilter(): TaskClientFilter {
    return { assignees: [] };
  }

  protected createFilterFromRoute(
    queryParamMap: ParamMap,
    paramMap: ParamMap,
    data: Data
  ): Observable<TaskClientFilter> {
    const id = paramMap.get(USER_ID_PARAM_SELECTOR);
    return of({
      assignees: [{ id: id ?? '', name: '', iconSrc: '', __typename: 'CaseDBUser' }],
    });
  }
}
