import { ChangeDetectionStrategy, Component } from '@angular/core';
import { TaskOrdEnum } from '@orion/graphql-types';
import { TaskOverviewElementFragment } from '@orion/task-components/overview';
import { TaskOverviewService } from '@orion/task-services';
import { TaskClientFilter } from '@orion/task-types';
import {
  INIT_PAGINATION_EVENT_BASE_TOKEN,
  PaginationBaseInit,
  PaginationService,
  QueryParamPaginationService,
} from '@csirtmu-orion/microframework/pagination-services';
import { EntityPaginableFilterableSmartOverviewDirective } from '@csirtmu-orion/microframework/entity-smart-directives';
import { takeUntil } from 'rxjs/operators';
import { UserTasksFilterService } from './user-tasks-filter.service';

@Component({
  selector: 'orion-user-tasks',
  templateUrl: './user-tasks.component.html',
  styleUrls: ['./user-tasks.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [
    TaskOverviewService,
    UserTasksFilterService,
    { provide: PaginationService, useClass: QueryParamPaginationService },
    {
      provide: INIT_PAGINATION_EVENT_BASE_TOKEN,
      useValue: new PaginationBaseInit(20, TaskOrdEnum.LAST_UPDATED, 'desc'),
    },
  ],
})
export class UserTasksComponent extends EntityPaginableFilterableSmartOverviewDirective<
  TaskOverviewElementFragment,
  TaskClientFilter
> {
  constructor(
    protected paginationService: PaginationService,
    protected tasksService: TaskOverviewService,
    protected filterService: UserTasksFilterService
  ) {
    super(tasksService, filterService, paginationService);
    filterService.filter$.pipe(takeUntil(this.destroy$)).subscribe();
  }
}
