import { Injectable } from '@angular/core';
import { ApolloQueryResult } from '@apollo/client/core';
import { ApolloQueryService } from '@csirtmu-orion/microframework/apollo-services';
import { Optional } from '@sentinel/common/utils';
import { CurrentUserFragment } from './current-user.fragment.generated';
import {
  GetCurrentUserQuery,
  GetCurrentUserQueryService,
  GetCurrentUserQueryVariables,
} from './current-user.operation.generated';

@Injectable({ providedIn: 'root' })
export class CurrentUserService extends ApolloQueryService<
  GetCurrentUserQuery,
  GetCurrentUserQueryVariables,
  CurrentUserFragment
> {
  private currentUser?: CurrentUserFragment;

  constructor(public getQuery: GetCurrentUserQueryService) {
    super(getQuery, 'Fetching current user', { fetchPolicy: 'cache-first' });
    this.initialize();
    this.updateQuery();
  }

  getCurrentUser(): Optional<CurrentUserFragment> {
    return this.currentUser;
  }

  protected createVariables(): GetCurrentUserQueryVariables {
    return {};
  }

  protected toData(result: ApolloQueryResult<GetCurrentUserQuery>): CurrentUserFragment {
    this.currentUser = result.data.getCurrentUser;
    return this.currentUser;
  }
}
