import { FormControl, FormGroup } from '@angular/forms';
import { jsonValidator } from '@orion/common';
import { BaseReactiveForm, SentinelValidators } from '@sentinel/common';
import { EditWorkflowTemplateFragment } from './graphql';

export interface WorkflowTemplateFormModel {
  name: FormControl<string>;
  description: FormControl<string>;
  template: FormControl<string>;
}

export interface CreateEditWorkflowTemplateData {
  name: string;
  description: string;
  template: string;
}

export class WorkflowTemplateForm extends BaseReactiveForm<WorkflowTemplateFormModel> {
  constructor(workflowTemplate?: EditWorkflowTemplateFragment) {
    const formGroup = new FormGroup<WorkflowTemplateFormModel>({
      name: new FormControl<string>(workflowTemplate?.name ?? '', {
        nonNullable: true,
        initialValueIsDefault: true,
      }),
      description: new FormControl<string>(workflowTemplate?.description ?? '', {
        nonNullable: true,
        initialValueIsDefault: true,
      }),
      template: new FormControl<string>(workflowTemplate?.template ?? '', {
        nonNullable: true,
        initialValueIsDefault: true,
      }),
    });
    formGroup.controls.name.setValidators([SentinelValidators.noWhitespace]);
    formGroup.controls.description.setValidators([SentinelValidators.noWhitespace]);
    formGroup.controls.template.setValidators([SentinelValidators.noWhitespace, jsonValidator]);
    formGroup.updateValueAndValidity();
    super(formGroup);
  }

  setValues(workflowTemplates: EditWorkflowTemplateFragment): void {
    if (workflowTemplates.name && workflowTemplates.description && workflowTemplates.template) {
      this.formGroup.controls.name.setValue(workflowTemplates.name);
      this.formGroup.controls.description.setValue(workflowTemplates.description);
      this.formGroup.controls.template.setValue(workflowTemplates.template);
    }
  }

  getData(): CreateEditWorkflowTemplateData {
    return {
      name: this.formGroup.controls.name.value,
      description: this.formGroup.controls.description.value,
      template: this.formGroup.controls.template.value,
    };
  }
}
