import { ChangeDetectionStrategy, Component } from '@angular/core';
import { WorkflowTemplateOrdEnum } from '@orion/graphql-types';
import { WorkflowTemplateFilterChipsService, WorkflowTemplateFilterService } from '@orion/workflow-template-services';
import { WorkflowTemplateClientFilter } from '@orion/workflow-template-types';
import {
  INIT_PAGINATION_EVENT_BASE_TOKEN,
  PaginationBaseInit,
  PaginationService,
  QueryParamPaginationService,
} from '@csirtmu-orion/microframework/pagination-services';
import { SentinelControlItem } from '@sentinel/components/controls';
import { EntityPaginableFilterableSmartOverviewDirective } from '@csirtmu-orion/microframework/entity-smart-directives';
import { defer, Observable, of } from 'rxjs';
import { take } from 'rxjs/operators';
import { WorkflowTemplateOverviewFragment } from './graphql';
import { WorkflowTemplateOverviewActionsService } from './workflow-template-overview-actions.service';
import { WorkflowTemplateOverviewService } from './workflow-template-overview.service';

@Component({
  selector: 'orion-workflow-template-overview-page',
  templateUrl: './workflow-template-overview-page.component.html',
  styleUrls: ['./workflow-template-overview-page.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [
    WorkflowTemplateOverviewService,
    WorkflowTemplateOverviewActionsService,
    WorkflowTemplateFilterService,
    WorkflowTemplateFilterChipsService,
    { provide: PaginationService, useClass: QueryParamPaginationService },
    {
      provide: INIT_PAGINATION_EVENT_BASE_TOKEN,
      useValue: new PaginationBaseInit(10, WorkflowTemplateOrdEnum.LAST_UPDATED, 'desc'),
    },
  ],
})
export class WorkflowTemplateOverviewPageComponent extends EntityPaginableFilterableSmartOverviewDirective<
  WorkflowTemplateOverviewFragment,
  WorkflowTemplateClientFilter
> {
  uploadTemplateDisplayed$: Observable<boolean>;
  controls: SentinelControlItem[] = [
    new SentinelControlItem(
      'upload',
      'Upload',
      'primary',
      of(false),
      defer(() => this.actionService.showUploadComponent())
    ),
    new SentinelControlItem(
      'create',
      'Create',
      'primary',
      of(false),
      defer(() => this.actionService.create())
    ),
  ];

  constructor(
    protected workflowTemplatesService: WorkflowTemplateOverviewService,
    protected paginationService: PaginationService,
    protected filterService: WorkflowTemplateFilterService,
    protected filterChipsService: WorkflowTemplateFilterChipsService,
    private actionService: WorkflowTemplateOverviewActionsService
  ) {
    super(workflowTemplatesService, filterService, paginationService, filterChipsService);
    this.uploadTemplateDisplayed$ = this.actionService.showUploadFileComponent$.asObservable();
  }

  onControlsEvent(clickedItem: SentinelControlItem): void {
    clickedItem.result$?.pipe(take(1)).subscribe();
  }
}
