import { Injectable } from '@angular/core';
import { WorkflowTemplateFilter1AndFilterEntry, WorkflowTemplateOrdEnum } from '@orion/graphql-types';
import { WorkflowTemplateClientFilter, WorkflowTemplateFilterConverter } from '@orion/workflow-template-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import {
  GetWorkflowTemplateOverviewQuery,
  GetWorkflowTemplateOverviewQueryService,
  GetWorkflowTemplateOverviewQueryVariables,
  WorkflowTemplateOverviewFragment,
} from './graphql';
import { ApolloPaginatedFilterablePollingService } from '@orion/shared-services';

@Injectable()
export class WorkflowTemplateOverviewService extends ApolloPaginatedFilterablePollingService<
  GetWorkflowTemplateOverviewQuery,
  GetWorkflowTemplateOverviewQueryVariables,
  WorkflowTemplateOverviewFragment,
  WorkflowTemplateOrdEnum,
  WorkflowTemplateClientFilter,
  WorkflowTemplateFilter1AndFilterEntry
> {
  constructor(public getQuery: GetWorkflowTemplateOverviewQueryService) {
    super(getQuery, 'Fetching workflow templates');
  }

  protected createFilterConverter(): FilterConverter<
    WorkflowTemplateClientFilter,
    WorkflowTemplateFilter1AndFilterEntry[]
  > {
    return new WorkflowTemplateFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: WorkflowTemplateClientFilter
  ): GetWorkflowTemplateOverviewQueryVariables {
    return {
      ...this.createPaginationVariables(paginationEvent),
      ...this.createOrderVariables(paginationEvent.sort, paginationEvent.sortDir),
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected getQueryResponse(
    query: GetWorkflowTemplateOverviewQuery
  ): CursorPaginatedResponse<WorkflowTemplateOverviewFragment> {
    return query.getWorkflowTemplateList;
  }

  protected strToOrderable(sort: string): Optional<WorkflowTemplateOrdEnum> {
    return enumFromValue(WorkflowTemplateOrdEnum, sort);
  }
}
