import { WorkflowTemplateOrdEnum } from '@orion/graphql-types';
import { IPaginatedElements } from '@sentinel/common/pagination';
import { isLoading } from '@sentinel/common/utils';
import { Column, Row, RowAction, RowExpand, SentinelTable } from '@sentinel/components/table';
import { defer, of } from 'rxjs';
import { map } from 'rxjs/operators';
import { WorkflowTemplateOverviewActionsService } from '../workflow-template-overview-actions.service';
import { WorkflowTemplateTableDetailComponent } from './workflow-template-table-detail';
import { WorkflowTemplateTableElementFragment } from './workflow-template-table-element.fragment.generated';

export class WorkflowTemplateTable extends SentinelTable<WorkflowTemplateTableElementFragment> {
  constructor(
    resources: IPaginatedElements<WorkflowTemplateTableElementFragment>,
    service: WorkflowTemplateOverviewActionsService
  ) {
    const columns = [
      new Column('name', 'Name', true, WorkflowTemplateOrdEnum.NAME),
      new Column('created', 'Created', true, WorkflowTemplateOrdEnum.CREATED),
      new Column('lastUpdated', 'Last Updated', true, WorkflowTemplateOrdEnum.LAST_UPDATED),
    ];
    const rows = resources.elements.map(
      (workflowTemplate) => new Row(workflowTemplate, WorkflowTemplateTable.createActions(workflowTemplate, service))
    );
    super(rows, columns);
    this.pagination = resources.pagination;
    this.expand = new RowExpand(WorkflowTemplateTableDetailComponent);
  }

  private static createActions(
    workflowTemplate: WorkflowTemplateTableElementFragment,
    service: WorkflowTemplateOverviewActionsService
  ): RowAction[] {
    const editAction = new RowAction(
      'edit',
      'Edit',
      'create',
      'primary',
      'Edit',
      of(false),
      defer(() => service.edit(workflowTemplate.id))
    );
    const deleteAction = new RowAction(
      'delete',
      'Delete',
      'delete',
      'warn',
      'Delete',
      of(false),
      defer(() => service.delete([workflowTemplate.id])),
      service.deletingInProgress$.pipe(map((state) => isLoading(state, workflowTemplate.id)))
    );
    const donwloadAction = new RowAction(
      'download',
      'Download',
      'file_download',
      'primary',
      'Download',
      of(false),
      defer(() => service.download(workflowTemplate))
    );

    return [editAction, deleteAction, donwloadAction];
  }
}
