import { Injectable } from '@angular/core';
import { ActivatedRoute, Data, ParamMap, Params, Router } from '@angular/router';
import { WorkflowTemplateClientFilter } from '@orion/workflow-template-types';
import { QueryParamFilterService } from '@csirtmu-orion/microframework/filter-services';
import { Observable, of } from 'rxjs';

@Injectable()
export class WorkflowTemplateFilterService extends QueryParamFilterService<WorkflowTemplateClientFilter> {
  constructor(protected router: Router, protected activatedRoute: ActivatedRoute) {
    super(router, activatedRoute);
  }

  protected createEmptyFilter(): WorkflowTemplateClientFilter {
    return { name: undefined, from: undefined, to: undefined };
  }

  protected toQueryParams(filter: WorkflowTemplateClientFilter): Params {
    const params = super.toQueryParams(filter);
    if (filter.from) {
      params.from = filter.from.valueOf();
    }
    if (filter.to) {
      params.to = filter.to.valueOf();
    }
    return params;
  }

  protected createFilterFromRoute(
    queryParamMap: ParamMap,
    paramMap: ParamMap,
    data: Data
  ): Observable<WorkflowTemplateClientFilter> {
    const nameParam = queryParamMap.get('name');
    const from = this.deslugifyTimestamp(queryParamMap.get('from'));
    const to = this.deslugifyTimestamp(queryParamMap.get('to'));
    const name = this.deslugify(nameParam);
    if (!name && !from && !to) {
      return of(this.EMPTY_FILTER);
    }
    return of({ from, to, name: name });
  }
}
