import { Injectable } from '@angular/core';
import { WorkflowStateEnum } from '@orion/graphql-types';
import {
  StageDetailMainContentFragment,
  StageOrWorkflowControlsService,
  WorkflowDetailMainContentFragment,
} from '@orion/stage-workflow-shared-components/detail';
import { SentinelControlItem } from '@sentinel/components/controls';
import { defer } from 'rxjs';
import { WorkflowActionService } from './workflow-action.service';

@Injectable()
export class WorkflowControlsService extends StageOrWorkflowControlsService {
  constructor(private workflowActionService: WorkflowActionService) {
    super();
  }

  protected createControls(
    stageOrWorkflow: StageDetailMainContentFragment | WorkflowDetailMainContentFragment
  ): SentinelControlItem[] {
    const exportControl = new SentinelControlItem(
      'EXPORT_WORKFLOW',
      'Export to Template',
      'primary',
      this.workflowActionService.exportInProgress$,
      defer(() => this.workflowActionService.exportToTemplate(stageOrWorkflow.id)),
      this.workflowActionService.exportInProgress$
    );
    const rejectWorkflowControl = new SentinelControlItem(
      'REJECT_WORKFLOW',
      'Reject',
      'primary',
      this.workflowActionService.rejectInProgress$,
      defer(() => this.workflowActionService.reject(stageOrWorkflow.id)),
      this.workflowActionService.rejectInProgress$
    );

    if (stageOrWorkflow.state === WorkflowStateEnum.IN_PROGRESS) {
      return [rejectWorkflowControl, exportControl];
    } else {
      return [exportControl];
    }
  }
}
