import { ChangeDetectionStrategy, Component, OnInit } from '@angular/core';
import { WorkflowUpdate } from '@orion/graphql-types';
import {
  EditableEntityPageCanDeactivateService,
  ENTITY_EDIT_FORM_MANDATORY_DESCRIPTION_TOKEN,
  EntityEditEventService,
  EntityEditModeService,
  PatchEntityEditService,
} from '@orion/shared-components/editable-entity';
import { EditableEntityDetailPageBaseDirective } from '@orion/shared-components/entity-base';
import { EntityEditService } from '@orion/shared-components/entity-edit';
import { StageOrWorkflowControlsService } from '@orion/stage-workflow-shared-components/detail';
import { WorkflowDetailFragment } from './graphql';
import { WorkflowActionService } from './workflow-action.service';
import { WorkflowControlsService } from './workflow-controls.service';
import { WorkflowDetailService } from './workflow-detail.service';
import { WorkflowPatchService } from './workflow-patch.service';
import { AssignedTasksFilterService } from '@orion/task-components/shared';
import { WorkflowAssignedTasksFilterService } from './assigned-tasks-panel';
import { WorkflowStageIdsService } from './workflow-stage-ids.service';
import { tap } from 'rxjs/operators';

@Component({
  selector: 'orion-workflow-detail-page',
  templateUrl: './workflow-detail-page.component.html',
  styleUrls: ['./workflow-detail-page.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [
    WorkflowDetailService,
    WorkflowPatchService,
    WorkflowActionService,
    EntityEditModeService,
    EntityEditEventService,
    EditableEntityPageCanDeactivateService,
    WorkflowStageIdsService,
    { provide: AssignedTasksFilterService, useClass: WorkflowAssignedTasksFilterService },
    { provide: ENTITY_EDIT_FORM_MANDATORY_DESCRIPTION_TOKEN, useValue: true },
    { provide: StageOrWorkflowControlsService, useClass: WorkflowControlsService },
    { provide: EntityEditService, useClass: PatchEntityEditService },
  ],
})
export class WorkflowDetailPageComponent
  extends EditableEntityDetailPageBaseDirective<WorkflowDetailFragment, WorkflowUpdate>
  implements OnInit
{
  constructor(
    protected workflowService: WorkflowDetailService,
    protected workflowPatchService: WorkflowPatchService,
    protected canDeactivateService: EditableEntityPageCanDeactivateService,
    protected stageIdsService: WorkflowStageIdsService
  ) {
    super(workflowService, workflowPatchService, canDeactivateService);
  }

  ngOnInit() {
    super.ngOnInit();
    this.entity$ = this.entityService.data$.pipe(
      tap((data) => {
        if (data) {
          this.stageIdsService.update(data);
        }
      })
    );
  }
}
