import { Injectable } from '@angular/core';
import { WorkflowTemplateFilter1AndFilterEntry, WorkflowTemplateOrdEnum } from '@orion/graphql-types';
import { WorkflowTemplateClientFilter, WorkflowTemplateFilterConverter } from '@orion/workflow-template-types';
import { ApolloPaginatedFilterableService } from '@csirtmu-orion/microframework/apollo-services';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import {
  GetWorkflowTemplatesQuery,
  GetWorkflowTemplatesQueryService,
  GetWorkflowTemplatesQueryVariables,
  WorkflowTemplateListFragment,
} from './graphql';

@Injectable()
export class WorkflowTemplateListService extends ApolloPaginatedFilterableService<
  GetWorkflowTemplatesQuery,
  GetWorkflowTemplatesQueryVariables,
  WorkflowTemplateListFragment,
  WorkflowTemplateOrdEnum,
  WorkflowTemplateClientFilter,
  WorkflowTemplateFilter1AndFilterEntry
> {
  constructor(public getQuery: GetWorkflowTemplatesQueryService) {
    super(getQuery, 'Fetching workflow templates');
  }

  protected createFilterConverter(): FilterConverter<
    WorkflowTemplateClientFilter,
    WorkflowTemplateFilter1AndFilterEntry[]
  > {
    return new WorkflowTemplateFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: WorkflowTemplateClientFilter,
    args: unknown
  ): GetWorkflowTemplatesQueryVariables {
    return {
      ...this.createPaginationVariables(paginationEvent),
      ...this.createOrderVariables(paginationEvent.sort, paginationEvent.sortDir),
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected getQueryResponse(query: GetWorkflowTemplatesQuery): CursorPaginatedResponse<WorkflowTemplateListFragment> {
    return query?.getWorkflowTemplateList;
  }

  protected strToOrderable(sort: string): Optional<WorkflowTemplateOrdEnum> {
    return enumFromValue(WorkflowTemplateOrdEnum, sort);
  }
}
