const workerSharedData = {
  accessToken: null,
  interceptedUrl: null,
  oidcProviderHeaderName: null,
  oidcProviderHeaderValue: null
};

/**
 * Listen to all fetch requests and wrap browser fetch requests to protected image storage
 * with authorization headers. Images are automatically fetched by browser and cannot be
 * intercepted by traditional Angular HTTP Interceptors.
 * This allows browser to fetch images through <img src=""> tags from protected endpoints.
 */
self.addEventListener('fetch', event => {
  if (workerSharedData.accessToken
    && workerSharedData.oidcProviderHeaderName
    && workerSharedData.oidcProviderHeaderValue
    && workerSharedData.interceptedUrl
    && event.request.url
    && event.request.url.startsWith(workerSharedData.interceptedUrl)) {
    event.respondWith(
      fetch(event.request, {
        mode: 'cors',
        credentials: 'include',
        headers: {
          'authorization': `Bearer ${workerSharedData.accessToken}`,
          [workerSharedData.oidcProviderHeaderName]: workerSharedData.oidcProviderHeaderValue
        }
      })
    )
  }
});


/**
 * Listen to messages from client with auth data for fetch interceptor
 */
onmessage = function(e) {
  if (e.data.accessToken) {
    workerSharedData.accessToken = e.data.accessToken;
  }
  if (e.data.interceptedUrl) {
    workerSharedData.interceptedUrl = e.data.interceptedUrl;
  }
  if (e.data.oidcProviderHeaderName) {
    workerSharedData.oidcProviderHeaderName = e.data.oidcProviderHeaderName
  }
  if (e.data.oidcProviderHeaderName) {
    workerSharedData.oidcProviderHeaderValue = e.data.oidcProviderHeaderValue;
  }
}
