# Apollo Services

Apollo services is a collection of services for handling common use cases of fetching data with Apollo queries.
Some services are designed to communicate with smart components extending directives from `@csirtmu-orion/microframework/entity-smart-directives`.
It is also expected to use generated queries, mutations, fragments, and types from `@graphql-codegen/typescript-apollo-angular`.

## Dependencies
```
"apollo-angular": "^4.1.1"
```

## Usage

1. Select appropriate service based on the table below
2. In your service, extend selected service
```
export class MyEntitiesService extends ApolloPaginatedFilterablePollingService<
  GetMyEntitiesQuery,
  GetMyEntitiesQueryVariables,
  MyEntityElementFragment,
  MyEntityOrdEnum,
  MyEntityClientFilter,
  MyEntityApiFilter
> {
  constructor(public getQuery: GetMyEntitiesQueryService) {
    super(getQuery, 'Fetching cases');
  }

  ...
}
```
3.  You can now use following attributes and methods
```
    queryRef?: QueryRef<Query, QueryVariables>;
    operationName: string;
    data$: Observable<Data>;
    isLoading$: Observable<boolean>;
    isRefetching$: Observable<boolean>;
    hasError$?: Observable<boolean>;
    update(paginationEvent: IPaginationEvent, clientFilter: ClientFilter, ...args: unknown[]): void
  ```

| Service                              | Directive                                       | Use cases                                                                                                        |
|--------------------------------------|-------------------------------------------------|------------------------------------------------------------------------------------------------------------------|
| ApolloQueryService                   | EntitySmartOverviewDirective                    | Fetching entity/entities. Initial loading, loading, error states, try again method. No pagination and filtering. |
| ApolloPaginatedBaseService           | EntityPaginableSmartOverviewDirective           | Fetching paginated generic entities. No filtering.                                                               |
| ApolloPaginatedDmtService            | EntityPaginableSmartOverviewDirective           |                                                                                                                  |
| ApolloPaginatedFilterableBaseService | EntityPaginableFilterableSmartOverviewDirective | Fetching paginated and filterable generic entities.                                                              |
| ApolloPaginatedFilterableService     | EntityPaginableFilterableSmartOverviewDirective |                                                                                                                  |
| ApolloFilterableService              | EntityFilterableSmartOverviewDirective          | Fetching filterable generic entities. No pagination.                                                             |
| ApolloFilterableOrderableService     | EntityFilterableOrderableSmartOverviewDirective | Fetching filterable and sortable generic entities. No pagination.                                                |
| ApolloChildEntitiesService           | ChildEntitySmartOverviewDirective               | Fetching all entities of a parent entity (by parent id). No pagination, filtering.                               |
| ApolloInterfaceChildEntitiesService  | ChildEntityInterfaceSmartOverviewDirective      | Fetching all entities of a parent interface (by parent id, and enumerated type). No pagination, filtering.       |
| ApolloEntityBaseService              | -                                               | Base for fetching entity by id.                                                                                  |
| ApolloEntityService                  | -                                               | Fetching entity by id.                                                                                           |
| ApolloRoutedEntityService            | -                                               | Fetching entity by id resolved from state of Angular Router                                                      |
| ApolloEntitiesBaseService            | -                                               | Base for fetching entites. No pagination, filtering.                                                             |
| ApolloEntitiesService                | -                                               | Fetching entites. No pagination, filtering.                                                                      |
| ApolloEntityPatchService             | -                                               | For update mutations on entity                                                                                   |
| ApolloBaseResolver                   | -                                               | Base for Angular resolver connected to Apollo query.                                                             |
| ApolloResolver                       | -                                               | Angular resolver connected to Apollo query.                                                                      |
| ApolloBreadcrumbResolver             | -                                               | Angular resolver connected to Apollo query, returning string.                                                    |****
