import * as Apollo from 'apollo-angular';
import { DmtOrderingConverter, DmtQueryOrder, QueryFilter } from '@csirtmu-orion/microframework/graphql';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { Optional } from '@sentinel/common/utils';
import { SortEvent } from '@csirtmu-orion/microframework/sort-services';
import { ApolloQueryServiceOptions } from '../general/apollo-query.service';
import { ApolloEntitiesBaseService } from '../general/apollo-entities-base.service';

export abstract class ApolloFilterableOrderableBaseService<
  Query,
  QueryVariables,
  Fragment,
  OrderableBy,
  ClientFilter,
  ApiFilter
> extends ApolloEntitiesBaseService<Query, QueryVariables, Fragment> {
  abstract filterConverter: FilterConverter<Partial<ClientFilter>, ApiFilter[]>;

  protected constructor(
    public override getQuery: Apollo.Query<Query, QueryVariables>,
    operationName: string,
    options?: ApolloQueryServiceOptions
  ) {
    super(getQuery, operationName, options);
  }

  protected abstract strToOrderable(sort: string): Optional<OrderableBy>;

  protected abstract createFilterConverter(): FilterConverter<ClientFilter, ApiFilter[]>;

  protected abstract override createVariables(
    clientFilter: ClientFilter,
    order: SortEvent,
    ...args: unknown[]
  ): QueryVariables;

  update(clientFilter: ClientFilter, sort: SortEvent, ...args: unknown[]): void {
    if (!this.initialized$.getValue()) {
      this.initialize();
    }
    this.updateVariables(clientFilter, sort, args);
    this.updateQuery();
  }

  protected override updateVariables(clientFilter: ClientFilter, sort: SortEvent, ...args: unknown[]): void {
    this.variables = this.createVariables(clientFilter, sort, args);
  }

  protected createFilterVariables(clientFilter: ClientFilter): QueryFilter<ApiFilter> {
    return { filter: this.filterConverter.convert(clientFilter) };
  }

  protected createOrderVariables(sortEvent: SortEvent): DmtQueryOrder<OrderableBy> {
    if (sortEvent.sort && sortEvent.sort !== '' && sortEvent.sortDir) {
      return DmtOrderingConverter.fromSingleSort(this.strToOrderable(sortEvent.sort), sortEvent.sortDir);
    } else {
      return {};
    }
  }
}
