import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import * as Apollo from 'apollo-angular';
import { QuerySingleFilter } from '@csirtmu-orion/microframework/graphql';
import { ApolloQueryServiceOptions } from '../general/apollo-query.service';
import { ApolloEntitiesBaseService } from '../general/apollo-entities-base.service';

export abstract class ApolloFilterableService<
  Query,
  QueryVariables,
  Entity,
  ClientFilter,
  ApiFilter
> extends ApolloEntitiesBaseService<Query, QueryVariables, Entity> {
  filterConverter: FilterConverter<Partial<ClientFilter>, ApiFilter>;

  protected constructor(
    public override getQuery: Apollo.Query<Query, QueryVariables>,
    operationName: string,
    options?: ApolloQueryServiceOptions
  ) {
    super(getQuery, operationName, options);
    this.filterConverter = this.createFilterConverter();
  }

  protected abstract createFilterConverter(): FilterConverter<ClientFilter, ApiFilter>;

  protected abstract override createVariables(clientFilter: ClientFilter, ...args: unknown[]): QueryVariables;

  update(clientFilter: ClientFilter, ...args: unknown[]): void {
    this.updateVariables(clientFilter, args);
    if (!this.initialized$.getValue()) {
      this.initialize();
    }
    this.updateQuery();
  }

  protected override updateVariables(clientFilter: ClientFilter, ...args: unknown[]): void {
    this.variables = this.createVariables(clientFilter, args);
  }

  protected createFilterVariables(clientFilter: ClientFilter): QuerySingleFilter<ApiFilter> {
    return { filter: this.filterConverter.convert(clientFilter) };
  }
}
