import { ActivatedRouteSnapshot, Resolve } from '@angular/router';
import { ApolloQueryResult } from '@apollo/client/core';
import { Optional } from '@sentinel/common/utils';
import * as Apollo from 'apollo-angular';
import { EMPTY, Observable, of } from 'rxjs';
import { catchError, mergeMap } from 'rxjs/operators';

export abstract class ApolloBaseResolver<Fragment, Query, QueryVariables> implements Resolve<Fragment> {
  protected constructor(public getQuery: Apollo.Query<Query, QueryVariables>) {}

  protected abstract toFragment(query: Query): Optional<Fragment>;

  protected abstract getIdParamSelector(): string;

  protected abstract createVariables(id: string, ...args: unknown[]): QueryVariables;

  resolve(route: ActivatedRouteSnapshot): Observable<Fragment> | Promise<Fragment> | Fragment {
    const id = route.paramMap.get(this.getIdParamSelector());
    if (id !== null) {
      return this.getEntity(id);
    } else {
      return EMPTY;
    }
  }

  protected getEntity(id: string, ...args: unknown[]): Observable<Fragment> {
    return this.getQuery.fetch(this.createVariables(id, ...args), { fetchPolicy: 'cache-first' }).pipe(
      mergeMap((res) => this.handleQueryResult(res)),
      catchError(() => EMPTY)
    );
  }

  protected handleQueryResult(result: ApolloQueryResult<Query>): Observable<Fragment> {
    const data = result?.data;
    if (data) {
      const entity = this.toFragment(data);
      if (entity) {
        return of(entity);
      }
    }
    return EMPTY;
  }
}
