import * as Apollo from 'apollo-angular';
import { ApolloEntitiesBaseService } from './apollo-entities-base.service';
import { ApolloQueryServiceOptions } from './apollo-query.service';

export abstract class ApolloChildEntitiesService<Query, QueryVariables, Entity> extends ApolloEntitiesBaseService<
  Query,
  QueryVariables,
  Entity
> {
  protected constructor(
    public override getQuery: Apollo.Query<Query, QueryVariables>,
    operationName: string,
    options?: ApolloQueryServiceOptions
  ) {
    super(getQuery, operationName, options);
  }

  protected abstract override createVariables(parentId: string, ...args: unknown[]): QueryVariables;

  protected override updateVariables(parentId: string, ...args: unknown[]): void {
    this.variables = this.createVariables(parentId, ...args);
  }

  setParent(parentId: string | number, ...args: unknown[]): void {
    this.updateVariables(this.resolveId(parentId), ...args);
    if (this.initialized$.getValue()) {
      this.updateQuery();
    } else {
      this.initialize();
    }
  }

  protected resolveId(id: string | number): string {
    return typeof id === 'string' ? id : id.toString();
  }
}
