import { ApolloQueryResult } from '@apollo/client/core';
import { Optional } from '@sentinel/common/utils';
import * as Apollo from 'apollo-angular';
import { ApolloQueryService, ApolloQueryServiceOptions } from './apollo-query.service';

export abstract class ApolloEntityBaseService<Query, QueryVariables, Fragment> extends ApolloQueryService<
  Query,
  QueryVariables,
  Optional<Fragment>
> {
  protected constructor(
    public override getQuery: Apollo.Query<Query, QueryVariables>,
    operationName: string,
    options?: ApolloQueryServiceOptions
  ) {
    super(getQuery, operationName, options);
  }

  protected abstract toFragment(query: Query): Optional<Fragment>;

  protected abstract override createVariables(entityId: string, ...args: unknown[]): QueryVariables;

  protected override updateVariables(entityId: string, ...args: unknown[]): void {
    this.variables = this.createVariables(entityId, ...args);
  }

  protected toData(queryRes: ApolloQueryResult<Query>): Optional<Fragment> {
    return this.toFragment(queryRes.data);
  }

  updateVars(id: string | number, ...args: unknown[]): void {
    this.updateVariables(this.resolveId(id), ...args);
    if (!this.initialized$.getValue()) {
      this.initialize();
    }
    this.updateQuery();
  }

  protected resolveId(id: string | number): string {
    return typeof id === 'string' ? id : id.toString();
  }
}
