import * as Apollo from 'apollo-angular';
import { Observable } from 'rxjs';
import { catchError, map, take } from 'rxjs/operators';
import { EntityPatchService } from './entity-patch.service';
import {
  ApolloOperationResultResolver,
  ApolloResult,
  createApolloContextErrorTitle,
  EntityUpdateEvent,
} from '@csirtmu-orion/microframework/graphql';

export abstract class ApolloEntityPatchService<EntityPatch, Mutation, MutationVariables>
  implements EntityPatchService<EntityPatch>
{
  protected abstract refetchQueriesNames: string[];

  protected constructor(protected patchMutation: Apollo.Mutation<Mutation, MutationVariables>) {}

  patch(event: EntityUpdateEvent<EntityPatch>): Observable<ApolloResult> {
    const vars = this.createVariables(event);
    return this.patchMutation
      .mutate(vars, {
        refetchQueries: this.refetchQueriesNames,
        awaitRefetchQueries: true,
        context: createApolloContextErrorTitle('Updating entity'),
      })
      .pipe(
        take(1),
        map((result) => ApolloOperationResultResolver.resolve(result)),
        catchError((err) => ApolloOperationResultResolver.handleError(err))
      );
  }

  abstract createVariables(event: EntityUpdateEvent<EntityPatch>): MutationVariables;
}
