import { ApolloQueryResult } from '@apollo/client/core';
import * as Apollo from 'apollo-angular';
import { ApolloQueryService, ApolloQueryServiceOptions } from './apollo-query.service';
import { IPaginatedElements, IPagination, IPaginationEvent, PaginatedResource } from '@sentinel/common/pagination';
import { DmtQueryOrder, PaginatedData, PaginationQuery } from '@csirtmu-orion/microframework/graphql';
import { Optional } from '@sentinel/common/utils';

export abstract class ApolloPaginatedBaseService<
  Query,
  QueryVariables,
  Fragment,
  OrderableBy
> extends ApolloQueryService<Query, QueryVariables, IPaginatedElements<Fragment>> {
  protected lastPaginationEvent: IPaginationEvent;

  protected constructor(
    public override getQuery: Apollo.Query<Query, QueryVariables>,
    operationName: string,
    options?: ApolloQueryServiceOptions
  ) {
    super(getQuery, operationName, options);
    this.lastPaginationEvent = this.createInitialPaginationEvent();
  }

  protected abstract strToOrderable(sort: string): Optional<OrderableBy>;

  protected abstract createInitialPaginationEvent(): IPaginationEvent;

  protected abstract queryToPaginationData(query: Query): PaginatedData;

  protected abstract toFragments(query: Query): Fragment[];

  protected abstract override createVariables(paginationEvent: IPaginationEvent, ...args: unknown[]): QueryVariables;

  protected abstract createPaginationVariables(paginationEvent: IPaginationEvent): PaginationQuery;

  protected abstract createOrderVariables(sort: string, dir: string): DmtQueryOrder<OrderableBy>;

  protected abstract createPaginationFromQueryResult(result: ApolloQueryResult<Query>): IPagination;

  protected override updateVariables(paginationEvent: IPaginationEvent, ...args: unknown[]): void {
    this.variables = this.createVariables(paginationEvent, args);
  }

  update(paginationEvent: IPaginationEvent, ...args: unknown[]): void {
    if (!this.initialized$.getValue()) {
      this.initialize();
    }
    this.lastPaginationEvent = paginationEvent;
    this.updateVariables(paginationEvent, args);
    this.updateQuery();
  }

  protected toData(result: ApolloQueryResult<Query>): IPaginatedElements<Fragment> {
    const entities = this.toFragments(result.data);
    const pagination = this.createPaginationFromQueryResult(result);
    return new PaginatedResource<Fragment>(entities, pagination);
  }
}
