import { QueryFilter } from '@csirtmu-orion/microframework/graphql';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import * as Apollo from 'apollo-angular';
import { IPaginationEvent } from '@sentinel/common/pagination';
import { ApolloPaginatedDmtService } from '../paginable/apollo-paginated-dmt.service';
import { ApolloQueryServiceOptions } from './apollo-query.service';

export abstract class ApolloPaginatedFilterableBaseService<
  Query,
  QueryVariables,
  Fragment,
  OrderableBy,
  ClientFilter,
  ApiFilter
> extends ApolloPaginatedDmtService<Query, QueryVariables, Fragment, OrderableBy> {
  abstract filterConverter: FilterConverter<Partial<ClientFilter>, ApiFilter[]>;

  protected constructor(
    public override getQuery: Apollo.Query<Query, QueryVariables>,
    operationName: string,
    options?: ApolloQueryServiceOptions
  ) {
    super(getQuery, operationName, options);
  }

  protected abstract createFilterConverter(): FilterConverter<ClientFilter, ApiFilter[]>;

  protected abstract override createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: ClientFilter,
    ...args: unknown[]
  ): QueryVariables;

  override update(paginationEvent: IPaginationEvent, clientFilter: ClientFilter, ...args: unknown[]): void {
    if (!this.initialized$.getValue()) {
      this.initialize();
    }
    this.lastPaginationEvent = paginationEvent;
    this.updateVariables(paginationEvent, clientFilter, args);
    this.updateQuery();
  }

  protected override updateVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: ClientFilter,
    ...args: unknown[]
  ): void {
    this.variables = this.createVariables(paginationEvent, clientFilter, args);
  }

  protected createFilterVariables(clientFilter: ClientFilter): QueryFilter<ApiFilter> {
    return { filter: this.filterConverter.convert(clientFilter) };
  }
}
