import { ActivatedRoute, ParamMap } from '@angular/router';
import { NetworkStatus } from '@apollo/client/core';
import { Identifiable } from '@sentinel/common/entity';
import * as Apollo from 'apollo-angular';
import { EMPTY, Observable } from 'rxjs';
import { catchError, concatMap, filter, map, shareReplay, switchMap, tap } from 'rxjs/operators';
import { ApolloEntityBaseService } from './apollo-entity-base.service';
import { ApolloQueryServiceOptions } from './apollo-query.service';

export abstract class ApolloRoutedEntityService<
  Query,
  QueryVariables,
  Fragment extends Identifiable
> extends ApolloEntityBaseService<Query, QueryVariables, Fragment> {
  protected constructor(
    public override getQuery: Apollo.Query<Query, QueryVariables>,
    protected activatedRoute: ActivatedRoute,
    operationName: string,
    options?: ApolloQueryServiceOptions
  ) {
    super(getQuery, operationName, options);
    this.data$ = this.initVarsFromParamMap().pipe(
      switchMap(() => this.initialized$),
      shareReplay({ refCount: true }),
      concatMap(
        () =>
          this.queryRef?.valueChanges.pipe(
            tap((queryRes) => this.checkAndHandleQueryError(queryRes)), // ignoring all responses not containing data
            filter((queryRes) => queryRes.data !== undefined && queryRes.networkStatus === NetworkStatus.ready),
            map((queryRes) => this.toData(queryRes)),
            catchError(() => EMPTY)
          ) ?? EMPTY
      )
    );
  }

  protected abstract idFromParamMap(paramMap: ParamMap): string | null;

  protected initVarsFromParamMap(): Observable<void> {
    return this.activatedRoute.paramMap.pipe(
      map((data) => this.idFromParamMap(data)),
      map((id) => {
        if (id === null) {
          throw new Error('Failed to initialize id from paramMap');
        } else {
          this.updateVars(id);
        }
      })
    );
  }
}
