import { ApolloQueryResult } from '@apollo/client/core';
import * as Apollo from 'apollo-angular';
import {
  CursorPaginationQuery,
  CursorPaginationResolver,
  DmtOrderingConverter,
  CursorPaginatedResponse,
  CursorPaginationConverter,
  QueryCursorPaginationDataResolver,
  DmtQueryOrder,
  QueryCursorPaginationData,
} from '@csirtmu-orion/microframework/graphql';
import { CursorPaginationEvent, IPagination, IPaginationEvent, isCursorEvent } from '@sentinel/common/pagination';
import { ApolloPaginatedBaseService } from '../general/apollo-paginated-base.service';
import { ApolloQueryServiceOptions } from '../general/apollo-query.service';

export abstract class ApolloPaginatedDmtService<
  Query,
  QueryVariables,
  Fragment,
  OrderableBy
> extends ApolloPaginatedBaseService<Query, QueryVariables, Fragment, OrderableBy> {
  protected constructor(
    public override getQuery: Apollo.Query<Query, QueryVariables>,
    operationName: string,
    options?: ApolloQueryServiceOptions
  ) {
    super(getQuery, operationName, options);
  }

  protected abstract getQueryResponse(query: Query): CursorPaginatedResponse<Fragment>;

  protected queryToPaginationData(query: Query): QueryCursorPaginationData {
    return QueryCursorPaginationDataResolver.resolve(this.getQueryResponse(query));
  }

  protected toFragments(query: Query): Fragment[] {
    return this.getQueryResponse(query).data;
  }

  protected createInitialPaginationEvent(): IPaginationEvent {
    return new CursorPaginationEvent(null, 0, '', '');
  }

  protected createPaginationVariables(paginationEvent: IPaginationEvent): CursorPaginationQuery {
    if (isCursorEvent(paginationEvent)) {
      return CursorPaginationConverter.convert(paginationEvent);
    } else {
      throw TypeError('Unsupported type of pagination');
    }
  }

  protected createOrderVariables(sort?: string, dir?: string): DmtQueryOrder<OrderableBy> {
    if (sort && sort !== '' && dir && dir !== '') {
      return DmtOrderingConverter.fromSingleSort(this.strToOrderable(sort), dir);
    } else {
      return {};
    }
  }

  protected createPaginationFromQueryResult(result: ApolloQueryResult<Query>): IPagination {
    if (isCursorEvent(this.lastPaginationEvent)) {
      const paginationData = this.queryToPaginationData(result.data);
      return CursorPaginationResolver.resolve(paginationData, this.lastPaginationEvent);
    } else {
      throw TypeError('Unsupported pagination');
    }
  }
}
