import { ChangeDetectionStrategy, Component, Inject, Input, OnChanges, Optional, SimpleChanges } from '@angular/core';
import { SentinelControlItem } from '@sentinel/components/controls';
import { take } from 'rxjs/operators';
import { ORION_CARD_CONFIG, OrionCardConfig } from '@csirtmu-orion/microframework/config';

@Component({
  selector: 'orion-card',
  templateUrl: './orion-card.component.html',
  styleUrls: ['./orion-card.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class OrionCardComponent implements OnChanges {
  @Input() isLoading?: boolean;
  @Input() titleIcon?: string;
  @Input() noMargin: boolean;
  /**
   * Angular material elevation size of the card. Default value is 8. See more at https://material.angular.io/guide/elevation
   */
  @Input() elevation: number;
  @Input() cardTitle?: string;
  @Input() subtitle?: string;
  @Input() headerImgSrc?: string;
  @Input() headerImgAlt?: string;
  @Input() controls?: SentinelControlItem[];
  classes: string[] = [];

  private readonly elevationClassPrefix = 'mat-elevation-z';

  constructor(@Optional() @Inject(ORION_CARD_CONFIG) private readonly config?: OrionCardConfig | null) {
    if (config?.noMargin === undefined) {
      this.noMargin = false;
    } else {
      this.noMargin = config.noMargin;
    }
    if (config?.elevation === undefined) {
      this.elevation = 8;
    } else {
      this.elevation = config.elevation;
    }
    this.createClasses();
  }

  onControlsItem(controlItem: SentinelControlItem): void {
    controlItem.result$?.pipe(take(1)).subscribe();
  }

  ngOnChanges(changes: SimpleChanges): void {
    if ('elevation' in changes) {
      this.createClasses();
    }
    if ('noMargin' in changes) {
      this.createClasses();
    }
  }

  private createClasses(): void {
    this.classes = [`${this.elevationClassPrefix}${this.elevation}`];
    if (this.noMargin) {
      this.classes.push('no-margin');
    }
  }
}
