import { ChangeDetectorRef } from '@angular/core';
import { ComponentFixture, fakeAsync, TestBed, waitForAsync } from '@angular/core/testing';
import { By } from '@angular/platform-browser';
import { OrionColorBlockComponent } from './orion-color-block.component';
import { testDetectChanges } from '@sentinel/common/testing';

describe('OrionColorBlockComponent', () => {
  let component: OrionColorBlockComponent;
  let fixture: ComponentFixture<OrionColorBlockComponent>;
  let cd: ChangeDetectorRef;

  beforeEach(waitForAsync(() => {
    TestBed.configureTestingModule({
      declarations: [OrionColorBlockComponent],
    }).compileComponents();
  }));

  beforeEach(() => {
    fixture = TestBed.createComponent(OrionColorBlockComponent);
    component = fixture.componentInstance;
    cd = fixture.componentRef.injector.get(ChangeDetectorRef);
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  it('should display color passed on input', fakeAsync(() => {
    const redHexColor = 'ff0000';
    const redColorTranslatedToCss = 'rgb(255, 0, 0)';
    const blueHexColor = '0000ff';
    const blueColorTranslatedToCss = 'rgb(0, 0, 255)';
    const colorBlockEl = fixture.debugElement.query(By.css('.color-block'));

    component.hexColor = redHexColor;
    testDetectChanges(cd, fixture);
    expect(colorBlockEl.styles['backgroundColor']).toEqual(redColorTranslatedToCss);

    component.hexColor = blueHexColor;
    testDetectChanges(cd, fixture);
    expect(colorBlockEl.styles['backgroundColor']).toEqual(blueColorTranslatedToCss);
  }));
});
