import { ChangeDetectorRef } from '@angular/core';
import { ComponentFixture, fakeAsync, TestBed, waitForAsync } from '@angular/core/testing';
import { Validators } from '@angular/forms';
import { By } from '@angular/platform-browser';
import { createTestSimpleChanges, testDetectChanges } from '@sentinel/common/testing';
import { DateForm } from './date-form';
import { OrionDateFormComponent } from './orion-date-form.component';

describe('OrionDateFormComponent', () => {
  let component: OrionDateFormComponent;
  let fixture: ComponentFixture<OrionDateFormComponent>;
  let cd: ChangeDetectorRef;
  const TEST_DATE = new Date(1646118000);

  beforeEach(waitForAsync(() => {
    TestBed.configureTestingModule({
      declarations: [OrionDateFormComponent],
    }).compileComponents();
  }));

  beforeEach(() => {
    fixture = TestBed.createComponent(OrionDateFormComponent);
    component = fixture.componentInstance;
    cd = fixture.componentRef.injector.get(ChangeDetectorRef);
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  it('should clear form date on clear date', () => {
    spyOn(component.form, 'clearDate');

    component.clearDate();

    expect(component.form.clearDate).toHaveBeenCalledTimes(1);
  });

  it('should create form with date passed on input', fakeAsync(() => {
    component.date = TEST_DATE;
    component.ngOnChanges(createTestSimpleChanges(TEST_DATE, 'date'));
    testDetectChanges(cd, fixture);

    expect(component.form.formGroup.controls.date.value).toEqual(TEST_DATE);
  }));

  it('should create form with required validator if required is set to true on input', fakeAsync(() => {
    spyOn(component.form.formGroup, 'setValidators');
    component.required = true;
    component.ngOnChanges(createTestSimpleChanges(true, 'required'));
    testDetectChanges(cd, fixture);

    expect(component.form.formGroup.setValidators).toHaveBeenCalledOnceWith([Validators.required]);
  }));

  it('should create form with no validator if required is set to false on input', fakeAsync(() => {
    spyOn(component.form.formGroup, 'setValidators');
    component.required = false;
    component.ngOnChanges(createTestSimpleChanges(false, 'required'));
    testDetectChanges(cd, fixture);

    expect(component.form.formGroup.setValidators).toHaveBeenCalledOnceWith([]);
  }));

  it('should date change emit event on date change', () => {
    spyOn(component.dateChange, 'emit');
    component.form = new DateForm(TEST_DATE);

    component.onDateChange();

    expect(component.dateChange.emit).toHaveBeenCalledOnceWith(TEST_DATE);
  });

  it('should emit validity change on date change', () => {
    spyOn(component.validityChange, 'emit');
    component.form = new DateForm(TEST_DATE);

    component.onDateChange();

    expect(component.validityChange.emit).toHaveBeenCalledOnceWith(true);
  });

  it('should display form', fakeAsync(() => {
    const formEl = fixture.debugElement.query(By.css('mat-form-field'));
    expect(formEl).toBeTruthy();
  }));
});
