import {
  ChangeDetectionStrategy,
  Component,
  EventEmitter,
  Input,
  OnChanges,
  Output,
  SimpleChanges,
} from '@angular/core';
import { Validators } from '@angular/forms';
import { DateForm } from './date-form';
import { MatFormFieldAppearance } from '@angular/material/form-field';

@Component({
  selector: 'orion-date-form',
  templateUrl: './orion-date-form.component.html',
  styleUrls: ['./orion-date-form.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class OrionDateFormComponent implements OnChanges {
  @Input() label? = 'Date';
  @Input() appearance: MatFormFieldAppearance = 'outline';
  @Input() disabled = false;
  @Input() required = false;
  @Input() withIcon = true;
  @Input() date?: Date;
  @Input() min?: Date;
  @Input() max?: Date;
  @Input() mode: 'date' | 'datetime' = 'datetime';
  @Output() dateChange: EventEmitter<Date> = new EventEmitter<Date>();
  @Output() validityChange: EventEmitter<boolean> = new EventEmitter<boolean>();
  form: DateForm;

  constructor() {
    this.form = new DateForm();
  }

  ngOnChanges(changes: SimpleChanges): void {
    if ('date' in changes && this.date) {
      this.form = new DateForm(this.date);
      if (this.required) {
        this.form.formGroup.setValidators([Validators.required]);
      }
      if (this.disabled) {
        this.updateDisabledState(this.disabled);
      }
      this.onDateChange();
    }
    if ('disabled' in changes) {
      this.updateDisabledState(this.disabled);
    }
    if ('required' in changes) {
      this.required ? this.form.formGroup.setValidators([Validators.required]) : this.form.formGroup.setValidators([]);
    }
  }

  updateDisabledState(disabled: boolean): void {
    disabled ? this.form.formGroup.disable({ emitEvent: false }) : this.form.formGroup.enable({ emitEvent: false });
  }

  onDateChange(): void {
    this.dateChange.emit(this.form.formGroup.value.date ?? undefined);
    if (this.form.formGroup.status === 'INVALID') {
      this.validityChange.emit(false);
    } else if (this.form.formGroup.status === 'VALID') {
      this.validityChange.emit(true);
    }
  }

  clearDate(): void {
    this.form.clearDate();
  }
}
