import { ChangeDetectorRef } from '@angular/core';
import { ComponentFixture, fakeAsync, TestBed, waitForAsync } from '@angular/core/testing';
import { By } from '@angular/platform-browser';
import { OrionDateRangeFormInputsComponent } from './orion-date-range-form-inputs.component';
import { testDetectChanges } from '@sentinel/common/testing';
import { DateRangeForm } from '@sentinel/common';

describe('OrionDateRangeFormInputsComponent', () => {
  let component: OrionDateRangeFormInputsComponent;
  let fixture: ComponentFixture<OrionDateRangeFormInputsComponent>;
  let cd: ChangeDetectorRef;
  const EARLIER_DATE = new Date(1646118000);
  const LATER_DATE = new Date(1648792800);

  beforeEach(waitForAsync(() => {
    TestBed.configureTestingModule({
      declarations: [OrionDateRangeFormInputsComponent],
    }).compileComponents();
  }));

  beforeEach(() => {
    fixture = TestBed.createComponent(OrionDateRangeFormInputsComponent);
    component = fixture.componentInstance;
    cd = fixture.componentRef.injector.get(ChangeDetectorRef);
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  it('should emit event on change of date', () => {
    const from = EARLIER_DATE;
    const to = LATER_DATE;
    const dateRangeForm = new DateRangeForm({ from: from, to: to });
    spyOn(component.dateRangeChange, 'emit');

    component.formGroup = dateRangeForm.formGroup;
    component.onDateChange();

    expect(component.dateRangeChange.emit).toHaveBeenCalledOnceWith({ from: from, to: to });
  });

  it('should display date range forms', fakeAsync(() => {
    const dateRangeForm = new DateRangeForm({ from: EARLIER_DATE, to: LATER_DATE });
    component.formGroup = dateRangeForm.formGroup;
    testDetectChanges(cd, fixture);

    const dateRangeFormFieldEls = fixture.debugElement.queryAll(By.css('mat-form-field'));
    expect(dateRangeFormFieldEls.length).toEqual(2);
  }));

  it('should not display error if from date is earlier than to date', fakeAsync(() => {
    const dateRangeForm = new DateRangeForm({ from: EARLIER_DATE, to: LATER_DATE });
    component.formGroup = dateRangeForm.formGroup;
    testDetectChanges(cd, fixture);

    const errorEl = fixture.debugElement.query(By.css('mat-error'));
    expect(errorEl).toBeFalsy();
  }));

  it('should display error if from date is later than to date', fakeAsync(() => {
    const dateRangeForm = new DateRangeForm({ from: LATER_DATE, to: EARLIER_DATE });
    component.formGroup = dateRangeForm.formGroup;
    testDetectChanges(cd, fixture);

    const errorEl = fixture.debugElement.query(By.css('mat-error'));
    expect(errorEl).toBeTruthy();
  }));
});
