import {
  ChangeDetectionStrategy,
  Component,
  EventEmitter,
  Input,
  OnChanges,
  Output,
  SimpleChanges,
} from '@angular/core';
import { DateRange, DateRangeForm } from '@sentinel/common';
import { MatFormFieldAppearance } from '@angular/material/form-field';

@Component({
  selector: 'orion-date-range-form',
  templateUrl: './orion-date-range-form.component.html',
  styleUrls: ['./orion-date-range-form.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class OrionDateRangeFormComponent implements OnChanges {
  @Input() appearance: MatFormFieldAppearance = 'outline';
  @Input() fromLabel = 'From';
  @Input() toLabel = 'To';
  @Input() inRow = true;
  @Input() dateRange?: DateRange;
  @Output() dateRangeChange: EventEmitter<DateRange> = new EventEmitter<DateRange>();
  form: DateRangeForm;

  constructor() {
    this.form = new DateRangeForm();
  }

  ngOnChanges(changes: SimpleChanges): void {
    if ('dateRange' in changes && this.dateRange) {
      this.form = new DateRangeForm(this.dateRange);
    }
  }

  onDateRangeChange(dateRange: DateRange): void {
    this.dateRangeChange.emit(dateRange);
  }
}
