import { ChangeDetectorRef } from '@angular/core';
import { ComponentFixture, fakeAsync, TestBed, waitForAsync } from '@angular/core/testing';
import { By } from '@angular/platform-browser';
import { createTestSimpleChanges, testDetectChanges } from '@sentinel/common/testing';
import { OrionDueDateComponent } from './orion-due-date.component';

describe('OrionDueDateComponent', () => {
  let component: OrionDueDateComponent;
  let fixture: ComponentFixture<OrionDueDateComponent>;
  let cd: ChangeDetectorRef;
  const EARLIER_DATE = new Date(1646118000);
  const LATER_DATE = new Date(1648792800);
  beforeEach(waitForAsync(() => {
    TestBed.configureTestingModule({
      declarations: [OrionDueDateComponent],
    }).compileComponents();
  }));

  beforeEach(() => {
    fixture = TestBed.createComponent(OrionDueDateComponent);
    component = fixture.componentInstance;
    cd = fixture.componentRef.injector.get(ChangeDetectorRef);
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  it('should be set past due if due date is in past', () => {
    component.resolveIsPastDue(EARLIER_DATE, LATER_DATE);
    expect(component.isPastDue).toBeTrue();
  });

  it('should not be set past due if due date is now', () => {
    component.resolveIsPastDue(EARLIER_DATE, EARLIER_DATE);
    expect(component.isPastDue).toBeFalse();
  });

  it('should not be set past due if due date is in future', () => {
    component.resolveIsPastDue(LATER_DATE, EARLIER_DATE);
    expect(component.isPastDue).toBeFalse();
  });

  it('should resolve whether is past due on input change', fakeAsync(() => {
    component.date = EARLIER_DATE;
    component.now = LATER_DATE;

    component.ngOnChanges(createTestSimpleChanges(EARLIER_DATE, 'date'));
    testDetectChanges(cd, fixture);

    expect(component.isPastDue).toBeTrue();
  }));

  it('should set past due css class', fakeAsync(() => {
    component.date = EARLIER_DATE;
    component.isPastDue = true;
    testDetectChanges(cd, fixture);

    const classedElement = fixture.debugElement.query(By.css('.pastDue'));

    expect(classedElement).toBeTruthy();
  }));
});
