import {
  ChangeDetectionStrategy,
  Component,
  EventEmitter,
  Input,
  OnChanges,
  Output,
  SimpleChanges,
} from '@angular/core';
import { Destroyable } from '@sentinel/common';

@Component({
  selector: 'orion-editable-date',
  templateUrl: './orion-editable-date.component.html',
  styleUrls: ['./orion-editable-date.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class OrionEditableDateComponent extends Destroyable() implements OnChanges {
  @Input() isEditable = true;
  @Input() label?: string;
  @Input() maxDate?: Date;
  @Input() minDate?: Date;
  @Input() date?: Date;
  @Output() save: EventEmitter<Date> = new EventEmitter<Date>();
  saveDisabled = false;
  selectedDate?: Date;

  ngOnChanges(changes: SimpleChanges): void {
    if ('date' in changes && this.date) {
      this.selectedDate = this.date;
    }
  }

  onSave(): void {
    this.save.emit(this.selectedDate);
  }

  onCancel(): void {
    this.selectedDate = this.date;
  }

  onDateChange(date?: Date): void {
    this.selectedDate = date;
  }

  onValidityChange(valid: boolean): void {
    this.saveDisabled = !valid;
  }
}
