import {
  ChangeDetectionStrategy,
  Component,
  EventEmitter,
  Input,
  OnChanges,
  Output,
  SimpleChanges,
} from '@angular/core';
import { EditableModeChange } from './editable-mode-change';

@Component({
  selector: 'orion-editable',
  templateUrl: './orion-editable.component.html',
  styleUrls: ['./orion-editable.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class OrionEditableComponent implements OnChanges {
  @Input() fullWidth = true;
  @Input() editMode = false;
  @Input() displayEditButton = true;
  @Input() saveDisabled = false;
  @Input() cancelDisabled = false;
  @Output() save: EventEmitter<void> = new EventEmitter<void>();
  @Output() cancel: EventEmitter<void> = new EventEmitter<void>();
  @Output() modeChange: EventEmitter<EditableModeChange> = new EventEmitter<EditableModeChange>();
  private editModeSetExternally = false;

  ngOnChanges(changes: SimpleChanges): void {
    if ('editMode' in changes && this.editMode !== undefined) {
      this.editModeSetExternally = true;
    }
  }

  onEditClicked(): void {
    if (!this.editModeSetExternally) {
      this.editMode = !this.editMode;
    }
    this.modeChange.emit(this.editMode ? EditableModeChange.EDIT : EditableModeChange.DISPLAY);
  }

  onEditSaved(): void {
    if (!this.editModeSetExternally) {
      this.editMode = false;
    }
    this.save.emit();
  }

  onEditCanceled(): void {
    if (!this.editModeSetExternally) {
      this.editMode = false;
    }
    this.cancel.emit();
  }

  onKey(event: KeyboardEvent): void {
    if (event.key === 'Enter' && !this.saveDisabled) {
      this.onEditSaved();
    }
  }
}
