# Entity Smart Directives

Entity smart directives is a collection of directives for handling generic smart components
connected with services from `@csirtmu-orion/microframework/apollo-services`

## Usage

1. Select appropriate directive based on the table below
2. In your component, extend selected directive
```
export class MyEntitySmartComponent
  extends EntityPaginableFilterableSmartOverviewDirective<MyEntity, MyFilter> {
    construtor(
      protected entitiesService: MyEntityService,
      protected filterService: MyEntityFilterService,
      protected paginationService: PaginationService,
      protected filterChipsServiec: MyEntityFilterChipsService,
    ) {
      super(entitiesService, filterService, paginationService, filterChipsService)
    }
  }
```
3. In you component, you can now use following attributes and methods
```
    isLoading$?: Observable<boolean>;
    initLoading$?: Observable<boolean>;
    hasError$?: Observable<boolean>;
    entities$?: Observable<Entity>;
    tryAgain$: Observable<void>;
    sort$?: Observable<Optional<string>>;
    sortDir$?: Observable<'desc' | 'asc'>;
    filterChangedByUser: boolean;
    filterLocalState$?: Observable<Filter>;
    filterChips$?: Observable<FilterChip[]>;
    onTryAgain(): void;
    onFilterChange(filter: Filter): void;
    onRemoveChip(chip: FilterChip): void;
    onClearFilters(): void;
    onSubmitFilter(): void;
    onPaginationChange(pagination: IPaginationEvent): void;
  ```

The directive then handles all common communication between you smart component and `@sentinel/common` or `@csirtmu-orion/microframework` services.

| Directive                                       | Service                                                                | Use cases                                                                                                                                                                                     |
|-------------------------------------------------|------------------------------------------------------------------------|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| EntitySmartOverviewDirective                    | ApolloQueryService                                                     | Fetching entity/entities. Initial loading, loading, error states, try again method. No pagination and filtering.                                                                              |
| EntityPaginableSmartOverviewDirective           | ApolloPaginatedBaseService, ApolloPaginatedDmtService                  | Fetching paginated generic entities. No filtering.                                                                                                                                            |
| EntityPaginableFilterableSmartOverviewDirective | ApolloPaginatedFilterableBaseService, ApolloPaginatedFilterableService | Fetching paginated and filterable generic entities.                                                                                                                                           |
| EntityFilterableSmartOverviewDirective          | ApolloFilterableService                                                | Fetching filterable generic entities. No pagination.                                                                                                                                          |
| EntityFilterableOrderableSmartOverviewDirective | ApolloFilterableOrderableService                                       | Fetching filterable and sortable generic entities. No pagination.                                                                                                                             |
| ChildEntitySmartOverviewDirective               | ApolloChildEntitiesService                                             | Fetching all entities of a parent entity (by parent id). No pagination, filtering.                                                                                                            |
| ChildEntityInterfaceSmartOverviewDirective      | ApolloInterfaceChildEntitiesService                                    | Fetching all entities of a parent interface (by parent id, and enumerated type). No pagination, filtering.                                                                                    |
| EntityOverviewDirective                         | -                                                                      | Accepts all attributes of EntitySmartOverviewDirective in sync `@Input()`. For dumb components used with EntitySmartOverviewDirective parent component.                                       |
| EntityPaginableOverviewDirective                | -                                                                      | Accepts all attributes of EntityPaginableSmartOverviewDirective in sync `@Input()`. For dumb components used with EntityPaginableSmartOverviewDirective parent component.                     |
| EntityPaginableFilterableOverviewDirective      | -                                                                      | Accepts all attributes of EntityPaginableFilterableSmartOverviewDirective in sync `@Input()`. For dumb components used with EntityPaginableFilterableSmartOverviewDirective parent component. |
| EntityFilterableOverviewDirective               | -                                                                      | Accepts all attributes of EntityFilterableSmartOverviewDirective in sync `@Input()`. For dumb components used with EntityFilterableSmartOverviewDirective parent component.                   |
| ChildEntitySmartOverviewDirective               | -                                                                      | Accepts all attributes of ChildEntitySmartOverviewDirective in sync `@Input()`. For dumb components used with ChildEntitySmartOverviewDirective parent component.                             |
| EntityTableBaseDirective                        | -                                                                      | Accepts all attributes for simple `SentinelTableComponent` through `@Input(). Handles sort change, instatiates `SentinelTable`.                                                               |
| EntityTableDirective                            | -                                                                      | Same as EntityTableBaseDirective, handles row action and selection events.                                                                                                                    |
| PaginatedEntityTableDirective                   | -                                                                      | Accepts all attributes for paginated `SentinelTableComponent` through `@Input()`. Handles pagination changes.                                                                                 |
| OptionallyPaginatedEntityTableDirective         | -                                                                      | Accepts paginated or simple data and creates table accordingly.                                                                                                                               |
