import { Directive, OnInit, Optional } from '@angular/core';
import { FilterChipsService, FilterService } from '@csirtmu-orion/microframework/filter-services';
import { FilterChip } from '@csirtmu-orion/microframework/filter';
import { Observable } from 'rxjs';
import { shareReplay, takeUntil } from 'rxjs/operators';
import { EntitySmartOverviewDirective } from './entity-smart-overview.directive';
import { ApolloFilterableOrderableService } from '@csirtmu-orion/microframework/apollo-services';
import { SortEvent, SortService } from '@csirtmu-orion/microframework/sort-services';

@Directive()
export class EntityFilterableOrderableSmartOverviewDirective<Entity, Filter>
  extends EntitySmartOverviewDirective<Entity[]>
  implements OnInit
{
  sort$?: Observable<SortEvent>;
  filterLocalState$?: Observable<Filter>;
  filterChips$?: Observable<FilterChip[]>;

  protected constructor(
    // No point in introducing a generic for query, query variables, and api filter in this component
    // as the types context doesn't matter to this component.
    // eslint-disable-next-line
    protected override entityService: ApolloFilterableOrderableService<any, any, Entity, any, Filter, any>,
    protected filterService: FilterService<Filter>,
    protected sortService: SortService,
    @Optional() protected chipsService?: FilterChipsService<Filter>
  ) {
    super(entityService);
  }

  override ngOnInit(): void {
    super.ngOnInit();
    this.filterLocalState$ = this.filterService.filterLocalState$;
    this.filterChips$ = this.chipsService?.chips$;
    this.filterService.filter$
      .pipe(shareReplay({ refCount: true }), takeUntil(this.destroy$))
      .subscribe((filter) => this.onFilterChange(filter));
    this.sort$ = this.sortService.sort$.pipe(takeUntil(this.destroy$), shareReplay({ refCount: true }));
    this.sort$.subscribe((sort) => this.onSortChange(sort));
  }

  onFilterChange(filter: Filter): void {
    this.entityService.update(filter, this.sortService.get());
  }

  onSortEvent(sort: SortEvent): void {
    this.sortService.update(sort);
  }

  onSortChange(sort: SortEvent): void {
    this.entityService.update(this.filterService.get(), sort);
  }

  onRemoveChip(chip: FilterChip): void {
    this.chipsService?.removeChip(chip);
  }

  onClearFilters(): void {
    this.filterService.clear();
  }

  onSubmitFilter(): void {
    this.filterService.submit();
  }
}
