import { Directive, EventEmitter, Input, Output } from '@angular/core';
import { FilterChip } from '@csirtmu-orion/microframework/filter';
import { SortEvent } from '@csirtmu-orion/microframework/sort-services';
import { EntityOverviewDirective } from './entity-overview.directive';

@Directive()
export abstract class EntityFilterableOverviewDirective<Entity, Filter> extends EntityOverviewDirective<Entity[]> {
  @Input() activeFilter?: Filter;
  @Input() filterChips?: FilterChip[];
  @Input() sort?: SortEvent;
  @Output() clearFilters: EventEmitter<void> = new EventEmitter<void>();
  @Output() submitClicked: EventEmitter<void> = new EventEmitter<void>();
  @Output() removeChip: EventEmitter<FilterChip> = new EventEmitter<FilterChip>();
  @Output() sortChange: EventEmitter<SortEvent> = new EventEmitter<SortEvent>();

  onClearFilters(): void {
    this.clearFilters.emit();
  }

  onSubmitFilter(): void {
    this.submitClicked.emit();
  }

  onRemoveChip(chip: FilterChip): void {
    this.removeChip.emit(chip);
  }

  onSortChange(sort: SortEvent): void {
    this.sortChange.emit(sort);
  }
}
