import { Directive, OnInit, Optional } from '@angular/core';
import { FilterChipsService, FilterService } from '@csirtmu-orion/microframework/filter-services';
import { ApolloFilterableService } from '@csirtmu-orion/microframework/apollo-services';
import { Observable } from 'rxjs';
import { shareReplay, takeUntil } from 'rxjs/operators';
import { EntitySmartOverviewDirective } from './entity-smart-overview.directive';
import { FilterChip } from '@csirtmu-orion/microframework/filter';

@Directive()
export abstract class EntityFilterableSmartOverviewDirective<Entity, Filter>
  extends EntitySmartOverviewDirective<Entity[]>
  implements OnInit
{
  filterLocalState$?: Observable<Filter>;
  filterChips$?: Observable<FilterChip[]>;

  protected constructor(
    // No point in introducing a generic for query, query variables, and api filter in this component
    // as the types context doesn't matter to this component.
    // eslint-disable-next-line
    protected override entityService: ApolloFilterableService<any, any, Entity, Filter, any>,
    protected filterService: FilterService<Filter>,
    @Optional() protected chipsService?: FilterChipsService<Filter>
  ) {
    super(entityService);
  }

  override ngOnInit(): void {
    super.ngOnInit();
    this.filterLocalState$ = this.filterService.filterLocalState$;
    this.filterChips$ = this.chipsService?.chips$;
    this.filterService.filter$
      .pipe(shareReplay({ refCount: true }), takeUntil(this.destroy$))
      .subscribe((filter) => this.onFilterChange(filter));
  }

  onFilterChange(filter: Filter): void {
    this.entityService.update(filter);
  }

  onRemoveChip(chip: FilterChip): void {
    this.chipsService?.removeChip(chip);
  }

  onClearFilters(): void {
    this.filterService.clear();
  }

  onSubmitFilter(): void {
    this.filterService.submit();
  }
}
