import { Directive, OnInit } from '@angular/core';
import { ApolloPaginatedBaseService } from '@csirtmu-orion/microframework/apollo-services';
import { PaginationService } from '@csirtmu-orion/microframework/pagination-services';
import { Optional } from '@sentinel/common/utils';
import { Observable } from 'rxjs';
import { map, shareReplay, takeUntil } from 'rxjs/operators';
import { EntitySmartOverviewDirective } from './entity-smart-overview.directive';
import { IPaginatedElements, IPaginationEvent } from '@sentinel/common/pagination';

@Directive()
export abstract class EntityPaginableSmartOverviewDirective<Entity>
  extends EntitySmartOverviewDirective<IPaginatedElements<Entity>>
  implements OnInit
{
  sort$?: Observable<Optional<string>>;
  sortDir$?: Observable<'desc' | 'asc'>;

  protected constructor(
    // No point in introducing a generic for query, query variables, and orderable in this component
    // as the types context doesn't matter to this component.
    // eslint-disable-next-line
    protected override entityService: ApolloPaginatedBaseService<any, any, Entity, any>,
    protected paginationService: PaginationService
  ) {
    super(entityService);
  }

  override ngOnInit(): void {
    super.ngOnInit();
    const pagination$ = this.paginationService.pagination$.pipe(
      takeUntil(this.destroy$),
      shareReplay({ refCount: true })
    );
    this.sort$ = pagination$.pipe(map((pagination) => pagination.sort));
    this.sortDir$ = pagination$.pipe(map((pagination) => (pagination.sortDir === 'asc' ? 'asc' : 'desc')));
    pagination$.subscribe((pagination) => this.onPaginationChange(pagination));
  }

  onPageEvent(pagination: IPaginationEvent): void {
    this.paginationService.update(pagination);
  }

  protected onPaginationChange(pagination: IPaginationEvent): void {
    this.entityService.update(pagination);
  }
}
