import { Directive, OnInit } from '@angular/core';
import { ApolloQueryService } from '@csirtmu-orion/microframework/apollo-services';
import { Destroyable } from '@sentinel/common';
import { combineLatest, defer, Observable, of } from 'rxjs';
import { map, startWith, takeWhile } from 'rxjs/operators';

@Directive()
export abstract class EntitySmartOverviewDirective<Entity> extends Destroyable() implements OnInit {
  isLoading$?: Observable<boolean>;
  initLoading$?: Observable<boolean>;
  hasError$?: Observable<boolean>;
  entities$?: Observable<Entity>;
  tryAgain$: Observable<void> = defer(() => this.onTryAgain());
  // No point in introducing a generic for query and query variables in this component
  // as the types context doesn't matter to this component.
  // eslint-disable-next-line
  protected constructor(protected entityService: ApolloQueryService<any, any, Entity>) {
    super();
  }

  ngOnInit(): void {
    this.entities$ = this.entityService.data$;
    this.isLoading$ = this.entityService.isLoading$;
    this.hasError$ = this.entityService.hasError$;
    const firstDataLoading$ = this.entityService.data$.pipe(
      takeWhile((data) => data === undefined, true),
      map((data) => data === undefined),
      startWith(true)
    );
    this.initLoading$ = combineLatest([firstDataLoading$, this.hasError$ ?? of(false)]).pipe(
      map(([loading, error]) => loading && !error)
    );
  }

  onTryAgain(): void {
    this.entityService.recoverAfterError();
  }
}
