import { Directive, EventEmitter, Input, OnChanges, Output, SimpleChanges } from '@angular/core';
import { SortEvent, trackByIdTableRow } from '@sentinel/components/table';
import { defer } from 'rxjs';

@Directive()
export abstract class EntityTableBaseDirective<InputData, TableData> implements OnChanges {
  @Input() entities?: InputData;
  @Input() initLoading = false;
  @Input() isLoading = false;
  @Input() hasError = false;
  @Input() sortAttr?: string;
  @Input() sortDir?: 'asc' | 'desc';
  @Input() selectable = false;
  @Output() tryAgain: EventEmitter<void> = new EventEmitter<void>();
  @Output() sortChange: EventEmitter<SortEvent> = new EventEmitter<SortEvent>();

  onTryAgain$ = defer(() => this.tryAgain.emit());
  trackByFn = trackByIdTableRow;
  tableData?: TableData;

  protected abstract createTable(entities: InputData): TableData;

  ngOnChanges(changes: SimpleChanges): void {
    if ('entities' in changes && this.entities) {
      this.tableData = this.createTable(this.entities);
    }
  }

  onSortChange(sort?: SortEvent): void {
    if (sort) {
      this.sortChange.emit(sort);
    }
  }
}
