import { Directive, EventEmitter, Output } from '@angular/core';
import { TableActionEvent, TableLoadEvent } from '@sentinel/components/table';
import { take } from 'rxjs/operators';
import { EntityTableBaseDirective } from './entity-table-base.directive';
import { IPaginatedElements, IPaginationEvent, isPaginatedElements } from '@sentinel/common/pagination';

@Directive()
export abstract class OptionallyPaginatedEntityTableDirective<InputData, TableData> extends EntityTableBaseDirective<
  IPaginatedElements<InputData> | InputData[],
  TableData
> {
  @Output() pageChange: EventEmitter<IPaginationEvent> = new EventEmitter<IPaginationEvent>();
  @Output() selectionChange: EventEmitter<InputData[]> = new EventEmitter<InputData[]>();

  onTableChange(event?: TableLoadEvent): void {
    if (this.entities && isPaginatedElements(this.entities)) {
      this.pageChange.emit(event?.pagination);
    } else {
      this.sortChange.emit(event?.sort);
    }
  }

  onRowAction(actionEvent: TableActionEvent<InputData>): void {
    actionEvent.action.result$.pipe(take(1)).subscribe();
  }

  onRowSelection(selection: InputData[]): void {
    this.selectionChange.emit(selection);
  }
}
