import { Directive, EventEmitter, Output } from '@angular/core';
import { TableActionEvent } from '@sentinel/components/table';
import { take } from 'rxjs/operators';
import { EntityTableBaseDirective } from './entity-table-base.directive';
import { IPaginatedElements, IPaginationEvent } from '@sentinel/common/pagination';

@Directive()
export abstract class PaginatedEntityTableDirective<Entity, TableData> extends EntityTableBaseDirective<
  IPaginatedElements<Entity>,
  TableData
> {
  @Output() pageChange: EventEmitter<IPaginationEvent> = new EventEmitter<IPaginationEvent>();
  @Output() selectionChange: EventEmitter<Entity[]> = new EventEmitter<Entity[]>();

  onPageChange(pagination?: IPaginationEvent): void {
    if (pagination) {
      this.pageChange.emit(pagination);
    }
  }

  onRowAction(actionEvent: TableActionEvent<Entity>): void {
    actionEvent.action.result$.pipe(take(1)).subscribe();
  }

  onRowSelection(selection: Entity[]): void {
    this.selectionChange.emit(selection);
  }
}
