# Orion Filter Services

Contains services for handling filters in your application.

- FilterService holds and updates current state of filter
- FilterChipsService creates chips based on the current state of filter
- QueryParamsFilterService creates filter from query params of current route. On filter update, it updates state of query params.

## Dependencies
```
"fast-deep-equal/es6": "^3.1.3"
```

## Examples

#### FilterService

```
@Injectable()
export class MyFilterService extends FilterService<MyFilter> {
  protected createEmptyFilter(): MyFilter {
    return { name: undefined, from: undefined, to: undefined };
  }
}
```

#### FilterChipsService

```
@Injectable()
export class MyFilterFilterChipsService extends FilterChipsService<MyFilter> {

  constructor(protected filterService: MyFilterFilterService) {
    super(filterService);
  }

  removeChip(removedChip: FilterChip): void {
    if (removedChip instanceof StringValueChip) {
      this.filterService.updateAndSubmit({ name: undefined });
    }
    if (removedChip instanceof DateValueChip && removedChip.direction === 'from') {
      this.filterService.updateAndSubmit({ from: undefined });
    }
    if (removedChip instanceof DateValueChip && removedChip.direction === 'to') {
      this.filterService.updateAndSubmit({ to: undefined });
    }
  }

  protected createChips(filter: MyFilter | undefined): FilterChip[] {
    if (filter === undefined || filter === this.filterService.EMPTY_FILTER) {
      return [];
    } else {
      const chips = [];
      if (filter?.name) {
        chips.push(new StringValueChip(filter?.name));
      }
      if (filter?.from) {
        chips.push(new DateValueChip(filter.from, 'from'));
      }
      if (filter?.to) {
        chips.push(new DateValueChip(filter.to, 'to'));
      }
      return chips;
    }
  }
}

```

#### QueryParamFilterService

```
@Injectable()
export class MyFilterFilterService extends QueryParamFilterService<MyFilter> {
  constructor(protected router: Router, protected activatedRoute: ActivatedRoute) {
    super(router, activatedRoute);
  }

  protected toQueryParams(filter: MyFilter): Params {
    const params = super.toQueryParams(filter);
    if (filter.from) {
      params.from = filter.from.valueOf();
    }
    if (filter.to) {
      params.to = filter.to.valueOf();
    }
    return params;
  }

  protected createEmptyFilter(): MyFilter {
    return { name: undefined, from: undefined, to: undefined };
  }

  protected createFilterFromRoute(queryParamMap: ParamMap, paramMap: ParamMap): Observable<MyFilter> {
    const name = this.deslugify(queryParamMap.get('name'));
    const from = this.deslugifyTimestamp(queryParamMap.get('from'));
    const to = this.deslugifyTimestamp(queryParamMap.get('to'));
    return of({ name, from, to });
  }
}
```
