import equal from 'fast-deep-equal/es6';
import { BehaviorSubject, Observable } from 'rxjs';
import { distinctUntilChanged, shareReplay, tap } from 'rxjs/operators';

export abstract class FilterService<Filter> {
  readonly EMPTY_FILTER: Filter;
  protected filterLocalStateSubject$: BehaviorSubject<Filter>;
  protected filterSubject$: BehaviorSubject<Filter>;
  filterLocalState$: Observable<Filter>;
  filter$: Observable<Filter>;

  protected constructor() {
    this.EMPTY_FILTER = this.createEmptyFilter();
    this.filterLocalStateSubject$ = new BehaviorSubject<Filter>(this.EMPTY_FILTER);
    this.filterSubject$ = new BehaviorSubject<Filter>(this.filterLocalStateSubject$.getValue());
    this.filterLocalState$ = this.filterLocalStateSubject$.asObservable();
    this.filter$ = this.filterSubject$.asObservable().pipe(
      distinctUntilChanged((prev, curr) => equal(prev, curr)),
      tap((filter) => this.filterLocalStateSubject$.next(filter), shareReplay({ refCount: true }))
    );
  }

  get(): Filter {
    return this.filterSubject$.getValue();
  }

  update(filter: Partial<Filter>): void {
    const curr = { ...this.filterLocalStateSubject$.getValue() };
    this.filterLocalStateSubject$.next({ ...curr, ...filter });
  }

  updateAndSubmit(filter: Partial<Filter>): void {
    this.update(filter);
    this.submit();
  }

  submit(): void {
    this.filterSubject$.next(this.filterLocalStateSubject$.getValue());
  }

  clear(): void {
    this.filterLocalStateSubject$.next({ ...this.EMPTY_FILTER });
    this.submit();
  }

  set(filter: Filter): void {
    this.filterLocalStateSubject$.next(filter);
  }

  protected abstract createEmptyFilter(): Filter;
}
