import { ChangeDetectionStrategy, Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { Destroyable } from '@sentinel/common';
import { Optional } from '@sentinel/common/utils';
import { Subject } from 'rxjs';
import { debounceTime, takeUntil } from 'rxjs/operators';

@Component({
  selector: 'orion-filter-free-input',
  templateUrl: './orion-filter-free-input.component.html',
  styleUrls: ['./orion-filter-free-input.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class OrionFilterFreeInputComponent extends Destroyable() implements OnInit {
  @Input() label?: string;
  @Input() placeholder?: string;
  @Input() value?: string;
  @Output() filterChange: EventEmitter<string> = new EventEmitter<string>();

  valueChangeObs$: Subject<Optional<string>> = new Subject<Optional<string>>();

  ngOnInit(): void {
    this.valueChangeObs$
      .pipe(debounceTime(300), takeUntil(this.destroy$))
      .subscribe((value) => this.filterChange.emit(value));
  }

  onValueChange(value?: string): void {
    this.valueChangeObs$.next(value);
  }
}
