import {
  ChangeDetectionStrategy,
  Component,
  EventEmitter,
  Inject,
  Input,
  OnChanges,
  Optional,
  Output,
  SimpleChanges,
} from '@angular/core';
import { SentinelControlItem } from '@sentinel/components/controls';
import { defer, of } from 'rxjs';
import { FilterChip } from '@csirtmu-orion/microframework/filter';
import { ORION_FILTER_PANEL_CONFIG, OrionFilterPanelConfig } from '@csirtmu-orion/microframework/config';

@Component({
  selector: 'orion-filter-panel',
  templateUrl: './orion-filter-panel.component.html',
  styleUrls: ['./orion-filter-panel.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class OrionFilterPanelComponent<Filter> implements OnChanges {
  @Input() defaultDescription?: string;
  @Input() activeFilter?: Filter;
  @Input() filterChips?: FilterChip[];
  @Input() expanded?: boolean;
  @Input() withSubmitButton: boolean;
  @Input() elevation = 8;
  @Output() clearFilters: EventEmitter<void> = new EventEmitter<void>();
  @Output() removeChip: EventEmitter<FilterChip> = new EventEmitter<FilterChip>();
  @Output() submitClicked: EventEmitter<void> = new EventEmitter<void>();
  controls: SentinelControlItem[] = [];

  private readonly SUBMIT_FILTERS_CONTROL_ITEM = new SentinelControlItem(
    'submitFilters',
    'Submit',
    'primary',
    of(false),
    defer(() => this.submitClicked.emit())
  );
  private readonly CLEAR_FILTERS_CONTROL_ITEM = new SentinelControlItem(
    'clearFilters',
    'Clear',
    'accent',
    of(false),
    defer(() => this.clearFilters.emit())
  );

  constructor(@Optional() @Inject(ORION_FILTER_PANEL_CONFIG) private readonly config?: OrionFilterPanelConfig | null) {
    if (config?.withSubmitButton === undefined) {
      this.withSubmitButton = true;
    } else {
      this.withSubmitButton = config.withSubmitButton;
    }
    this.createControls();
  }

  ngOnChanges(changes: SimpleChanges): void {
    if ('withSubmitButton' in changes && this.withSubmitButton !== undefined) {
      this.createControls();
    }
  }

  onChipRemoved(chip: FilterChip): void {
    this.removeChip.emit(chip);
  }

  private createControls(): void {
    if (this.withSubmitButton) {
      this.controls = [this.CLEAR_FILTERS_CONTROL_ITEM, this.SUBMIT_FILTERS_CONTROL_ITEM];
    } else {
      this.controls = [this.CLEAR_FILTERS_CONTROL_ITEM];
    }
  }
}
