import { CursorPaginatedResponse } from './paginated-response';
import { QueryCursorPaginationDataResolver } from './query-pagination-data-resolver';
import { QueryCursorPaginationData } from './query-pagination-data';

describe('DmtPaginationDataResolver', () => {
  it('should set query pagination data from dmt paginated response', () => {
    const prevCursorValue = 'testPrevCursor';
    const nextCursorValue = 'testNextCursor';
    const testData = ['hello', 'world'];
    const response: CursorPaginatedResponse<string> = {
      previous: prevCursorValue,
      next: nextCursorValue,
      data: testData,
      totalCount: testData.length,
    };
    const expected: QueryCursorPaginationData = {
      cursors: { prev: prevCursorValue, next: nextCursorValue },
      elementsCount: testData.length,
      totalCount: testData.length,
    };
    expect(QueryCursorPaginationDataResolver.resolve(response)).toEqual(expected);
  });

  it('should set query pagination data from empty dmt paginated response', () => {
    const response: CursorPaginatedResponse<string> = {
      previous: undefined,
      next: undefined,
      data: [],
      totalCount: undefined,
    };
    const expected: QueryCursorPaginationData = {
      cursors: { prev: undefined, next: undefined },
      elementsCount: 0,
      totalCount: 0,
    };
    expect(QueryCursorPaginationDataResolver.resolve(response)).toEqual(expected);
  });
});
