import { DefaultContext } from '@apollo/client/core/types';
import { HttpHeaders } from '@angular/common/http';

const ERROR_TITLE_ATTR = 'errorTitle';

export function createApolloContextErrorTitle(title: string): DefaultContext {
  return { [ERROR_TITLE_ATTR]: title };
}

export function retrieveApolloContextErrorTitle(context: DefaultContext): string {
  if (context[ERROR_TITLE_ATTR] !== undefined) {
    return context[ERROR_TITLE_ATTR];
  } else {
    return 'Unknown operation';
  }
}

export const RETRYABLE_ATTR = 'retryable';

export function createApolloContextRetryable(value: boolean): DefaultContext {
  return { [RETRYABLE_ATTR]: value };
}

export function retrieveApolloContextRetryable(context: DefaultContext): boolean {
  if (context[RETRYABLE_ATTR] !== undefined) {
    return context[RETRYABLE_ATTR];
  } else {
    return false;
  }
}

export function wrapApolloContextForFileUpload(currContext: DefaultContext): DefaultContext {
  currContext['useMultipart'] = true;
  if (currContext['headers']) {
    currContext['headers'] = currContext['headers'].append('Apollo-Require-Preflight', `true`);
  } else {
    currContext['headers'] = new HttpHeaders().set('Apollo-Require-Preflight', `true`);
  }
  return currContext;
}
