import { CursorPaginationResolver } from './pagination-resolver';
import { ICursorPaginationEvent, CursorPagination } from '@sentinel/common/pagination';
import { QueryCursorPaginationData } from './dmt/query-pagination-data';

describe('CursorPaginationResolver', () => {
  it('should resolve pagination with no curr, prev, next cursors', () => {
    const paginationData: QueryCursorPaginationData = {
      elementsCount: 5,
      totalCount: 5,
      cursors: { prev: undefined, next: undefined },
    };
    const event: ICursorPaginationEvent = { size: 10, sort: 'helloWorld', sortDir: 'asc', cursor: null };

    const expected = new CursorPagination(null, 5, 10, 5, null, null);
    const actual = CursorPaginationResolver.resolve(paginationData, event);

    expect(expected).toEqual(actual);
  });

  it('should resolve pagination with curr, prev, next cursors', () => {
    const paginationData: QueryCursorPaginationData = {
      elementsCount: 10,
      totalCount: 100,
      cursors: { prev: 'abc', next: 'xyz' },
    };
    const event: ICursorPaginationEvent = { size: 10, sort: 'helloWorld', sortDir: 'asc', cursor: '123' };

    const expected = new CursorPagination('123', 10, 10, 100, 'xyz', 'abc');
    const actual = CursorPaginationResolver.resolve(paginationData, event);

    expect(expected).toEqual(actual);
  });
});
