import {
  CursorPagination,
  ICursorPagination,
  ICursorPaginationEvent,
  IOffsetPagination,
  IOffsetPaginationEvent,
  OffsetPagination,
} from '@sentinel/common/pagination';
import { QueryCursorPaginationData, QueryOffsetPaginationData } from './dmt/query-pagination-data';

export class CursorPaginationResolver {
  static resolve(
    paginationData: QueryCursorPaginationData,
    paginationEvent: ICursorPaginationEvent
  ): ICursorPagination {
    return new CursorPagination(
      paginationEvent.cursor,
      paginationData.elementsCount,
      paginationEvent.size,
      paginationData.totalCount,
      paginationData.cursors.next ?? null,
      paginationData.cursors.prev ?? null
    );
  }
}

export class OffsetPaginationResolver {
  static resolve(
    paginationData: QueryOffsetPaginationData,
    paginationEvent: IOffsetPaginationEvent
  ): IOffsetPagination {
    return new OffsetPagination(
      paginationEvent.page,
      paginationData.elementsCount,
      paginationEvent.size,
      paginationData.totalCount,
      Math.floor(paginationData.totalCount / paginationEvent.size)
    );
  }
}
