import { ChangeDetectionStrategy, Component, Input, OnChanges, OnInit, SimpleChanges } from '@angular/core';
import { trackByIndex } from '@sentinel/common/utils';

@Component({
  selector: 'orion-table-skeleton',
  templateUrl: './orion-table-skeleton.component.html',
  styleUrls: ['./orion-table-skeleton.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class OrionTableSkeletonComponent implements OnInit, OnChanges {
  @Input() columnsCount = 5;
  @Input() rowsCount = 10;
  @Input() withPagination = false;
  @Input() withActions = false;

  trackByFn = trackByIndex;
  columnPlaceholders: number[] = [];
  rowPlaceholders: number[] = [];

  ngOnInit(): void {
    this.createColumnPlaceholders(this.columnsCount);
    this.createRowPlaceholders(this.rowsCount);
  }

  ngOnChanges(changes: SimpleChanges): void {
    if ('columnsCount' in changes && this.columnsCount) {
      this.createColumnPlaceholders(this.columnsCount);
    }
    if ('rowsCount' in changes && this.rowsCount) {
      this.createRowPlaceholders(this.rowsCount);
    }
  }

  private createColumnPlaceholders(count: number): void {
    this.columnPlaceholders = [...Array(count).keys()];
  }

  private createRowPlaceholders(count: number) {
    this.rowPlaceholders = [...Array(count + 1).keys()];
  }
}
