import {
  AfterViewInit,
  ChangeDetectionStrategy,
  Component,
  ElementRef,
  EventEmitter,
  Input,
  Output,
  ViewChild,
} from '@angular/core';
import { Destroyable } from '@sentinel/common';
import { fromEvent, merge } from 'rxjs';
import { debounceTime, takeUntil } from 'rxjs/operators';
import { TreeNode } from '../tree-node';

@Component({
  selector: 'orion-default-tree-node',
  templateUrl: './default-tree-node.component.html',
  styleUrls: ['./default-tree-node.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class DefaultTreeNodeComponent<T> extends Destroyable() implements AfterViewInit {
  @Input() node?: TreeNode<T>;
  @Input() selectable = true;
  @Output() selected: EventEmitter<TreeNode<T>> = new EventEmitter<TreeNode<T>>();
  @ViewChild('nodeElement', { static: true }) nodeElement?: ElementRef;

  ngAfterViewInit(): void {
    if (this.nodeElement !== undefined && this.nodeElement.nativeElement !== undefined) {
      this.handleClickAndDoubleClick(this.nodeElement.nativeElement);
    }
  }

  handleClickAndDoubleClick(el: HTMLDivElement): void {
    const clickEvent = fromEvent<MouseEvent>(el, 'click');
    const dblClickEvent = fromEvent<MouseEvent>(el, 'dblclick');
    const eventsMerged = merge(clickEvent, dblClickEvent).pipe(debounceTime(300), takeUntil(this.destroy$));
    eventsMerged.subscribe((event) => this.onMouseEvent(event));
  }

  private onMouseEvent(event: MouseEvent): void {
    if (event.type === 'click' && this.canBeSelected()) {
      this.selected.emit(this.node);
    }
  }

  private canBeSelected(): boolean {
    return this.node !== undefined && !this.node.disabled && this.selectable;
  }
}
