import { ChangeDetectionStrategy, Component, ContentChild, EventEmitter, Input, Output } from '@angular/core';
import { defer } from 'rxjs';
import { OrionNestedTreeControl } from './orion-nested-tree-control';
import { OrionNestedTreeDataSource } from './orion-nested-tree-data-source';
import { OrionTreeNodeDirective } from './orion-tree-node.directive';
import { TreeNode } from './tree-node';

@Component({
  selector: 'orion-nested-tree',
  templateUrl: './orion-nested-tree.component.html',
  styleUrls: ['./orion-nested-tree.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class OrionNestedTreeComponent<NodeData, NodeDataId = NodeData> {
  @Input() treeControl?: OrionNestedTreeControl<NodeData, NodeDataId>;
  @Input() dataSource?: OrionNestedTreeDataSource<NodeData, NodeDataId>;
  @Input() selectable = false;
  @Output() selected: EventEmitter<TreeNode<NodeData>> = new EventEmitter<TreeNode<NodeData>>();
  @ContentChild(OrionTreeNodeDirective) nodeDirective?: OrionTreeNodeDirective;

  private lastExpandedNode?: TreeNode<NodeData>;
  private lastLoadMoreNode?: TreeNode<NodeData>;
  private lastSelected?: TreeNode<NodeData>;
  tryAgainRoots$ = defer(() => this.loadMoreRoots());
  tryAgainExpand$ = defer(() => this.treeControl?.loadChildren$.next(this.lastExpandedNode));
  tryAgainLoadMoreChildren$ = defer(() => this.treeControl?.loadMoreChildren$.next(this.lastLoadMoreNode));

  hasChild = (index: number, node: TreeNode<NodeData>): boolean => node.isExpandable;

  toggle(node: TreeNode<NodeData>, origin: 'click' | 'dblclick' | 'expand'): void {
    if (this.shouldToggle(node, origin)) {
      if (!this.treeControl?.isExpanded(node)) {
        this.treeControl?.toggle(node);
        this.lastExpandedNode = node;
      } else {
        this.treeControl?.toggle(node);
      }
    }
  }

  loadModeChildren(node: TreeNode<NodeData>): void {
    this.lastLoadMoreNode = node;
    this.treeControl?.loadMoreChildren(node);
  }

  loadMoreRoots(): void {
    this.treeControl?.loadMoreRoots();
  }

  onSelect(node: TreeNode<NodeData>): void {
    if (this.selectable) {
      if (this.lastSelected !== undefined) {
        this.lastSelected.setIsSelected(false);
      }
      node.setIsSelected(true);
      this.lastSelected = node;
      this.selected.emit(node);
    }
  }

  private shouldToggle(node: TreeNode<NodeData>, origin: 'click' | 'dblclick' | 'expand'): boolean {
    return !node.disabled && !(origin === 'click' && this.selectable) && !(origin === 'dblclick' && !this.selectable);
  }
}
