import { BehaviorSubject, Observable } from 'rxjs';

export class TreeNode<NodeData> {
  data: NodeData;
  title?: string;
  icon?: string;
  isExpandable = false;
  hasMoreChildren = false;
  isLoading = false;
  disabled = false;
  isLast = false;
  isRoot = false;

  private isSelectedSubject$: BehaviorSubject<boolean> = new BehaviorSubject<boolean>(false);
  isSelected$: Observable<boolean> = this.isSelectedSubject$.asObservable();

  private expandNodeHasErrorSubject$: BehaviorSubject<boolean> = new BehaviorSubject<boolean>(false);
  expandNodeHasError$: Observable<boolean> = this.expandNodeHasErrorSubject$.asObservable();

  private loadMoreHasErrorSubject$: BehaviorSubject<boolean> = new BehaviorSubject<boolean>(false);
  loadMoreHasError$: Observable<boolean> = this.loadMoreHasErrorSubject$.asObservable();

  private childrenSubject$: BehaviorSubject<TreeNode<NodeData>[]> = new BehaviorSubject<TreeNode<NodeData>[]>([]);

  children$: Observable<TreeNode<NodeData>[]> = this.childrenSubject$.asObservable();

  protected constructor(data: NodeData) {
    this.data = data;
  }

  toggleLoading(): void {
    this.isLoading = !this.isLoading;
    this.disabled = this.isLoading;
  }

  setExpandError(value: boolean): void {
    this.expandNodeHasErrorSubject$.next(value);
    this.disabled = value;
  }

  setLoadMoreError(value: boolean): void {
    this.loadMoreHasErrorSubject$.next(value);
  }

  setIsSelected(value: boolean): void {
    this.isSelectedSubject$.next(value);
  }

  getChildrenCount(): number {
    return this.childrenSubject$.getValue().length;
  }

  setChildren(value: TreeNode<NodeData>[]): void {
    this.childrenSubject$.next(value);
  }

  appendChildren(value: TreeNode<NodeData>[]): void {
    const curr = this.childrenSubject$.getValue();
    curr.push(...value);
    this.childrenSubject$.next(curr);
  }
}
