import { OffsetPaginationResolver } from './offset-pagination-resolver';
import { OffsetPagination, IOffsetPaginationEvent } from '@sentinel/common/pagination';
import { QueryOffsetPaginationData } from '../../graphql/src/api/dmt/query-pagination-data';

describe('OffsetPaginationResolver', () => {
  it('should resolve pagination', () => {
    const paginationData: QueryOffsetPaginationData = {
      elementsCount: 10,
      totalCount: 100,
    };
    const event: IOffsetPaginationEvent = { page: 2, size: 10, sort: 'helloWorld', sortDir: 'asc' };

    const expected = new OffsetPagination(2, 10, 10, 100, 10);
    const actual = OffsetPaginationResolver.resolve(paginationData, event);

    expect(expected).toEqual(actual);
  });

  it('should resolve pagination if there are no elements', () => {
    const paginationData: QueryOffsetPaginationData = {
      elementsCount: 0,
      totalCount: 0,
    };
    const event: IOffsetPaginationEvent = { page: 2, size: 10, sort: 'helloWorld', sortDir: 'asc' };

    const expected = new OffsetPagination(2, 0, 10, 0, 0);
    const actual = OffsetPaginationResolver.resolve(paginationData, event);

    expect(expected).toEqual(actual);
  });
});
