import { ChangeDetectionStrategy, Component, ContentChild, Inject, Input, Optional } from '@angular/core';
import { SentinelControlItem } from '@sentinel/components/controls';
import { take } from 'rxjs/operators';
import { OrionPanelDirective } from './orion-panel.directive';
import { OrionPanelContentDirective } from './orion-panel-content.directive';
import { ORION_PANEL_CONFIG, OrionPanelConfig } from '@csirtmu-orion/microframework/config';

@Component({
  selector: 'orion-panel',
  templateUrl: './orion-panel.component.html',
  styleUrls: ['./orion-panel.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class OrionPanelComponent extends OrionPanelDirective {
  @Input() isExpanded: boolean;
  @Input() maxControlsCount?: number;
  @Input() controls?: SentinelControlItem[];
  @Input() isLoading = false;
  @Input() elevation: number;

  readonly elevationClassPrefix = 'mat-elevation-z';

  @ContentChild(OrionPanelContentDirective) panelContent?: OrionPanelContentDirective;

  constructor(@Optional() @Inject(ORION_PANEL_CONFIG) private readonly config?: OrionPanelConfig | null) {
    super();
    if (config?.elevation === undefined) {
      this.elevation = 8;
    } else {
      this.elevation = config.elevation;
    }
    if (config?.isExpanded === undefined) {
      this.isExpanded = false;
    } else {
      this.isExpanded = config.isExpanded;
    }
  }

  onControlItemClicked(item: SentinelControlItem): void {
    item.result$?.pipe(take(1)).subscribe();
    this.handleActionSelected();
  }
}
