import { TestBed, waitForAsync } from '@angular/core/testing';
import { skip, take } from 'rxjs/operators';
import { INIT_SORT_TOKEN } from './order-token';
import { SortService } from './sort.service';
import { SortEvent } from './sort-event';

describe('SortService', () => {
  let service: SortService;
  let initSort: SortEvent | undefined = undefined;

  beforeEach(waitForAsync(() => {
    TestBed.configureTestingModule({
      providers: [
        SortService,
        {
          provide: INIT_SORT_TOKEN,
          useValue: initSort,
        },
      ],
    });
    service = TestBed.inject(SortService);
  }));

  describe('With default configuration', () => {
    it('should create', () => {
      expect(service).toBeTruthy();
    });

    it('should only emit if updated sort is different from prev', (done) => {
      const sort1: SortEvent = { sort: 'sort1', sortDir: 'asc' };
      const sort2: SortEvent = { sort: 'sort2', sortDir: 'asc' };
      const expectedSorts: SortEvent[] = [sort1, sort2];

      const expectedSortsCount = expectedSorts.length;
      let resultIndex = 0;
      service.sort$.pipe(skip(1), take(expectedSortsCount)).subscribe({
        next: (sort) => {
          expect(sort).toEqual(expectedSorts[resultIndex]);
          resultIndex++;
          if (resultIndex === expectedSortsCount) {
            done();
          }
        },
        error: () => fail(),
      });
      service.update(sort1);
      service.update(sort1);
      service.update(sort2);
    });
  });

  describe('With init sort token', () => {
    const INIT_SORT = 'myInitSort';
    const INIT_SORT_DIR = 'asc';

    beforeAll(() => {
      initSort = { sort: INIT_SORT, sortDir: INIT_SORT_DIR };
    });

    it('should create', () => {
      expect(service).toBeTruthy();
    });

    it('should init with sort from token', (done) => {
      const expected: SortEvent = { sort: INIT_SORT, sortDir: INIT_SORT_DIR };
      service.sort$.pipe(take(1)).subscribe({
        next: (sort) => {
          expect(sort).toEqual(expected);
          done();
        },
        error: () => fail(),
      });
    });
  });
});
