import { Inject, Injectable, Optional } from '@angular/core';
import equal from 'fast-deep-equal/es6';
import { BehaviorSubject, Observable } from 'rxjs';
import { distinctUntilChanged, shareReplay } from 'rxjs/operators';
import { INIT_SORT_TOKEN } from './order-token';
import { SortEvent } from './sort-event';

@Injectable()
export class SortService {
  readonly INIT_SORT: SortEvent;
  protected sortSubject$: BehaviorSubject<SortEvent>;
  sort$: Observable<SortEvent>;

  constructor(@Optional() @Inject(INIT_SORT_TOKEN) protected readonly initSort?: SortEvent) {
    this.INIT_SORT = initSort ? initSort : { sort: undefined, sortDir: undefined };
    this.sortSubject$ = new BehaviorSubject<SortEvent>(this.INIT_SORT);

    this.sort$ = this.sortSubject$.asObservable().pipe(
      distinctUntilChanged((prev, curr) => equal(prev, curr)),
      shareReplay({ refCount: true })
    );
  }

  get(): SortEvent {
    return this.sortSubject$.getValue();
  }

  update(sort: SortEvent) {
    this.sortSubject$.next({ ...sort });
  }
}
