# Orion Tab Component

Orion Tab Component is collection of components, services, and directives for displaying tabs.

## Features

- Displays tabs
- Customizable tab label and icon
- Lazy loaded tab content through template projection
- Optional service, that stores active tab in query params of current route and on page refresh, retrieves and displays active tab
- Component and service communication is handled by extending `EntityDetailTabsDirective` from

## Usage

To use in your application:

1. In your module, import `OrionTabsModule`
2. In your component providers
```
@Component({
  selector: 'orion-example-component',
  templateUrl: './orion-example-component.html',
  styleUrls: ['./orion-example-component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [
    { provide: OrionTabService, useClass: OrionQueryParamTabService },
    { provide: TABS_TOKEN, useValue: ['tab_a, 'tab_b', 'tab_c'] },
  ],
})
export class OrionExampleComponent extends EntityDetailTabsDirective<MyFragment> {
```
3. In your component's template
```
<orion-tabs>
  <ng-template #tabALabelTemplate [orionTabLabel]="'tab_a'" [orionTabLabelTemplate]="tabALabelTemplate">
    <span>Tab A</span>
  </ng-template>
  <ng-template
    #tabAContentTemplate
    [orionTabContent]="'tab_a'"
    [orionTabContentTemplate]="tabAContentTemplate"
  >
    ...
  </ng-template>
  <ng-template #tabBLabelTemplate [orionTabLabel]="'tab_b'" [orionTabLabelTemplate]="tabBLabelTemplate">
    <span>Tab B</span>
  </ng-template>
  <ng-template
    #tabBContentTemplate
    [orionTabContent]="'tab_b'"
    [orionTabContentTemplate]="tabBContentTemplate"
  >
    ...
  </ng-template>
  <ng-template #tabCLabelTemplate [orionTabLabel]="'tab_c'" [orionTabLabelTemplate]="tabCLabelTemplate">
    <span>Tab C</span>
  </ng-template>
  <ng-template
    #tabCContentTemplate
    [orionTabContent]="'tab_c'"
    [orionTabContentTemplate]="tabCContentTemplate"
  >
    ...
  </ng-template>
</orion-tabs>
```
