import { Directive, Input, OnChanges, SimpleChanges } from '@angular/core';
import { Identifiable } from '@sentinel/common/entity';
import { take } from 'rxjs/operators';
import { OrionTabService } from '../services/orion-tab.service';

@Directive()
export abstract class EntityDetailTabsDirective<Entity extends Identifiable> implements OnChanges {
  @Input() entity?: Entity;

  protected constructor(protected tabService: OrionTabService) {}

  ngOnChanges(changes: SimpleChanges): void {
    if ('entity' in changes && changes['entity'].previousValue !== null && this.isDifferentEntity(changes)) {
      this.tabService.reset().pipe(take(1)).subscribe();
    }
  }

  private isDifferentEntity(changes: SimpleChanges): boolean {
    return (
      this.entity !== undefined &&
      changes['entity']?.previousValue?.id !== undefined &&
      this.entity.id !== changes['entity'].previousValue.id
    );
  }
}
