import { AfterContentInit, ChangeDetectionStrategy, Component, ContentChildren, QueryList } from '@angular/core';
import { OrionTabService } from '../services/orion-tab.service';
import { Observable } from 'rxjs';
import { take } from 'rxjs/operators';
import { ProjectedTabLabels } from './projected-tab-labels';
import { ProjectedTabs } from './projected-tabs';
import { TabContentDirective } from './tab-content.directive';
import { TabLabelDirective } from './tab-label.directive';

@Component({
  selector: 'orion-tabs',
  templateUrl: './orion-tabs.component.html',
  styleUrls: ['./orion-tabs.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class OrionTabsComponent implements AfterContentInit {
  selectedTabIndex$: Observable<number>;
  tabs: string[];
  projectedTabs?: ProjectedTabs;
  projectedLabels?: ProjectedTabLabels;
  @ContentChildren(TabContentDirective) tabContentDirectives?: QueryList<TabContentDirective>;
  @ContentChildren(TabLabelDirective) tabLabelDirectives?: QueryList<TabLabelDirective>;

  constructor(private tabsService: OrionTabService) {
    this.selectedTabIndex$ = this.tabsService.selectedIndex$;
    this.tabs = tabsService.tabs ?? [];
  }

  ngAfterContentInit(): void {
    this.createProjectedTabs();
    this.createProjectedLabels();
  }

  onTabSelected(index: number): void {
    this.tabsService.select(index).pipe(take(1)).subscribe();
  }

  private createProjectedTabs(): void {
    if (this.tabContentDirectives) {
      const tabs: ProjectedTabs = {};
      this.tabContentDirectives.forEach((directive) => {
        if (directive.tabId) {
          if (!this.tabs.includes(directive.tabId)) {
            console.error('No matching tab id for *orionTabContent');
          }
          if (tabs[directive.tabId]) {
            console.error('*orionTabContent id must be unique');
          } else {
            tabs[directive.tabId] = directive;
          }
        }
      });
      this.projectedTabs = tabs;
    }
  }

  private createProjectedLabels(): void {
    if (this.tabLabelDirectives) {
      const labels: ProjectedTabLabels = {};
      this.tabLabelDirectives.forEach((directive) => {
        if (directive.tabId) {
          if (!this.tabs.includes(directive.tabId)) {
            console.error('No matching tab id for *orionTabLabel');
          }
          if (labels[directive.tabId]) {
            console.error('*orionTabLabel id must be unique');
          } else {
            labels[directive.tabId] = directive;
          }
        }
      });
      this.projectedLabels = labels;
    }
  }
}
