import { Injectable } from '@angular/core';
import { BehaviorSubject, Observable } from 'rxjs';

@Injectable()
export class FilesService {
  protected filesToUploadSubject$: BehaviorSubject<File[]> = new BehaviorSubject<File[]>([]);
  filesToUpload$: Observable<File[]> = this.filesToUploadSubject$.asObservable();

  getCurrFiles(): File[] {
    return this.filesToUploadSubject$.getValue();
  }

  addFiles(files: File[]): void {
    const currFiles = this.filesToUploadSubject$.getValue();
    const mergedFiles = [...currFiles, ...files];
    // there are multiple sources of file selection, so we need to have uniqueness check here
    const uniqueFiles = [...new Map(mergedFiles.map((file) => [file.name, file])).values()];
    this.filesToUploadSubject$.next(uniqueFiles);
  }

  removeFile(fileIndex: number): void {
    const files = this.filesToUploadSubject$.getValue();
    files.splice(fileIndex, 1);
    this.filesToUploadSubject$.next(files);
  }

  clearFiles(): void {
    this.filesToUploadSubject$.next([]);
  }
}
