import { ApolloQueryResult } from '@apollo/client/core';
import { WatchQueryFetchPolicy } from '@apollo/client/core/watchQueryOptions';
import * as Apollo from 'apollo-angular';
import { QueryRef } from 'apollo-angular';
import { BehaviorSubject, Observable, Subject } from 'rxjs';
export interface ApolloQueryServiceOptions {
    fetchPolicy?: WatchQueryFetchPolicy;
    pollInterval?: number;
    retryable?: boolean;
}
export declare abstract class ApolloQueryService<Query, QueryVariables, Data> {
    getQuery: Apollo.Query<Query, QueryVariables>;
    queryRef?: QueryRef<Query, QueryVariables>;
    operationName: string;
    data$: Observable<Data>;
    isLoading$: Observable<boolean>;
    isRefetching$: Observable<boolean>;
    hasError$?: Observable<boolean>;
    protected loadingInternal$?: Observable<boolean>;
    protected hasErrorInternal$?: Observable<boolean>;
    protected isLoadingSubject$: Subject<boolean>;
    protected variables?: QueryVariables;
    protected initialized$: BehaviorSubject<boolean>;
    private isInErrorState;
    private options;
    protected abstract toData(queryRes: ApolloQueryResult<Query>): Data;
    protected constructor(getQuery: Apollo.Query<Query, QueryVariables>, operationName: string, options?: ApolloQueryServiceOptions);
    recoverAfterError(): void;
    protected abstract createVariables(...args: unknown[]): QueryVariables;
    protected updateVariables(...args: unknown[]): void;
    protected initialize(): void;
    protected initQueryWatch(): void;
    protected updateQuery(): void;
    protected initLoading(): void;
    protected initHasError(): void;
    protected checkAndHandleQueryError(queryRes: ApolloQueryResult<Query>): void;
    protected hasError(queryRes: ApolloQueryResult<Query>): boolean;
}
