import { ActivatedRouteSnapshot } from '@angular/router';
import { SentinelBreadcrumb } from './breadcrumb';
/**
 * @dynamic
 *  Creates and displays breadcrumbs from static or dynamic (resolve) route data.
 *  Breadcrumb data must be of type string.
 *  Two sequential breadcrumbs with same labels are ignored
 *  Ignores all non-primary router outlets
 *
 *  EXAMPLE OF STATIC DATA:
 *  {
 *   path:
 *   loadChildren:
 *   data: { breadcrumb: 'Home' }
 *  },
 *
 * EXAMPLE OF DYNAMIC DATA:
 *  {
 *   path:
 *   loadChildren:
 *   resolve: { breadcrumb: MyBreadcrumbResolver }
 *  },
 */
export declare class SentinelBreadcrumbBuilder {
    private static selector;
    /**
     * Builds ordered list of breadcrumbs from data retrieved from router's activated route
     * @param activeRoute router active route
     * @param selector optional, name of the attribute provided in Angular Route Data storing
     * the name of the breadcrumb. 'breadcrumb' is used if not provided
     * @param startWithHome if true add Home breadcrumb which navigates to root url at the
     * start of the breadcrumbs array
     */
    static build(activeRoute: ActivatedRouteSnapshot, selector?: string, startWithHome?: boolean): SentinelBreadcrumb[];
    private static createSegmentUrl;
    private static hasChildren;
    private static isDistinctFromLastOne;
    private static createBreadcrumb;
    private static createFromStaticData;
    private static hasBreadcrumbData;
    private static isPrimaryOutlet;
    private static createFromDynamicData;
}
