import { OnDestroy, OnInit } from '@angular/core';
import { MatDialog, MatDialogRef } from '@angular/material/dialog';
import { Observable } from 'rxjs';
import { BugReportCreateDateAndBlob } from './bug-report-create-date-and-blob';
import { UploadedFile } from '../../model/uploaded-file';
import { DialogData } from '../../model/bug-report-dialog-data.component';
import { FileHandleService } from '../../service/file-handle.service';
import { FileUpload } from '../../model/file-upload';
import { CanvasService } from '../../service/shared/canvas.service';
import { trackByIndex } from '@sentinel/common/utils';
import * as i0 from "@angular/core";
export declare class BugReportDialogComponent implements OnInit, OnDestroy {
    private bugReportCreateDateAndBlob;
    private canvasService;
    fileHandleService: FileHandleService;
    dialogRef: MatDialogRef<BugReportDialogComponent>;
    screenshotDialog: MatDialog;
    data: DialogData;
    sending: boolean;
    showError: boolean;
    errorMessage: string;
    uploadedScreenshot: UploadedFile[];
    canvasClone: HTMLCanvasElement;
    isScreenshotPresent: boolean;
    markdownData: string;
    fileUpload$: Observable<FileUpload>;
    trackByFn: typeof trackByIndex;
    private issueSubscription;
    private screenshotConversionSubject;
    screenshotConversion$: Observable<Blob>;
    constructor(bugReportCreateDateAndBlob: BugReportCreateDateAndBlob, canvasService: CanvasService, fileHandleService: FileHandleService, dialogRef: MatDialogRef<BugReportDialogComponent>, screenshotDialog: MatDialog, data: DialogData);
    onClose(): void;
    ngOnInit(): void;
    ngOnDestroy(): void;
    contentChange(event: any): void;
    openScreenshotDialog(): void;
    stopUploading(): void;
    /**
     * Uploaded file from dialogs loads file to inner attribute and sets name to label in dialogs
     * with selected file name
     * @param event contains file selected by user
     */
    onFileUpload(event: any): void;
    onFileDelete(id: number): void;
    /**
     * Create template of issue which will be present on gitlab
     */
    createIssueTemplate(dateTime: string, uploadedImageMarkdown?: any): string;
    /**
     * Creates issue with given information and screenshot which is already uploaded at gitlab
     * @param dateTime date of event
     * @param uploadedImageMarkdown screenshot in markdown from response-> can be used straightaway in issue
     */
    createIssue(dateTime: string, uploadedImageMarkdown?: any): Observable<any>;
    /**
     * Submit pressed in root dialogs + call upload and create issue from service and try to create issue
     * for given bug report. If user uploaded or modified screenshot it needs to be converted to blob
     * before uploading. At last, screenshot has to be uploaded before issue can be created.
     */
    onSubmit(): void;
    resetFileInput(event: any): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<BugReportDialogComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<BugReportDialogComponent, "sentinel-bug-report-dialog", never, {}, {}, never, never, false>;
}
