import { Observable, Subject } from 'rxjs';
import { HttpClient } from '@angular/common/http';
import { BugReportIssueInstance } from '../model/bug-report-issue-instance';
import { ContextService } from '../config/context.service';
import { SentinelBugReportEventsService } from './sentinel-bug-report-event.service';
import * as i0 from "@angular/core";
export declare class GitlabApiService {
    private eventReportService;
    private configs;
    private http;
    protected ngUnsubscribe: Subject<void>;
    constructor(eventReportService: SentinelBugReportEventsService, configs: ContextService, http: HttpClient);
    /**
     * Sends post request to gitlab serve and creates new issues under repository from config
     * @param issueData represents class that contains data needed for creating issue
     */
    createIssue(issueData: BugReportIssueInstance): Observable<any>;
    /**
     * Uploads screenshot to gitlab and returns its link for further usage in issue completion
     * @param fileBlob screenshot in blob format
     * @param file screenshot created/uploaded by user
     */
    uploadScreenshot(fileBlob: Blob, file?: File | HTMLCanvasElement): Observable<string>;
    cancelUpload(): void;
    /**
     * Creates default headers for http communication
     */
    private createDefaultHeaders;
    /**
     * Creates http parameters for issue post request with required params
     * @param issueData object with Title of issue and description + data collected about user
     */
    private createIssueParams;
    static ɵfac: i0.ɵɵFactoryDeclaration<GitlabApiService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<GitlabApiService>;
}
