import { EventEmitter } from '@angular/core';
import { SentinelBreadcrumb } from '@sentinel/layout/breadcrumbs';
import { SentinelNotification } from '@sentinel/layout/notification';
import { SentinelUser } from '@sentinel/layout';
import * as i0 from "@angular/core";
/**
 * Toolbar component with two rows
 */
export declare class ToolbarComponent {
    /**
     * Decides whether to display two lined toolbar with breadcrumbs or not
     */
    withBreadcrumbs?: boolean;
    breadcrumbMaxLength: number;
    /**
     * Breadcrumbs to be displayed in toolbar
     */
    breadcrumbs: SentinelBreadcrumb[];
    /**
     * User to be displayed in user menu. If not provided, user menu is not displayed
     */
    user: SentinelUser;
    /**
     * Optional route to user profile component
     */
    userProfileRoute?: string;
    /**
     * True if should display toggle for sidenav, false otherwise
     */
    displayNavToggle: boolean;
    /**
     * An array of notifications to display in notification menu
     */
    notifications: SentinelNotification[];
    /**
     * Last emitted notification
     */
    lastNotification: SentinelNotification;
    /**
     * Route to notification overview component page
     */
    notificationsRoute: string;
    /**
     * Character(s) dividing individual breadcrumbs
     */
    breadcrumbsDivider?: string;
    /**
     * Emits event when hamburger menu toggle is clicked
     */
    navToggle: EventEmitter<void>;
    /**
     * Emits event when refresh of notifications is requested
     */
    refreshNotifications: EventEmitter<void>;
    /**
     * Emits event when login is requested
     */
    login: EventEmitter<void>;
    /**
     * Emits event when logout is requested
     */
    logout: EventEmitter<void>;
    /**
     * Emits event when hamburger menu toggle is clicked
     */
    onNavToggle(): void;
    /**
     * Emits event when login is requested
     */
    onLogin(): void;
    /**
     * Emits event when logout is requested
     */
    onLogout(): void;
    onRefreshNotifications(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ToolbarComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ToolbarComponent, "sentinel-toolbar", never, { "withBreadcrumbs": "withBreadcrumbs"; "breadcrumbMaxLength": "breadcrumbMaxLength"; "breadcrumbs": "breadcrumbs"; "user": "user"; "userProfileRoute": "userProfileRoute"; "displayNavToggle": "displayNavToggle"; "notifications": "notifications"; "lastNotification": "lastNotification"; "notificationsRoute": "notificationsRoute"; "breadcrumbsDivider": "breadcrumbsDivider"; }, { "navToggle": "navToggle"; "refreshNotifications": "refreshNotifications"; "login": "login"; "logout": "logout"; }, never, ["*"], false>;
}
