# Sentinel Controls Component

Sentinel Controls is a component for creating uniform control rows like this

![controls](/uploads/d2fe8de7a62a240b6ec44164c5ec3908/controls.png)

On the picture below, you can see expandable control item, regular control item, and disabled control item.

## Features

- Regular control items
- Expandable control items
- Controlling disabled/enabled state by Observable
- Passing the result action triggered on click by Observable
- Customization of color of the control item

## Usage

To use in your application:

2. In your module, import `SentinelControlsModule`
3. In your component

```
@Component({
  ...
})
export class ExampleComponent implement OnInit {
    controls: SentinelControlItem[] = [];
    saveDisabled$: Observable<boolean>;

    constructor(private saveService: SaveService) {

    }

    ngOnInit() {
        this.controls = [
            new SentinelControlItem('UNIQUE ID', 'Save', 'primary', saveDisabled$, defer(() => saveService.save()))
        ]
  }

    onControlsAction(control: SentinelControlItem) {
        control.result$.pipe(take(1)).subscribe();
  }
}
```

4. In your component's template

```
<sentinel-controls
  [controls]="controls"
  (itemClicked)="onControlsAction($event)">
</sentinel-controls>
```

## Configuration

You can provide global configuration of `SentinelControlsComponent` by providing config through Angular DI.

For example:
```
providers: [
  { 
    provide: SENTINEL_CONTROLS_CONFIG, 
    useValue: { buttonStyle: 'stroked', maxItemsCount: 1, align: 'left' }
  }
],
```

The config can always be overriden by configuring the component directly through `
@Input()` parameters
