import { InjectionToken, Provider } from '@angular/core';
import { SentinelConfig } from './sentinel-config';
/**
 * Injection token of the application's dynamic config. Can be useful for dynamic injection into other modules
 * Use as dependency for providing a config through injections token and configurableModuleFactory.
 */
export declare const APP_CONFIG: InjectionToken<any>;
/**
 * App config provider. Provides dynamic config at runtime using a factory function.
 * USAGE EXAMPLE:
 *  @NgModule({
 *     declarations: [AppComponent],
 *     imports: [BrowserModule,],
 *     providers: [appConfigProvider]
 *     bootstrap: [AppComponent]
 *   })
 *  export class AppModule {}
 */
export declare const appConfigProvider: Provider;
/**
 * Allows access to parts of a config dynamically, at runtime.
 * USAGE EXAMPLE:
 *  @NgModule({
 *   imports: [CommonModule, SentinelAuthModule.forRoot(null)],
 *   providers: [
 *     {
 *       provide: SentinelAuthConfig,
 *       useFactory: configurableModuleFactory<KypoConfig>('authConfig'),
 *       deps: [APP_CONFIG],
 *     },
 *   ],
 * })
 *  export class AuthModule {}
 */
export declare const configurableModuleFactory: typeof configurableModuleFactoryFunc;
declare function configurableModuleFactoryFunc<T extends SentinelConfig>(prop: string): (sentinelConfig: T) => any;
export {};
