import { SentinelConfig } from './sentinel-config';
/**
 * Replacement of Angular's environment constants. This environment supports populating its properties at the run-time
 * loaded from an external file, thus supporting a build once deploy many approach in Angular.
 * RECOMMENDED USAGE:
 * Wrap this class with custom class to avoid the need for providing type with each call to getConfig method.
 * For example:
 * export class MyDynamicEnvironment {
 *   public static getConfig(): MyCustomConfig {
 *     return DynamicEnvironment.getConfig<MyCustomConfig>();
 *   }
 * }
 *
 * Then access the config from application's code like:
 *
 * const config: MyCustomConfig = MyDynamicEnvironment.getConfig();
 *
 * vs
 *
 * const config: MyCustomConfig = DynamicEnvironment.getConfig<MyCustomConfig>();
 */
export declare class DynamicEnvironment {
    static getConfig<T extends SentinelConfig>(): T;
    static setConfig<T extends SentinelConfig>(config: T): void;
}
