import { ComponentFactory, ComponentFactoryResolver, ComponentRef, TemplateRef, ViewContainerRef } from '@angular/core';
import { SentinelErrorComponent } from './sentinel-error.component';
import { Observable } from 'rxjs';
import * as i0 from "@angular/core";
/**
 * Structural directive on *ngIf principle. Displays error message if the condition is true,
 * desired component if the condition is false. Optionally, tryAgain$ Observable can be passed
 * using the Angular micro syntax. The tryAgain$ should be an observable, repeating the failed action
 * and it will be triggered after user clicks on "try again button".
 *
 * @usage
 * <div *sentinelError="hasError; tryAgain$: onTryAgain$"></div>
 */
export declare class SentinelErrorDirective {
    private templateRef;
    private vcRef;
    private componentFactoryResolver;
    private tryAgain$;
    private hasError;
    errorFactory: ComponentFactory<SentinelErrorComponent>;
    errorComponent: ComponentRef<SentinelErrorComponent>;
    set sentinelError(hasError: boolean);
    set sentinelErrorTryAgain$(tryAgain$: Observable<any>);
    constructor(templateRef: TemplateRef<any>, vcRef: ViewContainerRef, componentFactoryResolver: ComponentFactoryResolver);
    private createComponent;
    private createErrorComponent;
    private destroyErrorComponent;
    private setupTryAgain;
    private createEmbeddedComponent;
    static ɵfac: i0.ɵɵFactoryDeclaration<SentinelErrorDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<SentinelErrorDirective, "[sentinelError], [sentinelErrorTryAgain]", never, { "sentinelError": "sentinelError"; "sentinelErrorTryAgain$": "sentinelErrorTryAgain$"; }, {}, never, never, false>;
}
