import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { Directive, EventEmitter, Component, ChangeDetectionStrategy, Input, Output, NgModule } from '@angular/core';
import * as i2 from '@angular/material/button';
import { MatButtonModule } from '@angular/material/button';
import * as i3 from '@angular/material/icon';
import { MatIconModule } from '@angular/material/icon';
import { SentinelPipesModule } from '@sentinel/common/pipes';

// Using element-name selector because it is meant to replace inject special type of content and match to select attr
// eslint-disable-next-line @angular-eslint/directive-selector
class EditableDisplayModeContentDirective {
}
EditableDisplayModeContentDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: EditableDisplayModeContentDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive });
EditableDisplayModeContentDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.12", type: EditableDisplayModeContentDirective, selector: "orion-editable-display-mode-content", ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: EditableDisplayModeContentDirective, decorators: [{
            type: Directive,
            args: [{ selector: 'orion-editable-display-mode-content' }]
        }] });

class EditableEditModeContentDirective {
}
EditableEditModeContentDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: EditableEditModeContentDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive });
EditableEditModeContentDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.12", type: EditableEditModeContentDirective, selector: "orion-editable-edit-mode-content", ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: EditableEditModeContentDirective, decorators: [{
            type: Directive,
            args: [{
                    // Using element-name selector because it is meant to replace inject special type of content and match to select attr
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: 'orion-editable-edit-mode-content',
                }]
        }] });

var EditableModeChange;
(function (EditableModeChange) {
    EditableModeChange[EditableModeChange["EDIT"] = 0] = "EDIT";
    EditableModeChange[EditableModeChange["DISPLAY"] = 1] = "DISPLAY";
})(EditableModeChange || (EditableModeChange = {}));

class OrionEditableComponent {
    constructor() {
        this.fullWidth = true;
        this.editMode = false;
        this.displayEditButton = true;
        this.saveDisabled = false;
        this.cancelDisabled = false;
        this.save = new EventEmitter();
        this.cancel = new EventEmitter();
        this.modeChange = new EventEmitter();
        this.editModeSetExternally = false;
    }
    ngOnChanges(changes) {
        if ('editMode' in changes && this.editMode !== undefined) {
            this.editModeSetExternally = true;
        }
    }
    onEditClicked() {
        if (!this.editModeSetExternally) {
            this.editMode = !this.editMode;
        }
        this.modeChange.emit(this.editMode ? EditableModeChange.EDIT : EditableModeChange.DISPLAY);
    }
    onEditSaved() {
        if (!this.editModeSetExternally) {
            this.editMode = false;
        }
        this.save.emit();
    }
    onEditCanceled() {
        if (!this.editModeSetExternally) {
            this.editMode = false;
        }
        this.cancel.emit();
    }
    onKey(event) {
        if (event.key === 'Enter' && !this.saveDisabled) {
            this.onEditSaved();
        }
    }
}
OrionEditableComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: OrionEditableComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
OrionEditableComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: OrionEditableComponent, selector: "orion-editable", inputs: { fullWidth: "fullWidth", editMode: "editMode", displayEditButton: "displayEditButton", saveDisabled: "saveDisabled", cancelDisabled: "cancelDisabled" }, outputs: { save: "save", cancel: "cancel", modeChange: "modeChange" }, usesOnChanges: true, ngImport: i0, template: "<div class=\"editable-element-content\">\n  <ng-container *ngIf=\"editMode; else displayMode\">\n    <div class=\"projected-content\" [ngClass]=\"fullWidth ? 'full-width' : ''\" (keypress)=\"onKey($event)\">\n      <ng-content select=\"orion-editable-edit-mode-content\"></ng-content>\n    </div>\n    <div class=\"action-button\">\n      <button mat-icon-button color=\"warn\" [disabled]=\"cancelDisabled\" (click)=\"onEditCanceled()\">\n        <mat-icon>clear</mat-icon>\n      </button>\n      <button mat-icon-button color=\"primary\" [disabled]=\"saveDisabled\" (click)=\"onEditSaved()\">\n        <mat-icon>done</mat-icon>\n      </button>\n    </div>\n  </ng-container>\n</div>\n\n<ng-template #displayMode>\n  <div class=\"projected-content\" [ngClass]=\"fullWidth ? 'full-width' : ''\">\n    <ng-content select=\"orion-editable-display-mode-content\"></ng-content>\n  </div>\n  <div *ngIf=\"displayEditButton\" class=\"action-button\">\n    <button mat-icon-button color=\"primary\" (click)=\"onEditClicked()\">\n      <mat-icon>create</mat-icon>\n    </button>\n  </div>\n</ng-template>\n", styles: [".editable-element-content{display:flex;flex-direction:row;align-items:center;width:100%}.projected-content{display:flex;margin-right:5px}.full-width{flex-grow:1}.action-button{display:flex}\n"], dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i2.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { kind: "component", type: i3.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: OrionEditableComponent, decorators: [{
            type: Component,
            args: [{ selector: 'orion-editable', changeDetection: ChangeDetectionStrategy.OnPush, template: "<div class=\"editable-element-content\">\n  <ng-container *ngIf=\"editMode; else displayMode\">\n    <div class=\"projected-content\" [ngClass]=\"fullWidth ? 'full-width' : ''\" (keypress)=\"onKey($event)\">\n      <ng-content select=\"orion-editable-edit-mode-content\"></ng-content>\n    </div>\n    <div class=\"action-button\">\n      <button mat-icon-button color=\"warn\" [disabled]=\"cancelDisabled\" (click)=\"onEditCanceled()\">\n        <mat-icon>clear</mat-icon>\n      </button>\n      <button mat-icon-button color=\"primary\" [disabled]=\"saveDisabled\" (click)=\"onEditSaved()\">\n        <mat-icon>done</mat-icon>\n      </button>\n    </div>\n  </ng-container>\n</div>\n\n<ng-template #displayMode>\n  <div class=\"projected-content\" [ngClass]=\"fullWidth ? 'full-width' : ''\">\n    <ng-content select=\"orion-editable-display-mode-content\"></ng-content>\n  </div>\n  <div *ngIf=\"displayEditButton\" class=\"action-button\">\n    <button mat-icon-button color=\"primary\" (click)=\"onEditClicked()\">\n      <mat-icon>create</mat-icon>\n    </button>\n  </div>\n</ng-template>\n", styles: [".editable-element-content{display:flex;flex-direction:row;align-items:center;width:100%}.projected-content{display:flex;margin-right:5px}.full-width{flex-grow:1}.action-button{display:flex}\n"] }]
        }], propDecorators: { fullWidth: [{
                type: Input
            }], editMode: [{
                type: Input
            }], displayEditButton: [{
                type: Input
            }], saveDisabled: [{
                type: Input
            }], cancelDisabled: [{
                type: Input
            }], save: [{
                type: Output
            }], cancel: [{
                type: Output
            }], modeChange: [{
                type: Output
            }] } });

class OrionEditableComponentModule {
}
OrionEditableComponentModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: OrionEditableComponentModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
OrionEditableComponentModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: OrionEditableComponentModule, declarations: [OrionEditableComponent, EditableDisplayModeContentDirective, EditableEditModeContentDirective], imports: [CommonModule, MatButtonModule, MatIconModule, SentinelPipesModule], exports: [OrionEditableComponent, EditableDisplayModeContentDirective, EditableEditModeContentDirective] });
OrionEditableComponentModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: OrionEditableComponentModule, imports: [CommonModule, MatButtonModule, MatIconModule, SentinelPipesModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: OrionEditableComponentModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [OrionEditableComponent, EditableDisplayModeContentDirective, EditableEditModeContentDirective],
                    imports: [CommonModule, MatButtonModule, MatIconModule, SentinelPipesModule],
                    exports: [OrionEditableComponent, EditableDisplayModeContentDirective, EditableEditModeContentDirective],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { EditableDisplayModeContentDirective, EditableEditModeContentDirective, EditableModeChange, OrionEditableComponent, OrionEditableComponentModule };
//# sourceMappingURL=csirtmu-orion-microframework-editable.mjs.map
