import { HttpHeaders } from '@angular/common/http';
import { of } from 'rxjs';
import { CursorPagination, OffsetPagination } from '@sentinel/common/pagination';

class ApolloResult {
    constructor(type, errors) {
        this.type = type;
        this.errors = errors;
    }
}

var ApolloResultType;
(function (ApolloResultType) {
    ApolloResultType[ApolloResultType["SUCCESS"] = 0] = "SUCCESS";
    ApolloResultType[ApolloResultType["ERROR"] = 1] = "ERROR";
})(ApolloResultType || (ApolloResultType = {}));

class DmtOrderingConverter {
    static fromSingleSort(sort, sortDir) {
        if (sort && sortDir) {
            return { order: [{ o: sort, desc: sortDir === 'desc' }] };
        }
        else {
            return {};
        }
    }
}

class CursorPaginationConverter {
    static convert(pagination) {
        var _a;
        return {
            cursor: (_a = pagination.cursor) !== null && _a !== void 0 ? _a : undefined,
            limit: pagination.size,
        };
    }
}
class OffsetPaginationConverter {
    static convert(pagination) {
        return {
            offset: pagination.page * pagination.size,
            limit: pagination.size,
        };
    }
}

class QueryCursorPaginationDataResolver {
    static resolve(cursorPaginatedResponse) {
        var _a, _b, _c;
        return {
            cursors: { prev: cursorPaginatedResponse.previous, next: cursorPaginatedResponse.next },
            elementsCount: (_b = (_a = cursorPaginatedResponse === null || cursorPaginatedResponse === void 0 ? void 0 : cursorPaginatedResponse.data) === null || _a === void 0 ? void 0 : _a.length) !== null && _b !== void 0 ? _b : 0,
            totalCount: (_c = cursorPaginatedResponse === null || cursorPaginatedResponse === void 0 ? void 0 : cursorPaginatedResponse.totalCount) !== null && _c !== void 0 ? _c : 0,
        };
    }
}
class QueryOffsetPaginationDataResolver {
    static resolve(offsetPaginatedResponse) {
        var _a, _b, _c;
        return {
            elementsCount: (_b = (_a = offsetPaginatedResponse === null || offsetPaginatedResponse === void 0 ? void 0 : offsetPaginatedResponse.data) === null || _a === void 0 ? void 0 : _a.length) !== null && _b !== void 0 ? _b : 0,
            totalCount: (_c = offsetPaginatedResponse === null || offsetPaginatedResponse === void 0 ? void 0 : offsetPaginatedResponse.totalCount) !== null && _c !== void 0 ? _c : 0,
        };
    }
}

const ERROR_TITLE_ATTR = 'errorTitle';
function createApolloContextErrorTitle(title) {
    return { [ERROR_TITLE_ATTR]: title };
}
function retrieveApolloContextErrorTitle(context) {
    if (context[ERROR_TITLE_ATTR] !== undefined) {
        return context[ERROR_TITLE_ATTR];
    }
    else {
        return 'Unknown operation';
    }
}
const RETRYABLE_ATTR = 'retryable';
function createApolloContextRetryable(value) {
    return { [RETRYABLE_ATTR]: value };
}
function retrieveApolloContextRetryable(context) {
    if (context[RETRYABLE_ATTR] !== undefined) {
        return context[RETRYABLE_ATTR];
    }
    else {
        return false;
    }
}
function wrapApolloContextForFileUpload(currContext) {
    currContext['useMultipart'] = true;
    if (currContext['headers']) {
        currContext['headers'] = currContext['headers'].append('Apollo-Require-Preflight', `true`);
    }
    else {
        currContext['headers'] = new HttpHeaders().set('Apollo-Require-Preflight', `true`);
    }
    return currContext;
}

class ApolloOperationResultResolver {
    static resolve(fetchResult) {
        return fetchResult.errors
            ? new ApolloResult(ApolloResultType.ERROR, fetchResult.errors)
            : new ApolloResult(ApolloResultType.SUCCESS);
    }
    static handleError(err) {
        return of(new ApolloResult(ApolloResultType.ERROR, err));
    }
}

class CursorPaginationResolver {
    static resolve(paginationData, paginationEvent) {
        var _a, _b;
        return new CursorPagination(paginationEvent.cursor, paginationData.elementsCount, paginationEvent.size, paginationData.totalCount, (_a = paginationData.cursors.next) !== null && _a !== void 0 ? _a : null, (_b = paginationData.cursors.prev) !== null && _b !== void 0 ? _b : null);
    }
}
class OffsetPaginationResolver {
    static resolve(paginationData, paginationEvent) {
        return new OffsetPagination(paginationEvent.page, paginationData.elementsCount, paginationEvent.size, paginationData.totalCount, Math.floor(paginationData.totalCount / paginationEvent.size));
    }
}

/**
 * Generated bundle index. Do not edit.
 */

export { ApolloOperationResultResolver, ApolloResult, ApolloResultType, CursorPaginationConverter, CursorPaginationResolver, DmtOrderingConverter, OffsetPaginationConverter, OffsetPaginationResolver, QueryCursorPaginationDataResolver, QueryOffsetPaginationDataResolver, RETRYABLE_ATTR, createApolloContextErrorTitle, createApolloContextRetryable, retrieveApolloContextErrorTitle, retrieveApolloContextRetryable, wrapApolloContextForFileUpload };
//# sourceMappingURL=csirtmu-orion-microframework-graphql.mjs.map
