import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { Injectable, EventEmitter, Component, ChangeDetectionStrategy, Input, Output, NgModule } from '@angular/core';
import * as i2 from '@angular/material/button';
import { MatButtonModule } from '@angular/material/button';
import * as i3 from '@angular/material/icon';
import { MatIconModule } from '@angular/material/icon';
import * as i3$1 from '@csirtmu-orion/microframework/card';
import { OrionCardModule } from '@csirtmu-orion/microframework/card';
import * as i7 from '@sentinel/common/pipes';
import { SentinelPipesModule } from '@sentinel/common/pipes';
import * as i2$1 from 'angular-file';
import { ngfModule } from 'angular-file';
import { Destroyable } from '@sentinel/common';
import { BehaviorSubject, combineLatest } from 'rxjs';
import { map, takeUntil, skip, tap } from 'rxjs/operators';
import { trackByIndex } from '@sentinel/common/utils';

class FilesService {
    constructor() {
        this.filesToUploadSubject$ = new BehaviorSubject([]);
        this.filesToUpload$ = this.filesToUploadSubject$.asObservable();
    }
    getCurrFiles() {
        return this.filesToUploadSubject$.getValue();
    }
    addFiles(files) {
        const currFiles = this.filesToUploadSubject$.getValue();
        const mergedFiles = [...currFiles, ...files];
        // there are multiple sources of file selection, so we need to have uniqueness check here
        const uniqueFiles = [...new Map(mergedFiles.map((file) => [file.name, file])).values()];
        this.filesToUploadSubject$.next(uniqueFiles);
    }
    removeFile(fileIndex) {
        const files = this.filesToUploadSubject$.getValue();
        files.splice(fileIndex, 1);
        this.filesToUploadSubject$.next(files);
    }
    clearFiles() {
        this.filesToUploadSubject$.next([]);
    }
}
FilesService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: FilesService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
FilesService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: FilesService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: FilesService, decorators: [{
            type: Injectable
        }] });

class OrionUploadFilesListComponent {
    constructor() {
        this.files = [];
        this.deleteDisabled = false;
        this.removeByIndex = new EventEmitter();
        this.trackByFn = trackByIndex;
    }
    removeFile(index) {
        this.removeByIndex.emit(index);
    }
}
OrionUploadFilesListComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: OrionUploadFilesListComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
OrionUploadFilesListComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: OrionUploadFilesListComponent, selector: "orion-upload-files-list", inputs: { files: "files", deleteDisabled: "deleteDisabled" }, outputs: { removeByIndex: "removeByIndex" }, ngImport: i0, template: "<ul>\n  <li *ngFor=\"let file of files; trackBy: trackByFn; let i = index\">\n    <span>{{ file.name }}</span>\n    <button\n      mat-icon-button\n      [disabled]=\"deleteDisabled\"\n      matTooltip=\"Remove selected file\"\n      (click)=\"removeFile(i)\"\n      class=\"clear-button\"\n      color=\"warn\"\n    >\n      <mat-icon>delete</mat-icon>\n    </button>\n  </li>\n</ul>\n", styles: ["li{list-style:none;display:flex;align-items:baseline;justify-content:space-between;max-width:600px}ul{padding-left:10px}\n"], dependencies: [{ kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "component", type: i2.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { kind: "component", type: i3.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: OrionUploadFilesListComponent, decorators: [{
            type: Component,
            args: [{ selector: 'orion-upload-files-list', changeDetection: ChangeDetectionStrategy.OnPush, template: "<ul>\n  <li *ngFor=\"let file of files; trackBy: trackByFn; let i = index\">\n    <span>{{ file.name }}</span>\n    <button\n      mat-icon-button\n      [disabled]=\"deleteDisabled\"\n      matTooltip=\"Remove selected file\"\n      (click)=\"removeFile(i)\"\n      class=\"clear-button\"\n      color=\"warn\"\n    >\n      <mat-icon>delete</mat-icon>\n    </button>\n  </li>\n</ul>\n", styles: ["li{list-style:none;display:flex;align-items:baseline;justify-content:space-between;max-width:600px}ul{padding-left:10px}\n"] }]
        }], propDecorators: { files: [{
                type: Input
            }], deleteDisabled: [{
                type: Input
            }], removeByIndex: [{
                type: Output
            }] } });

class OrionUploadFilesActionsComponent {
    constructor() {
        this.cancellable = true;
        this.uploadDisabled = false;
        this.cancel = new EventEmitter();
        this.upload = new EventEmitter();
    }
    onCancel() {
        this.cancel.emit();
    }
    onUpload() {
        this.upload.emit();
    }
}
OrionUploadFilesActionsComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: OrionUploadFilesActionsComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
OrionUploadFilesActionsComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: OrionUploadFilesActionsComponent, selector: "orion-upload-files-actions", inputs: { cancellable: "cancellable", uploadDisabled: "uploadDisabled" }, outputs: { cancel: "cancel", upload: "upload" }, ngImport: i0, template: "<button *ngIf=\"cancellable\" (click)=\"onCancel()\" mat-flat-button color=\"warn\">Cancel</button>\n<button [disabled]=\"uploadDisabled\" (click)=\"onUpload()\" mat-flat-button color=\"primary\">Upload</button>\n", styles: ["button{margin-left:10px}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i2.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: OrionUploadFilesActionsComponent, decorators: [{
            type: Component,
            args: [{ selector: 'orion-upload-files-actions', changeDetection: ChangeDetectionStrategy.OnPush, template: "<button *ngIf=\"cancellable\" (click)=\"onCancel()\" mat-flat-button color=\"warn\">Cancel</button>\n<button [disabled]=\"uploadDisabled\" (click)=\"onUpload()\" mat-flat-button color=\"primary\">Upload</button>\n", styles: ["button{margin-left:10px}\n"] }]
        }], propDecorators: { cancellable: [{
                type: Input
            }], uploadDisabled: [{
                type: Input
            }], cancel: [{
                type: Output
            }], upload: [{
                type: Output
            }] } });

class OrionUploadFilesSelectionComponent {
    constructor() {
        this.multiple = true;
        this.disabled = false;
        this.fileSelected = new EventEmitter();
        this.files = [];
    }
    onFilesSelected(files) {
        this.fileSelected.emit(files);
        // needs to be reset to prevent duplicities due to ngFile library using two-way binding
        this.files = [];
    }
}
OrionUploadFilesSelectionComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: OrionUploadFilesSelectionComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
OrionUploadFilesSelectionComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: OrionUploadFilesSelectionComponent, selector: "orion-upload-files-selection", inputs: { multiple: "multiple", disabled: "disabled" }, outputs: { fileSelected: "fileSelected" }, ngImport: i0, template: "<div class=\"select-text\">\n  <span>Drag files below or &nbsp;</span>\n  <ng-container [ngTemplateOutlet]=\"multiple ? multipleUploadTemplate : singleUploadTemplate\"></ng-container>\n</div>\n\n<div class=\"drop-zone\" [fileDropDisabled]=\"disabled\" ngfDrop [(files)]=\"files\" (filesChange)=\"onFilesSelected($event)\">\n  <mat-icon>save_alt</mat-icon>\n</div>\n\n<ng-template #multipleUploadTemplate>\n  <button\n    mat-button\n    color=\"primary\"\n    ngf\n    multiple=\"1\"\n    [selectable]=\"true\"\n    [disabled]=\"disabled\"\n    [(files)]=\"files\"\n    (filesChange)=\"onFilesSelected($event)\"\n  >\n    select files\n  </button>\n</ng-template>\n\n<ng-template #singleUploadTemplate>\n  <button\n    mat-button\n    color=\"primary\"\n    ngf\n    [selectable]=\"true\"\n    [disabled]=\"disabled\"\n    [(files)]=\"files\"\n    (filesChange)=\"onFilesSelected($event)\"\n  >\n    select file\n  </button>\n</ng-template>\n", styles: [".drop-zone{display:flex;justify-content:center;align-items:center;width:100%;border:1px dashed rgba(0,0,0,.25);min-height:120px;max-width:600px}.drop-zone mat-icon{font-size:60px;height:60px;width:60px;color:#00000040}.select-text{display:flex;align-items:center}.select-text button{padding:0}\n"], dependencies: [{ kind: "directive", type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: i2$1.ngfDrop, selector: "[ngfDrop]", inputs: ["validDrag", "invalidDrag", "dragFiles"], outputs: ["fileOver", "validDragChange", "invalidDragChange", "dragFilesChange"], exportAs: ["ngfDrop"] }, { kind: "directive", type: i2$1.ngf, selector: "[ngf]", inputs: ["ngfFixOrientation", "fileDropDisabled", "selectable", "lastInvalids", "files", "file", "multiple", "accept", "maxSize", "lastBaseUrl", "capturePaste"], outputs: ["init", "lastInvalidsChange", "lastBaseUrlChange", "fileChange", "filesChange", "fileSelectStart"], exportAs: ["ngf"] }, { kind: "component", type: i2.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { kind: "component", type: i3.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: OrionUploadFilesSelectionComponent, decorators: [{
            type: Component,
            args: [{ selector: 'orion-upload-files-selection', changeDetection: ChangeDetectionStrategy.OnPush, template: "<div class=\"select-text\">\n  <span>Drag files below or &nbsp;</span>\n  <ng-container [ngTemplateOutlet]=\"multiple ? multipleUploadTemplate : singleUploadTemplate\"></ng-container>\n</div>\n\n<div class=\"drop-zone\" [fileDropDisabled]=\"disabled\" ngfDrop [(files)]=\"files\" (filesChange)=\"onFilesSelected($event)\">\n  <mat-icon>save_alt</mat-icon>\n</div>\n\n<ng-template #multipleUploadTemplate>\n  <button\n    mat-button\n    color=\"primary\"\n    ngf\n    multiple=\"1\"\n    [selectable]=\"true\"\n    [disabled]=\"disabled\"\n    [(files)]=\"files\"\n    (filesChange)=\"onFilesSelected($event)\"\n  >\n    select files\n  </button>\n</ng-template>\n\n<ng-template #singleUploadTemplate>\n  <button\n    mat-button\n    color=\"primary\"\n    ngf\n    [selectable]=\"true\"\n    [disabled]=\"disabled\"\n    [(files)]=\"files\"\n    (filesChange)=\"onFilesSelected($event)\"\n  >\n    select file\n  </button>\n</ng-template>\n", styles: [".drop-zone{display:flex;justify-content:center;align-items:center;width:100%;border:1px dashed rgba(0,0,0,.25);min-height:120px;max-width:600px}.drop-zone mat-icon{font-size:60px;height:60px;width:60px;color:#00000040}.select-text{display:flex;align-items:center}.select-text button{padding:0}\n"] }]
        }], propDecorators: { multiple: [{
                type: Input
            }], disabled: [{
                type: Input
            }], fileSelected: [{
                type: Output
            }] } });

class OrionUploadFilesComponent extends Destroyable() {
    constructor(filesService) {
        super();
        this.filesService = filesService;
        this.cancellable = true;
        this.withActions = true;
        this.withCard = true;
        this.multiple = true;
        this.upload = new EventEmitter();
        this.cancel = new EventEmitter();
        this.selectedFilesChange = new EventEmitter();
        this.disabled$ = new BehaviorSubject(false);
    }
    ngOnInit() {
        this.selectedFiles$ = this.filesService.filesToUpload$;
        const noSelectedFiles$ = this.selectedFiles$.pipe(map((files) => files.length === 0));
        this.uploadDisabled$ = combineLatest([this.disabled$, noSelectedFiles$]).pipe(map((conditions) => conditions[0] || conditions[1]));
        const selectionChangeEvent$ = this.selectedFiles$.pipe(takeUntil(this.destroy$), skip(1), tap((files) => this.selectedFilesChange.emit(files)));
        selectionChangeEvent$.subscribe();
    }
    ngOnChanges(changes) {
        if ('disabled' in changes && this.disabled !== undefined) {
            this.disabled$.next(this.disabled);
        }
    }
    removeFile(fileIndex) {
        this.filesService.removeFile(fileIndex);
    }
    selectFiles(files) {
        if (this.multiple) {
            this.filesService.addFiles(files);
        }
        else if (files.length > 0) {
            this.filesService.clearFiles();
            this.filesService.addFiles([files[0]]);
        }
    }
    onUpload() {
        this.upload.emit(this.filesService.getCurrFiles());
    }
    onCancel() {
        this.filesService.clearFiles();
        this.cancel.emit();
    }
}
OrionUploadFilesComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: OrionUploadFilesComponent, deps: [{ token: FilesService }], target: i0.ɵɵFactoryTarget.Component });
OrionUploadFilesComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: OrionUploadFilesComponent, selector: "orion-upload-files", inputs: { cancellable: "cancellable", withActions: "withActions", withCard: "withCard", multiple: "multiple", disabled: "disabled" }, outputs: { upload: "upload", cancel: "cancel", selectedFilesChange: "selectedFilesChange" }, providers: [FilesService], usesInheritance: true, usesOnChanges: true, ngImport: i0, template: "<orion-card *ngIf=\"withCard; else uploadContentTemplate\" [cardTitle]=\"multiple ? 'Upload Files' : 'Upload File'\">\n  <ng-container [ngTemplateOutlet]=\"uploadContentTemplate\"></ng-container>\n  <orion-card-actions>\n    <ng-container [ngTemplateOutlet]=\"uploadActionsTemplate\"></ng-container>\n  </orion-card-actions>\n</orion-card>\n\n<ng-template #uploadContentTemplate>\n  <orion-upload-files-selection\n    [multiple]=\"multiple\"\n    [disabled]=\"disabled || false\"\n    (fileSelected)=\"selectFiles($event)\"\n  ></orion-upload-files-selection>\n  <orion-upload-files-list\n    [files]=\"selectedFiles$ | sAsync: []\"\n    [deleteDisabled]=\"disabled\"\n    (removeByIndex)=\"removeFile($event)\"\n  ></orion-upload-files-list>\n  <div *ngIf=\"withActions && !withCard\" class=\"actions\">\n    <ng-container [ngTemplateOutlet]=\"uploadActionsTemplate\"></ng-container>\n  </div>\n</ng-template>\n\n<ng-template #uploadActionsTemplate>\n  <orion-upload-files-actions\n    *ngIf=\"withActions\"\n    [cancellable]=\"cancellable\"\n    [uploadDisabled]=\"uploadDisabled$ | sAsync: false\"\n    (upload)=\"onUpload()\"\n    (cancel)=\"onCancel()\"\n  ></orion-upload-files-actions>\n</ng-template>\n", styles: [".actions{display:flex;justify-content:flex-end;max-width:600px}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: i3$1.OrionCardComponent, selector: "orion-card", inputs: ["isLoading", "titleIcon", "noMargin", "elevation", "cardTitle", "subtitle", "headerImgSrc", "headerImgAlt", "controls"] }, { kind: "directive", type: i3$1.OrionCardActionsDirective, selector: "orion-card-actions" }, { kind: "component", type: OrionUploadFilesListComponent, selector: "orion-upload-files-list", inputs: ["files", "deleteDisabled"], outputs: ["removeByIndex"] }, { kind: "component", type: OrionUploadFilesActionsComponent, selector: "orion-upload-files-actions", inputs: ["cancellable", "uploadDisabled"], outputs: ["cancel", "upload"] }, { kind: "component", type: OrionUploadFilesSelectionComponent, selector: "orion-upload-files-selection", inputs: ["multiple", "disabled"], outputs: ["fileSelected"] }, { kind: "pipe", type: i7.SentinelAsyncPipe, name: "sAsync" }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: OrionUploadFilesComponent, decorators: [{
            type: Component,
            args: [{ selector: 'orion-upload-files', changeDetection: ChangeDetectionStrategy.OnPush, providers: [FilesService], template: "<orion-card *ngIf=\"withCard; else uploadContentTemplate\" [cardTitle]=\"multiple ? 'Upload Files' : 'Upload File'\">\n  <ng-container [ngTemplateOutlet]=\"uploadContentTemplate\"></ng-container>\n  <orion-card-actions>\n    <ng-container [ngTemplateOutlet]=\"uploadActionsTemplate\"></ng-container>\n  </orion-card-actions>\n</orion-card>\n\n<ng-template #uploadContentTemplate>\n  <orion-upload-files-selection\n    [multiple]=\"multiple\"\n    [disabled]=\"disabled || false\"\n    (fileSelected)=\"selectFiles($event)\"\n  ></orion-upload-files-selection>\n  <orion-upload-files-list\n    [files]=\"selectedFiles$ | sAsync: []\"\n    [deleteDisabled]=\"disabled\"\n    (removeByIndex)=\"removeFile($event)\"\n  ></orion-upload-files-list>\n  <div *ngIf=\"withActions && !withCard\" class=\"actions\">\n    <ng-container [ngTemplateOutlet]=\"uploadActionsTemplate\"></ng-container>\n  </div>\n</ng-template>\n\n<ng-template #uploadActionsTemplate>\n  <orion-upload-files-actions\n    *ngIf=\"withActions\"\n    [cancellable]=\"cancellable\"\n    [uploadDisabled]=\"uploadDisabled$ | sAsync: false\"\n    (upload)=\"onUpload()\"\n    (cancel)=\"onCancel()\"\n  ></orion-upload-files-actions>\n</ng-template>\n", styles: [".actions{display:flex;justify-content:flex-end;max-width:600px}\n"] }]
        }], ctorParameters: function () { return [{ type: FilesService }]; }, propDecorators: { cancellable: [{
                type: Input
            }], withActions: [{
                type: Input
            }], withCard: [{
                type: Input
            }], multiple: [{
                type: Input
            }], disabled: [{
                type: Input
            }], upload: [{
                type: Output
            }], cancel: [{
                type: Output
            }], selectedFilesChange: [{
                type: Output
            }] } });

class OrionUploadFilesModule {
}
OrionUploadFilesModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: OrionUploadFilesModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
OrionUploadFilesModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: OrionUploadFilesModule, declarations: [OrionUploadFilesComponent,
        OrionUploadFilesListComponent,
        OrionUploadFilesActionsComponent,
        OrionUploadFilesSelectionComponent], imports: [CommonModule, OrionCardModule, SentinelPipesModule, ngfModule, MatButtonModule, MatIconModule], exports: [OrionUploadFilesComponent,
        OrionUploadFilesListComponent,
        OrionUploadFilesActionsComponent,
        OrionUploadFilesSelectionComponent] });
OrionUploadFilesModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: OrionUploadFilesModule, imports: [CommonModule, OrionCardModule, SentinelPipesModule, ngfModule, MatButtonModule, MatIconModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: OrionUploadFilesModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        OrionUploadFilesComponent,
                        OrionUploadFilesListComponent,
                        OrionUploadFilesActionsComponent,
                        OrionUploadFilesSelectionComponent,
                    ],
                    imports: [CommonModule, OrionCardModule, SentinelPipesModule, ngfModule, MatButtonModule, MatIconModule],
                    exports: [
                        OrionUploadFilesComponent,
                        OrionUploadFilesListComponent,
                        OrionUploadFilesActionsComponent,
                        OrionUploadFilesSelectionComponent,
                    ],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { FilesService, OrionUploadFilesActionsComponent, OrionUploadFilesComponent, OrionUploadFilesListComponent, OrionUploadFilesModule, OrionUploadFilesSelectionComponent };
//# sourceMappingURL=csirtmu-orion-microframework-upload-files.mjs.map
