import * as i0 from '@angular/core';
import { Component, ChangeDetectionStrategy, NgModule } from '@angular/core';
import * as i1 from '@sentinel/auth';
import * as i2 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i3 from '@angular/material/button';
import { MatButtonModule } from '@angular/material/button';
import { MatCardModule } from '@angular/material/card';

/**
 * Component displaying all available providers. User can select OIDC providers to log in with
 */
class SentinelAuthProviderListComponent {
    constructor(configService, authService) {
        this.configService = configService;
        this.authService = authService;
        this.providers = [];
    }
    ngOnInit() {
        this.providers = this.configService.config.providers;
    }
    /**
     * Selects provider, configures authentication service with selected provider and tries to login
     * @param provider selected OIDC provider
     */
    select(provider) {
        this.configService.selectProvider(provider);
        this.authService.configure(provider);
        this.authService.login();
    }
}
SentinelAuthProviderListComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelAuthProviderListComponent, deps: [{ token: i1.SentinelAuthContext }, { token: i1.SentinelAuthService }], target: i0.ɵɵFactoryTarget.Component });
SentinelAuthProviderListComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: SentinelAuthProviderListComponent, selector: "sentinel-auth-provider-list", ngImport: i0, template: "<div class=\"providers\">\n  <button *ngFor=\"let provider of providers\"\n          mat-raised-button\n          [ngStyle]=\"{'background-color': provider.backgroundColor, 'color': provider.textColor}\"\n          (click)=\"select(provider)\">\n    {{ provider.label }}\n  </button>\n</div>\n", styles: [".providers{width:100%;display:flex;flex-direction:column;place-items:center}.providers>button{color:#fff;background-color:#000}button{width:100%;margin:5px}\n"], dependencies: [{ kind: "directive", type: i2.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i2.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }, { kind: "component", type: i3.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelAuthProviderListComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sentinel-auth-provider-list', changeDetection: ChangeDetectionStrategy.OnPush, template: "<div class=\"providers\">\n  <button *ngFor=\"let provider of providers\"\n          mat-raised-button\n          [ngStyle]=\"{'background-color': provider.backgroundColor, 'color': provider.textColor}\"\n          (click)=\"select(provider)\">\n    {{ provider.label }}\n  </button>\n</div>\n", styles: [".providers{width:100%;display:flex;flex-direction:column;place-items:center}.providers>button{color:#fff;background-color:#000}button{width:100%;margin:5px}\n"] }]
        }], ctorParameters: function () { return [{ type: i1.SentinelAuthContext }, { type: i1.SentinelAuthService }]; } });

class SentinelAuthProviderListModule {
}
SentinelAuthProviderListModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelAuthProviderListModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
SentinelAuthProviderListModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: SentinelAuthProviderListModule, declarations: [SentinelAuthProviderListComponent], imports: [CommonModule, MatCardModule, MatButtonModule], exports: [SentinelAuthProviderListComponent] });
SentinelAuthProviderListModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelAuthProviderListModule, imports: [CommonModule, MatCardModule, MatButtonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelAuthProviderListModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [SentinelAuthProviderListComponent],
                    imports: [CommonModule, MatCardModule, MatButtonModule],
                    exports: [SentinelAuthProviderListComponent],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { SentinelAuthProviderListComponent, SentinelAuthProviderListModule };
//# sourceMappingURL=sentinel-auth-components.mjs.map
