import * as i0 from '@angular/core';
import { Injectable, NgModule, Optional, SkipSelf } from '@angular/core';
import * as i4 from 'angular-oauth2-oidc';
import { OAuthModule, OAuthModuleConfig, OAuthStorage } from 'angular-oauth2-oidc';
import { JwksValidationHandler } from 'angular-oauth2-oidc-jwks';
import { BehaviorSubject, from, of, throwError } from 'rxjs';
import { takeWhile, switchMap, tap, catchError, map, retry } from 'rxjs/operators';
import * as i3 from '@angular/common/http';

/**
 * Configuration class of the library
 */
class SentinelAuthConfig {
}
SentinelAuthConfig.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelAuthConfig, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
SentinelAuthConfig.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelAuthConfig });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelAuthConfig, decorators: [{
            type: Injectable
        }] });

/**
 * Config service storing and providing authentication config
 */
class SentinelAuthContext {
    constructor(config) {
        this.PROVIDER_ID_STORAGE_NAME = 'sentinel_auth_provider_id';
        this.config = config;
        this.selectedProviderConfig = this.getProviderFromStorage();
    }
    /**
     * Returns OIDC config of OIDC provider
     * @param providerConfig provider which OIDC config should be returned
     */
    static getOIDCConfig(providerConfig) {
        return providerConfig.oidcConfig;
    }
    /**
     * Selects OIDC provider, and stores it in browser storage
     * @param provider selected OIDC provider
     */
    selectProvider(provider) {
        this.selectedProviderConfig = provider;
        const providerInStorage = this.getProviderFromStorage();
        if (providerInStorage === undefined ||
            providerInStorage === null ||
            providerInStorage.oidcConfig.clientId !== provider.oidcConfig.clientId) {
            localStorage.setItem(this.PROVIDER_ID_STORAGE_NAME, provider.oidcConfig.clientId);
        }
    }
    /**
     * True if OIDC provider was already selected, false otherwise
     */
    hasSelectedProvider() {
        return this.selectedProviderConfig !== null && this.selectedProviderConfig !== undefined;
    }
    /**
     * Returns provider stored in browser storage
     */
    getProviderFromStorage() {
        return this.config.providers.find((provider) => provider.oidcConfig.clientId === localStorage.getItem(this.PROVIDER_ID_STORAGE_NAME));
    }
    /**
     * Clears previously selected OIDC provider from browser storage
     */
    clearSelectedProvider() {
        localStorage.removeItem(this.PROVIDER_ID_STORAGE_NAME);
    }
}
SentinelAuthContext.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelAuthContext, deps: [{ token: SentinelAuthConfig }], target: i0.ɵɵFactoryTarget.Injectable });
SentinelAuthContext.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelAuthContext });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelAuthContext, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: SentinelAuthConfig }]; } });

/**
 * Abstract class to be overridden by the client. Emits errors during authentication or authorization process
 */
class SentinelAuthErrorHandler {
}

/**
 * An authorization strategy, can be overriden through Angular dependency injection to provide authorization against custom authority
 * Needs to create a User with at least one role in the process.
 */
class SentinelAuthorizationStrategy {
}

/**
 * Main authentication service. Wrapper around OAuthService for OIDC provider login combined with user
 * authorization based on currently injected strategy
 * If used for the first time the correct flow is - configure, login. If it was already
 * configured one time, and oidc client id is stored in localStorage of browser, it is configured automatically.
 * Logout clears configuration and all stored tokens. Service automatically starts silent refreshing service
 * which will check whether OIDC tokens are about to expire and handles acquiring new tokens from OIDC provider silently.
 */
class SentinelAuthService {
    constructor(authContext, errorHandler, authorizationService, oAuthService) {
        this.authContext = authContext;
        this.errorHandler = errorHandler;
        this.authorizationService = authorizationService;
        this.oAuthService = oAuthService;
        this.onActiveUserChangedSubject = new BehaviorSubject(null);
        /**
         * Emits new active user whenever it changes
         */
        this.activeUser$ = this.onActiveUserChangedSubject.asObservable();
        const provider = this.authContext.getProviderFromStorage();
        if (provider) {
            this.configure(provider);
        }
    }
    /**
     * Configures the service with OIDC provider config
     * @param providerConfig config of the OIDC provider to use with the service
     */
    configure(providerConfig) {
        this.authContext.selectProvider(providerConfig);
        this.oAuthService.configure(SentinelAuthContext.getOIDCConfig(providerConfig));
        this.oAuthService.tokenValidationHandler = new JwksValidationHandler();
    }
    /**
     * Logs in with OIDC provider to get token and then tries to authorize using an injected authorization strategy
     */
    login() {
        return this.authenticate().pipe(takeWhile((validTokens) => validTokens), switchMap((_) => this.authorizationService.authorize()), tap((authorizedUser) => {
            this.setActiveUser(authorizedUser);
            if (this.authContext.selectedProviderConfig.oidcConfig.silentRefreshRedirectUri !== '') {
                this.oAuthService.setupAutomaticSilentRefresh();
            }
        }));
    }
    /**
     * Logs out active user and clears selected OIDC provider
     */
    logout() {
        this.setActiveUser(undefined);
        this.authContext.clearSelectedProvider();
        this.oAuthService.logOut(false);
    }
    /**
     * True if user is logged in (authenticated with OIDC provider and authorized (active user with at least one role exists)
     */
    isLoggedIn() {
        return this.isAuthenticated() && this.isAuthorized();
    }
    /**
     * Returns logged in user
     */
    getActiveUser() {
        return this.activeUser;
    }
    /**
     * Returns roles of logged in user
     */
    getRoles() {
        return this.activeUser.roles;
    }
    /**
     * Returns authorization header of logged in user
     */
    getActiveUserAuthorizationHeader() {
        return this.oAuthService.authorizationHeader();
    }
    setActiveUser(user) {
        this.activeUser = user;
        this.onActiveUserChangedSubject.next(user);
    }
    isAuthenticated() {
        return this.oAuthService.hasValidIdToken() && this.oAuthService.hasValidAccessToken();
    }
    isAuthorized() {
        return this.getActiveUser() !== null && this.getActiveUser() !== undefined && this.hasSomeRoles();
    }
    authenticate() {
        return from(this.oAuthService.loadDiscoveryDocumentAndLogin()).pipe(catchError((err) => {
            this.errorHandler.emit(err, 'Authenticating to OIDC');
            return of(false);
        }));
    }
    hasSomeRoles() {
        return this.activeUser.roles.length > 0;
    }
}
SentinelAuthService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelAuthService, deps: [{ token: SentinelAuthContext }, { token: SentinelAuthErrorHandler }, { token: SentinelAuthorizationStrategy }, { token: i4.OAuthService }], target: i0.ɵɵFactoryTarget.Injectable });
SentinelAuthService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelAuthService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelAuthService, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: SentinelAuthContext }, { type: SentinelAuthErrorHandler }, { type: SentinelAuthorizationStrategy }, { type: i4.OAuthService }]; } });

/**
 * Role of a user in some microservice
 */
class UserRole {
    /**
     * Creates role object from DTO
     * @param roleDto DTO from which Role class should be created
     */
    static fromDTO(roleDto) {
        const role = new UserRole();
        role.id = roleDto.id;
        role.microserviceId = roleDto.id_of_microservice;
        role.microserviceName = roleDto.name_of_microservice;
        role.roleType = roleDto.role_type;
        role.description = roleDto.description ? roleDto.description : '';
        return role;
    }
    toString() {
        return this.roleType.toLowerCase().split('_').join(' ');
    }
}

/**
 * Class representing user in a system. User can be uniquely identified by combination of his login and OIDC issuer but
 * using equals() method is advised.
 * @dynamic
 */
class User {
    constructor(roles) {
        this.roles = roles;
    }
    /**
     * Creates user class from DTO
     * @param userDTO DTO to use to create new User
     */
    static fromDTO(userDTO) {
        let user = new User([]);
        if (userDTO.roles) {
            user = new User(this.mapRoleDTOsToRoles(userDTO.roles));
        }
        if (userDTO.id !== null && userDTO.id !== undefined) {
            user.id = userDTO.id;
        }
        if (userDTO.user_ref_id !== null && userDTO.user_ref_id !== undefined) {
            user.id = userDTO.user_ref_id;
        }
        if (userDTO.mail !== null && userDTO.mail !== undefined) {
            user.mail = userDTO.mail;
        }
        user.login = userDTO.sub;
        user.picture = userDTO.picture;
        user.issuer = userDTO.iss;
        user.name = `${userDTO.given_name} ${userDTO.family_name}`;
        user.nameWithAcademicTitles = userDTO.full_name;
        return user;
    }
    static mapRoleDTOsToRoles(roles) {
        return roles.map((roleDTO) => UserRole.fromDTO(roleDTO));
    }
    toString() {
        return this.name;
    }
    equals(user) {
        if (!user) {
            return false;
        }
        return this.id === user.id;
    }
}

/**
 * Default authorization strategy, gets user profile and roles from User and Group microservice
 */
class SentinelUagAuthorizationStrategy extends SentinelAuthorizationStrategy {
    constructor(configService, errorHandler, http) {
        super();
        this.configService = configService;
        this.errorHandler = errorHandler;
        this.http = http;
        this.POSSIBLE_RETRIES = 3;
    }
    authorize() {
        const config = this.configService.config.authorizationStrategyConfig;
        return this.http.get(config.authorizationUrl).pipe(map((resp) => User.fromDTO(resp)), retry(this.POSSIBLE_RETRIES), catchError((err) => {
            this.errorHandler.emit(err, 'Authorizing to User & Group');
            return throwError(err);
        }));
    }
}
SentinelUagAuthorizationStrategy.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelUagAuthorizationStrategy, deps: [{ token: SentinelAuthContext }, { token: SentinelAuthErrorHandler }, { token: i3.HttpClient }], target: i0.ɵɵFactoryTarget.Injectable });
SentinelUagAuthorizationStrategy.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelUagAuthorizationStrategy });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelUagAuthorizationStrategy, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: SentinelAuthContext }, { type: SentinelAuthErrorHandler }, { type: i3.HttpClient }]; } });

class SentinelAuthDefaultErrorHandler extends SentinelAuthErrorHandler {
    emit(err, operation, action) {
        console.log(`Auth error during ${operation}. Error code ${err === null || err === void 0 ? void 0 : err.status} with following message: ${err === null || err === void 0 ? void 0 : err.message}`);
        return of(false);
    }
}

function storageFactory() {
    return localStorage;
}
function oAuthConfigFactory(sentinelAuthConfig) {
    return {
        resourceServer: {
            allowedUrls: (sentinelAuthConfig === null || sentinelAuthConfig === void 0 ? void 0 : sentinelAuthConfig.interceptorAllowedUrls) ? sentinelAuthConfig === null || sentinelAuthConfig === void 0 ? void 0 : sentinelAuthConfig.interceptorAllowedUrls : [],
            sendAccessToken: true,
        },
    };
}
/**
 * Main module, contain the auth service and config. Needs to have config passed in forRoot() method.
 */
class SentinelAuthModule {
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('SentinelAuthModule is already loaded. Import it in the main module only');
        }
    }
    static forRoot(sentinelAuthConfig) {
        return {
            ngModule: SentinelAuthModule,
            providers: [
                OAuthModule.forRoot().providers,
                { provide: SentinelAuthConfig, useValue: sentinelAuthConfig },
                { provide: OAuthModuleConfig, useFactory: oAuthConfigFactory, deps: [SentinelAuthConfig] },
                { provide: OAuthStorage, useFactory: storageFactory },
            ],
        };
    }
}
SentinelAuthModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelAuthModule, deps: [{ token: SentinelAuthModule, optional: true, skipSelf: true }], target: i0.ɵɵFactoryTarget.NgModule });
SentinelAuthModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: SentinelAuthModule });
SentinelAuthModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelAuthModule, providers: [
        SentinelAuthService,
        SentinelAuthConfig,
        SentinelAuthContext,
        { provide: SentinelAuthErrorHandler, useClass: SentinelAuthDefaultErrorHandler },
        { provide: SentinelAuthorizationStrategy, useClass: SentinelUagAuthorizationStrategy },
    ] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelAuthModule, decorators: [{
            type: NgModule,
            args: [{
                    providers: [
                        SentinelAuthService,
                        SentinelAuthConfig,
                        SentinelAuthContext,
                        { provide: SentinelAuthErrorHandler, useClass: SentinelAuthDefaultErrorHandler },
                        { provide: SentinelAuthorizationStrategy, useClass: SentinelUagAuthorizationStrategy },
                    ],
                }]
        }], ctorParameters: function () {
        return [{ type: SentinelAuthModule, decorators: [{
                        type: Optional
                    }, {
                        type: SkipSelf
                    }] }];
    } });

/**
 * Configuration of OIDC provider
 */
class SentinelAuthProviderConfig {
}

class SentinelUagStrategyConfig {
}

class UserDTO {
}

class RoleDTO {
}

/*
 * Public API Surface of sentinel-auth
 */

/**
 * Generated bundle index. Do not edit.
 */

export { RoleDTO, SentinelAuthConfig, SentinelAuthContext, SentinelAuthErrorHandler, SentinelAuthModule, SentinelAuthProviderConfig, SentinelAuthService, SentinelAuthorizationStrategy, SentinelUagStrategyConfig, User, UserDTO, UserRole };
//# sourceMappingURL=sentinel-auth.mjs.map
