import * as i0 from '@angular/core';
import { Pipe, NgModule } from '@angular/core';
import { isArray, prettifyEnum } from '@sentinel/common/utils';
import { AsyncPipe, DatePipe, CommonModule } from '@angular/common';

class SentinelHasElementsPipe {
    transform(value) {
        if (value === undefined || value === null) {
            return false;
        }
        if (isArray(value)) {
            return value.length > 0;
        }
        else {
            return value.data && value.data.length > 0;
        }
    }
}
SentinelHasElementsPipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelHasElementsPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
SentinelHasElementsPipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: SentinelHasElementsPipe, name: "sentinelHasElements" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelHasElementsPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'sentinelHasElements',
                }]
        }] });

class SentinelPrettifyEnumPipe {
    transform(value) {
        return prettifyEnum(value);
    }
}
SentinelPrettifyEnumPipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelPrettifyEnumPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
SentinelPrettifyEnumPipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: SentinelPrettifyEnumPipe, name: "sentinelPrettifyEnum" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelPrettifyEnumPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'sentinelPrettifyEnum',
                }]
        }] });

/**
 * Uses async pipe internally but retypes null to undefined as this is more in line with TypeScript optional attributes
 * and results in less retyping and boilerplate if strict checking is active. It also allows to provide default value
 * for cases where undefined type is not possible/desired.
 */
class SentinelAsyncPipe extends AsyncPipe {
    transform(obj, defaultValue) {
        const asyncPipeResult = super.transform(obj);
        if (asyncPipeResult !== undefined && !asyncPipeResult !== null) {
            return asyncPipeResult;
        }
        else {
            if (defaultValue) {
                return defaultValue;
            }
            else {
                return undefined;
            }
        }
    }
}
SentinelAsyncPipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelAsyncPipe, deps: null, target: i0.ɵɵFactoryTarget.Pipe });
SentinelAsyncPipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: SentinelAsyncPipe, name: "sAsync", pure: false });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelAsyncPipe, decorators: [{
            type: Pipe,
            args: [{ name: 'sAsync', pure: false }]
        }] });

class SentinelElementsTooltipPipe {
    transform(elements, name = 'element') {
        const lowerCased = name.toLowerCase();
        if (elements === undefined || elements.length === 0) {
            return `No ${lowerCased}s`;
        }
        if (elements.length === 1) {
            return `1 ${lowerCased}`;
        }
        return `${elements.length} ${lowerCased}s`;
    }
}
SentinelElementsTooltipPipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelElementsTooltipPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
SentinelElementsTooltipPipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: SentinelElementsTooltipPipe, name: "sentinelElementsTooltip" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelElementsTooltipPipe, decorators: [{
            type: Pipe,
            args: [{ name: 'sentinelElementsTooltip' }]
        }] });

/**
 * Transforms date to string in european style DD/MM/YYYY HH:MM format
 */
class SentinelDateTimeFormatPipe extends DatePipe {
    transform(value, args) {
        return super.transform(value, 'dd MMM yyyy HH:mm');
    }
}
SentinelDateTimeFormatPipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelDateTimeFormatPipe, deps: null, target: i0.ɵɵFactoryTarget.Pipe });
SentinelDateTimeFormatPipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: SentinelDateTimeFormatPipe, name: "sentinelDateTimeFormat" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelDateTimeFormatPipe, decorators: [{
            type: Pipe,
            args: [{ name: 'sentinelDateTimeFormat' }]
        }] });

/**
 * Shortens string by slicing end of the string and replacing it with "..."
 */
class SentinelShortStringPipe {
    transform(text, maxLength = 10) {
        if (text === undefined || text === null) {
            return '';
        }
        return text.length > maxLength ? text.slice(0, maxLength) + '...' : text;
    }
}
SentinelShortStringPipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelShortStringPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
SentinelShortStringPipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: SentinelShortStringPipe, name: "sentinelShortString" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelShortStringPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'sentinelShortString',
                }]
        }] });

class SentinelTooltipOnShortenedPipe {
    transform(value, maxLength = 30) {
        if (value === undefined || value === null) {
            return '';
        }
        else {
            return value.length > maxLength ? value : '';
        }
    }
}
SentinelTooltipOnShortenedPipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelTooltipOnShortenedPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
SentinelTooltipOnShortenedPipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: SentinelTooltipOnShortenedPipe, name: "sentinelTooltipOnShortened" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelTooltipOnShortenedPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'sentinelTooltipOnShortened',
                }]
        }] });

class SentinelDashReplacePipe {
    transform(value, replaceWith = ' ') {
        return value.replace(new RegExp('[_-]'), replaceWith);
    }
}
SentinelDashReplacePipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelDashReplacePipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
SentinelDashReplacePipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: SentinelDashReplacePipe, name: "sentinelDashReplace" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelDashReplacePipe, decorators: [{
            type: Pipe,
            args: [{ name: 'sentinelDashReplace' }]
        }] });

class SentinelDefaultValueStringPipe {
    transform(value, defaultValue = '') {
        return value ? value : defaultValue;
    }
}
SentinelDefaultValueStringPipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelDefaultValueStringPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
SentinelDefaultValueStringPipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: SentinelDefaultValueStringPipe, name: "sentinelDefaultValueString" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelDefaultValueStringPipe, decorators: [{
            type: Pipe,
            args: [{ name: 'sentinelDefaultValueString' }]
        }] });

class SentinelDefaultValueArrayPipe {
    transform(value, defaultValue = []) {
        return value ? value : defaultValue;
    }
}
SentinelDefaultValueArrayPipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelDefaultValueArrayPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
SentinelDefaultValueArrayPipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: SentinelDefaultValueArrayPipe, name: "sentinelDefaultValueArray" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelDefaultValueArrayPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'sentinelDefaultValueArray',
                }]
        }] });

/**
 * Contains all custom pipes
 */
class SentinelPipesModule {
}
SentinelPipesModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelPipesModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
SentinelPipesModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: SentinelPipesModule, declarations: [SentinelDefaultValueArrayPipe,
        SentinelDefaultValueStringPipe,
        SentinelDashReplacePipe,
        SentinelTooltipOnShortenedPipe,
        SentinelDateTimeFormatPipe,
        SentinelShortStringPipe,
        SentinelAsyncPipe,
        SentinelElementsTooltipPipe,
        SentinelHasElementsPipe,
        SentinelPrettifyEnumPipe], imports: [CommonModule], exports: [SentinelDefaultValueArrayPipe,
        SentinelDefaultValueStringPipe,
        SentinelDashReplacePipe,
        SentinelTooltipOnShortenedPipe,
        SentinelDateTimeFormatPipe,
        SentinelShortStringPipe,
        SentinelAsyncPipe,
        SentinelElementsTooltipPipe,
        SentinelHasElementsPipe,
        SentinelPrettifyEnumPipe] });
SentinelPipesModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelPipesModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelPipesModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule],
                    declarations: [
                        SentinelDefaultValueArrayPipe,
                        SentinelDefaultValueStringPipe,
                        SentinelDashReplacePipe,
                        SentinelTooltipOnShortenedPipe,
                        SentinelDateTimeFormatPipe,
                        SentinelShortStringPipe,
                        SentinelAsyncPipe,
                        SentinelElementsTooltipPipe,
                        SentinelHasElementsPipe,
                        SentinelPrettifyEnumPipe,
                    ],
                    exports: [
                        SentinelDefaultValueArrayPipe,
                        SentinelDefaultValueStringPipe,
                        SentinelDashReplacePipe,
                        SentinelTooltipOnShortenedPipe,
                        SentinelDateTimeFormatPipe,
                        SentinelShortStringPipe,
                        SentinelAsyncPipe,
                        SentinelElementsTooltipPipe,
                        SentinelHasElementsPipe,
                        SentinelPrettifyEnumPipe,
                    ],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { SentinelAsyncPipe, SentinelDashReplacePipe, SentinelDateTimeFormatPipe, SentinelDefaultValueArrayPipe, SentinelDefaultValueStringPipe, SentinelElementsTooltipPipe, SentinelHasElementsPipe, SentinelPipesModule, SentinelPrettifyEnumPipe, SentinelShortStringPipe, SentinelTooltipOnShortenedPipe };
//# sourceMappingURL=sentinel-common-pipes.mjs.map
