import { FormGroup, FormControl, Validators } from '@angular/forms';
import { Subject, merge, BehaviorSubject, timer } from 'rxjs';
import { map, distinctUntilChanged, startWith, switchMap, retryWhen } from 'rxjs/operators';
import * as i0 from '@angular/core';
import { Directive, Input, NgModule } from '@angular/core';
import { HttpParams } from '@angular/common/http';
import { PaginatedResource, CursorPagination, OffsetPagination } from '@sentinel/common/pagination';

class DateRangeForm {
    constructor(dateRange) {
        var _a, _b;
        this.formGroup = new FormGroup({
            from: new FormControl((_a = dateRange === null || dateRange === void 0 ? void 0 : dateRange.from) !== null && _a !== void 0 ? _a : null),
            to: new FormControl((_b = dateRange === null || dateRange === void 0 ? void 0 : dateRange.to) !== null && _b !== void 0 ? _b : null),
        }, { validators: dateOrderValidator });
    }
}
const dateOrderValidator = (control) => {
    var _a, _b, _c, _d;
    let error = null;
    if (((_a = control.get('from')) === null || _a === void 0 ? void 0 : _a.value) instanceof Date && ((_b = control.get('to')) === null || _b === void 0 ? void 0 : _b.value) instanceof Date) {
        const startTime = (_c = control.get('from')) === null || _c === void 0 ? void 0 : _c.value;
        const endTime = (_d = control.get('to')) === null || _d === void 0 ? void 0 : _d.value;
        if (startTime && endTime && startTime && startTime.valueOf() > endTime.valueOf()) {
            error = { dateTimeOrder: true };
        }
    }
    return error;
};

class BaseReactiveForm {
    constructor(formGroup) {
        this.dirtySubject$ = new Subject();
        this.formGroup = formGroup;
        this.valid$ = this.formGroup.statusChanges.pipe(map(() => this.formGroup.valid), distinctUntilChanged(), startWith(this.formGroup.valid));
        const dirtyFromForm$ = this.formGroup.statusChanges.pipe(map(() => this.formGroup.dirty));
        this.dirty$ = merge(dirtyFromForm$, this.dirtySubject$).pipe(distinctUntilChanged(), startWith(this.dirty));
    }
    get valid() {
        return this.formGroup.valid;
    }
    get dirty() {
        return this.formGroup.dirty;
    }
    set dirty(value) {
        value ? this.formGroup.markAsDirty() : this.formGroup.markAsPristine();
        this.dirtySubject$.next(value);
    }
    set isSaving(value) {
        value ? this.formGroup.disable({ emitEvent: false }) : this.formGroup.enable({ emitEvent: false });
    }
}

class SLetDirective {
    constructor(viewContainer, templateRef) {
        this.context = { sLet: null };
        viewContainer.createEmbeddedView(templateRef, this.context);
    }
    set sLet(value) {
        this.context.sLet = value;
    }
}
SLetDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SLetDirective, deps: [{ token: i0.ViewContainerRef }, { token: i0.TemplateRef }], target: i0.ɵɵFactoryTarget.Directive });
SLetDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.12", type: SLetDirective, selector: "[sLet]", inputs: { sLet: "sLet" }, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SLetDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[sLet]',
                }]
        }], ctorParameters: function () { return [{ type: i0.ViewContainerRef }, { type: i0.TemplateRef }]; }, propDecorators: { sLet: [{
                type: Input
            }] } });

class SLetModule {
}
SLetModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SLetModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
SLetModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: SLetModule, declarations: [SLetDirective], exports: [SLetDirective] });
SLetModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SLetModule });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SLetModule, decorators: [{
            type: NgModule,
            args: [{ declarations: [SLetDirective], exports: [SLetDirective] }]
        }] });

/**
 * Base directive to handle behaviour common for all components.
 * By extending this directive you don't need to store subscriptions and unsubscribe in ngOnDestroy of each component
 * but simply pipe the observable with takeWhile(() => this.isAlive)
 */
class SentinelBaseDirective {
    constructor() {
        this.isAlive = true;
    }
    ngOnDestroy() {
        this.isAlive = false;
    }
}
SentinelBaseDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelBaseDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive });
SentinelBaseDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.12", type: SentinelBaseDirective, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelBaseDirective, decorators: [{
            type: Directive
        }] });

function Destroyable(Base = class {
}) {
    return class extends Base {
        constructor() {
            super(...arguments);
            this.destroy$ = new Subject();
        }
        ngOnDestroy() {
            this.destroy$.next();
        }
    };
}

/**
 * Util class merging multiple http params into one http params object
 */
class SentinelParamsMerger {
    /**
     * Merges multiple http params into one http params object
     * @param params list of http params object to be merged
     */
    static merge(params) {
        let resultParams = new HttpParams();
        params.forEach((param) => param.keys().forEach((key) => (resultParams = resultParams.set(key, param.get(key)))));
        return resultParams;
    }
}

class ResponseHeaderContentDispositionReader {
    static getFilenameFromResponse(resp, defaultFilename) {
        try {
            return resp.headers.get('content-disposition').split(';')[1].split('filename')[1].split('=')[1].trim();
        }
        catch (error) {
            return defaultFilename;
        }
    }
}

/**
 * Holds resource state data in an observable.
 * Subscribe to resource$ to receive latest data updates.
 */
class ResourceService {
    constructor() {
        /**
         * True if server returned error response on the latest request, false otherwise
         * Change internally in extending service. Client should subscribe to the observable
         */
        this.hasErrorSubject$ = new BehaviorSubject(false);
        /**
         * True if server returned error response on the latest request, false otherwise
         * @contract must be updated every time new data are received
         */
        this.hasError$ = this.hasErrorSubject$.asObservable();
        /**
         * True if response to the latest request was not yet received
         * Change internally in extending service. Client should subscribe to the observable
         */
        this.isLoadingSubject$ = new BehaviorSubject(false);
        /**
         * True if response to the latest request was not yet received
         * @contract must be updated every time new data are received
         */
        this.isLoading$ = this.isLoadingSubject$.asObservable();
        /**
         * Resource data of generic type. Change internally in extending service.
         * Client should subscribe to the observable
         * @contract must be updated every time new data are received
         */
        this.resourceSubject$ = new BehaviorSubject(undefined);
        /**
         * Resource data of generic type. Change internally in extending service.
         * Client should subscribe to the observable
         * @contract must be updated every time new data are received
         */
        this.resource$ = this.resourceSubject$.asObservable();
    }
}

/**
 * Adds polling behaviour to resource service
 */
class ResourcePollingService extends ResourceService {
    constructor(pollPeriod = 5000) {
        super();
        /**
         * Observable triggering retry of polling after it was interrupted (e.g. by error)
         */
        this.retryPolling$ = new Subject();
        this.pollPeriod = pollPeriod;
        this.resource$ = merge(this.createPoll(), this.resourceSubject$.asObservable());
    }
    /**
     * Performs necessary operations and updates state of the service.
     * @contract Needs to update hasError subject and retry polling
     * if it was previously interrupted
     * @param params any other parameters required to update data in your concrete service
     */
    onManualResourceRefresh(...params) {
        if (this.hasErrorSubject$.getValue()) {
            this.retryPolling$.next(true);
        }
        this.hasErrorSubject$.next(false);
    }
    /**
     * Creates poll observable using a timer. You can extend the behaviour by piping the observable and applying
     * RxJs operators on it (e.g. takeWhile to stop polling on specific conditions)
     * @param dueTime optionally set a due time when the timer should start. By default it equals to the
     * poll period as it is expected that the first request is made from the service or component
     * using the service (to properly set up pagination and all other possible params like ids etc)
     */
    createPoll(dueTime = this.pollPeriod) {
        return timer(dueTime, this.pollPeriod).pipe(switchMap(() => this.refreshResource()), retryWhen(() => this.retryPolling$));
    }
}

/**
 * Contains subjects and observables typically used when handling paginated data.
 * Subscribe to resource$ to receive latest data updates.
 */
class PaginatedElementsService {
    constructor(pageSize = 10) {
        /**
         * True if server returned error response on the latest request, false otherwise
         * Change internally in extending service. Client should subscribe to the observable
         */
        this.hasErrorSubject$ = new BehaviorSubject(false);
        /**
         * True if server returned error response on the latest request, false otherwise
         * @contract must be updated every time new data are received
         */
        this.hasError$ = this.hasErrorSubject$.asObservable();
        /**
         * True if response to the latest request was not yet received
         * Change internally in extending service. Client should subscribe to the observable
         */
        this.isLoadingSubject$ = new BehaviorSubject(false);
        /**
         * True if response to the latest request was not yet received
         * @contract must be updated every time new data are received
         */
        this.isLoading$ = this.isLoadingSubject$.asObservable();
        this.resourceSubject$ = new BehaviorSubject(this.initSubject(pageSize));
        this.resource$ = this.resourceSubject$.asObservable();
    }
}

class CursorPaginatedElementsService extends PaginatedElementsService {
    initSubject(pageSize) {
        return new PaginatedResource([], new CursorPagination(null, 0, pageSize, 0, null, null));
    }
}

/**
 * Adds polling behaviour to paginated elements service
 */
class PaginatedElementsPollingService extends PaginatedElementsService {
    constructor(defaultPaginationSize, pollPeriod) {
        super(defaultPaginationSize);
        /**
         * Observable triggering retry of polling after it was interrupted (e.g. by error)
         */
        this.retryPolling$ = new Subject();
        this.pollPeriod = pollPeriod;
        this.resource$ = merge(this.createPoll(), this.resourceSubject$.asObservable());
    }
    /**
     * Performs necessary operations and updates state of the service.
     * @contract Needs to update lastPagination attribute, hasError subject and retry polling
     * if it was previously interrupted
     * @param pagination new requested pagination
     * @param params any other parameters required to update data in your concrete service
     */
    onManualResourceRefresh(pagination, ...params) {
        this.lastPagination = pagination;
        if (this.hasErrorSubject$.getValue()) {
            this.retryPolling$.next(true);
        }
        this.hasErrorSubject$.next(false);
    }
    /**
     * Creates poll observable using a timer. You can extend the behaviour by piping the observable and applying
     * RxJs operators on it (e.g. takeWhile to stop polling on specific conditions)
     * @param dueTime optionally set a due time when the timer should start. By default it equals to the
     * poll period as it is expected that the first request is made from the service or component
     * using the service (to properly set up pagination and all other possible params like ids etc)
     */
    createPoll(dueTime = this.pollPeriod) {
        return timer(dueTime, this.pollPeriod).pipe(switchMap(() => this.refreshResource()), retryWhen(() => this.retryPolling$));
    }
}

class CursorPaginatedElementsPollingService extends PaginatedElementsPollingService {
    initSubject(pageSize) {
        return new PaginatedResource([], new CursorPagination(null, 0, pageSize, 0, null, null));
    }
}

class OffsetPaginatedElementsService extends PaginatedElementsService {
    initSubject(pageSize) {
        return new PaginatedResource([], new OffsetPagination(0, 0, pageSize, 0, 0));
    }
}

class OffsetPaginatedElementsPollingService extends PaginatedElementsPollingService {
    initSubject(pageSize) {
        return new PaginatedResource([], new OffsetPagination(0, 0, pageSize, 0, 0));
    }
}

class SentinelValidators {
}
SentinelValidators.noWhitespace = (control) => {
    const isWhitespace = (control.value || '').trim().length === 0;
    const isValid = !isWhitespace;
    return isValid ? null : { whitespace: true };
};
SentinelValidators.min = (min) => {
    return Validators.min(min);
};
SentinelValidators.max = (max) => {
    return Validators.max(max);
};
SentinelValidators.required = (control) => {
    return Validators.required(control);
};
SentinelValidators.requiredTrue = (control) => {
    return Validators.requiredTrue(control);
};
SentinelValidators.email = (control) => {
    return Validators.email(control);
};
SentinelValidators.minLength = (minLength) => {
    return Validators.minLength(minLength);
};
SentinelValidators.maxLength = (maxLength) => {
    return Validators.maxLength(maxLength);
};
SentinelValidators.pattern = (pattern) => {
    return Validators.pattern(pattern);
};
SentinelValidators.nullValidator = (control) => {
    return Validators.nullValidator(control);
};
SentinelValidators.compose = (validators) => {
    return Validators.compose(validators);
};
SentinelValidators.composeAsync = (validators) => {
    return Validators.composeAsync(validators);
};

/*
 * Public API Surface of sentinel-common
 */

/**
 * Generated bundle index. Do not edit.
 */

export { BaseReactiveForm, CursorPaginatedElementsPollingService, CursorPaginatedElementsService, DateRangeForm, Destroyable, OffsetPaginatedElementsPollingService, OffsetPaginatedElementsService, ResourcePollingService, ResourceService, ResponseHeaderContentDispositionReader, SLetDirective, SLetModule, SentinelBaseDirective, SentinelParamsMerger, SentinelValidators, dateOrderValidator };
//# sourceMappingURL=sentinel-common.mjs.map
