import * as i0 from '@angular/core';
import { EventEmitter, Component, ChangeDetectionStrategy, Output, Input, Directive, NgModule } from '@angular/core';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i2 from '@angular/material/button';
import { MatButtonModule } from '@angular/material/button';
import * as i3 from '@angular/material/icon';
import { MatIconModule } from '@angular/material/icon';
import { switchMap, takeWhile } from 'rxjs/operators';

/**
 * Error component with optional try again button
 */
class SentinelErrorComponent {
    constructor() {
        /**
         * Emits event when try again button is clicked
         */
        this.tryAgainClicked = new EventEmitter();
        this.isAlive = true;
    }
    ngOnDestroy() {
        this.isAlive = false;
    }
}
SentinelErrorComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelErrorComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
SentinelErrorComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: SentinelErrorComponent, selector: "sentinel-error", inputs: { hasTryAgainButton: "hasTryAgainButton" }, outputs: { tryAgainClicked: "tryAgainClicked" }, ngImport: i0, template: "<div class=\"sentinel-error-message\">\n  <span class=\"sentinel-error-message-icon\"><mat-icon color=\"warn\">warning</mat-icon></span>\n  <div class=\"sentinel-error-message-content\">\n    <span>We had some trouble loading the data</span>\n  </div>\n  <div class=\"sentinel-error-try-again\">\n    <button *ngIf=\"hasTryAgainButton\" mat-flat-button (click)=\"tryAgainClicked.emit()\" color=\"primary\">\n      Try Again\n    </button>\n  </div>\n</div>\n", styles: [".sentinel-error-message{display:flex;flex-direction:column}.sentinel-error-message-icon,.sentinel-error-try-again{display:flex;justify-content:center}.sentinel-error-message-content{text-align:center;margin:10px 0}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i2.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { kind: "component", type: i3.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelErrorComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sentinel-error', changeDetection: ChangeDetectionStrategy.OnPush, template: "<div class=\"sentinel-error-message\">\n  <span class=\"sentinel-error-message-icon\"><mat-icon color=\"warn\">warning</mat-icon></span>\n  <div class=\"sentinel-error-message-content\">\n    <span>We had some trouble loading the data</span>\n  </div>\n  <div class=\"sentinel-error-try-again\">\n    <button *ngIf=\"hasTryAgainButton\" mat-flat-button (click)=\"tryAgainClicked.emit()\" color=\"primary\">\n      Try Again\n    </button>\n  </div>\n</div>\n", styles: [".sentinel-error-message{display:flex;flex-direction:column}.sentinel-error-message-icon,.sentinel-error-try-again{display:flex;justify-content:center}.sentinel-error-message-content{text-align:center;margin:10px 0}\n"] }]
        }], propDecorators: { tryAgainClicked: [{
                type: Output
            }], hasTryAgainButton: [{
                type: Input
            }] } });

/**
 * Structural directive on *ngIf principle. Displays error message if the condition is true,
 * desired component if the condition is false. Optionally, tryAgain$ Observable can be passed
 * using the Angular micro syntax. The tryAgain$ should be an observable, repeating the failed action
 * and it will be triggered after user clicks on "try again button".
 *
 * @usage
 * <div *sentinelError="hasError; tryAgain$: onTryAgain$"></div>
 */
class SentinelErrorDirective {
    constructor(templateRef, vcRef, componentFactoryResolver) {
        this.templateRef = templateRef;
        this.vcRef = vcRef;
        this.componentFactoryResolver = componentFactoryResolver;
        this.errorFactory = this.componentFactoryResolver.resolveComponentFactory(SentinelErrorComponent);
    }
    set sentinelError(hasError) {
        this.hasError = hasError;
        this.vcRef.clear();
        this.createComponent();
    }
    set sentinelErrorTryAgain$(tryAgain$) {
        this.tryAgain$ = tryAgain$;
        this.vcRef.clear();
        this.createComponent();
    }
    createComponent() {
        if (this.hasError) {
            this.createErrorComponent();
            if (this.tryAgain$ !== undefined) {
                this.setupTryAgain(this.errorComponent.instance);
            }
        }
        else {
            this.destroyErrorComponent();
            this.createEmbeddedComponent();
        }
    }
    createErrorComponent() {
        this.errorComponent = this.vcRef.createComponent(this.errorFactory, 0);
    }
    destroyErrorComponent() {
        if (this.errorComponent) {
            this.errorComponent.destroy();
        }
    }
    setupTryAgain(errorComponentInstance) {
        errorComponentInstance.hasTryAgainButton = this.tryAgain$ !== undefined;
        errorComponentInstance.tryAgainClicked
            .pipe(switchMap((event) => this.tryAgain$.pipe(takeWhile((_) => errorComponentInstance.isAlive))))
            .subscribe();
    }
    createEmbeddedComponent() {
        this.vcRef.createEmbeddedView(this.templateRef);
    }
}
SentinelErrorDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelErrorDirective, deps: [{ token: i0.TemplateRef }, { token: i0.ViewContainerRef }, { token: i0.ComponentFactoryResolver }], target: i0.ɵɵFactoryTarget.Directive });
SentinelErrorDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.12", type: SentinelErrorDirective, selector: "[sentinelError], [sentinelErrorTryAgain]", inputs: { sentinelError: "sentinelError", sentinelErrorTryAgain$: "sentinelErrorTryAgain$" }, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelErrorDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[sentinelError], [sentinelErrorTryAgain]',
                }]
        }], ctorParameters: function () { return [{ type: i0.TemplateRef }, { type: i0.ViewContainerRef }, { type: i0.ComponentFactoryResolver }]; }, propDecorators: { sentinelError: [{
                type: Input
            }], sentinelErrorTryAgain$: [{
                type: Input
            }] } });

class SentinelErrorModule {
}
SentinelErrorModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelErrorModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
SentinelErrorModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: SentinelErrorModule, declarations: [SentinelErrorComponent, SentinelErrorDirective], imports: [CommonModule, MatButtonModule, MatIconModule], exports: [SentinelErrorComponent, SentinelErrorDirective] });
SentinelErrorModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelErrorModule, imports: [CommonModule, MatButtonModule, MatIconModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelErrorModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [SentinelErrorComponent, SentinelErrorDirective],
                    imports: [CommonModule, MatButtonModule, MatIconModule],
                    exports: [SentinelErrorComponent, SentinelErrorDirective],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { SentinelErrorComponent, SentinelErrorDirective, SentinelErrorModule };
//# sourceMappingURL=sentinel-components-error.mjs.map
