import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { NgModule, EventEmitter, Component, ChangeDetectionStrategy, Input, Output } from '@angular/core';
import * as i2 from '@angular/forms';
import { UntypedFormGroup, UntypedFormArray, UntypedFormControl, FormsModule, ReactiveFormsModule } from '@angular/forms';
import * as i4 from '@angular/material/button';
import { MatButtonModule } from '@angular/material/button';
import * as i7 from '@angular/material/divider';
import { MatDividerModule } from '@angular/material/divider';
import * as i5 from '@angular/material/form-field';
import { MatFormFieldModule } from '@angular/material/form-field';
import * as i3 from '@angular/material/icon';
import { MatIconModule } from '@angular/material/icon';
import * as i6 from '@angular/material/input';
import { MatInputModule } from '@angular/material/input';
import { SentinelValidators, SentinelBaseDirective } from '@sentinel/common';
import { trackByIndex } from '@sentinel/common/utils';

/**
 * Material component imports for shared module
 */
class SentinelFreeFormMaterialModule {
}
SentinelFreeFormMaterialModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelFreeFormMaterialModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
SentinelFreeFormMaterialModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: SentinelFreeFormMaterialModule, imports: [MatIconModule, MatButtonModule, MatFormFieldModule, MatInputModule, MatDividerModule], exports: [MatIconModule, MatButtonModule, MatFormFieldModule, MatInputModule, MatDividerModule] });
SentinelFreeFormMaterialModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelFreeFormMaterialModule, imports: [MatIconModule, MatButtonModule, MatFormFieldModule, MatInputModule, MatDividerModule, MatIconModule, MatButtonModule, MatFormFieldModule, MatInputModule, MatDividerModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelFreeFormMaterialModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [MatIconModule, MatButtonModule, MatFormFieldModule, MatInputModule, MatDividerModule],
                    exports: [MatIconModule, MatButtonModule, MatFormFieldModule, MatInputModule, MatDividerModule],
                }]
        }] });

/**
 * Group of inputs for free form component
 */
class FreeFormItemFormGroup {
    constructor(ffa, required) {
        this.formGroup = new UntypedFormGroup({
            items: new UntypedFormArray(ffa.value.map((item) => new UntypedFormControl(item, required ? SentinelValidators.noWhitespace : undefined))),
        });
    }
}

/**
 * Component coupling multiple form inputs with possibility to add more inputs and remove already existing.
 * Suitable for forms where user should input multiple values under some group/topic
 */
class SentinelFreeFormComponent extends SentinelBaseDirective {
    constructor() {
        super(...arguments);
        /**
         * Emits current state of items on each change of input
         */
        this.itemsChange = new EventEmitter();
        this.trackByFn = trackByIndex;
    }
    get items() {
        return this.freeFormItemFormGroup.formGroup.get('items');
    }
    ngOnInit() {
        this.initForm();
    }
    ngOnChanges(changes) {
        if ('formData' in changes) {
            if (this.freeFormItemFormGroup) {
                this.freeFormItemFormGroup.formGroup.patchValue({ items: this.formData });
            }
            else {
                this.freeFormItemFormGroup = new FreeFormItemFormGroup(this.formData, this.required);
            }
            this.freeFormItemFormGroup.formGroup.updateValueAndValidity();
        }
        if ('required' in changes) {
            this.freeFormItemFormGroup.formGroup.updateValueAndValidity();
        }
    }
    /**
     * Initializes form with default values and placeholders
     */
    initForm() {
        if (!this.formName || this.formName === '') {
            this.formName = 'Items';
        }
        if (!this.formPlaceholder || this.formPlaceholder === '') {
            this.formPlaceholder = 'Item';
        }
    }
    /**
     * Adds new input to the form
     */
    addItem() {
        this.items.push(new UntypedFormControl('', this.required ? SentinelValidators.noWhitespace : undefined));
        this.freeFormItemFormGroup.formGroup.markAsDirty();
        this.freeFormItemFormGroup.formGroup.updateValueAndValidity();
        this.emitChange();
    }
    /**
     * Removes input
     * @param index index of input in form
     */
    removeItem(index) {
        this.items.removeAt(index);
        this.emitChange();
    }
    /**
     * Removes all inputs
     */
    clear() {
        this.items.clear();
        this.freeFormItemFormGroup.formGroup.updateValueAndValidity();
        this.emitChange();
    }
    onChanged() {
        this.freeFormItemFormGroup.formGroup.updateValueAndValidity();
        this.freeFormItemFormGroup.formGroup.markAsDirty();
        this.emitChange();
    }
    emitChange() {
        this.itemsChange.emit(this.freeFormItemFormGroup.formGroup);
    }
}
SentinelFreeFormComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelFreeFormComponent, deps: null, target: i0.ɵɵFactoryTarget.Component });
SentinelFreeFormComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: SentinelFreeFormComponent, selector: "sentinel-free-form", inputs: { formName: "formName", formPlaceholder: "formPlaceholder", formData: "formData", hasHeader: "hasHeader", required: "required" }, outputs: { itemsChange: "itemsChange" }, usesInheritance: true, usesOnChanges: true, ngImport: i0, template: "<div class=\"free-form-header\" *ngIf=\"hasHeader\">\n  <!-- FORM label-->\n  <mat-label>{{ formName }}</mat-label>\n  <mat-divider></mat-divider>\n</div>\n\n<!-- ADD button-->\n<button color=\"primary\" mat-button (click)=\"addItem()\">Add {{ formPlaceholder }}</button>\n<!-- DELETE button-->\n<button [disabled]=\"items.controls.length < 1\" color=\"warn\" mat-button (click)=\"clear()\">Delete all</button>\n\n<!-- ITEM field-->\n<form [formGroup]=\"freeFormItemFormGroup.formGroup\">\n  <div class=\"form-container\">\n    <div *ngIf=\"items.controls && items.controls.length > 0; else noItems\" formArrayName=\"items\">\n      <div class=\"item\" *ngFor=\"let item of items.controls; index as i; trackBy: trackByFn\">\n        <mat-form-field appearance=\"outline\" (keydown.enter)=\"$event.preventDefault()\">\n          <mat-label>{{ formPlaceholder }}</mat-label>\n          <input matInput placeholder=\"{{ formPlaceholder }}\" [formControl]=\"item\" (input)=\"onChanged()\" />\n          <button\n            class=\"free-form-clear-btn\"\n            mat-button\n            *ngIf=\"item.value\"\n            matSuffix\n            mat-icon-button\n            aria-label=\"Clear\"\n            (click)=\"item.setValue(''); onChanged()\"\n          >\n            <mat-icon>close</mat-icon>\n          </button>\n          <mat-error *ngIf=\"item.hasError('whitespace')\">{{ formName }} cannot be empty</mat-error>\n        </mat-form-field>\n\n        <!-- REMOVE button-->\n        <button class=\"remove-btn\" mat-button color=\"warn\" (click)=\"removeItem(i)\">\n          <mat-icon>remove_circle</mat-icon>\n        </button>\n      </div>\n    </div>\n    <ng-template #noItems>\n      <h4>No items added</h4>\n    </ng-template>\n  </div>\n</form>\n", styles: ["@media screen and (max-width: 900px){.form-container{display:flex;flex-direction:column}}.item{display:flex}.item mat-form-field{width:100%}.remove-btn{height:60px;width:20px}mat-divider{padding-bottom:10px}h4{text-align:center;color:#00000042}\n"], dependencies: [{ kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "component", type: i3.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { kind: "component", type: i4.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { kind: "directive", type: i5.MatError, selector: "mat-error", inputs: ["id"] }, { kind: "component", type: i5.MatFormField, selector: "mat-form-field", inputs: ["color", "appearance", "hideRequiredMarker", "hintLabel", "floatLabel"], exportAs: ["matFormField"] }, { kind: "directive", type: i5.MatLabel, selector: "mat-label" }, { kind: "directive", type: i5.MatSuffix, selector: "[matSuffix]" }, { kind: "directive", type: i6.MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["disabled", "id", "placeholder", "name", "required", "type", "errorStateMatcher", "aria-describedby", "value", "readonly"], exportAs: ["matInput"] }, { kind: "component", type: i7.MatDivider, selector: "mat-divider", inputs: ["vertical", "inset"] }, { kind: "directive", type: i2.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }, { kind: "directive", type: i2.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i2.FormArrayName, selector: "[formArrayName]", inputs: ["formArrayName"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelFreeFormComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sentinel-free-form', changeDetection: ChangeDetectionStrategy.OnPush, template: "<div class=\"free-form-header\" *ngIf=\"hasHeader\">\n  <!-- FORM label-->\n  <mat-label>{{ formName }}</mat-label>\n  <mat-divider></mat-divider>\n</div>\n\n<!-- ADD button-->\n<button color=\"primary\" mat-button (click)=\"addItem()\">Add {{ formPlaceholder }}</button>\n<!-- DELETE button-->\n<button [disabled]=\"items.controls.length < 1\" color=\"warn\" mat-button (click)=\"clear()\">Delete all</button>\n\n<!-- ITEM field-->\n<form [formGroup]=\"freeFormItemFormGroup.formGroup\">\n  <div class=\"form-container\">\n    <div *ngIf=\"items.controls && items.controls.length > 0; else noItems\" formArrayName=\"items\">\n      <div class=\"item\" *ngFor=\"let item of items.controls; index as i; trackBy: trackByFn\">\n        <mat-form-field appearance=\"outline\" (keydown.enter)=\"$event.preventDefault()\">\n          <mat-label>{{ formPlaceholder }}</mat-label>\n          <input matInput placeholder=\"{{ formPlaceholder }}\" [formControl]=\"item\" (input)=\"onChanged()\" />\n          <button\n            class=\"free-form-clear-btn\"\n            mat-button\n            *ngIf=\"item.value\"\n            matSuffix\n            mat-icon-button\n            aria-label=\"Clear\"\n            (click)=\"item.setValue(''); onChanged()\"\n          >\n            <mat-icon>close</mat-icon>\n          </button>\n          <mat-error *ngIf=\"item.hasError('whitespace')\">{{ formName }} cannot be empty</mat-error>\n        </mat-form-field>\n\n        <!-- REMOVE button-->\n        <button class=\"remove-btn\" mat-button color=\"warn\" (click)=\"removeItem(i)\">\n          <mat-icon>remove_circle</mat-icon>\n        </button>\n      </div>\n    </div>\n    <ng-template #noItems>\n      <h4>No items added</h4>\n    </ng-template>\n  </div>\n</form>\n", styles: ["@media screen and (max-width: 900px){.form-container{display:flex;flex-direction:column}}.item{display:flex}.item mat-form-field{width:100%}.remove-btn{height:60px;width:20px}mat-divider{padding-bottom:10px}h4{text-align:center;color:#00000042}\n"] }]
        }], propDecorators: { formName: [{
                type: Input
            }], formPlaceholder: [{
                type: Input
            }], formData: [{
                type: Input
            }], hasHeader: [{
                type: Input
            }], required: [{
                type: Input
            }], itemsChange: [{
                type: Output
            }] } });

/**
 * Free form component module
 */
class SentinelFreeFormModule {
}
SentinelFreeFormModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelFreeFormModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
SentinelFreeFormModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: SentinelFreeFormModule, declarations: [SentinelFreeFormComponent], imports: [CommonModule, FormsModule, SentinelFreeFormMaterialModule, ReactiveFormsModule], exports: [SentinelFreeFormComponent] });
SentinelFreeFormModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelFreeFormModule, imports: [CommonModule, FormsModule, SentinelFreeFormMaterialModule, ReactiveFormsModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelFreeFormModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule, FormsModule, SentinelFreeFormMaterialModule, ReactiveFormsModule],
                    declarations: [SentinelFreeFormComponent],
                    exports: [SentinelFreeFormComponent],
                }]
        }] });

/*
 * Public API Surface of @sentinel/components/free-form
 */

/**
 * Generated bundle index. Do not edit.
 */

export { SentinelFreeFormComponent, SentinelFreeFormModule };
//# sourceMappingURL=sentinel-components-free-form.mjs.map
