import * as i0 from '@angular/core';
import { Pipe, EventEmitter, Component, ChangeDetectionStrategy, Input, Output, NgModule } from '@angular/core';
import * as i3 from '@angular/material/radio';
import { MatRadioChange, MatRadioModule } from '@angular/material/radio';
import { SentinelInfiniteScrollerDirective } from '@sentinel/components/infinite-scroll';
import * as i1 from '@angular/cdk/scrolling';
import { ScrollingModule } from '@angular/cdk/scrolling';
import * as i2 from '@angular/material/list';
import { MatListModule } from '@angular/material/list';
import * as i4 from '@angular/material/button';
import { MatButtonModule } from '@angular/material/button';
import * as i5 from '@angular/material/progress-spinner';
import { MatProgressSpinnerModule } from '@angular/material/progress-spinner';
import * as i6 from '@angular/material/checkbox';
import { MatCheckboxModule } from '@angular/material/checkbox';
import * as i7 from '@angular/material/icon';
import { MatIconModule } from '@angular/material/icon';
import * as i8 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i9 from '@sentinel/common/pipes';
import { SentinelPipesModule } from '@sentinel/common/pipes';

class IsSelectedPipe {
    static resourceEquals(a, b, resourceMapping) {
        if (a === undefined || a === null || b === undefined || b === null) {
            return false;
        }
        return a[resourceMapping.id] === b[resourceMapping.id];
    }
    transform(resource, resourceMapping, selections) {
        return (resource &&
            selections.some((selectedResource) => IsSelectedPipe.resourceEquals(selectedResource, resource, resourceMapping)));
    }
}
IsSelectedPipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: IsSelectedPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
IsSelectedPipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: IsSelectedPipe, name: "isSelected" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: IsSelectedPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'isSelected',
                }]
        }] });

/**
 * Basic component displaying resource in a list with the infinite scroll. It provides selectable behaviour (radio or checkbox)
 */
class SentinelListComponent extends SentinelInfiniteScrollerDirective {
    constructor() {
        super(...arguments);
        this.DEFAULT_RESOURCE_MAPPING = { id: 'id', title: 'title' };
        /**
         * Mode of the list
         * View only displays the resource, radio and checkbox adds selection options
         */
        this.mode = 'view';
        /**
         * Mapping of resource attribute names. Resource is expected to have attributes that can be used as an id and title.
         */
        this.resourceMapping = this.DEFAULT_RESOURCE_MAPPING;
        /**
         * Currently selected resources
         */
        this.selected = [];
        /**
         * Emits event on selection change. Emits all currently selected resources
         */
        this.selectionChange = new EventEmitter();
    }
    onSelected(selected, changeEvent) {
        if (changeEvent instanceof MatRadioChange) {
            this.onRadioSelected(selected);
        }
        else {
            this.onCheckboxSelected(selected, changeEvent);
        }
    }
    onRadioSelected(selected) {
        this.selectionChange.emit([selected]);
    }
    onCheckboxSelected(selected, changeEvent) {
        if (changeEvent.checked) {
            this.selectionChange.emit([selected, ...this.selected]);
        }
        else {
            const filtered = this.selected.filter((resource) => !IsSelectedPipe.resourceEquals(selected, resource, this.resourceMapping));
            this.selectionChange.emit(filtered);
        }
    }
}
SentinelListComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelListComponent, deps: null, target: i0.ɵɵFactoryTarget.Component });
SentinelListComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: SentinelListComponent, selector: "sentinel-list", inputs: { mode: "mode", resourceName: "resourceName", titleMaxLength: "titleMaxLength", resourceMapping: "resourceMapping", selected: "selected" }, outputs: { selectionChange: "selectionChange" }, usesInheritance: true, ngImport: i0, template: "<div *ngIf=\"scrollItems.length > 0 || hasError; else isEmpty\" class=\"sentinel-list-container\">\n  <h3 *ngIf=\"resourceName\" mat-subheader>{{ resourceName | titlecase }}</h3>\n  <div *ngIf=\"hasError\" class=\"error\">\n    <p>We have some trouble loading the data. Please try again later.</p>\n    <button mat-icon-button (click)=\"reload()\" color=\"primary\"><mat-icon>refresh</mat-icon></button>\n  </div>\n  <cdk-virtual-scroll-viewport\n    [itemSize]=\"viewPortItemHeight\"\n    [style.height.px]=\"viewportHeight\"\n    (scrolledIndexChange)=\"nextPage($event)\"\n  >\n    <mat-list-item *cdkVirtualFor=\"let resource of scrollItems; trackBy: trackByFn\">\n      <div class=\"list-item\">\n        <div [ngSwitch]=\"mode\">\n          <mat-radio-button\n            *ngSwitchCase=\"'radio'\"\n            class=\"radio-element\"\n            [checked]=\"resource | isSelected: resourceMapping:selected\"\n            [value]=\"resource\"\n            (change)=\"onSelected(resource, $event)\"\n          >\n            {{\n              titleMaxLength\n                ? (resource[resourceMapping.title] | sentinelShortString: titleMaxLength)\n                : resource[resourceMapping.title]\n            }}\n          </mat-radio-button>\n\n          <mat-checkbox\n            *ngSwitchCase=\"'checkbox'\"\n            class=\"checkbox-element\"\n            [checked]=\"resource | isSelected: resourceMapping:selected\"\n            [value]=\"resource\"\n            (change)=\"onSelected(resource, $event)\"\n          >\n            {{\n              titleMaxLength\n                ? (resource[resourceMapping.title] | sentinelShortString: titleMaxLength)\n                : resource[resourceMapping.title]\n            }}\n          </mat-checkbox>\n\n          <p *ngSwitchCase=\"'view'\" class=\"view-element\">\n            {{\n              titleMaxLength\n                ? (resource[resourceMapping.title] | sentinelShortString: titleMaxLength)\n                : resource[resourceMapping.title]\n            }}\n          </p>\n        </div>\n      </div>\n    </mat-list-item>\n  </cdk-virtual-scroll-viewport>\n  <div *ngIf=\"isLoading\" class=\"loading\">\n    <mat-spinner mode=\"indeterminate\" color=\"accent\" diameter=\"25\"></mat-spinner>\n  </div>\n</div>\n<ng-template #isEmpty>\n  <p class=\"no-resource-message\">No {{ resourceName | lowercase }} found</p>\n</ng-template>\n", styles: [".error{color:#f44336;display:flex;flex-direction:row;align-items:baseline;justify-content:center}.sentinel-list-container{background-color:inherit;color:inherit}.loading{display:flex;width:100%;justify-content:center}.list-item{height:25px;padding:10px}\n"], dependencies: [{ kind: "directive", type: i1.CdkFixedSizeVirtualScroll, selector: "cdk-virtual-scroll-viewport[itemSize]", inputs: ["itemSize", "minBufferPx", "maxBufferPx"] }, { kind: "directive", type: i1.CdkVirtualForOf, selector: "[cdkVirtualFor][cdkVirtualForOf]", inputs: ["cdkVirtualForOf", "cdkVirtualForTrackBy", "cdkVirtualForTemplate", "cdkVirtualForTemplateCacheSize"] }, { kind: "component", type: i1.CdkVirtualScrollViewport, selector: "cdk-virtual-scroll-viewport", inputs: ["orientation", "appendOnly"], outputs: ["scrolledIndexChange"] }, { kind: "component", type: i2.MatListItem, selector: "mat-list-item, a[mat-list-item], button[mat-list-item]", inputs: ["disableRipple", "disabled"], exportAs: ["matListItem"] }, { kind: "directive", type: i2.MatListSubheaderCssMatStyler, selector: "[mat-subheader], [matSubheader]" }, { kind: "component", type: i3.MatRadioButton, selector: "mat-radio-button", inputs: ["disableRipple", "tabIndex"], exportAs: ["matRadioButton"] }, { kind: "component", type: i4.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { kind: "component", type: i5.MatProgressSpinner, selector: "mat-progress-spinner, mat-spinner", inputs: ["color", "diameter", "strokeWidth", "mode", "value"], exportAs: ["matProgressSpinner"] }, { kind: "component", type: i6.MatCheckbox, selector: "mat-checkbox", inputs: ["disableRipple", "color", "tabIndex"], exportAs: ["matCheckbox"] }, { kind: "component", type: i7.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { kind: "directive", type: i8.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i8.NgSwitch, selector: "[ngSwitch]", inputs: ["ngSwitch"] }, { kind: "directive", type: i8.NgSwitchCase, selector: "[ngSwitchCase]", inputs: ["ngSwitchCase"] }, { kind: "pipe", type: i9.SentinelShortStringPipe, name: "sentinelShortString" }, { kind: "pipe", type: i8.LowerCasePipe, name: "lowercase" }, { kind: "pipe", type: i8.TitleCasePipe, name: "titlecase" }, { kind: "pipe", type: IsSelectedPipe, name: "isSelected" }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelListComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sentinel-list', changeDetection: ChangeDetectionStrategy.OnPush, template: "<div *ngIf=\"scrollItems.length > 0 || hasError; else isEmpty\" class=\"sentinel-list-container\">\n  <h3 *ngIf=\"resourceName\" mat-subheader>{{ resourceName | titlecase }}</h3>\n  <div *ngIf=\"hasError\" class=\"error\">\n    <p>We have some trouble loading the data. Please try again later.</p>\n    <button mat-icon-button (click)=\"reload()\" color=\"primary\"><mat-icon>refresh</mat-icon></button>\n  </div>\n  <cdk-virtual-scroll-viewport\n    [itemSize]=\"viewPortItemHeight\"\n    [style.height.px]=\"viewportHeight\"\n    (scrolledIndexChange)=\"nextPage($event)\"\n  >\n    <mat-list-item *cdkVirtualFor=\"let resource of scrollItems; trackBy: trackByFn\">\n      <div class=\"list-item\">\n        <div [ngSwitch]=\"mode\">\n          <mat-radio-button\n            *ngSwitchCase=\"'radio'\"\n            class=\"radio-element\"\n            [checked]=\"resource | isSelected: resourceMapping:selected\"\n            [value]=\"resource\"\n            (change)=\"onSelected(resource, $event)\"\n          >\n            {{\n              titleMaxLength\n                ? (resource[resourceMapping.title] | sentinelShortString: titleMaxLength)\n                : resource[resourceMapping.title]\n            }}\n          </mat-radio-button>\n\n          <mat-checkbox\n            *ngSwitchCase=\"'checkbox'\"\n            class=\"checkbox-element\"\n            [checked]=\"resource | isSelected: resourceMapping:selected\"\n            [value]=\"resource\"\n            (change)=\"onSelected(resource, $event)\"\n          >\n            {{\n              titleMaxLength\n                ? (resource[resourceMapping.title] | sentinelShortString: titleMaxLength)\n                : resource[resourceMapping.title]\n            }}\n          </mat-checkbox>\n\n          <p *ngSwitchCase=\"'view'\" class=\"view-element\">\n            {{\n              titleMaxLength\n                ? (resource[resourceMapping.title] | sentinelShortString: titleMaxLength)\n                : resource[resourceMapping.title]\n            }}\n          </p>\n        </div>\n      </div>\n    </mat-list-item>\n  </cdk-virtual-scroll-viewport>\n  <div *ngIf=\"isLoading\" class=\"loading\">\n    <mat-spinner mode=\"indeterminate\" color=\"accent\" diameter=\"25\"></mat-spinner>\n  </div>\n</div>\n<ng-template #isEmpty>\n  <p class=\"no-resource-message\">No {{ resourceName | lowercase }} found</p>\n</ng-template>\n", styles: [".error{color:#f44336;display:flex;flex-direction:row;align-items:baseline;justify-content:center}.sentinel-list-container{background-color:inherit;color:inherit}.loading{display:flex;width:100%;justify-content:center}.list-item{height:25px;padding:10px}\n"] }]
        }], propDecorators: { mode: [{
                type: Input
            }], resourceName: [{
                type: Input
            }], titleMaxLength: [{
                type: Input
            }], resourceMapping: [{
                type: Input
            }], selected: [{
                type: Input
            }], selectionChange: [{
                type: Output
            }] } });

class SentinelListMaterialModule {
}
SentinelListMaterialModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelListMaterialModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
SentinelListMaterialModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: SentinelListMaterialModule, imports: [ScrollingModule,
        MatListModule,
        MatRadioModule,
        MatButtonModule,
        MatProgressSpinnerModule,
        MatCheckboxModule,
        MatIconModule], exports: [ScrollingModule,
        MatListModule,
        MatRadioModule,
        MatButtonModule,
        MatProgressSpinnerModule,
        MatCheckboxModule,
        MatIconModule] });
SentinelListMaterialModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelListMaterialModule, imports: [ScrollingModule,
        MatListModule,
        MatRadioModule,
        MatButtonModule,
        MatProgressSpinnerModule,
        MatCheckboxModule,
        MatIconModule, ScrollingModule,
        MatListModule,
        MatRadioModule,
        MatButtonModule,
        MatProgressSpinnerModule,
        MatCheckboxModule,
        MatIconModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelListMaterialModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        ScrollingModule,
                        MatListModule,
                        MatRadioModule,
                        MatButtonModule,
                        MatProgressSpinnerModule,
                        MatCheckboxModule,
                        MatIconModule,
                    ],
                    exports: [
                        ScrollingModule,
                        MatListModule,
                        MatRadioModule,
                        MatButtonModule,
                        MatProgressSpinnerModule,
                        MatCheckboxModule,
                        MatIconModule,
                    ],
                }]
        }] });

class SentinelListModule {
}
SentinelListModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelListModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
SentinelListModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: SentinelListModule, declarations: [SentinelListComponent, IsSelectedPipe], imports: [SentinelListMaterialModule, SentinelPipesModule, CommonModule], exports: [SentinelListComponent] });
SentinelListModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelListModule, imports: [SentinelListMaterialModule, SentinelPipesModule, CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelListModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [SentinelListComponent, IsSelectedPipe],
                    imports: [SentinelListMaterialModule, SentinelPipesModule, CommonModule],
                    exports: [SentinelListComponent],
                }]
        }] });

/*
 * Public API Surface of @sentinel/components/list
 */

/**
 * Generated bundle index. Do not edit.
 */

export { SentinelListComponent, SentinelListModule };
//# sourceMappingURL=sentinel-components-list.mjs.map
