import * as i0 from '@angular/core';
import { Injectable } from '@angular/core';
import { BehaviorSubject, combineLatest } from 'rxjs';
import { map, distinctUntilChanged, tap } from 'rxjs/operators';

class MenuElement {
    constructor(label) {
        this.label = label;
    }
}

/**
 * Class representing an agenda displayed in nav
 */
class Agenda extends MenuElement {
    constructor(label, path) {
        super(label);
        this.path = path;
    }
}

/**
 * Class representing an agenda container
 */
class AgendaContainer extends MenuElement {
    constructor(label, menuElements) {
        super(label);
        this.children = menuElements;
    }
}

class AgendaResolver {
    isAgendaContainer(element) {
        return element instanceof AgendaContainer;
    }
}

class WindowSizeService {
    constructor() {
        this.sizeSubject$ = new BehaviorSubject({
            height: window.innerHeight,
            width: window.innerWidth,
        });
        this.size$ = this.sizeSubject$.asObservable();
    }
    onResize(height, width) {
        this.sizeSubject$.next({ height: height, width: width });
    }
}
WindowSizeService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: WindowSizeService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
WindowSizeService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: WindowSizeService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: WindowSizeService, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }] });

class NavBarStateService {
    constructor(windowSizeService) {
        this.windowSizeService = windowSizeService;
        this.stateSubject$ = new BehaviorSubject('expanded');
        this.state$ = this.stateSubject$.asObservable();
        this.smallViewBreakpointSubject$ = new BehaviorSubject(749);
        this.smallViewBreakpoint$ = this.smallViewBreakpointSubject$.asObservable();
        this.isSmallView$ = combineLatest([this.windowSizeService.size$, this.smallViewBreakpoint$]).pipe(map((values) => this.resolveIsSmallSize(values[0].width, values[1])), distinctUntilChanged(), tap((isSmallSize) => this.onSizeChange(isSmallSize)), tap((isSmallSize) => (this.isSmallViewLastValue = isSmallSize)));
    }
    geState() {
        return this.stateSubject$.getValue();
    }
    setState(state) {
        this.stateSubject$.next(state);
    }
    toggleState() {
        if (this.stateSubject$.getValue() === 'expanded') {
            this.stateSubject$.next('collapsed');
        }
        else {
            this.stateSubject$.next('expanded');
        }
    }
    getIsSmallView() {
        return this.isSmallViewLastValue;
    }
    setSmallViewBreakpoint(value) {
        this.smallViewBreakpointSubject$.next(value);
    }
    onSizeChange(isSmallSize) {
        isSmallSize ? this.stateSubject$.next('collapsed') : this.stateSubject$.next('expanded');
    }
    resolveIsSmallSize(windowWidth, breakpoint) {
        return windowWidth < breakpoint;
    }
}
NavBarStateService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: NavBarStateService, deps: [{ token: WindowSizeService }], target: i0.ɵɵFactoryTarget.Injectable });
NavBarStateService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: NavBarStateService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: NavBarStateService, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }], ctorParameters: function () { return [{ type: WindowSizeService }]; } });

/*
 * Public API Surface of sentinel-layout
 */

/**
 * Generated bundle index. Do not edit.
 */

export { Agenda, AgendaContainer, AgendaResolver, MenuElement, NavBarStateService, WindowSizeService };
//# sourceMappingURL=sentinel-layout.mjs.map
