import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { EventEmitter, Component, ChangeDetectionStrategy, Input, Output, NgModule } from '@angular/core';
import * as i3 from '@angular/forms';
import { FormGroup, FormControl, Validators, ReactiveFormsModule } from '@angular/forms';
import * as i6 from '@angular/material/button';
import { MatButtonModule } from '@angular/material/button';
import * as i4 from '@angular/material/form-field';
import { MatFormFieldModule } from '@angular/material/form-field';
import * as i7 from '@angular/material/icon';
import { MatIconModule } from '@angular/material/icon';
import * as i5 from '@angular/material/input';
import { MatInputModule } from '@angular/material/input';
import * as i2 from '@danielmoncada/angular-datetime-picker';
import { OwlDateTimeModule, OwlNativeDateTimeModule } from '@danielmoncada/angular-datetime-picker';

class DateForm {
    constructor(date) {
        this.formGroup = new FormGroup({
            date: new FormControl(date ?? null),
        });
    }
    clearDate() {
        this.formGroup.controls.date.reset();
    }
}

class OrionDateFormComponent {
    constructor() {
        this.label = 'Date';
        this.appearance = 'outline';
        this.disabled = false;
        this.required = false;
        this.withIcon = true;
        this.mode = 'datetime';
        this.dateChange = new EventEmitter();
        this.validityChange = new EventEmitter();
        this.form = new DateForm();
    }
    ngOnChanges(changes) {
        if ('date' in changes && this.date) {
            this.form = new DateForm(this.date);
            if (this.required) {
                this.form.formGroup.setValidators([Validators.required]);
            }
            if (this.disabled) {
                this.updateDisabledState(this.disabled);
            }
            this.onDateChange();
        }
        if ('disabled' in changes) {
            this.updateDisabledState(this.disabled);
        }
        if ('required' in changes) {
            this.required ? this.form.formGroup.setValidators([Validators.required]) : this.form.formGroup.setValidators([]);
        }
    }
    updateDisabledState(disabled) {
        disabled ? this.form.formGroup.disable({ emitEvent: false }) : this.form.formGroup.enable({ emitEvent: false });
    }
    onDateChange() {
        this.dateChange.emit(this.form.formGroup.value.date ?? undefined);
        if (this.form.formGroup.status === 'INVALID') {
            this.validityChange.emit(false);
        }
        else if (this.form.formGroup.status === 'VALID') {
            this.validityChange.emit(true);
        }
    }
    clearDate() {
        this.form.clearDate();
    }
}
OrionDateFormComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: OrionDateFormComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
OrionDateFormComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: OrionDateFormComponent, selector: "orion-date-form", inputs: { label: "label", appearance: "appearance", disabled: "disabled", required: "required", withIcon: "withIcon", date: "date", min: "min", max: "max", mode: "mode" }, outputs: { dateChange: "dateChange", validityChange: "validityChange" }, usesOnChanges: true, ngImport: i0, template: "<mat-form-field [appearance]=\"appearance\" *ngIf=\"form.formGroup as formGroup\">\n  <mat-label>{{ label }}</mat-label>\n  <input\n    matInput\n    [required]=\"required\"\n    [placeholder]=\"label ?? ''\"\n    [min]=\"min\"\n    [max]=\"max\"\n    [formControl]=\"formGroup.controls.date\"\n    [owlDateTime]=\"fromDatePicker\"\n    [owlDateTimeTrigger]=\"fromDatePicker\"\n    (dateTimeChange)=\"onDateChange()\"\n  />\n  <button\n    mat-button\n    *ngIf=\"withIcon && formGroup.controls.date?.value\"\n    [disabled]=\"disabled\"\n    matSuffix\n    mat-icon-button\n    aria-label=\"Clear\"\n    (click)=\"clearDate()\"\n  >\n    <mat-icon>delete</mat-icon>\n  </button>\n  <owl-date-time\n    #fromDatePicker\n    [disabled]=\"disabled\"\n    [pickerType]=\"mode === 'datetime' ? 'both' : 'calendar'\"\n  ></owl-date-time>\n  <mat-error *ngIf=\"formGroup.controls.date.hasError('required')\">Date is required</mat-error>\n</mat-form-field>\n", styles: [".mat-icon{font-size:1.1em}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2.OwlDateTimeTriggerDirective, selector: "[owlDateTimeTrigger]", inputs: ["owlDateTimeTrigger", "disabled"] }, { kind: "directive", type: i2.OwlDateTimeInputDirective, selector: "input[owlDateTime]", inputs: ["required", "owlDateTime", "owlDateTimeFilter", "_disabled", "min", "max", "selectMode", "rangeSeparator", "value", "values"], outputs: ["dateTimeChange", "dateTimeInput"], exportAs: ["owlDateTimeInput"] }, { kind: "component", type: i2.OwlDateTimeComponent, selector: "owl-date-time", inputs: ["backdropClass", "panelClass", "startAt", "endAt", "pickerType", "pickerMode", "disabled", "opened", "scrollStrategy"], outputs: ["afterPickerClosed", "afterPickerOpen", "yearSelected", "monthSelected", "dateSelected"], exportAs: ["owlDateTime"] }, { kind: "directive", type: i3.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i3.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i3.RequiredValidator, selector: ":not([type=checkbox])[required][formControlName],:not([type=checkbox])[required][formControl],:not([type=checkbox])[required][ngModel]", inputs: ["required"] }, { kind: "directive", type: i3.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }, { kind: "directive", type: i4.MatError, selector: "mat-error", inputs: ["id"] }, { kind: "component", type: i4.MatFormField, selector: "mat-form-field", inputs: ["color", "appearance", "hideRequiredMarker", "hintLabel", "floatLabel"], exportAs: ["matFormField"] }, { kind: "directive", type: i4.MatLabel, selector: "mat-label" }, { kind: "directive", type: i4.MatSuffix, selector: "[matSuffix]" }, { kind: "directive", type: i5.MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["disabled", "id", "placeholder", "name", "required", "type", "errorStateMatcher", "aria-describedby", "value", "readonly"], exportAs: ["matInput"] }, { kind: "component", type: i6.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { kind: "component", type: i7.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: OrionDateFormComponent, decorators: [{
            type: Component,
            args: [{ selector: 'orion-date-form', changeDetection: ChangeDetectionStrategy.OnPush, template: "<mat-form-field [appearance]=\"appearance\" *ngIf=\"form.formGroup as formGroup\">\n  <mat-label>{{ label }}</mat-label>\n  <input\n    matInput\n    [required]=\"required\"\n    [placeholder]=\"label ?? ''\"\n    [min]=\"min\"\n    [max]=\"max\"\n    [formControl]=\"formGroup.controls.date\"\n    [owlDateTime]=\"fromDatePicker\"\n    [owlDateTimeTrigger]=\"fromDatePicker\"\n    (dateTimeChange)=\"onDateChange()\"\n  />\n  <button\n    mat-button\n    *ngIf=\"withIcon && formGroup.controls.date?.value\"\n    [disabled]=\"disabled\"\n    matSuffix\n    mat-icon-button\n    aria-label=\"Clear\"\n    (click)=\"clearDate()\"\n  >\n    <mat-icon>delete</mat-icon>\n  </button>\n  <owl-date-time\n    #fromDatePicker\n    [disabled]=\"disabled\"\n    [pickerType]=\"mode === 'datetime' ? 'both' : 'calendar'\"\n  ></owl-date-time>\n  <mat-error *ngIf=\"formGroup.controls.date.hasError('required')\">Date is required</mat-error>\n</mat-form-field>\n", styles: [".mat-icon{font-size:1.1em}\n"] }]
        }], ctorParameters: function () { return []; }, propDecorators: { label: [{
                type: Input
            }], appearance: [{
                type: Input
            }], disabled: [{
                type: Input
            }], required: [{
                type: Input
            }], withIcon: [{
                type: Input
            }], date: [{
                type: Input
            }], min: [{
                type: Input
            }], max: [{
                type: Input
            }], mode: [{
                type: Input
            }], dateChange: [{
                type: Output
            }], validityChange: [{
                type: Output
            }] } });

class OrionDateFormModule {
}
OrionDateFormModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: OrionDateFormModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
OrionDateFormModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: OrionDateFormModule, declarations: [OrionDateFormComponent], imports: [CommonModule,
        OwlDateTimeModule,
        OwlNativeDateTimeModule,
        ReactiveFormsModule,
        MatInputModule,
        MatFormFieldModule,
        MatButtonModule,
        MatIconModule], exports: [OrionDateFormComponent] });
OrionDateFormModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: OrionDateFormModule, imports: [CommonModule,
        OwlDateTimeModule,
        OwlNativeDateTimeModule,
        ReactiveFormsModule,
        MatInputModule,
        MatFormFieldModule,
        MatButtonModule,
        MatIconModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: OrionDateFormModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [OrionDateFormComponent],
                    imports: [
                        CommonModule,
                        OwlDateTimeModule,
                        OwlNativeDateTimeModule,
                        ReactiveFormsModule,
                        MatInputModule,
                        MatFormFieldModule,
                        MatButtonModule,
                        MatIconModule,
                    ],
                    exports: [OrionDateFormComponent],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { DateForm, OrionDateFormComponent, OrionDateFormModule };
//# sourceMappingURL=csirtmu-orion-microframework-date-form.mjs.map
