import * as i0 from '@angular/core';
import { Directive, Optional, EventEmitter, Input, Output } from '@angular/core';
import { takeWhile, map, startWith, takeUntil, shareReplay, take } from 'rxjs/operators';
import { Destroyable } from '@sentinel/common';
import { defer, combineLatest, of } from 'rxjs';
import * as i1 from '@csirtmu-orion/microframework/apollo-services';
import * as i2 from '@csirtmu-orion/microframework/pagination-services';
import * as i2$1 from '@csirtmu-orion/microframework/filter-services';
import { trackByIdTableRow } from '@sentinel/components/table';
import { isPaginatedElements } from '@sentinel/common/pagination';
import * as i3 from '@csirtmu-orion/microframework/sort-services';

class EntitySmartOverviewDirective extends Destroyable() {
    // No point in introducing a generic for query and query variables in this component
    // as the types context doesn't matter to this component.
    // eslint-disable-next-line
    constructor(entityService) {
        super();
        this.entityService = entityService;
        this.tryAgain$ = defer(() => this.onTryAgain());
    }
    ngOnInit() {
        this.entities$ = this.entityService.data$;
        this.isLoading$ = this.entityService.isLoading$;
        this.hasError$ = this.entityService.hasError$;
        const firstDataLoading$ = this.entityService.data$.pipe(takeWhile((data) => data === undefined, true), map((data) => data === undefined), startWith(true));
        this.initLoading$ = combineLatest([firstDataLoading$, this.hasError$ ?? of(false)]).pipe(map(([loading, error]) => loading && !error));
    }
    onTryAgain() {
        this.entityService.recoverAfterError();
    }
}
EntitySmartOverviewDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: EntitySmartOverviewDirective, deps: [{ token: i1.ApolloQueryService }], target: i0.ɵɵFactoryTarget.Directive });
EntitySmartOverviewDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.12", type: EntitySmartOverviewDirective, usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: EntitySmartOverviewDirective, decorators: [{
            type: Directive
        }], ctorParameters: function () { return [{ type: i1.ApolloQueryService }]; } });

class EntityPaginableSmartOverviewDirective extends EntitySmartOverviewDirective {
    constructor(
    // No point in introducing a generic for query, query variables, and orderable in this component
    // as the types context doesn't matter to this component.
    // eslint-disable-next-line
    entityService, paginationService) {
        super(entityService);
        this.entityService = entityService;
        this.paginationService = paginationService;
    }
    ngOnInit() {
        super.ngOnInit();
        const pagination$ = this.paginationService.pagination$.pipe(takeUntil(this.destroy$), shareReplay({ refCount: true }));
        this.sort$ = pagination$.pipe(map((pagination) => pagination.sort));
        this.sortDir$ = pagination$.pipe(map((pagination) => (pagination.sortDir === 'asc' ? 'asc' : 'desc')));
        pagination$.subscribe((pagination) => this.onPaginationChange(pagination));
    }
    onPageEvent(pagination) {
        this.paginationService.update(pagination);
    }
    onPaginationChange(pagination) {
        this.entityService.update(pagination);
    }
}
EntityPaginableSmartOverviewDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: EntityPaginableSmartOverviewDirective, deps: [{ token: i1.ApolloPaginatedBaseService }, { token: i2.PaginationService }], target: i0.ɵɵFactoryTarget.Directive });
EntityPaginableSmartOverviewDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.12", type: EntityPaginableSmartOverviewDirective, usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: EntityPaginableSmartOverviewDirective, decorators: [{
            type: Directive
        }], ctorParameters: function () { return [{ type: i1.ApolloPaginatedBaseService }, { type: i2.PaginationService }]; } });

class EntityPaginableFilterableSmartOverviewDirective extends EntityPaginableSmartOverviewDirective {
    constructor(
    // No point in introducing a generic for query, query variables, orderable, and api filter in this component
    // as the types context doesn't matter to this component.
    // eslint-disable-next-line
    entityService, filterService, paginationService, chipsService) {
        super(entityService, paginationService);
        this.entityService = entityService;
        this.filterService = filterService;
        this.paginationService = paginationService;
        this.chipsService = chipsService;
        this.filterChangedByUser = false;
    }
    ngOnInit() {
        super.ngOnInit();
        this.filterLocalState$ = this.filterService.filterLocalState$;
        this.filterChips$ = this.chipsService?.chips$;
        this.filterService.filter$
            .pipe(shareReplay({ refCount: true }), takeUntil(this.destroy$))
            .subscribe((filter) => this.onFilterChange(filter));
    }
    onFilterChange(filter) {
        this.resetPaginationOnUserFilterChange();
        this.entityService.update(this.paginationService.get(), filter);
    }
    onRemoveChip(chip) {
        this.chipsService?.removeChip(chip);
    }
    onClearFilters() {
        this.filterService.clear();
    }
    onSubmitFilter() {
        this.filterService.submit();
    }
    onPaginationChange(pagination) {
        this.entityService.update(pagination, this.filterService.get());
    }
    resetPaginationOnUserFilterChange() {
        // initial filter change is always filter init (from route or default), all subsequent changes are done by user
        if (this.filterChangedByUser) {
            this.paginationService.resetPosition();
        }
        else {
            this.filterChangedByUser = true;
        }
    }
}
EntityPaginableFilterableSmartOverviewDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: EntityPaginableFilterableSmartOverviewDirective, deps: [{ token: i1.ApolloPaginatedFilterableBaseService }, { token: i2$1.FilterService }, { token: i2.PaginationService }, { token: i2$1.FilterChipsService, optional: true }], target: i0.ɵɵFactoryTarget.Directive });
EntityPaginableFilterableSmartOverviewDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.12", type: EntityPaginableFilterableSmartOverviewDirective, usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: EntityPaginableFilterableSmartOverviewDirective, decorators: [{
            type: Directive
        }], ctorParameters: function () { return [{ type: i1.ApolloPaginatedFilterableBaseService }, { type: i2$1.FilterService }, { type: i2.PaginationService }, { type: i2$1.FilterChipsService, decorators: [{
                    type: Optional
                }] }]; } });

class EntityOverviewDirective {
    constructor() {
        this.isLoading = false;
        this.initLoading = false;
        this.hasError = false;
        this.tryAgain = new EventEmitter();
    }
    onTryAgain() {
        this.tryAgain.emit();
    }
}
EntityOverviewDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: EntityOverviewDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive });
EntityOverviewDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.12", type: EntityOverviewDirective, inputs: { entities: "entities", isLoading: "isLoading", initLoading: "initLoading", hasError: "hasError" }, outputs: { tryAgain: "tryAgain" }, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: EntityOverviewDirective, decorators: [{
            type: Directive
        }], propDecorators: { entities: [{
                type: Input
            }], isLoading: [{
                type: Input
            }], initLoading: [{
                type: Input
            }], hasError: [{
                type: Input
            }], tryAgain: [{
                type: Output
            }] } });

class EntityPaginableOverviewDirective extends EntityOverviewDirective {
    constructor() {
        super(...arguments);
        this.pageChange = new EventEmitter();
    }
    onPageChange(pagination) {
        this.pageChange.emit(pagination);
    }
}
EntityPaginableOverviewDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: EntityPaginableOverviewDirective, deps: null, target: i0.ɵɵFactoryTarget.Directive });
EntityPaginableOverviewDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.12", type: EntityPaginableOverviewDirective, inputs: { sortAttr: "sortAttr", sortDir: "sortDir" }, outputs: { pageChange: "pageChange" }, usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: EntityPaginableOverviewDirective, decorators: [{
            type: Directive
        }], propDecorators: { sortAttr: [{
                type: Input
            }], sortDir: [{
                type: Input
            }], pageChange: [{
                type: Output
            }] } });

class EntityPaginableFilterableOverviewDirective extends EntityPaginableOverviewDirective {
    constructor() {
        super(...arguments);
        this.clearFilters = new EventEmitter();
        this.submitClicked = new EventEmitter();
        this.removeChip = new EventEmitter();
    }
    onClearFilters() {
        this.clearFilters.emit();
    }
    onRemoveChip(chip) {
        this.removeChip.emit(chip);
    }
    onSubmit() {
        this.submitClicked.emit();
    }
}
EntityPaginableFilterableOverviewDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: EntityPaginableFilterableOverviewDirective, deps: null, target: i0.ɵɵFactoryTarget.Directive });
EntityPaginableFilterableOverviewDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.12", type: EntityPaginableFilterableOverviewDirective, inputs: { activeFilter: "activeFilter", filterChips: "filterChips" }, outputs: { clearFilters: "clearFilters", submitClicked: "submitClicked", removeChip: "removeChip" }, usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: EntityPaginableFilterableOverviewDirective, decorators: [{
            type: Directive
        }], propDecorators: { activeFilter: [{
                type: Input
            }], filterChips: [{
                type: Input
            }], clearFilters: [{
                type: Output
            }], submitClicked: [{
                type: Output
            }], removeChip: [{
                type: Output
            }] } });

class EntityTableBaseDirective {
    constructor() {
        this.initLoading = false;
        this.isLoading = false;
        this.hasError = false;
        this.selectable = false;
        this.tryAgain = new EventEmitter();
        this.sortChange = new EventEmitter();
        this.onTryAgain$ = defer(() => this.tryAgain.emit());
        this.trackByFn = trackByIdTableRow;
    }
    ngOnChanges(changes) {
        if ('entities' in changes && this.entities) {
            this.tableData = this.createTable(this.entities);
        }
    }
    onSortChange(sort) {
        if (sort) {
            this.sortChange.emit(sort);
        }
    }
}
EntityTableBaseDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: EntityTableBaseDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive });
EntityTableBaseDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.12", type: EntityTableBaseDirective, inputs: { entities: "entities", initLoading: "initLoading", isLoading: "isLoading", hasError: "hasError", sortAttr: "sortAttr", sortDir: "sortDir", selectable: "selectable" }, outputs: { tryAgain: "tryAgain", sortChange: "sortChange" }, usesOnChanges: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: EntityTableBaseDirective, decorators: [{
            type: Directive
        }], propDecorators: { entities: [{
                type: Input
            }], initLoading: [{
                type: Input
            }], isLoading: [{
                type: Input
            }], hasError: [{
                type: Input
            }], sortAttr: [{
                type: Input
            }], sortDir: [{
                type: Input
            }], selectable: [{
                type: Input
            }], tryAgain: [{
                type: Output
            }], sortChange: [{
                type: Output
            }] } });

class PaginatedEntityTableDirective extends EntityTableBaseDirective {
    constructor() {
        super(...arguments);
        this.pageChange = new EventEmitter();
        this.selectionChange = new EventEmitter();
    }
    onPageChange(pagination) {
        if (pagination) {
            this.pageChange.emit(pagination);
        }
    }
    onRowAction(actionEvent) {
        actionEvent.action.result$.pipe(take(1)).subscribe();
    }
    onRowSelection(selection) {
        this.selectionChange.emit(selection);
    }
}
PaginatedEntityTableDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: PaginatedEntityTableDirective, deps: null, target: i0.ɵɵFactoryTarget.Directive });
PaginatedEntityTableDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.12", type: PaginatedEntityTableDirective, outputs: { pageChange: "pageChange", selectionChange: "selectionChange" }, usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: PaginatedEntityTableDirective, decorators: [{
            type: Directive
        }], propDecorators: { pageChange: [{
                type: Output
            }], selectionChange: [{
                type: Output
            }] } });

class EntityTableDirective extends EntityTableBaseDirective {
    constructor() {
        super(...arguments);
        this.selectionChange = new EventEmitter();
    }
    onRowAction(actionEvent) {
        actionEvent.action.result$.pipe(take(1)).subscribe();
    }
    onRowSelection(selection) {
        this.selectionChange.emit(selection);
    }
}
EntityTableDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: EntityTableDirective, deps: null, target: i0.ɵɵFactoryTarget.Directive });
EntityTableDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.12", type: EntityTableDirective, outputs: { selectionChange: "selectionChange" }, usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: EntityTableDirective, decorators: [{
            type: Directive
        }], propDecorators: { selectionChange: [{
                type: Output
            }] } });

class OptionallyPaginatedEntityTableDirective extends EntityTableBaseDirective {
    constructor() {
        super(...arguments);
        this.pageChange = new EventEmitter();
        this.selectionChange = new EventEmitter();
    }
    onTableChange(event) {
        if (this.entities && isPaginatedElements(this.entities)) {
            this.pageChange.emit(event?.pagination);
        }
        else {
            this.sortChange.emit(event?.sort);
        }
    }
    onRowAction(actionEvent) {
        actionEvent.action.result$.pipe(take(1)).subscribe();
    }
    onRowSelection(selection) {
        this.selectionChange.emit(selection);
    }
}
OptionallyPaginatedEntityTableDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: OptionallyPaginatedEntityTableDirective, deps: null, target: i0.ɵɵFactoryTarget.Directive });
OptionallyPaginatedEntityTableDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.12", type: OptionallyPaginatedEntityTableDirective, outputs: { pageChange: "pageChange", selectionChange: "selectionChange" }, usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: OptionallyPaginatedEntityTableDirective, decorators: [{
            type: Directive
        }], propDecorators: { pageChange: [{
                type: Output
            }], selectionChange: [{
                type: Output
            }] } });

class EntityFilterableOverviewDirective extends EntityOverviewDirective {
    constructor() {
        super(...arguments);
        this.clearFilters = new EventEmitter();
        this.submitClicked = new EventEmitter();
        this.removeChip = new EventEmitter();
        this.sortChange = new EventEmitter();
    }
    onClearFilters() {
        this.clearFilters.emit();
    }
    onSubmitFilter() {
        this.submitClicked.emit();
    }
    onRemoveChip(chip) {
        this.removeChip.emit(chip);
    }
    onSortChange(sort) {
        this.sortChange.emit(sort);
    }
}
EntityFilterableOverviewDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: EntityFilterableOverviewDirective, deps: null, target: i0.ɵɵFactoryTarget.Directive });
EntityFilterableOverviewDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.12", type: EntityFilterableOverviewDirective, inputs: { activeFilter: "activeFilter", filterChips: "filterChips", sort: "sort" }, outputs: { clearFilters: "clearFilters", submitClicked: "submitClicked", removeChip: "removeChip", sortChange: "sortChange" }, usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: EntityFilterableOverviewDirective, decorators: [{
            type: Directive
        }], propDecorators: { activeFilter: [{
                type: Input
            }], filterChips: [{
                type: Input
            }], sort: [{
                type: Input
            }], clearFilters: [{
                type: Output
            }], submitClicked: [{
                type: Output
            }], removeChip: [{
                type: Output
            }], sortChange: [{
                type: Output
            }] } });

class ChildEntitySmartOverviewDirective extends EntitySmartOverviewDirective {
    constructor(
    // No point in introducing a generic for query, query variables in this component
    // as the types context doesn't matter to this component.
    // eslint-disable-next-line
    entityService) {
        super(entityService);
        this.entityService = entityService;
    }
    ngOnChanges(changes) {
        if ('parentId' in changes && this.parentId) {
            this.entityService.setParent(this.parentId);
        }
    }
}
ChildEntitySmartOverviewDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: ChildEntitySmartOverviewDirective, deps: [{ token: i1.ApolloChildEntitiesService }], target: i0.ɵɵFactoryTarget.Directive });
ChildEntitySmartOverviewDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.12", type: ChildEntitySmartOverviewDirective, inputs: { parentId: "parentId" }, usesInheritance: true, usesOnChanges: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: ChildEntitySmartOverviewDirective, decorators: [{
            type: Directive
        }], ctorParameters: function () { return [{ type: i1.ApolloChildEntitiesService }]; }, propDecorators: { parentId: [{
                type: Input
            }] } });

class ChildEntityInterfaceSmartOverviewDirective extends ChildEntitySmartOverviewDirective {
    constructor(
    // No point in introducing a generic for query, query variables, and parent type in this component
    // as the types context doesn't matter to this component.
    // eslint-disable-next-line
    entityService) {
        super(entityService);
        this.entityService = entityService;
    }
    ngOnChanges(changes) {
        if (('parentId' in changes || 'parentType' in changes) && this.parentId && this.parentType) {
            this.entityService.setParent(this.parentId, this.parentType);
        }
    }
}
ChildEntityInterfaceSmartOverviewDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: ChildEntityInterfaceSmartOverviewDirective, deps: [{ token: i1.ApolloInterfaceChildEntitiesService }], target: i0.ɵɵFactoryTarget.Directive });
ChildEntityInterfaceSmartOverviewDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.12", type: ChildEntityInterfaceSmartOverviewDirective, inputs: { parentType: "parentType" }, usesInheritance: true, usesOnChanges: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: ChildEntityInterfaceSmartOverviewDirective, decorators: [{
            type: Directive
        }], ctorParameters: function () { return [{ type: i1.ApolloInterfaceChildEntitiesService }]; }, propDecorators: { parentType: [{
                type: Input
            }] } });

class EntityFilterableSmartOverviewDirective extends EntitySmartOverviewDirective {
    constructor(
    // No point in introducing a generic for query, query variables, and api filter in this component
    // as the types context doesn't matter to this component.
    // eslint-disable-next-line
    entityService, filterService, chipsService) {
        super(entityService);
        this.entityService = entityService;
        this.filterService = filterService;
        this.chipsService = chipsService;
    }
    ngOnInit() {
        super.ngOnInit();
        this.filterLocalState$ = this.filterService.filterLocalState$;
        this.filterChips$ = this.chipsService?.chips$;
        this.filterService.filter$
            .pipe(shareReplay({ refCount: true }), takeUntil(this.destroy$))
            .subscribe((filter) => this.onFilterChange(filter));
    }
    onFilterChange(filter) {
        this.entityService.update(filter);
    }
    onRemoveChip(chip) {
        this.chipsService?.removeChip(chip);
    }
    onClearFilters() {
        this.filterService.clear();
    }
    onSubmitFilter() {
        this.filterService.submit();
    }
}
EntityFilterableSmartOverviewDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: EntityFilterableSmartOverviewDirective, deps: [{ token: i1.ApolloFilterableService }, { token: i2$1.FilterService }, { token: i2$1.FilterChipsService, optional: true }], target: i0.ɵɵFactoryTarget.Directive });
EntityFilterableSmartOverviewDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.12", type: EntityFilterableSmartOverviewDirective, usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: EntityFilterableSmartOverviewDirective, decorators: [{
            type: Directive
        }], ctorParameters: function () { return [{ type: i1.ApolloFilterableService }, { type: i2$1.FilterService }, { type: i2$1.FilterChipsService, decorators: [{
                    type: Optional
                }] }]; } });

class EntityFilterableOrderableSmartOverviewDirective extends EntitySmartOverviewDirective {
    constructor(
    // No point in introducing a generic for query, query variables, and api filter in this component
    // as the types context doesn't matter to this component.
    // eslint-disable-next-line
    entityService, filterService, sortService, chipsService) {
        super(entityService);
        this.entityService = entityService;
        this.filterService = filterService;
        this.sortService = sortService;
        this.chipsService = chipsService;
    }
    ngOnInit() {
        super.ngOnInit();
        this.filterLocalState$ = this.filterService.filterLocalState$;
        this.filterChips$ = this.chipsService?.chips$;
        this.filterService.filter$
            .pipe(shareReplay({ refCount: true }), takeUntil(this.destroy$))
            .subscribe((filter) => this.onFilterChange(filter));
        this.sort$ = this.sortService.sort$.pipe(takeUntil(this.destroy$), shareReplay({ refCount: true }));
        this.sort$.subscribe((sort) => this.onSortChange(sort));
    }
    onFilterChange(filter) {
        this.entityService.update(filter, this.sortService.get());
    }
    onSortEvent(sort) {
        this.sortService.update(sort);
    }
    onSortChange(sort) {
        this.entityService.update(this.filterService.get(), sort);
    }
    onRemoveChip(chip) {
        this.chipsService?.removeChip(chip);
    }
    onClearFilters() {
        this.filterService.clear();
    }
    onSubmitFilter() {
        this.filterService.submit();
    }
}
EntityFilterableOrderableSmartOverviewDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: EntityFilterableOrderableSmartOverviewDirective, deps: [{ token: i1.ApolloFilterableOrderableService }, { token: i2$1.FilterService }, { token: i3.SortService }, { token: i2$1.FilterChipsService, optional: true }], target: i0.ɵɵFactoryTarget.Directive });
EntityFilterableOrderableSmartOverviewDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.12", type: EntityFilterableOrderableSmartOverviewDirective, usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: EntityFilterableOrderableSmartOverviewDirective, decorators: [{
            type: Directive
        }], ctorParameters: function () { return [{ type: i1.ApolloFilterableOrderableService }, { type: i2$1.FilterService }, { type: i3.SortService }, { type: i2$1.FilterChipsService, decorators: [{
                    type: Optional
                }] }]; } });

/**
 * Generated bundle index. Do not edit.
 */

export { ChildEntityInterfaceSmartOverviewDirective, ChildEntitySmartOverviewDirective, EntityFilterableOrderableSmartOverviewDirective, EntityFilterableOverviewDirective, EntityFilterableSmartOverviewDirective, EntityOverviewDirective, EntityPaginableFilterableOverviewDirective, EntityPaginableFilterableSmartOverviewDirective, EntityPaginableOverviewDirective, EntityPaginableSmartOverviewDirective, EntitySmartOverviewDirective, EntityTableBaseDirective, EntityTableDirective, OptionallyPaginatedEntityTableDirective, PaginatedEntityTableDirective };
//# sourceMappingURL=csirtmu-orion-microframework-entity-smart-directives.mjs.map
