import * as i0 from '@angular/core';
import { InjectionToken, Injectable, Optional, Inject } from '@angular/core';
import * as equal from 'fast-deep-equal/es6';
import equal__default from 'fast-deep-equal/es6';
import { BehaviorSubject } from 'rxjs';
import { distinctUntilChanged, shareReplay, take, concatMap, tap, map } from 'rxjs/operators';
import { toQueryParams } from '@sentinel/common/utils';
import * as i1 from '@angular/router';

const INIT_SORT_TOKEN = new InjectionToken('INIT_ORDER_TOKEN');

class SortService {
    constructor(initSort) {
        this.initSort = initSort;
        this.INIT_SORT = initSort ? initSort : { sort: undefined, sortDir: undefined };
        this.sortSubject$ = new BehaviorSubject(this.INIT_SORT);
        this.sort$ = this.sortSubject$.asObservable().pipe(distinctUntilChanged((prev, curr) => equal__default(prev, curr)), shareReplay({ refCount: true }));
    }
    get() {
        return this.sortSubject$.getValue();
    }
    update(sort) {
        this.sortSubject$.next({ ...sort });
    }
}
SortService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SortService, deps: [{ token: INIT_SORT_TOKEN, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
SortService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SortService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SortService, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [INIT_SORT_TOKEN]
                }] }]; } });

class QueryParamSortService extends SortService {
    constructor(router, activatedRoute, initSort) {
        super(initSort);
        this.router = router;
        this.activatedRoute = activatedRoute;
        this.initSort = initSort;
        this.sort$ = this.createSortObservable();
    }
    updateQueryParams(sort) {
        setTimeout(() => {
            this.router
                .navigate([], {
                queryParams: toQueryParams(sort),
                queryParamsHandling: 'merge',
                replaceUrl: true,
            })
                .catch(() => console.error('Failed to update sort query params'));
        }, 0);
    }
    createSortObservable() {
        return this.fromRoute().pipe(take(1), concatMap(() => this.sortSubject$), distinctUntilChanged((prev, curr) => equal(prev, curr)), tap((sort) => this.updateQueryParams(sort)), shareReplay({ refCount: true }));
    }
    fromRoute() {
        return this.activatedRoute.queryParamMap.pipe(take(1), map((paramMap) => this.sortFromParamMap(paramMap)));
    }
    sortFromParamMap(paramMap) {
        const sort = paramMap.get('sort');
        const sortDirStr = paramMap.get('sortDir');
        if (sort !== null && sortDirStr !== null) {
            const sortDir = sortDirStr === 'asc' ? 'asc' : 'desc';
            return { sort, sortDir };
        }
        return this.INIT_SORT;
    }
}
QueryParamSortService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: QueryParamSortService, deps: [{ token: i1.Router }, { token: i1.ActivatedRoute }, { token: INIT_SORT_TOKEN, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
QueryParamSortService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: QueryParamSortService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: QueryParamSortService, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: i1.Router }, { type: i1.ActivatedRoute }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [INIT_SORT_TOKEN]
                }] }]; } });

/**
 * Generated bundle index. Do not edit.
 */

export { INIT_SORT_TOKEN, QueryParamSortService, SortService };
//# sourceMappingURL=csirtmu-orion-microframework-sort-services.mjs.map
