import * as i0 from '@angular/core';
import { Injectable } from '@angular/core';
import { map } from 'rxjs/operators';
import * as i1 from '@sentinel/auth';
import * as i2 from '@angular/router';

/**
 * Checks whether user is logged in. If not and provider was already configured it tries to login user.
 * If login fails or provider was not configured, user is redirected to login page provided in config.
 */
class SentinelAuthGuardWithLogin {
    constructor(authService, configService, router) {
        this.authService = authService;
        this.configService = configService;
        this.router = router;
    }
    canActivate(route, state) {
        if (this.authService.isLoggedIn()) {
            return true;
        }
        if (!this.configService.hasSelectedProvider()) {
            return this.tryRedirectToLogin();
        }
        return this.authService.login().pipe(map((user) => (user ? true : this.tryRedirectToLogin())));
    }
    tryRedirectToLogin() {
        if (this.configService.config.guardLoginPageRedirect) {
            this.router.navigate([this.configService.config.guardLoginPageRedirect]);
        }
        return false;
    }
}
SentinelAuthGuardWithLogin.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelAuthGuardWithLogin, deps: [{ token: i1.SentinelAuthService }, { token: i1.SentinelAuthContext }, { token: i2.Router }], target: i0.ɵɵFactoryTarget.Injectable });
SentinelAuthGuardWithLogin.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelAuthGuardWithLogin });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelAuthGuardWithLogin, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: i1.SentinelAuthService }, { type: i1.SentinelAuthContext }, { type: i2.Router }]; } });

/**
 * Checks whether user is authenticated but does not try to perform login. Use only when you are sure that user must be
 * already logged in (not suitable for guarding whole application or route on which user is redirected directly after login)
 * If user has not selected provider and is not logged in redirect to login page provided in config is performed
 */
class SentinelAuthGuard {
    constructor(authService, configService, router) {
        this.authService = authService;
        this.configService = configService;
        this.router = router;
    }
    canActivate(route, state) {
        if (this.authService.isLoggedIn()) {
            return true;
        }
        if (!this.configService.hasSelectedProvider()) {
            return this.redirectToLoginPage();
        }
        return false;
    }
    redirectToLoginPage() {
        if (this.configService.config.guardLoginPageRedirect) {
            this.router.navigate([this.configService.config.guardLoginPageRedirect]);
        }
        return false;
    }
}
SentinelAuthGuard.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelAuthGuard, deps: [{ token: i1.SentinelAuthService }, { token: i1.SentinelAuthContext }, { token: i2.Router }], target: i0.ɵɵFactoryTarget.Injectable });
SentinelAuthGuard.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelAuthGuard });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelAuthGuard, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: i1.SentinelAuthService }, { type: i1.SentinelAuthContext }, { type: i2.Router }]; } });

/**
 * Allows to activate route only for not authenticated routes. Suitable for protecting components for anonymous or
 * not logged in users.
 */
class SentinelNegativeAuthGuard {
    constructor(authService, configService, router) {
        this.authService = authService;
        this.configService = configService;
        this.router = router;
    }
    canActivate(route, state) {
        if (this.authService.isLoggedIn()) {
            return this.tryRedirectToHomepage();
        }
        return true;
    }
    tryRedirectToHomepage() {
        if (this.configService.config.guardMainPageRedirect) {
            this.router.navigate([this.configService.config.guardMainPageRedirect]);
        }
        return false;
    }
}
SentinelNegativeAuthGuard.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelNegativeAuthGuard, deps: [{ token: i1.SentinelAuthService }, { token: i1.SentinelAuthContext }, { token: i2.Router }], target: i0.ɵɵFactoryTarget.Injectable });
SentinelNegativeAuthGuard.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelNegativeAuthGuard });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelNegativeAuthGuard, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: i1.SentinelAuthService }, { type: i1.SentinelAuthContext }, { type: i2.Router }]; } });

/**
 * Generated bundle index. Do not edit.
 */

export { SentinelAuthGuard, SentinelAuthGuardWithLogin, SentinelNegativeAuthGuard };
//# sourceMappingURL=sentinel-auth-guards.mjs.map
