import * as i0 from '@angular/core';
import { Injectable, Component, Inject, Input, NgModule } from '@angular/core';
import html2canvas from 'html2canvas';
import * as i4 from '@angular/material/dialog';
import { MAT_DIALOG_DATA, MatDialogModule } from '@angular/material/dialog';
import { fromEvent, Subject, of, EMPTY } from 'rxjs';
import { switchMap, takeUntil, pairwise, map, catchError, tap, take, concatMap } from 'rxjs/operators';
import * as i3 from '@angular/material/tooltip';
import { MatTooltipModule } from '@angular/material/tooltip';
import * as i10 from '@angular/material/form-field';
import { MatFormFieldModule } from '@angular/material/form-field';
import * as i5 from '@angular/material/button';
import { MatButtonModule } from '@angular/material/button';
import * as i3$1 from '@angular/common/http';
import { HttpHeaders, HttpParams } from '@angular/common/http';
import { trackByIndex } from '@sentinel/common/utils';
import * as i5$1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i6 from '@angular/forms';
import { FormsModule } from '@angular/forms';
import * as i8 from '@angular/material/progress-spinner';
import { MatProgressSpinnerModule } from '@angular/material/progress-spinner';
import * as i9 from '@angular/material/progress-bar';
import { MatProgressBarModule } from '@angular/material/progress-bar';
import * as i11 from '@angular/material/input';
import { MatInputModule } from '@angular/material/input';
import * as i13 from '@sentinel/components/markdown-editor';
import { SentinelMarkdownEditorModule } from '@sentinel/components/markdown-editor';
import { MatNativeDateModule } from '@angular/material/core';

class CanvasDrawService {
    static resizeCanvas(canvasScreenshot) {
        canvasScreenshot.width = 980;
        canvasScreenshot.height = 560;
        canvasScreenshot.style.width = '980px';
        canvasScreenshot.style.height = '560px';
        canvasScreenshot.style.border = '2px dashed black';
        return canvasScreenshot;
    }
    initDrawing(canvasScreenshot, ctx) {
        const canvasEl = canvasScreenshot;
        ctx = canvasEl.getContext('2d');
        ctx.lineWidth = 3;
        ctx.lineCap = 'round';
        ctx.strokeStyle = '#FF0000';
        this.captureEvents(canvasEl, ctx);
    }
    cloneScreenshot(canvasScreenshot) {
        const screenshotDataCopy = JSON.parse(JSON.stringify(canvasScreenshot.toDataURL()));
        const screenshotCopy = new Image();
        screenshotCopy.src = screenshotDataCopy;
        return screenshotCopy;
    }
    clearDrawing(screenshotCopy) {
        const canvas = document.getElementById('screenshot-from-user');
        canvas
            .getContext('2d')
            .drawImage(screenshotCopy, 0, 0, screenshotCopy.width, screenshotCopy.height, 0, 0, canvas.width, canvas.height);
    }
    captureEvents(canvasEl, ctx) {
        // this will capture all mousedown events from the canvas element
        fromEvent(canvasEl, 'mousedown')
            .pipe(switchMap((e) => {
            // after a mouse down, we'll record all mouse moves
            return fromEvent(canvasEl, 'mousemove').pipe(
            // we'll stop (and unsubscribe) once the user releases the mouse
            // this will trigger a 'mouseup' event
            takeUntil(fromEvent(canvasEl, 'mouseup')), 
            // we'll also stop (and unsubscribe) once the mouse leaves the canvas (mouseleave event)
            takeUntil(fromEvent(canvasEl, 'mouseleave')), 
            // pairwise lets us get the previous value to draw a line from
            // the previous point to the current point
            pairwise());
        }))
            .subscribe((res) => {
            const rect = canvasEl.getBoundingClientRect();
            // previous and current position with the offset
            const prevPos = {
                x: res[0].clientX - rect.left,
                y: res[0].clientY - rect.top,
            };
            const currentPos = {
                x: res[1].clientX - rect.left,
                y: res[1].clientY - rect.top,
            };
            // do the actual drawing
            this.drawOnCanvas(prevPos, currentPos, ctx);
        });
    }
    drawOnCanvas(prevPos, currentPos, ctx) {
        // incase the context is not set
        if (!ctx) {
            return;
        }
        // start our drawing path
        ctx.beginPath();
        // we're drawing lines so we need a previous position
        if (prevPos) {
            // change cursor so user knows he is drawing
            ctx.canvas.style.cursor = 'crosshair';
            // sets the start point
            ctx.moveTo(prevPos.x, prevPos.y); // from
            // draws a line from the start pos until the current position
            ctx.lineTo(currentPos.x, currentPos.y);
            // strokes the current path with the styles we set earlier
            ctx.stroke();
        }
    }
}
CanvasDrawService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: CanvasDrawService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
CanvasDrawService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: CanvasDrawService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: CanvasDrawService, decorators: [{
            type: Injectable
        }] });

class ScreenshotDialogComponent {
    constructor(dialogRef, canvasDrawService, data) {
        this.dialogRef = dialogRef;
        this.canvasDrawService = canvasDrawService;
        this.data = data;
    }
    ngOnInit() {
        this.insertCanvas();
    }
    insertCanvas() {
        this.data.canvasScreenshot.setAttribute('id', 'screenshot-from-user');
        this.screenshotCopy = this.canvasDrawService.cloneScreenshot(this.data.canvasScreenshot);
        this.data.canvasScreenshot = CanvasDrawService.resizeCanvas(this.data.canvasScreenshot);
        document.getElementById('screenshot-html').appendChild(this.data.canvasScreenshot);
        // insert saved image to canvas
        this.screenshotCopy.onload = () => {
            const canvas = document.getElementById('screenshot-from-user');
            // resize image to match canvas size
            canvas
                .getContext('2d')
                .drawImage(this.screenshotCopy, 0, 0, this.screenshotCopy.width, this.screenshotCopy.height, 0, 0, canvas.width, canvas.height);
        };
        this.canvasDrawService.initDrawing(this.data.canvasScreenshot, this.ctx);
    }
    resetDrawing() {
        this.canvasDrawService.clearDrawing(this.screenshotCopy);
    }
    closeDialog() {
        this.resetDrawing();
        this.dialogRef.close();
    }
    /**
     * Return changed screenshot to parent dialogs
     */
    saveChanges() {
        this.dialogRef.close(document.getElementById('screenshot-from-user'));
    }
}
ScreenshotDialogComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: ScreenshotDialogComponent, deps: [{ token: i4.MatDialogRef }, { token: CanvasDrawService }, { token: MAT_DIALOG_DATA }], target: i0.ɵɵFactoryTarget.Component });
ScreenshotDialogComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: ScreenshotDialogComponent, selector: "sentinel-screenshot-dialog", ngImport: i0, template: "<div id=\"reset-container\">\n  <mat-label>Use your mouse to mark the area of interest</mat-label>\n  <span class=\"spacer\"></span>\n  <button id=\"reset-button\" mat-button color=\"warn\" matTooltip=\"Clean all the marks\" (click)=\"resetDrawing()\">\n    Reset\n  </button>\n</div>\n<p id=\"screenshot-html\"></p>\n<div id=\"action-btns\" mat-dialog-actions>\n  <button mat-button cdkFocusInitial color=\"warn\" (click)=\"closeDialog()\">Cancel</button>\n  <span class=\"spacer\"></span>\n  <button id=\"submit-btn\" mat-button color=\"primary\" (click)=\"saveChanges()\">Submit</button>\n</div>\n", styles: ["mat-label{font-family:Roboto,Helvetica Neue,sans-serif;font-size:14px;font-weight:500}#action-btns button{margin:auto}#reset-container{position:relative;padding-bottom:2em}#reset-button{position:absolute;right:0}.spacer{flex:1 1 0}\n"], dependencies: [{ kind: "directive", type: i3.MatTooltip, selector: "[matTooltip]", exportAs: ["matTooltip"] }, { kind: "directive", type: i10.MatLabel, selector: "mat-label" }, { kind: "component", type: i5.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { kind: "directive", type: i4.MatDialogActions, selector: "[mat-dialog-actions], mat-dialog-actions, [matDialogActions]", inputs: ["align"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: ScreenshotDialogComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sentinel-screenshot-dialog', template: "<div id=\"reset-container\">\n  <mat-label>Use your mouse to mark the area of interest</mat-label>\n  <span class=\"spacer\"></span>\n  <button id=\"reset-button\" mat-button color=\"warn\" matTooltip=\"Clean all the marks\" (click)=\"resetDrawing()\">\n    Reset\n  </button>\n</div>\n<p id=\"screenshot-html\"></p>\n<div id=\"action-btns\" mat-dialog-actions>\n  <button mat-button cdkFocusInitial color=\"warn\" (click)=\"closeDialog()\">Cancel</button>\n  <span class=\"spacer\"></span>\n  <button id=\"submit-btn\" mat-button color=\"primary\" (click)=\"saveChanges()\">Submit</button>\n</div>\n", styles: ["mat-label{font-family:Roboto,Helvetica Neue,sans-serif;font-size:14px;font-weight:500}#action-btns button{margin:auto}#reset-container{position:relative;padding-bottom:2em}#reset-button{position:absolute;right:0}.spacer{flex:1 1 0}\n"] }]
        }], ctorParameters: function () { return [{ type: i4.MatDialogRef }, { type: CanvasDrawService }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [MAT_DIALOG_DATA]
                }] }]; } });

class BugReportIssueInstance {
    constructor(problemDesc, rootTitle) {
        this.problemDescription = problemDesc;
        this.rootTitle = rootTitle;
    }
}

class UploadedFile {
    constructor(markdown, file) {
        if (file) {
            this.file = file;
            this.title = file.name;
        }
        else {
            this.title = 'screenshot.png';
        }
        this.markdown = `${markdown}`;
    }
}

class FileUpload {
    constructor(files, missingFiles) {
        this.markdown = '';
        this.screenshots = files;
        this.notUploaded = missingFiles;
        this.createMarkdown();
    }
    createMarkdown() {
        this.screenshots.forEach((item) => (this.markdown += `!${item.markdown}\n`));
    }
}

var BugReportIssueErrorSource;
(function (BugReportIssueErrorSource) {
    BugReportIssueErrorSource["UPLOAD"] = "Upload";
    BugReportIssueErrorSource["CREATE_ISSUE"] = "Create issue";
})(BugReportIssueErrorSource || (BugReportIssueErrorSource = {}));

class BugReportIssueError {
    constructor(source, errorMessage, file) {
        this.source = source;
        this.errorMessage = errorMessage;
        if (file instanceof File) {
            this.filename = file.name;
        }
        else {
            this.filename = 'screenshot.png';
        }
    }
    toString() {
        const errWordType = this.source === BugReportIssueErrorSource.CREATE_ISSUE ? 'create issue' : `upload image: ${this.filename}`;
        return `Failed to ${errWordType} to ${this.source} because of error: ${this.errorMessage}`;
    }
}

class BugReport {
    constructor(alert, url) {
        this.alert = alert;
        this.reportURL = url;
    }
}

class BugReportScreenshotUpload {
    constructor(file, alert) {
        if (file instanceof File) {
            this.screenshotName = file.name;
        }
        else if (file instanceof HTMLCanvasElement) {
            this.screenshotName = 'screenshot.png';
        }
        this.alert = alert;
    }
}

class BugReportingConfig {
}

class ContextService {
    constructor(config) {
        this._config = config;
    }
    get config() {
        return this._config;
    }
}
ContextService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: ContextService, deps: [{ token: BugReportingConfig }], target: i0.ɵɵFactoryTarget.Injectable });
ContextService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: ContextService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: ContextService, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: BugReportingConfig }]; } });

class SentinelBugReportEventsService {
    constructor(configs) {
        this.configs = configs;
        this.bugIsReported = new Subject();
        this.bugReported$ = this.bugIsReported.asObservable();
        this.screenshotUploadedSubject = new Subject();
        this.screenshotUploaded$ = this.screenshotUploadedSubject.asObservable();
        this.uploadErrorSubject = new Subject();
        this.uploadError$ = this.uploadErrorSubject.asObservable();
    }
    eventSuccess() {
        this.bugIsReported.next(new BugReport('Thank you for helping us to improve our software. We filed your bug report at ', this.extractUrl()));
    }
    screenshotUploaded(file) {
        this.screenshotUploadedSubject.next(new BugReportScreenshotUpload(file, 'Screenshot was successfully uploaded'));
    }
    eventError(errorSource, err, file) {
        this.uploadErrorSubject.next(new BugReportIssueError(errorSource, err.message, file));
    }
    extractUrl() {
        return this.configs.config.gitlabIssuesUrl
            .substring(0, this.configs.config.gitlabIssuesUrl.lastIndexOf('/'))
            .replace(/\/api\/v4/g, '');
    }
}
SentinelBugReportEventsService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelBugReportEventsService, deps: [{ token: ContextService }], target: i0.ɵɵFactoryTarget.Injectable });
SentinelBugReportEventsService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelBugReportEventsService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelBugReportEventsService, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: ContextService }]; } });

class GitlabApiService {
    constructor(eventReportService, configs, http) {
        this.eventReportService = eventReportService;
        this.configs = configs;
        this.http = http;
        this.ngUnsubscribe = new Subject();
    }
    /**
     * Sends post request to gitlab serve and creates new issues under repository from config
     * @param issueData represents class that contains data needed for creating issue
     */
    createIssue(issueData) {
        return this.http
            .post(this.configs.config.gitlabIssuesUrl, {}, { headers: this.createDefaultHeaders(), params: this.createIssueParams(issueData) })
            .pipe(map(() => {
            this.eventReportService.eventSuccess();
        }), catchError((err) => {
            this.eventReportService.eventError(BugReportIssueErrorSource.CREATE_ISSUE, err);
            return of(err);
        }));
    }
    /**
     * Uploads screenshot to gitlab and returns its link for further usage in issue completion
     * @param fileBlob screenshot in blob format
     * @param file screenshot created/uploaded by user
     */
    uploadScreenshot(fileBlob, file) {
        const fileData = new FormData();
        fileData.append('file', fileBlob, 'file');
        return this.http
            .post(this.configs.config.gitlabUploadUrl, fileData, { headers: this.createDefaultHeaders() })
            .pipe(takeUntil(this.ngUnsubscribe), tap(() => this.eventReportService.screenshotUploaded(file)), map((response) => JSON.parse(JSON.stringify(response)).markdown), catchError((err) => {
            this.eventReportService.eventError(BugReportIssueErrorSource.UPLOAD, err, file);
            return of(err);
        }));
    }
    cancelUpload() {
        this.ngUnsubscribe.next();
        this.ngUnsubscribe.complete();
        this.ngUnsubscribe.next();
    }
    /**
     * Creates default headers for http communication
     */
    createDefaultHeaders() {
        const httpHeaderAccepts = ['*/*', 'application/json'];
        const headers = new HttpHeaders().append('Private-Token', this.configs.config.gitlabPrivateToken);
        headers.set('Accept', httpHeaderAccepts);
        return headers;
    }
    /**
     * Creates http parameters for issue post request with required params
     * @param issueData object with Title of issue and description + data collected about user
     */
    createIssueParams(issueData) {
        return new HttpParams().append('title', issueData.rootTitle).append('description', issueData.problemDescription);
    }
}
GitlabApiService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: GitlabApiService, deps: [{ token: SentinelBugReportEventsService }, { token: ContextService }, { token: i3$1.HttpClient }], target: i0.ɵɵFactoryTarget.Injectable });
GitlabApiService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: GitlabApiService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: GitlabApiService, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: SentinelBugReportEventsService }, { type: ContextService }, { type: i3$1.HttpClient }]; } });

class BackendApiService {
    constructor(eventReportService, context, http) {
        this.eventReportService = eventReportService;
        this.context = context;
        this.http = http;
        this.ngUnsubscribe = new Subject();
    }
    /**
     * Sends post request to the local backend which should create new issue
     * @param issueData represents class that contains data needed for creating issue
     */
    createIssue(issueData) {
        return this.http
            .post(this.context.config.backendIssuesUrl, { title: issueData.rootTitle, description: issueData.problemDescription }, { headers: this.httpHeaders })
            .pipe(map(() => {
            this.eventReportService.eventSuccess();
        }), catchError((err) => {
            this.eventReportService.eventError(BugReportIssueErrorSource.CREATE_ISSUE, err);
            return of(err);
        }));
    }
    /**
     * Sends screenshot to the backend and returns its link for further usage in issue completion
     * @param fileBlob screenshot in Blob format
     * @param file screenshot created/uploaded by user
     */
    uploadScreenshot(fileBlob, file) {
        const fileData = new FormData();
        fileData.append('image', fileBlob, 'screenshot.png');
        return this.http.post(this.context.config.backendUploadUrl, fileData, { headers: this.httpHeaders }).pipe(takeUntil(this.ngUnsubscribe), tap(() => this.eventReportService.screenshotUploaded(file)), map((response) => JSON.parse(JSON.stringify(response)).markdown), catchError((err) => {
            this.eventReportService.eventError(BugReportIssueErrorSource.UPLOAD, err, file);
            return of(err);
        }));
    }
    cancelUpload() {
        this.ngUnsubscribe.next();
        this.ngUnsubscribe.complete();
        this.ngUnsubscribe.next();
    }
}
BackendApiService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: BackendApiService, deps: [{ token: SentinelBugReportEventsService }, { token: ContextService }, { token: i3$1.HttpClient }], target: i0.ɵɵFactoryTarget.Injectable });
BackendApiService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: BackendApiService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: BackendApiService, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: SentinelBugReportEventsService }, { type: ContextService }, { type: i3$1.HttpClient }]; } });

class BugReportCreateDateAndBlob {
    createCurrentDate() {
        const currentDate = new Date();
        return (+currentDate.getDate() +
            '/' +
            (currentDate.getMonth() + 1) +
            '/' +
            currentDate.getFullYear() +
            ' @ ' +
            currentDate.getHours() +
            ':' +
            currentDate.getMinutes() +
            ':' +
            currentDate.getSeconds());
    }
    base64toBlob(base64Data, contentType) {
        contentType = contentType || '';
        const sliceSize = 1024;
        // 22 to cut start of the string so that blob can be created
        const byteCharacters = atob(base64Data.toString().substring(22));
        const bytesLength = byteCharacters.length;
        const slicesCount = Math.ceil(bytesLength / sliceSize);
        const byteArrays = new Array(slicesCount);
        for (let sliceIndex = 0; sliceIndex < slicesCount; ++sliceIndex) {
            const begin = sliceIndex * sliceSize;
            const end = Math.min(begin + sliceSize, bytesLength);
            const bytes = new Array(end - begin);
            for (let offset = begin, i = 0; offset < end; ++i, ++offset) {
                bytes[i] = byteCharacters[offset].charCodeAt(0);
            }
            byteArrays[sliceIndex] = new Uint8Array(bytes);
        }
        return new Blob(byteArrays, { type: contentType });
    }
}
BugReportCreateDateAndBlob.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: BugReportCreateDateAndBlob, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
BugReportCreateDateAndBlob.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: BugReportCreateDateAndBlob });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: BugReportCreateDateAndBlob, decorators: [{
            type: Injectable
        }] });

class FileHandleService {
    constructor(gitlabApiService, backendApiService, configService, bugReportCreateDateAndBlob) {
        this.gitlabApiService = gitlabApiService;
        this.backendApiService = backendApiService;
        this.configService = configService;
        this.bugReportCreateDateAndBlob = bugReportCreateDateAndBlob;
        this.isLoading = false;
        this.screenshotConversionSubject = new Subject();
        this.screenshotConversion$ = this.screenshotConversionSubject.asObservable();
        this.filesSubject = new Subject();
        this.files$ = this.filesSubject.asObservable();
    }
    uploadFile(file) {
        if (!this.uploadedFiles) {
            this.uploadedFiles = [];
        }
        this.isLoading = true;
        let screenshot;
        if (file instanceof File) {
            screenshot = this.fileToBlob(file);
        }
        else {
            screenshot = this.screenshotToBlob(file);
        }
        return screenshot.pipe(take(1), concatMap((result) => this.uploadScreenshot(result, file)), catchError((err, caught) => ''), tap((markdown) => {
            if (typeof markdown === 'string') {
                if (file instanceof File) {
                    this.uploadedFiles.push(new UploadedFile(markdown, file));
                }
                else {
                    this.uploadedFiles.push(new UploadedFile(markdown));
                }
                this.filesSubject.next(new FileUpload(this.uploadedFiles, []));
            }
            this.isLoading = false;
        }));
    }
    deleteFile(index) {
        this.uploadedFiles.splice(index, 1);
        this.filesSubject.next(new FileUpload(this.uploadedFiles, []));
    }
    submitIssue(issueData) {
        if (this.configService.config.useLocalBackend) {
            return this.backendApiService.createIssue(issueData);
        }
        return this.gitlabApiService.createIssue(issueData);
    }
    cancelUpload() {
        if (this.configService.config.useLocalBackend) {
            this.backendApiService.cancelUpload();
        }
        else {
            this.gitlabApiService.cancelUpload();
        }
    }
    fileToBlob(file) {
        const myReader = new FileReader();
        myReader.onloadend = (e) => {
            this.screenshotConversionSubject.next(this.bugReportCreateDateAndBlob.base64toBlob(myReader.result, 'image/png'));
        };
        myReader.readAsDataURL(file);
        return this.screenshotConversion$;
    }
    screenshotToBlob(screenshot) {
        screenshot.toBlob((blob) => {
            this.screenshotConversionSubject.next(blob);
        }, 'screen/png', 1);
        return this.screenshotConversion$;
    }
    /**
     * Upload screenshot to gitlab
     * @param file uploaded file
     * @param screenshot provided by user/created automatically
     */
    uploadScreenshot(screenshot, file) {
        if (this.configService.config.useLocalBackend) {
            return this.backendApiService.uploadScreenshot(screenshot, file);
        }
        return this.gitlabApiService.uploadScreenshot(screenshot, file);
    }
}
FileHandleService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: FileHandleService, deps: [{ token: GitlabApiService }, { token: BackendApiService }, { token: ContextService }, { token: BugReportCreateDateAndBlob }], target: i0.ɵɵFactoryTarget.Injectable });
FileHandleService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: FileHandleService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: FileHandleService, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: GitlabApiService }, { type: BackendApiService }, { type: ContextService }, { type: BugReportCreateDateAndBlob }]; } });

class CanvasService {
    cloneCanvas(canvasElement) {
        const newCanvas = document.createElement('canvas');
        const context = newCanvas.getContext('2d');
        newCanvas.width = canvasElement.width;
        newCanvas.height = canvasElement.height;
        context.drawImage(canvasElement, 0, 0);
        return newCanvas;
    }
}
CanvasService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: CanvasService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
CanvasService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: CanvasService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: CanvasService, decorators: [{
            type: Injectable
        }] });

class BugReportDialogComponent {
    constructor(bugReportCreateDateAndBlob, canvasService, fileHandleService, dialogRef, screenshotDialog, data) {
        this.bugReportCreateDateAndBlob = bugReportCreateDateAndBlob;
        this.canvasService = canvasService;
        this.fileHandleService = fileHandleService;
        this.dialogRef = dialogRef;
        this.screenshotDialog = screenshotDialog;
        this.data = data;
        this.sending = false; // form is being sent
        this.showError = false;
        this.errorMessage = '';
        this.isScreenshotPresent = false;
        this.trackByFn = trackByIndex;
        this.issueSubscription = [];
        this.screenshotConversionSubject = new Subject();
        this.screenshotConversion$ = this.screenshotConversionSubject.asObservable();
    }
    onClose() {
        this.dialogRef.close();
    }
    ngOnInit() {
        if (this.data.issueTemplate) {
            this.data.problemDescription = this.data.issueTemplate;
        }
        this.uploadedScreenshot = [];
        this.fileUpload$ = this.fileHandleService.files$;
        this.canvasClone = this.canvasService.cloneCanvas(this.data.userScreenshot.canvasScreenshot);
        this.issueSubscription[0] = this.fileUpload$.subscribe((files) => {
            this.uploadedScreenshot = files.screenshots;
            this.markdownData = files.markdown;
        });
    }
    ngOnDestroy() {
        if (this.issueSubscription[1] && this.issueSubscription[1].closed) {
            this.issueSubscription[1].unsubscribe();
        }
    }
    contentChange(event) {
        this.data.problemDescription = event;
    }
    openScreenshotDialog() {
        const dialogRef = this.screenshotDialog.open(ScreenshotDialogComponent, {
            // decrease size of dialogs -> screenshot is too big and not modified yet
            height: 'auto',
            data: {
                canvasScreenshot: this.data.userScreenshot.canvasScreenshot,
            },
        });
        dialogRef
            .afterClosed()
            .pipe(map((result) => (result ? result : EMPTY)))
            .subscribe((result) => {
            if (result instanceof HTMLCanvasElement) {
                this.fileHandleService.uploadFile(result).subscribe(() => {
                    this.isScreenshotPresent = true;
                    this.data.userScreenshot.canvasScreenshot = this.canvasClone;
                });
            }
        });
    }
    stopUploading() {
        this.fileHandleService.cancelUpload();
        this.fileHandleService.isLoading = false;
    }
    /**
     * Uploaded file from dialogs loads file to inner attribute and sets name to label in dialogs
     * with selected file name
     * @param event contains file selected by user
     */
    onFileUpload(event) {
        if (event.target.files.length > 0) {
            this.fileHandleService.uploadFile(event.target.files[0]).subscribe(() => {
                this.isScreenshotPresent = true;
            });
        }
    }
    onFileDelete(id) {
        this.fileHandleService.deleteFile(id);
    }
    /**
     * Create template of issue which will be present on gitlab
     */
    createIssueTemplate(dateTime, uploadedImageMarkdown = null) {
        if (this.data.userEmailFromInside) {
            this.data.userEmail = this.data.userEmailFromInside;
        }
        if (this.data.userNameFromInside) {
            this.data.userName = this.data.userNameFromInside;
        }
        if (!this.data.problemDescription) {
            this.data.problemDescription = 'Not provided';
        }
        let reportData = '## Description of problem from user:\n' +
            this.data.problemDescription +
            '\n# Data collected from user:\n' +
            'User email: ' +
            this.data.userEmail +
            '<br>' +
            'User name: ' +
            this.data.userName +
            '<br>' +
            'URL: ' +
            window.location.href +
            '<br>' +
            'Date of event: ' +
            dateTime +
            '<br>' +
            'Browser info: ' +
            navigator.userAgent.replace(/;/g, ',') +
            '<br>' +
            'System info: ' +
            navigator.platform +
            '<br>' +
            'Screen resolution: ' +
            window.screen.availWidth +
            'x' +
            window.screen.availHeight;
        if (this.isScreenshotPresent) {
            reportData += `\n## Screenshots from user:\n${uploadedImageMarkdown}`;
        }
        else {
            reportData += `\n## Screenshots from user:\n Not provided`;
        }
        return reportData;
    }
    /**
     * Creates issue with given information and screenshot which is already uploaded at gitlab
     * @param dateTime date of event
     * @param uploadedImageMarkdown screenshot in markdown from response-> can be used straightaway in issue
     */
    createIssue(dateTime, uploadedImageMarkdown = null) {
        const issueData = new BugReportIssueInstance(this.createIssueTemplate(dateTime, uploadedImageMarkdown), this.data.issueTitle);
        return this.fileHandleService.submitIssue(issueData);
    }
    /**
     * Submit pressed in root dialogs + call upload and create issue from service and try to create issue
     * for given bug report. If user uploaded or modified screenshot it needs to be converted to blob
     * before uploading. At last, screenshot has to be uploaded before issue can be created.
     */
    onSubmit() {
        this.sending = true;
        this.issueSubscription[1] = this.createIssue(this.bugReportCreateDateAndBlob.createCurrentDate(), this.markdownData).subscribe((_) => {
            this.sending = false;
            this.dialogRef.close();
        }, (err) => {
            this.sending = false;
            this.errorMessage = err;
            this.showError = true;
        });
    }
    resetFileInput(event) {
        event.target.value = null;
    }
}
BugReportDialogComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: BugReportDialogComponent, deps: [{ token: BugReportCreateDateAndBlob }, { token: CanvasService }, { token: FileHandleService }, { token: i4.MatDialogRef }, { token: i4.MatDialog }, { token: MAT_DIALOG_DATA }], target: i0.ɵɵFactoryTarget.Component });
BugReportDialogComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: BugReportDialogComponent, selector: "sentinel-bug-report-dialog", providers: [FileHandleService, CanvasService], ngImport: i0, template: "<!-- Main dialogs which pops after user click bug-icon -->\n<h1 class=\"centered-elements\" mat-dialog-title>Submit your bug report</h1>\n<div *ngIf=\"showError\" class=\"error-message\">{{ errorMessage }}</div>\n<form name=\"mainForm\" #issueForm=\"ngForm\">\n  <ng-container *ngIf=\"!sending\">\n    <div mat-dialog-content>\n      <!-- User Email input - required -->\n      <div *ngIf=\"!data.userEmailFromInside\">\n        <mat-form-field>\n          <!-- voidEmail present for proper work of form -->\n          <input\n            type=\"email\"\n            matInput\n            ngModel\n            email\n            [(ngModel)]=\"data.userEmail\"\n            name=\"voidEmail\"\n            placeholder=\"Your email address\"\n            required\n          />\n        </mat-form-field>\n      </div>\n\n      <!-- User name - optional -->\n      <div *ngIf=\"!data.userNameFromInside\">\n        <mat-form-field>\n          <input\n            class=\"input-field\"\n            matInput\n            [(ngModel)]=\"data.userName\"\n            [ngModelOptions]=\"{ standalone: true }\"\n            placeholder=\"Your\n            name(optional)\"\n          />\n        </mat-form-field>\n      </div>\n\n      <div>\n        <mat-form-field>\n          <!-- voidTitle present for proper work of form -->\n          <input\n            class=\"input-field\"\n            type=\"text\"\n            matInput\n            [(ngModel)]=\"data.issueTitle\"\n            name=\"voidTitle\"\n            placeholder=\"Title\"\n            required\n            minlength=\"3\"\n          />\n        </mat-form-field>\n      </div>\n      <!--Description of problem from user-->\n      <div class=\"markdown-editor-container\">\n        <sentinel-markdown-editor\n          class=\"fixed-size\"\n          [content]=\"data.problemDescription\"\n          (contentChange)=\"contentChange($event)\"\n          [sentinel-markdown-file-upload]=\"false\"\n        ></sentinel-markdown-editor>\n      </div>\n      <!-- User option to pick image from user's device -->\n\n      <div class=\"container\">\n        <button\n          class=\"screenshot-btns mat-h2\"\n          mat-button\n          color=\"primary\"\n          [disabled]=\"fileHandleService.isLoading\"\n          (click)=\"fileInput.click()\"\n        >\n          Upload screenshot\n        </button>\n        <input hidden type=\"file\" accept=\"image/*\" #fileInput (change)=\"onFileUpload($event); resetFileInput($event)\" />\n\n        <button class=\"screenshot-btns\" mat-button color=\"primary\" (click)=\"openScreenshotDialog()\">\n          Take screenshot\n        </button>\n\n        <div id=\"uploaded-files-text-data\" *ngIf=\"uploadedScreenshot\">\n          <div *ngFor=\"let item of uploadedScreenshot; let i = index; trackBy: trackByFn\">\n            <mat-label class=\"selected-files-description mat-h4\">{{ i + 1 }}. {{ item.title }}</mat-label>\n            <span class=\"mat-h2 delete-icon\" (click)=\"onFileDelete(i)\">x</span>\n          </div>\n        </div>\n        <div class=\"load-container\" *ngIf=\"fileHandleService.isLoading\">\n          <mat-progress-bar mode=\"indeterminate\"></mat-progress-bar>\n          <span class=\"mat-h2 delete-icon\" matTooltip=\"Stop file uploading\" (click)=\"stopUploading()\">x</span>\n        </div>\n      </div>\n    </div>\n  </ng-container>\n  <div class=\"spinner\" *ngIf=\"sending\">\n    <mat-spinner></mat-spinner>\n  </div>\n\n  <div mat-dialog-actions *ngIf=\"!sending\">\n    <button mat-button cdkFocusInitial color=\"warn\" (click)=\"onClose()\">\n      Cancel\n    </button>\n    <span class=\"spacer\"></span>\n    <button\n      id=\"submit-btn\"\n      mat-button\n      color=\"primary\"\n      [disabled]=\"issueForm.invalid || fileHandleService.isLoading\"\n      (click)=\"onSubmit()\"\n    >\n      Submit\n    </button>\n  </div>\n</form>\n", styles: [".selected-files-description{width:100%}.delete-icon{color:red;margin-left:1em;transition:.5s}.delete-icon:hover{color:#c80000;cursor:pointer}.screenshot-btns{margin-top:1em;margin-bottom:1em}.centered-elements{text-align:center}.container .mat-h5{color:#696969}.spacer{flex:1 1 0}mat-form-field,mat-form-field textarea{margin-top:1em;width:100%;min-width:350px}mat-progress-bar{width:50%}.load-container{display:flex}.load-container .delete-icon{margin-top:-16px;margin-left:10px}.spinner{width:100px;margin-left:auto;margin-right:auto}.error-message{background-color:#f8d7da;border-color:#f5c6cb;color:#721c24;position:relative;padding:.75rem 1.25rem;margin-bottom:1rem;border:1px solid transparent;border-radius:.25rem}sentinel-markdown-editor{margin:20px 0}sentinel-markdown-editor.fixed-size{margin-top:20px;height:30vh}.markdown-editor-container{display:flex;flex-direction:column;align-items:center}\n"], dependencies: [{ kind: "directive", type: i5$1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i5$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i6.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i6.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i6.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i6.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i6.RequiredValidator, selector: ":not([type=checkbox])[required][formControlName],:not([type=checkbox])[required][formControl],:not([type=checkbox])[required][ngModel]", inputs: ["required"] }, { kind: "directive", type: i6.MinLengthValidator, selector: "[minlength][formControlName],[minlength][formControl],[minlength][ngModel]", inputs: ["minlength"] }, { kind: "directive", type: i6.EmailValidator, selector: "[email][formControlName],[email][formControl],[email][ngModel]", inputs: ["email"] }, { kind: "directive", type: i6.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "directive", type: i6.NgForm, selector: "form:not([ngNoForm]):not([formGroup]),ng-form,[ngForm]", inputs: ["ngFormOptions"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i3.MatTooltip, selector: "[matTooltip]", exportAs: ["matTooltip"] }, { kind: "component", type: i8.MatProgressSpinner, selector: "mat-progress-spinner, mat-spinner", inputs: ["color", "diameter", "strokeWidth", "mode", "value"], exportAs: ["matProgressSpinner"] }, { kind: "component", type: i9.MatProgressBar, selector: "mat-progress-bar", inputs: ["color", "value", "bufferValue", "mode"], outputs: ["animationEnd"], exportAs: ["matProgressBar"] }, { kind: "component", type: i10.MatFormField, selector: "mat-form-field", inputs: ["color", "appearance", "hideRequiredMarker", "hintLabel", "floatLabel"], exportAs: ["matFormField"] }, { kind: "directive", type: i10.MatLabel, selector: "mat-label" }, { kind: "directive", type: i11.MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["disabled", "id", "placeholder", "name", "required", "type", "errorStateMatcher", "aria-describedby", "value", "readonly"], exportAs: ["matInput"] }, { kind: "component", type: i5.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { kind: "directive", type: i4.MatDialogTitle, selector: "[mat-dialog-title], [matDialogTitle]", inputs: ["id"], exportAs: ["matDialogTitle"] }, { kind: "directive", type: i4.MatDialogContent, selector: "[mat-dialog-content], mat-dialog-content, [matDialogContent]" }, { kind: "directive", type: i4.MatDialogActions, selector: "[mat-dialog-actions], mat-dialog-actions, [matDialogActions]", inputs: ["align"] }, { kind: "component", type: i13.SentinelMarkdownEditorComponent, selector: "sentinel-markdown-editor", inputs: ["content", "tagTriggers", "actionDispatcher", "sentinel-markdown-autosize", "sentinel-markdown-focus", "sentinel-markdown-file-upload"], outputs: ["contentChange", "tagTrigger", "tagTextChange", "positionChange", "uploadFiles"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: BugReportDialogComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sentinel-bug-report-dialog', providers: [FileHandleService, CanvasService], template: "<!-- Main dialogs which pops after user click bug-icon -->\n<h1 class=\"centered-elements\" mat-dialog-title>Submit your bug report</h1>\n<div *ngIf=\"showError\" class=\"error-message\">{{ errorMessage }}</div>\n<form name=\"mainForm\" #issueForm=\"ngForm\">\n  <ng-container *ngIf=\"!sending\">\n    <div mat-dialog-content>\n      <!-- User Email input - required -->\n      <div *ngIf=\"!data.userEmailFromInside\">\n        <mat-form-field>\n          <!-- voidEmail present for proper work of form -->\n          <input\n            type=\"email\"\n            matInput\n            ngModel\n            email\n            [(ngModel)]=\"data.userEmail\"\n            name=\"voidEmail\"\n            placeholder=\"Your email address\"\n            required\n          />\n        </mat-form-field>\n      </div>\n\n      <!-- User name - optional -->\n      <div *ngIf=\"!data.userNameFromInside\">\n        <mat-form-field>\n          <input\n            class=\"input-field\"\n            matInput\n            [(ngModel)]=\"data.userName\"\n            [ngModelOptions]=\"{ standalone: true }\"\n            placeholder=\"Your\n            name(optional)\"\n          />\n        </mat-form-field>\n      </div>\n\n      <div>\n        <mat-form-field>\n          <!-- voidTitle present for proper work of form -->\n          <input\n            class=\"input-field\"\n            type=\"text\"\n            matInput\n            [(ngModel)]=\"data.issueTitle\"\n            name=\"voidTitle\"\n            placeholder=\"Title\"\n            required\n            minlength=\"3\"\n          />\n        </mat-form-field>\n      </div>\n      <!--Description of problem from user-->\n      <div class=\"markdown-editor-container\">\n        <sentinel-markdown-editor\n          class=\"fixed-size\"\n          [content]=\"data.problemDescription\"\n          (contentChange)=\"contentChange($event)\"\n          [sentinel-markdown-file-upload]=\"false\"\n        ></sentinel-markdown-editor>\n      </div>\n      <!-- User option to pick image from user's device -->\n\n      <div class=\"container\">\n        <button\n          class=\"screenshot-btns mat-h2\"\n          mat-button\n          color=\"primary\"\n          [disabled]=\"fileHandleService.isLoading\"\n          (click)=\"fileInput.click()\"\n        >\n          Upload screenshot\n        </button>\n        <input hidden type=\"file\" accept=\"image/*\" #fileInput (change)=\"onFileUpload($event); resetFileInput($event)\" />\n\n        <button class=\"screenshot-btns\" mat-button color=\"primary\" (click)=\"openScreenshotDialog()\">\n          Take screenshot\n        </button>\n\n        <div id=\"uploaded-files-text-data\" *ngIf=\"uploadedScreenshot\">\n          <div *ngFor=\"let item of uploadedScreenshot; let i = index; trackBy: trackByFn\">\n            <mat-label class=\"selected-files-description mat-h4\">{{ i + 1 }}. {{ item.title }}</mat-label>\n            <span class=\"mat-h2 delete-icon\" (click)=\"onFileDelete(i)\">x</span>\n          </div>\n        </div>\n        <div class=\"load-container\" *ngIf=\"fileHandleService.isLoading\">\n          <mat-progress-bar mode=\"indeterminate\"></mat-progress-bar>\n          <span class=\"mat-h2 delete-icon\" matTooltip=\"Stop file uploading\" (click)=\"stopUploading()\">x</span>\n        </div>\n      </div>\n    </div>\n  </ng-container>\n  <div class=\"spinner\" *ngIf=\"sending\">\n    <mat-spinner></mat-spinner>\n  </div>\n\n  <div mat-dialog-actions *ngIf=\"!sending\">\n    <button mat-button cdkFocusInitial color=\"warn\" (click)=\"onClose()\">\n      Cancel\n    </button>\n    <span class=\"spacer\"></span>\n    <button\n      id=\"submit-btn\"\n      mat-button\n      color=\"primary\"\n      [disabled]=\"issueForm.invalid || fileHandleService.isLoading\"\n      (click)=\"onSubmit()\"\n    >\n      Submit\n    </button>\n  </div>\n</form>\n", styles: [".selected-files-description{width:100%}.delete-icon{color:red;margin-left:1em;transition:.5s}.delete-icon:hover{color:#c80000;cursor:pointer}.screenshot-btns{margin-top:1em;margin-bottom:1em}.centered-elements{text-align:center}.container .mat-h5{color:#696969}.spacer{flex:1 1 0}mat-form-field,mat-form-field textarea{margin-top:1em;width:100%;min-width:350px}mat-progress-bar{width:50%}.load-container{display:flex}.load-container .delete-icon{margin-top:-16px;margin-left:10px}.spinner{width:100px;margin-left:auto;margin-right:auto}.error-message{background-color:#f8d7da;border-color:#f5c6cb;color:#721c24;position:relative;padding:.75rem 1.25rem;margin-bottom:1rem;border:1px solid transparent;border-radius:.25rem}sentinel-markdown-editor{margin:20px 0}sentinel-markdown-editor.fixed-size{margin-top:20px;height:30vh}.markdown-editor-container{display:flex;flex-direction:column;align-items:center}\n"] }]
        }], ctorParameters: function () { return [{ type: BugReportCreateDateAndBlob }, { type: CanvasService }, { type: FileHandleService }, { type: i4.MatDialogRef }, { type: i4.MatDialog }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [MAT_DIALOG_DATA]
                }] }]; } });

class BugReportScreenshotInstance {
}
BugReportScreenshotInstance.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: BugReportScreenshotInstance, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
BugReportScreenshotInstance.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: BugReportScreenshotInstance });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: BugReportScreenshotInstance, decorators: [{
            type: Injectable
        }] });

class SentinelBugReportService {
    constructor(dialog) {
        this.dialog = dialog;
    }
    report(userInsertedEmail, userInsertedName, issueTemplateData) {
        this._openDialogData = new BugReportScreenshotInstance();
        html2canvas(document.body, {
            allowTaint: true,
            useCORS: true,
        }).then((canvas) => {
            this._openDialogData.canvasScreenshot = canvas;
            canvas.toBlob((blob) => {
                this._openDialogData.blobScreenshot = blob;
            }, 'screen/png', 1);
            this.dialog.open(BugReportDialogComponent, {
                data: {
                    userNameFromInside: userInsertedName,
                    userEmailFromInside: userInsertedEmail,
                    userScreenshot: this._openDialogData,
                    issueTemplate: issueTemplateData,
                },
            });
        });
    }
}
SentinelBugReportService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelBugReportService, deps: [{ token: i4.MatDialog }], target: i0.ɵɵFactoryTarget.Injectable });
SentinelBugReportService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelBugReportService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelBugReportService, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: i4.MatDialog }]; } });

class SentinelBugReportComponent {
    constructor(bugReportService) {
        this.bugReportService = bugReportService;
    }
    openDialog() {
        this.bugReportService.report(this.userEmailFromInside, this.userNameFromInside, this.issueTemplate);
    }
}
SentinelBugReportComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelBugReportComponent, deps: [{ token: SentinelBugReportService }], target: i0.ɵɵFactoryTarget.Component });
SentinelBugReportComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: SentinelBugReportComponent, selector: "sentinel-bug-report", inputs: { userNameFromInside: "userNameFromInside", userEmailFromInside: "userEmailFromInside", issueTemplate: "issueTemplate" }, ngImport: i0, template: "<button mat-raised-button color=\"primary\" (click)=\"openDialog()\">Open Dialog</button>\n", styles: [""], dependencies: [{ kind: "component", type: i5.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelBugReportComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sentinel-bug-report', template: "<button mat-raised-button color=\"primary\" (click)=\"openDialog()\">Open Dialog</button>\n" }]
        }], ctorParameters: function () { return [{ type: SentinelBugReportService }]; }, propDecorators: { userNameFromInside: [{
                type: Input
            }], userEmailFromInside: [{
                type: Input
            }], issueTemplate: [{
                type: Input
            }] } });

class SentinelBugReportMaterialModule {
}
SentinelBugReportMaterialModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelBugReportMaterialModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
SentinelBugReportMaterialModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: SentinelBugReportMaterialModule, imports: [MatTooltipModule,
        MatProgressSpinnerModule,
        MatProgressBarModule,
        MatNativeDateModule,
        MatInputModule,
        MatFormFieldModule,
        MatButtonModule,
        MatDialogModule], exports: [MatTooltipModule,
        MatProgressSpinnerModule,
        MatProgressBarModule,
        MatNativeDateModule,
        MatInputModule,
        MatFormFieldModule,
        MatButtonModule,
        MatDialogModule] });
SentinelBugReportMaterialModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelBugReportMaterialModule, imports: [MatTooltipModule,
        MatProgressSpinnerModule,
        MatProgressBarModule,
        MatNativeDateModule,
        MatInputModule,
        MatFormFieldModule,
        MatButtonModule,
        MatDialogModule, MatTooltipModule,
        MatProgressSpinnerModule,
        MatProgressBarModule,
        MatNativeDateModule,
        MatInputModule,
        MatFormFieldModule,
        MatButtonModule,
        MatDialogModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelBugReportMaterialModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        MatTooltipModule,
                        MatProgressSpinnerModule,
                        MatProgressBarModule,
                        MatNativeDateModule,
                        MatInputModule,
                        MatFormFieldModule,
                        MatButtonModule,
                        MatDialogModule,
                    ],
                    exports: [
                        MatTooltipModule,
                        MatProgressSpinnerModule,
                        MatProgressBarModule,
                        MatNativeDateModule,
                        MatInputModule,
                        MatFormFieldModule,
                        MatButtonModule,
                        MatDialogModule,
                    ],
                }]
        }] });

class SentinelBugReportModule {
    static forRoot(config) {
        return {
            ngModule: SentinelBugReportModule,
            providers: [
                SentinelMarkdownEditorModule.forRoot(config.markdownConfig).providers,
                { provide: BugReportingConfig, useValue: config },
            ],
        };
    }
}
SentinelBugReportModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelBugReportModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
SentinelBugReportModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: SentinelBugReportModule, declarations: [SentinelBugReportComponent, BugReportDialogComponent, ScreenshotDialogComponent], imports: [CommonModule, FormsModule, SentinelBugReportMaterialModule, SentinelMarkdownEditorModule], exports: [SentinelBugReportComponent] });
SentinelBugReportModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelBugReportModule, providers: [
        GitlabApiService,
        BackendApiService,
        BugReportScreenshotInstance,
        BugReportCreateDateAndBlob,
        SentinelBugReportEventsService,
        SentinelBugReportService,
        CanvasDrawService,
        ContextService,
    ], imports: [CommonModule, FormsModule, SentinelBugReportMaterialModule, SentinelMarkdownEditorModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelBugReportModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [SentinelBugReportComponent, BugReportDialogComponent, ScreenshotDialogComponent],
                    imports: [CommonModule, FormsModule, SentinelBugReportMaterialModule, SentinelMarkdownEditorModule],
                    exports: [SentinelBugReportComponent],
                    providers: [
                        GitlabApiService,
                        BackendApiService,
                        BugReportScreenshotInstance,
                        BugReportCreateDateAndBlob,
                        SentinelBugReportEventsService,
                        SentinelBugReportService,
                        CanvasDrawService,
                        ContextService,
                    ],
                }]
        }] });

class BugReportingConfigLocal extends BugReportingConfig {
}

class BugReportingConfigRemote extends BugReportingConfig {
}

/*
 * Public API Surface of @sentinel/components/bug-report
 */

/**
 * Generated bundle index. Do not edit.
 */

export { BugReportingConfig, BugReportingConfigLocal, BugReportingConfigRemote, SentinelBugReportComponent, SentinelBugReportEventsService, SentinelBugReportModule, SentinelBugReportService };
//# sourceMappingURL=sentinel-components-bug-report.mjs.map
