import * as i3 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { Directive, Input, Injectable, Component, ChangeDetectionStrategy, NgModule, EventEmitter, Output, ViewChild } from '@angular/core';
import * as i4$1 from '@angular/forms';
import { FormsModule } from '@angular/forms';
import * as i2 from 'angular-file';
import { ngfModule } from 'angular-file';
import { trackByIndex } from '@sentinel/common/utils';
import { Subject, BehaviorSubject } from 'rxjs';
import * as i4 from '@angular/material/button';
import { MatButtonModule } from '@angular/material/button';
import * as i5 from '@angular/material/button-toggle';
import { MatButtonToggleModule } from '@angular/material/button-toggle';
import * as i6 from '@angular/material/icon';
import { MatIconModule } from '@angular/material/icon';
import * as i7 from '@angular/material/tooltip';
import { MatTooltipModule } from '@angular/material/tooltip';
import * as i8 from '@angular/material/menu';
import { MatMenuModule } from '@angular/material/menu';
import * as i7$1 from '@angular/cdk/text-field';
import { TextFieldModule } from '@angular/cdk/text-field';
import { MatDividerModule } from '@angular/material/divider';
import { position } from 'caret-pos';
import * as i6$1 from '@sentinel/components/markdown-view';
import { SentinelMarkdownViewModule } from '@sentinel/components/markdown-view';

/**
 * Directive to autofocus on given textarea html element
 */
class FocusDirective {
    constructor(element) {
        this.element = element;
        // eslint-disable-next-line  @angular-eslint/no-input-rename
        this.focused = false;
    }
    /**
     * Sets focus to html element
     */
    ngAfterViewInit() {
        if (this.focused) {
            setTimeout(() => this.element.nativeElement.focus(), 0);
        }
    }
}
FocusDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: FocusDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive });
FocusDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.12", type: FocusDirective, selector: "textarea[sentinel-markdown-focus]", inputs: { focused: ["sentinel-markdown-focus", "focused"] }, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: FocusDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: 'textarea[sentinel-markdown-focus]',
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { focused: [{
                type: Input,
                args: ['sentinel-markdown-focus']
            }] } });

/**
 * Configuration class of markdown library
 */
class MarkdownConfig {
}

/**
 * Markdown editor bold action
 */
class BoldAction {
    constructor() {
        this.icon = 'format_bold';
        this.tooltipHint = 'Add bold text';
    }
    /**
     * Adds bold markdown tags to content of the markdown editor action (or its selection)
     * @param content content to be transformed
     * @param selected current selection to be transformed
     */
    transform(content, selected) {
        return `${content.slice(0, selected.from)}**${content.slice(selected.from, selected.to)}**${content.slice(selected.to)}`;
    }
}

/**
 * Markdown editor bullet list action
 */
class BulletListAction {
    constructor() {
        this.icon = 'format_list_bulleted';
        this.tooltipHint = 'Add a bullet list';
    }
    /**
     * Adds bullet list markdown tags to content of the markdown editor action (or its selection)
     * @param content content to be transformed
     * @param selected current selection to be transformed
     */
    transform(content, selected) {
        return (content.slice(0, selected.from) +
            this.addBulletPoints(content.slice(selected.from, selected.to)) +
            content.slice(selected.to));
    }
    addBulletPoints(selectedText) {
        const lines = selectedText.split('\n');
        return lines.map((line) => '* ' + line).join('\n') + '\n';
    }
}

/**
 * Markdown editor code action
 */
class CodeAction {
    constructor() {
        this.icon = 'code';
        this.tooltipHint = 'Insert code';
        this._singleLineCodeMark = '`';
        this._multiLineCodeMark = '```';
    }
    /**
     * Adds code markdown tags to content of the markdown editor action (or its selection)
     * @param content content to be transformed
     * @param selected current selection to be transformed
     */
    transform(content, selected) {
        return (content.slice(0, selected.from) +
            this.addCodeMarks(content.slice(selected.from, selected.to)) +
            content.slice(selected.to));
    }
    addCodeMarks(selectedText) {
        if (!selectedText.includes('\n')) {
            return this._singleLineCodeMark + selectedText + this._singleLineCodeMark;
        }
        const nonEmptyLines = selectedText.split('\n').filter((line) => line !== '');
        if (nonEmptyLines.length <= 1) {
            return this._singleLineCodeMark + nonEmptyLines[0] + this._singleLineCodeMark;
        }
        else {
            return this._multiLineCodeMark + '\n' + selectedText + '\n' + this._multiLineCodeMark;
        }
    }
}

/**
 * Markdown editor header action
 */
class HeaderAction {
    /**
     * @param headlineWeight weight of the headline. Must be in range of [1, 6]
     */
    constructor(headlineWeight) {
        this.icon = 'format_size';
        this.tooltipHint = 'Add header text';
        if (headlineWeight < 1 || headlineWeight > 6) {
            console.error('Headline weight must be a number between 1 and 6.' + headlineWeight + ' was provided.');
        }
        this.headlineWeight = headlineWeight;
    }
    /**
     * Adds header markdown tags to content of the markdown editor action (or its selection)
     * @param content content to be transformed
     * @param selected current selection to be transformed
     */
    transform(content, selected) {
        return `${content.slice(0, selected.from)}${this.getHeadlineMark()}${content.slice(selected.from, selected.to)}${content.slice(selected.to)}`;
    }
    getHeadlineMark() {
        return '#'.repeat(this.headlineWeight) + ' ';
    }
}

/**
 * Markdown editor italic action
 */
class ItalicAction {
    constructor() {
        this.icon = 'format_italic';
        this.tooltipHint = 'Add italic text';
    }
    /**
     * Adds italic markdown tags to content of the markdown editor action (or its selection)
     * @param content content to be transformed
     * @param selected current selection to be transformed
     */
    transform(content, selected) {
        return `${content.slice(0, selected.from)}*${content.slice(selected.from, selected.to)}*${content.slice(selected.to)}`;
    }
}

/**
 * Markdown editor link action
 */
class LinkAction {
    constructor() {
        this.icon = 'link';
        this.tooltipHint = 'Add a link';
    }
    /**
     * Adds link markdown tags to content of the markdown editor action (or its selection)
     * @param content content to be transformed
     * @param selected current selection to be transformed
     */
    transform(content, selected) {
        return (content.slice(0, selected.from) +
            this.addLinkMarks(content.slice(selected.from, selected.to)) +
            content.slice(selected.to));
    }
    addLinkMarks(selectedText) {
        if (selectedText.length === 0) {
            return '[text](url)';
        }
        else if (this.isUrl(selectedText)) {
            return '[text](' + selectedText + ')';
        }
        else {
            return '[' + selectedText + '](url)';
        }
    }
    isUrl(selectedText) {
        return selectedText.startsWith('http://') || selectedText.startsWith('https://');
    }
}

/**
 * Markdown editor numbered list action
 */
class NumberedListAction {
    constructor() {
        this.icon = 'format_list_numbered';
        this.tooltipHint = 'Add a numbered list';
    }
    /**
     * Adds numbered list markdown tags to content of the markdown editor action (or its selection)
     * @param content content to be transformed
     * @param selected current selection to be transformed
     */
    transform(content, selected) {
        return (content.slice(0, selected.from) +
            this.addNumberedList(content.slice(selected.from, selected.to)) +
            content.slice(selected.to));
    }
    addNumberedList(selectedText) {
        const lines = selectedText.split('\n');
        return lines.map((line) => '1. ' + line).join('\n') + '\n';
    }
}

/**
 * Markdown editor quote action
 */
class QuoteAction {
    constructor() {
        this.icon = 'format_quote';
        this.tooltipHint = 'Add a quote';
        this._quoteMark = '> ';
    }
    /**
     * Adds quote markdown tags to content of the markdown editor action (or its selection)
     * @param content content to be transformed
     * @param selected current selection to be transformed
     */
    transform(content, selected) {
        return (content.slice(0, selected.from) +
            this.addQuoteMarks(content.slice(selected.from, selected.to)) +
            content.slice(selected.to));
    }
    addQuoteMarks(selectedText) {
        if (selectedText === '') {
            return this._quoteMark;
        }
        else {
            return selectedText
                .split('\n')
                .map((line) => this._quoteMark + line)
                .join('\n');
        }
    }
}

/**
 * Markdown editor strikethrough action
 */
class StrikethroughAction {
    constructor() {
        this.icon = 'strikethrough_s';
        this.tooltipHint = 'Add strikethrough text';
    }
    /**
     * Adds strikethrough markdown tags to content of the markdown editor action (or its selection)
     * @param content content to be transformed
     * @param selected current selection to be transformed
     */
    transform(content, selected) {
        return `${content.slice(0, selected.from)}~~${content.slice(selected.from, selected.to)}~~${content.slice(selected.to)}`;
    }
}

/**
 * Markdown editor table action
 */
class TableAction {
    constructor() {
        this.icon = 'table_chart';
        this.tooltipHint = 'Add a table';
    }
    /**
     * Adds table markdown tags to content of the markdown editor action (or its selection)
     * @param content content to be transformed
     * @param selected current selection to be transformed
     */
    transform(content, selected) {
        return (content.slice(0, selected.from) +
            this.addTable(content.slice(selected.from, selected.to)) +
            content.slice(selected.to));
    }
    addTable(selectedText) {
        return (selectedText + '\n\n| header | header |\n' + '| ------ | ------ |\n' + '| cell | cell |\n' + '| cell | cell |\n\n');
    }
}

/**
 * Markdown editor task list action
 */
class TaskListAction {
    constructor() {
        this.icon = 'check_box';
        this.tooltipHint = 'Add a task list';
    }
    /**
     * Adds task list markdown tags to content of the markdown editor action (or its selection)
     * @param content content to be transformed
     * @param selected current selection to be transformed
     */
    transform(content, selected) {
        return (content.slice(0, selected.from) +
            this.addTaskList(content.slice(selected.from, selected.to)) +
            content.slice(selected.to));
    }
    addTaskList(selectedText) {
        const lines = selectedText.split('\n');
        return lines.map((line) => '* [ ] ' + line).join('\n') + '\n';
    }
}

/**
 * Service for execution of markdown actions
 */
class ActionService {
    constructor() {
        this._action = new Subject();
        /**
         * Observable of emitted markdown editor actions
         */
        this.action$ = this._action.asObservable();
    }
    /**
     * Emits new markdown editor action
     * @param action editor action to emit
     */
    dispatch(action) {
        this._action.next(action);
    }
}
ActionService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: ActionService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
ActionService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: ActionService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: ActionService, decorators: [{
            type: Injectable
        }] });

/**
 * Service holding state of markdown mode
 */
class MarkdownModeService {
    constructor() {
        this._editModeSubject = new BehaviorSubject(true);
        /**
         * True if markdown is in edit mode, false if in preview mode
         */
        this.editMode$ = this._editModeSubject.asObservable();
    }
    /**
     * Set edit mode to true or false (for preview mode)
     * @param value true for edit mode, false for preview mode
     */
    setIsEditMode(value) {
        this._editModeSubject.next(value);
    }
    /**
     * Get state of the markdown mode. True if edit mode, false if preview mode
     */
    getIsEditMode() {
        return this._editModeSubject.getValue();
    }
}
MarkdownModeService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: MarkdownModeService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
MarkdownModeService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: MarkdownModeService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: MarkdownModeService, decorators: [{
            type: Injectable
        }] });

/**
 * Component of action bar of the markdown editor
 */
class ActionBarComponent {
    constructor(actionService, modeService) {
        this.actionService = actionService;
        this.modeService = modeService;
        /**
         * Actions available to perform
         */
        this.actions = [];
        /**
         * Headings actions
         */
        this.headingActions = [];
        this.trackByFn = trackByIndex;
    }
    ngOnInit() {
        this.createHeaderActions();
        this.createActions();
    }
    /**
     * Sets edit mode or preview mode
     * @param value true if edit mode should be set, false if preview mode
     */
    setEditMode(value) {
        this.modeService.setIsEditMode(value);
    }
    /**
     * Calls service to execute action
     * @param action markdown editor action to execute
     */
    executeAction(action) {
        this.actionService.dispatch(action);
    }
    createActions() {
        this.actions.push(new BoldAction(), new ItalicAction(), new StrikethroughAction(), new QuoteAction(), new CodeAction(), new LinkAction(), new BulletListAction(), new NumberedListAction(), new TaskListAction(), new TableAction());
    }
    createHeaderActions() {
        this.headingActions.push(new HeaderAction(1), new HeaderAction(2), new HeaderAction(3), new HeaderAction(4), new HeaderAction(5), new HeaderAction(6));
    }
}
ActionBarComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: ActionBarComponent, deps: [{ token: ActionService }, { token: MarkdownModeService }], target: i0.ɵɵFactoryTarget.Component });
ActionBarComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: ActionBarComponent, selector: "sentinel-action-bar", ngImport: i0, template: "<div class=\"action-bar\">\n  <mat-button-toggle-group>\n    <mat-button-toggle class=\"edit-toggle\" [checked]=\"modeService.editMode$ | async\" (click)=\"setEditMode(true)\">\n      Edit\n    </mat-button-toggle>\n    <mat-button-toggle\n      class=\"preview-toggle\"\n      [checked]=\"(modeService.editMode$ | async) === false\"\n      (click)=\"setEditMode(false)\"\n    >\n      Preview\n    </mat-button-toggle>\n  </mat-button-toggle-group>\n  <div class=\"actions\" *ngIf=\"modeService.editMode$ | async\">\n    <button mat-icon-button color=\"primary\" [matMenuTriggerFor]=\"menu\" [matTooltip]=\"headingActions[0]?.tooltipHint\">\n      <mat-icon>{{ headingActions[0]?.icon }}</mat-icon>\n    </button>\n    <mat-menu #menu=\"matMenu\">\n      <button\n        mat-menu-item\n        *ngFor=\"let headerAction of headingActions; trackBy: trackByFn\"\n        (click)=\"executeAction(headerAction)\"\n      >\n        <mat-icon>{{ headerAction?.icon }}</mat-icon>\n        <span>H{{ headerAction.headlineWeight }}</span>\n      </button>\n    </mat-menu>\n    <button\n      *ngFor=\"let action of actions; trackBy: trackByFn\"\n      mat-icon-button\n      class=\"action\"\n      color=\"primary\"\n      (click)=\"executeAction(action)\"\n      [matTooltip]=\"action?.tooltipHint\"\n    >\n      <mat-icon>{{ action?.icon }}</mat-icon>\n    </button>\n  </div>\n</div>\n", styles: ["mat-button-toggle-group{border:0;border-bottom-left-radius:0;border-bottom-right-radius:0;width:200px}:host,mat-button-toggle-group,.actions{border-top-left-radius:4px;border-top-right-radius:4px}.action-bar{display:flex;flex-direction:row;align-items:baseline}.actions{display:flex;flex-direction:row;justify-content:flex-end;width:100%}\n"], dependencies: [{ kind: "directive", type: i3.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i3.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i4.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { kind: "directive", type: i5.MatButtonToggleGroup, selector: "mat-button-toggle-group", inputs: ["appearance", "name", "vertical", "value", "multiple", "disabled"], outputs: ["valueChange", "change"], exportAs: ["matButtonToggleGroup"] }, { kind: "component", type: i5.MatButtonToggle, selector: "mat-button-toggle", inputs: ["disableRipple", "aria-label", "aria-labelledby", "id", "name", "value", "tabIndex", "appearance", "checked", "disabled"], outputs: ["change"], exportAs: ["matButtonToggle"] }, { kind: "component", type: i6.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { kind: "directive", type: i7.MatTooltip, selector: "[matTooltip]", exportAs: ["matTooltip"] }, { kind: "component", type: i8.MatMenu, selector: "mat-menu", exportAs: ["matMenu"] }, { kind: "component", type: i8.MatMenuItem, selector: "[mat-menu-item]", inputs: ["disabled", "disableRipple", "role"], exportAs: ["matMenuItem"] }, { kind: "directive", type: i8.MatMenuTrigger, selector: "[mat-menu-trigger-for], [matMenuTriggerFor]", exportAs: ["matMenuTrigger"] }, { kind: "pipe", type: i3.AsyncPipe, name: "async" }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: ActionBarComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sentinel-action-bar', changeDetection: ChangeDetectionStrategy.OnPush, template: "<div class=\"action-bar\">\n  <mat-button-toggle-group>\n    <mat-button-toggle class=\"edit-toggle\" [checked]=\"modeService.editMode$ | async\" (click)=\"setEditMode(true)\">\n      Edit\n    </mat-button-toggle>\n    <mat-button-toggle\n      class=\"preview-toggle\"\n      [checked]=\"(modeService.editMode$ | async) === false\"\n      (click)=\"setEditMode(false)\"\n    >\n      Preview\n    </mat-button-toggle>\n  </mat-button-toggle-group>\n  <div class=\"actions\" *ngIf=\"modeService.editMode$ | async\">\n    <button mat-icon-button color=\"primary\" [matMenuTriggerFor]=\"menu\" [matTooltip]=\"headingActions[0]?.tooltipHint\">\n      <mat-icon>{{ headingActions[0]?.icon }}</mat-icon>\n    </button>\n    <mat-menu #menu=\"matMenu\">\n      <button\n        mat-menu-item\n        *ngFor=\"let headerAction of headingActions; trackBy: trackByFn\"\n        (click)=\"executeAction(headerAction)\"\n      >\n        <mat-icon>{{ headerAction?.icon }}</mat-icon>\n        <span>H{{ headerAction.headlineWeight }}</span>\n      </button>\n    </mat-menu>\n    <button\n      *ngFor=\"let action of actions; trackBy: trackByFn\"\n      mat-icon-button\n      class=\"action\"\n      color=\"primary\"\n      (click)=\"executeAction(action)\"\n      [matTooltip]=\"action?.tooltipHint\"\n    >\n      <mat-icon>{{ action?.icon }}</mat-icon>\n    </button>\n  </div>\n</div>\n", styles: ["mat-button-toggle-group{border:0;border-bottom-left-radius:0;border-bottom-right-radius:0;width:200px}:host,mat-button-toggle-group,.actions{border-top-left-radius:4px;border-top-right-radius:4px}.action-bar{display:flex;flex-direction:row;align-items:baseline}.actions{display:flex;flex-direction:row;justify-content:flex-end;width:100%}\n"] }]
        }], ctorParameters: function () { return [{ type: ActionService }, { type: MarkdownModeService }]; } });

/**
 * Material component imports for markdown editor
 */
class SentinelMarkdownEditorMaterialModule {
}
SentinelMarkdownEditorMaterialModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelMarkdownEditorMaterialModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
SentinelMarkdownEditorMaterialModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: SentinelMarkdownEditorMaterialModule, imports: [MatButtonModule,
        MatButtonToggleModule,
        MatDividerModule,
        MatIconModule,
        MatTooltipModule,
        MatMenuModule,
        TextFieldModule], exports: [MatButtonModule,
        MatButtonToggleModule,
        MatDividerModule,
        MatIconModule,
        MatTooltipModule,
        MatMenuModule,
        TextFieldModule] });
SentinelMarkdownEditorMaterialModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelMarkdownEditorMaterialModule, imports: [MatButtonModule,
        MatButtonToggleModule,
        MatDividerModule,
        MatIconModule,
        MatTooltipModule,
        MatMenuModule,
        TextFieldModule, MatButtonModule,
        MatButtonToggleModule,
        MatDividerModule,
        MatIconModule,
        MatTooltipModule,
        MatMenuModule,
        TextFieldModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelMarkdownEditorMaterialModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        MatButtonModule,
                        MatButtonToggleModule,
                        MatDividerModule,
                        MatIconModule,
                        MatTooltipModule,
                        MatMenuModule,
                        TextFieldModule,
                    ],
                    exports: [
                        MatButtonModule,
                        MatButtonToggleModule,
                        MatDividerModule,
                        MatIconModule,
                        MatTooltipModule,
                        MatMenuModule,
                        TextFieldModule,
                    ],
                }]
        }] });

/**
 * Class holding state of editor selection
 */
class EditorSelection {
    constructor(from, to) {
        this.from = from;
        this.to = to;
    }
    /**
     * Get position of current markdown editor selection
     * @param editor html text area element
     */
    static getSelectedPosition(editor) {
        const selection = window.getSelection();
        if (selection.focusNode) {
            return new EditorSelection(editor.selectionStart, editor.selectionEnd);
        }
        else {
            return new EditorSelection(0, 0);
        }
    }
}

/**
 * Markdown footer class for file upload
 */
class MarkdownFooterComponent {
    constructor() {
        /**
         * Selected files to upload
         */
        this.uploadFiles = new EventEmitter();
    }
    /**
     * Call service to upload files to server
     */
    filesSelected(files) {
        this.uploadFiles.emit(files);
    }
}
MarkdownFooterComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: MarkdownFooterComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
MarkdownFooterComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: MarkdownFooterComponent, selector: "sentinel-markdown-footer", inputs: { activeFileUpload: "activeFileUpload" }, outputs: { uploadFiles: "uploadFiles" }, ngImport: i0, template: "<div class=\"footer\">\n  <span\n    ><a href=\"https://github.github.com/gfm\" target=\"_blank\">Markdown</a>\n    supported.</span\n  >\n  <span *ngIf=\"activeFileUpload\">Drag files to insert</span>\n  <div class=\"spacer\"></div>\n  <button\n    *ngIf=\"activeFileUpload\"\n    mat-button\n    color=\"accent\"\n    class=\"upload-btn\"\n    ngf\n    multiple=\"1\"\n    selectable=\"true\"\n    (filesChange)=\"filesSelected($event)\"\n  >\n    <mat-icon>attach_file</mat-icon>Attach a file\n  </button>\n</div>\n", styles: [":host,.footer{border-bottom-left-radius:4px;border-bottom-right-radius:4px}.footer{padding-left:10px;height:100%;display:flex;flex-direction:row;align-items:center}span{margin:0 1px}.spacer{flex:1 1 0}\n"], dependencies: [{ kind: "directive", type: i3.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2.ngf, selector: "[ngf]", inputs: ["ngfFixOrientation", "fileDropDisabled", "selectable", "lastInvalids", "files", "file", "multiple", "accept", "maxSize", "lastBaseUrl", "capturePaste"], outputs: ["init", "lastInvalidsChange", "lastBaseUrlChange", "fileChange", "filesChange", "fileSelectStart"], exportAs: ["ngf"] }, { kind: "component", type: i4.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { kind: "component", type: i6.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: MarkdownFooterComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sentinel-markdown-footer', changeDetection: ChangeDetectionStrategy.OnPush, template: "<div class=\"footer\">\n  <span\n    ><a href=\"https://github.github.com/gfm\" target=\"_blank\">Markdown</a>\n    supported.</span\n  >\n  <span *ngIf=\"activeFileUpload\">Drag files to insert</span>\n  <div class=\"spacer\"></div>\n  <button\n    *ngIf=\"activeFileUpload\"\n    mat-button\n    color=\"accent\"\n    class=\"upload-btn\"\n    ngf\n    multiple=\"1\"\n    selectable=\"true\"\n    (filesChange)=\"filesSelected($event)\"\n  >\n    <mat-icon>attach_file</mat-icon>Attach a file\n  </button>\n</div>\n", styles: [":host,.footer{border-bottom-left-radius:4px;border-bottom-right-radius:4px}.footer{padding-left:10px;height:100%;display:flex;flex-direction:row;align-items:center}span{margin:0 1px}.spacer{flex:1 1 0}\n"] }]
        }], propDecorators: { activeFileUpload: [{
                type: Input
            }], uploadFiles: [{
                type: Output
            }] } });

const WHITESPACE_REGEX = new RegExp('\\s');
/**
 * Main component of markdown editor
 */
class SentinelMarkdownEditorComponent {
    constructor(actionService, modeService) {
        this.actionService = actionService;
        this.modeService = modeService;
        /**
         * Watch for keys provided in array
         */
        this.tagTriggers = [];
        /**
         * True if the text area should be autosized, false otherwise
         */
        // eslint-disable-next-line @angular-eslint/no-input-rename
        this.autosize = false;
        /**
         * True if the text area should be auto focused, false otherwise
         */
        // eslint-disable-next-line @angular-eslint/no-input-rename
        this.autofocus = false;
        /**
         * Event emitter emitting when content changes
         */
        this.contentChange = new EventEmitter();
        /**
         * Emits when one of the watched tag key chars were triggered
         */
        this.tagTrigger = new EventEmitter();
        this.tagTextChange = new EventEmitter();
        this.positionChange = new EventEmitter();
        /**
         * Emits file selected to upload
         */
        this.uploadFiles = new EventEmitter();
        this.files = [];
    }
    ngOnInit() {
        this._internalActionSubscription = this.actionService.action$.subscribe((action) => this.dispatchAction(action));
    }
    ngOnChanges(changes) {
        if ('actionDispatcher' in changes && this.actionDispatcher) {
            if (this._externalActionSubscription) {
                this._externalActionSubscription.unsubscribe();
            }
            this._externalActionSubscription = this.actionDispatcher.subscribe((action) => this.dispatchAction(action));
        }
    }
    ngOnDestroy() {
        if (this._internalActionSubscription) {
            this._internalActionSubscription.unsubscribe();
        }
        if (this._externalActionSubscription) {
            this._externalActionSubscription.unsubscribe();
        }
    }
    /**
     * Emits changed content
     */
    contentChanged() {
        this.contentChange.emit(this.content);
    }
    onCaretChange() {
        const currPosition = this.getPosition();
        this.positionChange.emit(currPosition);
        if (this.tagTriggers && this.tagTriggers.length > 0) {
            this.checkForActiveTag(currPosition, this.content);
        }
    }
    /**
     * Calls service to upload selected files
     */
    onUploadFiles(files) {
        const filesToUpload = files ? files : this.files;
        if (this.modeService.getIsEditMode && this.activeFileUpload) {
            this.uploadFiles.emit(filesToUpload);
        }
        this.files = [];
    }
    /**
     * Dispatches editor action
     * @param action editor action transforming the current text
     */
    dispatchAction(action) {
        const editorSelection = EditorSelection.getSelectedPosition(this.editorRef.nativeElement);
        this.content = action.transform(this.content ? this.content : '', editorSelection);
        this.editorRef.nativeElement.focus();
        this.contentChanged();
    }
    getPosition() {
        return position(this.editorRef.nativeElement);
    }
    checkForActiveTag(currPosition, text) {
        const caretPos = currPosition.pos;
        if (caretPos === 0) {
            this.tagTrigger.emit(undefined);
            this.tagTextChange.emit(undefined);
            return;
        }
        const potentiallyTagged = this.findPotentiallyTaggedSubstr(caretPos, text);
        if (!this.startsWithTag(potentiallyTagged, this.tagTriggers)) {
            this.tagTrigger.emit(undefined);
            this.tagTextChange.emit(undefined);
            return;
        }
        // now we are sure that it contains a tag
        this.calculateProjectedComponentOffset(currPosition);
        const tag = potentiallyTagged[0];
        if (tag && potentiallyTagged.length === 1) {
            // contains only tag and no search text
            this.tagTrigger.emit(tag);
            this.tagTextChange.emit(undefined);
        }
        const tagWithTextRegex = new RegExp(`([${tag}])(\\S+)`);
        const match = potentiallyTagged.match(tagWithTextRegex);
        if (match && match.length === 3) {
            // contains tag and text
            this.tagTrigger.emit(tag);
            this.tagTextChange.emit(match[2]);
        }
    }
    startsWithTag(str, tagTriggers) {
        return str.length > 0 && tagTriggers.includes(str[0]);
    }
    findPotentiallyTaggedSubstr(index, text) {
        let foundWhiteSpace = false;
        let indexToWhitespaceSubstr = '';
        let i = index;
        while (!foundWhiteSpace && i > 0) {
            i--;
            const currChar = text[i];
            if (currChar.match(WHITESPACE_REGEX)?.length === 1) {
                foundWhiteSpace = true;
            }
            else {
                indexToWhitespaceSubstr += currChar;
            }
        }
        return indexToWhitespaceSubstr.split('').reverse().join('');
    }
    calculateProjectedComponentOffset(pos) {
        const top = pos.top - // caret position
            this.editorRef.nativeElement.scrollHeight + // curr scroll height
            this.editorRef.nativeElement.offsetHeight + // height of textarea element
            pos.height +
            50; // caret height and constant to display slightly below the caret
        this.projectedComponentOffset = { top: top, left: pos.left, height: pos.height };
    }
}
SentinelMarkdownEditorComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelMarkdownEditorComponent, deps: [{ token: ActionService }, { token: MarkdownModeService }], target: i0.ɵɵFactoryTarget.Component });
SentinelMarkdownEditorComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: SentinelMarkdownEditorComponent, selector: "sentinel-markdown-editor", inputs: { content: "content", tagTriggers: "tagTriggers", actionDispatcher: "actionDispatcher", autosize: ["sentinel-markdown-autosize", "autosize"], autofocus: ["sentinel-markdown-focus", "autofocus"], activeFileUpload: ["sentinel-markdown-file-upload", "activeFileUpload"] }, outputs: { contentChange: "contentChange", tagTrigger: "tagTrigger", tagTextChange: "tagTextChange", positionChange: "positionChange", uploadFiles: "uploadFiles" }, providers: [ActionService, MarkdownModeService], viewQueries: [{ propertyName: "editorRef", first: true, predicate: ["editor"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "<div class=\"wrapper\">\n  <div class=\"mrkdwn-editor\" ngfDrop [files]=\"files\" (filesChange)=\"onUploadFiles()\">\n    <sentinel-action-bar></sentinel-action-bar>\n    <textarea\n      #editor\n      *ngIf=\"modeService.editMode$ | async\"\n      name=\"content\"\n      [cdkTextareaAutosize]=\"autosize\"\n      [sentinel-markdown-focus]=\"autofocus\"\n      [(ngModel)]=\"content\"\n      (ngModelChange)=\"contentChanged()\"\n      (keyup)=\"onCaretChange()\"\n      (mouseup)=\"onCaretChange()\"\n      (touchend)=\"onCaretChange()\"\n      (paste)=\"onCaretChange()\"\n    >\n    </textarea>\n    <div class=\"projected-component\" [ngStyle]=\"{ 'left.px': projectedComponentOffset?.left, 'top.px': projectedComponentOffset?.top}\">\n      <ng-content></ng-content>\n    </div>\n    <sentinel-markdown-view *ngIf=\"(modeService.editMode$ | async) === false\" [markdown]=\"content\"></sentinel-markdown-view>\n    <sentinel-markdown-footer *ngIf=\"modeService.editMode$ | async\"\n                              [activeFileUpload]=\"activeFileUpload\"\n                              (uploadFiles)=\"onUploadFiles($event)\">\n    </sentinel-markdown-footer>\n  </div>\n</div>\n", styles: [".wrapper{height:100%}.projected-component{position:absolute}.mrkdwn-editor{height:100%;position:relative;display:flex;flex-direction:column;border-radius:4px;transition:box-shadow .2s linear}sentinel-markdown-footer{height:36px}textarea{height:100%;overflow-y:auto;border:0;resize:none;padding:10px}sentinel-markdown-view{height:100%;overflow-y:auto;padding:10px;border-bottom-left-radius:4px;border-bottom-right-radius:4px}textarea:focus{outline:none}sentinel-markdown-view ::ng-deep img{max-width:100%;display:block;margin:0 auto}sentinel-markdown-view ::ng-deep pre{white-space:pre-wrap;overflow-wrap:break-word}\n"], dependencies: [{ kind: "directive", type: i3.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i3.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }, { kind: "directive", type: i4$1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i4$1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i4$1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "directive", type: i2.ngfDrop, selector: "[ngfDrop]", inputs: ["validDrag", "invalidDrag", "dragFiles"], outputs: ["fileOver", "validDragChange", "invalidDragChange", "dragFilesChange"], exportAs: ["ngfDrop"] }, { kind: "component", type: i6$1.SentinelMarkdownViewComponent, selector: "sentinel-markdown-view", inputs: ["markdown", "options"] }, { kind: "directive", type: i7$1.CdkTextareaAutosize, selector: "textarea[cdkTextareaAutosize]", inputs: ["cdkAutosizeMinRows", "cdkAutosizeMaxRows", "cdkTextareaAutosize", "placeholder"], exportAs: ["cdkTextareaAutosize"] }, { kind: "directive", type: FocusDirective, selector: "textarea[sentinel-markdown-focus]", inputs: ["sentinel-markdown-focus"] }, { kind: "component", type: ActionBarComponent, selector: "sentinel-action-bar" }, { kind: "component", type: MarkdownFooterComponent, selector: "sentinel-markdown-footer", inputs: ["activeFileUpload"], outputs: ["uploadFiles"] }, { kind: "pipe", type: i3.AsyncPipe, name: "async" }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelMarkdownEditorComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sentinel-markdown-editor', changeDetection: ChangeDetectionStrategy.OnPush, providers: [ActionService, MarkdownModeService], template: "<div class=\"wrapper\">\n  <div class=\"mrkdwn-editor\" ngfDrop [files]=\"files\" (filesChange)=\"onUploadFiles()\">\n    <sentinel-action-bar></sentinel-action-bar>\n    <textarea\n      #editor\n      *ngIf=\"modeService.editMode$ | async\"\n      name=\"content\"\n      [cdkTextareaAutosize]=\"autosize\"\n      [sentinel-markdown-focus]=\"autofocus\"\n      [(ngModel)]=\"content\"\n      (ngModelChange)=\"contentChanged()\"\n      (keyup)=\"onCaretChange()\"\n      (mouseup)=\"onCaretChange()\"\n      (touchend)=\"onCaretChange()\"\n      (paste)=\"onCaretChange()\"\n    >\n    </textarea>\n    <div class=\"projected-component\" [ngStyle]=\"{ 'left.px': projectedComponentOffset?.left, 'top.px': projectedComponentOffset?.top}\">\n      <ng-content></ng-content>\n    </div>\n    <sentinel-markdown-view *ngIf=\"(modeService.editMode$ | async) === false\" [markdown]=\"content\"></sentinel-markdown-view>\n    <sentinel-markdown-footer *ngIf=\"modeService.editMode$ | async\"\n                              [activeFileUpload]=\"activeFileUpload\"\n                              (uploadFiles)=\"onUploadFiles($event)\">\n    </sentinel-markdown-footer>\n  </div>\n</div>\n", styles: [".wrapper{height:100%}.projected-component{position:absolute}.mrkdwn-editor{height:100%;position:relative;display:flex;flex-direction:column;border-radius:4px;transition:box-shadow .2s linear}sentinel-markdown-footer{height:36px}textarea{height:100%;overflow-y:auto;border:0;resize:none;padding:10px}sentinel-markdown-view{height:100%;overflow-y:auto;padding:10px;border-bottom-left-radius:4px;border-bottom-right-radius:4px}textarea:focus{outline:none}sentinel-markdown-view ::ng-deep img{max-width:100%;display:block;margin:0 auto}sentinel-markdown-view ::ng-deep pre{white-space:pre-wrap;overflow-wrap:break-word}\n"] }]
        }], ctorParameters: function () { return [{ type: ActionService }, { type: MarkdownModeService }]; }, propDecorators: { content: [{
                type: Input
            }], tagTriggers: [{
                type: Input
            }], actionDispatcher: [{
                type: Input
            }], autosize: [{
                type: Input,
                args: ['sentinel-markdown-autosize']
            }], autofocus: [{
                type: Input,
                args: ['sentinel-markdown-focus']
            }], activeFileUpload: [{
                type: Input,
                args: ['sentinel-markdown-file-upload']
            }], contentChange: [{
                type: Output
            }], tagTrigger: [{
                type: Output
            }], tagTextChange: [{
                type: Output
            }], positionChange: [{
                type: Output
            }], uploadFiles: [{
                type: Output
            }], editorRef: [{
                type: ViewChild,
                args: ['editor']
            }] } });

/**
 * Main module of markdown editor library containing necessary imports, components and config provider.
 * Use forRoot() method with config to import into you app
 */
class SentinelMarkdownEditorModule {
    /**
     * Import the module in your app with config class
     */
    static forRoot(markdownConfig) {
        return {
            ngModule: SentinelMarkdownEditorModule,
            providers: [
                SentinelMarkdownViewModule.forRoot({ ...markdownConfig.markdownParser }).providers,
                { provide: MarkdownConfig, useValue: markdownConfig },
            ],
        };
    }
    static forChild() {
        return {
            ngModule: SentinelMarkdownEditorModule,
        };
    }
}
SentinelMarkdownEditorModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelMarkdownEditorModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
SentinelMarkdownEditorModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: SentinelMarkdownEditorModule, declarations: [SentinelMarkdownEditorComponent, FocusDirective, ActionBarComponent, MarkdownFooterComponent], imports: [CommonModule, FormsModule, ngfModule, SentinelMarkdownViewModule, SentinelMarkdownEditorMaterialModule], exports: [SentinelMarkdownEditorComponent] });
SentinelMarkdownEditorModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelMarkdownEditorModule, imports: [CommonModule, FormsModule, ngfModule, SentinelMarkdownViewModule, SentinelMarkdownEditorMaterialModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelMarkdownEditorModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule, FormsModule, ngfModule, SentinelMarkdownViewModule, SentinelMarkdownEditorMaterialModule],
                    declarations: [SentinelMarkdownEditorComponent, FocusDirective, ActionBarComponent, MarkdownFooterComponent],
                    exports: [SentinelMarkdownEditorComponent],
                }]
        }] });

/**
 * Util class resolving type of file
 */
class FileTypeResolver {
    /**
     * True if file is of supported image type, false otherwise
     * @param file file to be checked
     */
    static isImage(file) {
        return (file.type.endsWith('png') || file.type.endsWith('jpg') || file.type.endsWith('jpeg') || file.type.endsWith('gif'));
    }
}

/**
 * Markdown editor file action
 */
class FileAction {
    /**
     *
     * @param url url of the file
     * @param name filename
     * @param isImage true if is image, false if other file
     */
    constructor(url, name, isImage) {
        this.icon = 'attach_file';
        this.tooltipHint = 'Attach file';
        this.url = 'url';
        this.filename = 'filename';
        this.isImage = false;
        this.url = url;
        this.filename = name;
        this.isImage = isImage;
    }
    /**
     * Adds file markdown tags to content of the markdown editor action (or its selection)
     * @param content content to be transformed
     * @param selected current selection to be transformed
     */
    transform(content, selected) {
        return (content.slice(0, selected.from) +
            this.addFile(content.slice(selected.from, selected.to)) +
            content.slice(selected.to));
    }
    addFile(selectedText) {
        return this.isImage
            ? selectedText + '\n ![' + this.filename + '](' + this.url + ')\n'
            : selectedText + '\n [' + this.filename + '](' + this.url + ')\n';
    }
}

/*
 * Public API Surface of @sentinel/components/markdown-editor
 */

/**
 * Generated bundle index. Do not edit.
 */

export { EditorSelection, FileAction, FileTypeResolver, MarkdownConfig, SentinelMarkdownEditorComponent, SentinelMarkdownEditorModule };
//# sourceMappingURL=sentinel-components-markdown-editor.mjs.map
