import * as i0 from '@angular/core';
import { InjectionToken, Injectable, Inject, Optional, Component, Input, HostListener, SecurityContext, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { marked } from 'marked';
import * as i2 from '@angular/platform-browser';
import * as i1 from '@angular/router';
import { SentinelBaseDirective } from '@sentinel/common';

class MarkedOptions {
}

const SECURITY_CONTEXT = new InjectionToken('SECURITY_CONTEXT');
class SentinelMarkdownViewService {
    constructor(securityContext, options, sanitizer) {
        this.securityContext = securityContext;
        this.sanitizer = sanitizer;
        if (options) {
            this.setOptions(options);
        }
    }
    setOptions(value) {
        marked.use(value);
    }
    compile(markdown) {
        const trimmed = this.trimIndentation(markdown);
        const compiled = marked(trimmed);
        return this.sanitizer.sanitize(this.securityContext, compiled);
    }
    trimIndentation(markdown) {
        if (!markdown) {
            return '';
        }
        let indentStart;
        return markdown
            .split('\n')
            .map((line) => {
            let lineIdentStart = indentStart;
            if (line.length > 0) {
                lineIdentStart = isNaN(lineIdentStart) ? line.search(/\S|$/) : Math.min(line.search(/\S|$/), lineIdentStart);
            }
            if (isNaN(indentStart)) {
                indentStart = lineIdentStart;
            }
            return lineIdentStart ? line.substring(lineIdentStart) : line;
        })
            .join('\n');
    }
}
SentinelMarkdownViewService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelMarkdownViewService, deps: [{ token: SECURITY_CONTEXT }, { token: MarkedOptions, optional: true }, { token: i2.DomSanitizer }], target: i0.ɵɵFactoryTarget.Injectable });
SentinelMarkdownViewService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelMarkdownViewService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelMarkdownViewService, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: i0.SecurityContext, decorators: [{
                    type: Inject,
                    args: [SECURITY_CONTEXT]
                }] }, { type: MarkedOptions, decorators: [{
                    type: Optional
                }] }, { type: i2.DomSanitizer }]; } });

class SentinelMarkdownAnchorService {
    constructor(router) {
        this.router = router;
    }
    interceptAndNavigate(event) {
        if (!(event.target instanceof HTMLAnchorElement)) {
            return;
        }
        const href = event.target.getAttribute('href');
        if (href === null) {
            return;
        }
        if (this.isExternalUrl(href) || this.isRouterLink(event.target)) {
            return;
        }
        this.navigateInternally(href);
        event.preventDefault(); // blocks default browser anchor navigation
    }
    isExternalUrl(url) {
        return /^(?!http(s?):\/\/).+$/.exec(url) == null;
    }
    isRouterLink(el) {
        return el.getAttributeNames().some((n) => n.startsWith('_ngcontent'));
    }
    navigateInternally(url) {
        const urlTree = this.getUrlTree(url);
        this.router.navigated = false;
        this.router.navigateByUrl(urlTree);
    }
    getUrlTree(url) {
        const urlPath = this.stripFragment(url) || this.stripFragment(this.router.url);
        return this.router.createUrlTree([urlPath]);
    }
    stripFragment(url) {
        const match = /[^#]*/.exec(url);
        if (match && match.length > 0) {
            return match[0];
        }
        else {
            return url;
        }
    }
}
SentinelMarkdownAnchorService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelMarkdownAnchorService, deps: [{ token: i1.Router }], target: i0.ɵɵFactoryTarget.Injectable });
SentinelMarkdownAnchorService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelMarkdownAnchorService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelMarkdownAnchorService, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: i1.Router }]; } });

class SentinelMarkdownViewComponent extends SentinelBaseDirective {
    constructor(element, markdownService, anchorService) {
        super();
        this.element = element;
        this.markdownService = markdownService;
        this.anchorService = anchorService;
    }
    onDocumentClick(event) {
        this.anchorService.interceptAndNavigate(event);
    }
    ngOnChanges(changes) {
        if ('markdown' in changes && this.markdown) {
            this.render(this.markdown);
        }
        if ('options' in changes && this.options) {
            this.markdownService.setOptions(this.options);
            if (this.markdown) {
                this.render(this.markdown);
            }
        }
    }
    render(markdown) {
        this.element.nativeElement.innerHTML = this.markdownService.compile(markdown);
    }
}
SentinelMarkdownViewComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelMarkdownViewComponent, deps: [{ token: i0.ElementRef }, { token: SentinelMarkdownViewService }, { token: SentinelMarkdownAnchorService }], target: i0.ɵɵFactoryTarget.Component });
SentinelMarkdownViewComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: SentinelMarkdownViewComponent, selector: "sentinel-markdown-view", inputs: { markdown: "markdown", options: "options" }, host: { listeners: { "document:click": "onDocumentClick($event)" } }, providers: [SentinelMarkdownViewService, SentinelMarkdownAnchorService], usesInheritance: true, usesOnChanges: true, ngImport: i0, template: '<ng-content></ng-content>', isInline: true, styles: [":host ::ng-deep img{max-width:100%}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelMarkdownViewComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sentinel-markdown-view', template: '<ng-content></ng-content>', providers: [SentinelMarkdownViewService, SentinelMarkdownAnchorService], styles: [":host ::ng-deep img{max-width:100%}\n"] }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: SentinelMarkdownViewService }, { type: SentinelMarkdownAnchorService }]; }, propDecorators: { markdown: [{
                type: Input
            }], options: [{
                type: Input
            }], onDocumentClick: [{
                type: HostListener,
                args: ['document:click', ['$event']]
            }] } });

class SentinelMarkdownViewModule {
    static forRoot(markdownModuleConfig) {
        return {
            ngModule: SentinelMarkdownViewModule,
            providers: [
                (markdownModuleConfig && markdownModuleConfig.markedOptions) || [],
                {
                    provide: SECURITY_CONTEXT,
                    useValue: markdownModuleConfig &&
                        markdownModuleConfig.sanitize !== null &&
                        markdownModuleConfig.sanitize !== undefined
                        ? markdownModuleConfig.sanitize
                        : SecurityContext.HTML,
                },
            ],
        };
    }
    static forChild() {
        return {
            ngModule: SentinelMarkdownViewModule,
        };
    }
}
SentinelMarkdownViewModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelMarkdownViewModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
SentinelMarkdownViewModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: SentinelMarkdownViewModule, declarations: [SentinelMarkdownViewComponent], imports: [CommonModule], exports: [SentinelMarkdownViewComponent] });
SentinelMarkdownViewModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelMarkdownViewModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelMarkdownViewModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [SentinelMarkdownViewComponent],
                    imports: [CommonModule],
                    exports: [SentinelMarkdownViewComponent],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { MarkedOptions, SentinelMarkdownViewComponent, SentinelMarkdownViewModule };
//# sourceMappingURL=sentinel-components-markdown-view.mjs.map
