import * as i3$1 from '@angular/cdk/drag-drop';
import { moveItemInArray, DragDropModule } from '@angular/cdk/drag-drop';
import { ScrollingModule } from '@angular/cdk/scrolling';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { Pipe, Component, Input, EventEmitter, Output, NgModule } from '@angular/core';
import * as i2$1 from '@angular/material/button';
import { MatButtonModule } from '@angular/material/button';
import { MatDividerModule } from '@angular/material/divider';
import * as i3 from '@angular/material/form-field';
import { MatFormFieldModule } from '@angular/material/form-field';
import * as i2 from '@angular/material/icon';
import { MatIconModule } from '@angular/material/icon';
import { trackById } from '@sentinel/common/utils';

var StepStateEnum;
(function (StepStateEnum) {
    StepStateEnum["ACTIVE"] = "active";
    StepStateEnum["SELECTABLE"] = "selectable";
    StepStateEnum["DISABLED"] = "disabled";
})(StepStateEnum || (StepStateEnum = {}));

/**
 * Pipe to create readable label for steps in level stepper.
 * For steppers with less than 8 levels returns string 'Level x' and for steppers with more than 8 levels
 * returns only 'x', where x is index of the level (its order).
 */
class StepperItemLabelPipe {
    transform(title, index, length) {
        if (length > 11) {
            return '';
        }
        if (length < 9 && length > 7) {
            return `${index + '. ' + title.substr(0, 3)}...`;
        }
        return length <= 7 ? index + '. ' + title : index.toString();
    }
}
StepperItemLabelPipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: StepperItemLabelPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
StepperItemLabelPipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: StepperItemLabelPipe, name: "stepperItemLabel" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: StepperItemLabelPipe, decorators: [{
            type: Pipe,
            args: [{ name: 'stepperItemLabel' }]
        }] });

/**
 * Transforms stepper's item label length if it exceeds given value. Places dots after cut characters.
 * If there is more then 7 levels pipe only returns given value.
 */
class TruncatePipe {
    transform(value, limit = 25, length) {
        if (length < 8 && value.length > limit) {
            return `${value.substr(0, limit)}...`;
        }
        else {
            return value;
        }
    }
}
TruncatePipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: TruncatePipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
TruncatePipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: TruncatePipe, name: "truncate" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: TruncatePipe, decorators: [{
            type: Pipe,
            args: [{ name: 'truncate' }]
        }] });

class StepperStepComponent {
    constructor() {
        this.StepStateEnum = StepStateEnum;
    }
    ngOnInit() {
        if (this.stepperLength === this.itemIndex) {
            this.isLastItem = true;
        }
        if (this.stepperLength > 11 || !this.itemOverflow) {
            this.itemOverflow = true;
        }
    }
}
StepperStepComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: StepperStepComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
StepperStepComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: StepperStepComponent, selector: "sentinel-stepper-step", inputs: { stepperLength: "stepperLength", stepperItem: "stepperItem", itemIndex: "itemIndex", color: "color" }, ngImport: i0, template: "<div\n  class=\"icon-container stepper-background\"\n  [ngClass]=\"{\n    'icon-container-last-child': stepperLength === itemIndex,\n    'icon-container-first-child': itemIndex === 0\n  }\"\n>\n  <mat-icon\n    class=\"item-icon item-selected\"\n    [ngClass]=\"{\n      'item-active': stepperItem.state === StepStateEnum.ACTIVE,\n      'item-selectable': stepperItem.state === StepStateEnum.SELECTABLE,\n      'item-disabled': stepperItem.state === StepStateEnum.DISABLED\n    }\"\n  >\n    {{ stepperItem.icon }}\n  </mat-icon>\n\n  <mat-label\n    class=\"item-name stepper-background\"\n    [ngClass]=\"{ 'item-name-last-wide': isLastItem, 'item-name-empty': itemOverflow }\"\n  >\n    {{ stepperItem.title | stepperItemLabel: itemIndex + 1:stepperLength | truncate: 10:stepperLength }}\n  </mat-label>\n</div>\n", styles: [".item-icon{border-radius:50%;margin-right:10px;display:inline-block;text-align:center;line-height:25px;font-size:18px;margin-left:10px}.icon-container{width:-moz-fit-content;width:fit-content}.icon-container-first-child{margin-left:-1.5em}.icon-container-last-child{margin-right:-.2em;width:auto!important}.item-name{padding-right:.6em;font-weight:400;white-space:nowrap;overflow:hidden;text-overflow:ellipsis}.item-name-empty{background:transparent!important}.item-name-selected{font-weight:500}.item-has-state{background-color:transparent}.item-name-last-wide{max-width:40px!important}\n"], dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "component", type: i2.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { kind: "directive", type: i3.MatLabel, selector: "mat-label" }, { kind: "pipe", type: StepperItemLabelPipe, name: "stepperItemLabel" }, { kind: "pipe", type: TruncatePipe, name: "truncate" }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: StepperStepComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sentinel-stepper-step', template: "<div\n  class=\"icon-container stepper-background\"\n  [ngClass]=\"{\n    'icon-container-last-child': stepperLength === itemIndex,\n    'icon-container-first-child': itemIndex === 0\n  }\"\n>\n  <mat-icon\n    class=\"item-icon item-selected\"\n    [ngClass]=\"{\n      'item-active': stepperItem.state === StepStateEnum.ACTIVE,\n      'item-selectable': stepperItem.state === StepStateEnum.SELECTABLE,\n      'item-disabled': stepperItem.state === StepStateEnum.DISABLED\n    }\"\n  >\n    {{ stepperItem.icon }}\n  </mat-icon>\n\n  <mat-label\n    class=\"item-name stepper-background\"\n    [ngClass]=\"{ 'item-name-last-wide': isLastItem, 'item-name-empty': itemOverflow }\"\n  >\n    {{ stepperItem.title | stepperItemLabel: itemIndex + 1:stepperLength | truncate: 10:stepperLength }}\n  </mat-label>\n</div>\n", styles: [".item-icon{border-radius:50%;margin-right:10px;display:inline-block;text-align:center;line-height:25px;font-size:18px;margin-left:10px}.icon-container{width:-moz-fit-content;width:fit-content}.icon-container-first-child{margin-left:-1.5em}.icon-container-last-child{margin-right:-.2em;width:auto!important}.item-name{padding-right:.6em;font-weight:400;white-space:nowrap;overflow:hidden;text-overflow:ellipsis}.item-name-empty{background:transparent!important}.item-name-selected{font-weight:500}.item-has-state{background-color:transparent}.item-name-last-wide{max-width:40px!important}\n"] }]
        }], propDecorators: { stepperLength: [{
                type: Input
            }], stepperItem: [{
                type: Input
            }], itemIndex: [{
                type: Input
            }], color: [{
                type: Input
            }] } });

class StepperStateChange {
    constructor(previousIndex, currentIndex, snapshot) {
        this.currentIndex = currentIndex;
        this.previousIndex = previousIndex;
        this.snapshot = snapshot;
    }
}

class SentinelStepperComponent {
    constructor() {
        this.draggable = true;
        this.selectable = true;
        this.indexSelected = new EventEmitter();
        this.stepSwapped = new EventEmitter();
        this.selectedStepSwapped = new EventEmitter();
        this.activeItemIndex = 0;
        this.trackByFn = trackById;
        this.StepStateEnum = StepStateEnum;
    }
    ngOnInit() {
        this.initStepperSettings();
    }
    ngOnChanges(changes) {
        if ('activeIndex' in changes) {
            this.activeItemIndex = this.activeIndex;
        }
    }
    /**
     * Initial settings of stepper. Selects first item as active if stepper is in mode
     * where drag is disabled. Shows scrollbar if stepper has more than 15 items.
     */
    initStepperSettings() {
        this.stepperData = this.stepperItems;
        if (!this.selectable) {
            this.activeItemIndex = 0;
            this.itemSelected(this.activeItemIndex);
        }
        if (this.getStepperLength() > 15) {
            this.displayScrollbar = true;
        }
        if (this.activeIndex || this.activeIndex === 0) {
            this.activeItemIndex = this.activeIndex;
            this.itemSelected(this.activeItemIndex);
        }
    }
    /**
     * Optimistic, swap is done by user and it is displayed before swapping on server
     * @param event contains indexes of items which were swapped
     */
    drop(event) {
        if (this.draggable) {
            const itemsSnapshot = [];
            this.stepperData.items.forEach((item) => itemsSnapshot.push(item.id));
            this.swapFromTo(this.stepperData.items, event.previousIndex, event.currentIndex);
            if (event.previousIndex !== event.currentIndex) {
                this.updateActiveItem(event);
                this.stepSwapped.emit(new StepperStateChange(event.previousIndex, event.currentIndex, itemsSnapshot));
            }
        }
    }
    /**
     * Swaps items in stepper array
     * @param items array of items
     * @param previousIndex past index from which we want to move item
     * @param currentIndex new index, where we want to move item
     */
    swapFromTo(items, previousIndex, currentIndex) {
        moveItemInArray(items, previousIndex, currentIndex);
    }
    /**
     * Changes actual item if it changed its position during drag of any items.
     * @param event contains indexes of moved items
     */
    updateActiveItem(event) {
        if (this.activeItemIndex === event.previousIndex) {
            this.activeItemIndex = event.currentIndex;
            this.selectedStepSwapped.emit(this.activeItemIndex);
        }
        else {
            if (this.notActiveLowerItemSwapped(event)) {
                this.activeItemIndex -= 1;
                this.selectedStepSwapped.emit(this.activeItemIndex);
            }
            else if (this.notActiveHigherItemSwapped(event)) {
                this.activeItemIndex += 1;
                this.selectedStepSwapped.emit(this.activeItemIndex);
            }
        }
    }
    /**
     * @return true if any of these conditions are met:
     *  1. non-active item with lower index is swapped with active item
     *  2. non-active item with lower index is swapped with non-active item with greater index
     */
    notActiveLowerItemSwapped(event) {
        return ((this.activeItemIndex === event.currentIndex && event.previousIndex < this.activeItemIndex) ||
            (event.previousIndex < this.activeItemIndex && event.currentIndex > this.activeItemIndex));
    }
    /**
     * @return true if any of these conditions are met:
     *  1. non-active item with higher index is swapped with active item
     *  2. non-active item with higher index is swapped with non-active item with lower index
     */
    notActiveHigherItemSwapped(event) {
        return ((this.activeItemIndex === event.currentIndex && event.previousIndex > this.activeItemIndex) ||
            (event.previousIndex > this.activeItemIndex && event.currentIndex < this.activeItemIndex));
    }
    /**
     * @return length of stepper
     */
    getStepperLength() {
        return this.stepperData.items.length - 1;
    }
    /**
     * Sets stepper item to active state
     * @param index access to proper item in stepper item array
     */
    itemSelected(index) {
        this.itemUnSelected(this.activeItemIndex);
        this.stepperData.items[index].state = StepStateEnum.ACTIVE;
        this.activeItemIndex = index;
        this.indexSelected.emit(index);
    }
    /**
     * Sets item as no longer active element
     * @param index access to proper item in stepper item array
     */
    itemUnSelected(index) {
        this.stepperData.items[index].state = StepStateEnum.SELECTABLE;
    }
}
SentinelStepperComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelStepperComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
SentinelStepperComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: SentinelStepperComponent, selector: "sentinel-stepper", inputs: { stepperItems: "stepperItems", activeIndex: "activeIndex", draggable: "draggable", selectable: "selectable" }, outputs: { indexSelected: "indexSelected", stepSwapped: "stepSwapped", selectedStepSwapped: "selectedStepSwapped" }, usesOnChanges: true, ngImport: i0, template: "<div class=\"stepper-container stepper-background\" *ngIf=\"stepperData && stepperData.items\">\n  <!--Main stepper field-->\n  <div\n    cdkDropList\n    cdkDropListOrientation=\"horizontal\"\n    class=\"stepper-box stepper-scroller-hidden\"\n    [ngClass]=\"{\n      'stepper-background': stepperData.items.length === 1,\n      'stepper-scroller': displayScrollbar,\n      'stepper-box-without-scrollbar': !displayScrollbar\n    }\"\n    (cdkDropListDropped)=\"drop($event)\"\n  >\n    <!--Line between stepper items-->\n    <div class=\"line-space\"></div>\n\n    <!--Stepper item-->\n    <button\n      *ngFor=\"let dataElement of stepperData.items; let index = index; let last = last; let first = first;trackBy: trackByFn\"\n      mat-button\n      class=\"stepper-item-box\"\n      cdkDrag\n      [cdkDragDisabled]=\"!draggable || !selectable || stepperData.items.length - 1 < 1\"\n      [disabled]=\"!selectable || dataElement.state === StepStateEnum.DISABLED\"\n      [ngClass]=\"{ 'stepper-item-first': first, 'stepper-item-last': last, 'draggable': selectable }\"\n      (click)=\"itemSelected(index)\"\n      attr.data-cy=\"{{ dataElement?.id }}\"\n    >\n      <sentinel-stepper-step\n        [stepperItem]=\"dataElement\"\n        [stepperLength]=\"stepperData.items.length - 1\"\n        [itemIndex]=\"index\"\n      >\n      </sentinel-stepper-step>\n    </button>\n  </div>\n</div>\n", styles: ["@media (max-width: 1600px){.stepper-box{min-width:auto!important}.stepper-container{width:auto;min-width:420px}}.stepper-box{min-height:60px;padding:10px 40px;position:relative;background:linear-gradient(to bottom,gainsboro 1%,transparent 0);background-position-y:30px;display:flex;flex-direction:row;justify-content:space-between}.stepper-box-without-scrollbar{background-position-y:40px}.stepper-item-first{margin-left:-40px}.stepper-item-last{margin-right:-40px}.stepper-item-box{max-width:200px;padding-right:1px;background:transparent;font-size:14px;white-space:nowrap;overflow:hidden;text-overflow:ellipsis;flex-direction:row;flex-grow:1;flex-basis:0;box-sizing:border-box;align-items:center;justify-content:space-between}.draggable{cursor:move}.stepper-item-box:first-child{padding:0!important}.stepper-scroller{width:1000px;overflow-x:scroll!important}.stepper-scroller-hidden{overflow-x:visible}.stepper-container{overflow-x:auto}.cdk-drag-preview{box-sizing:border-box;border-radius:4px;box-shadow:0 5px 5px -3px #0003,0 8px 10px 1px #00000024,0 3px 14px 2px #0000001f}.cdk-drag-placeholder{opacity:0}.cdk-drag-animating{transition:transform .25s cubic-bezier(0,0,.2,1)}.stepper-item-box:last-child{border:none}.stepper-box.cdk-drop-list-dragging .stepper-item-box:not(.cdk-drag-placeholder){transition:transform .25s cubic-bezier(0,0,.2,1)}.spacer{flex:1 1 0}.line-space{position:absolute}\n"], dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i2$1.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { kind: "directive", type: i3$1.CdkDropList, selector: "[cdkDropList], cdk-drop-list", inputs: ["cdkDropListConnectedTo", "cdkDropListData", "cdkDropListOrientation", "id", "cdkDropListLockAxis", "cdkDropListDisabled", "cdkDropListSortingDisabled", "cdkDropListEnterPredicate", "cdkDropListSortPredicate", "cdkDropListAutoScrollDisabled", "cdkDropListAutoScrollStep"], outputs: ["cdkDropListDropped", "cdkDropListEntered", "cdkDropListExited", "cdkDropListSorted"], exportAs: ["cdkDropList"] }, { kind: "directive", type: i3$1.CdkDrag, selector: "[cdkDrag]", inputs: ["cdkDragData", "cdkDragLockAxis", "cdkDragRootElement", "cdkDragBoundary", "cdkDragStartDelay", "cdkDragFreeDragPosition", "cdkDragDisabled", "cdkDragConstrainPosition", "cdkDragPreviewClass", "cdkDragPreviewContainer"], outputs: ["cdkDragStarted", "cdkDragReleased", "cdkDragEnded", "cdkDragEntered", "cdkDragExited", "cdkDragDropped", "cdkDragMoved"], exportAs: ["cdkDrag"] }, { kind: "component", type: StepperStepComponent, selector: "sentinel-stepper-step", inputs: ["stepperLength", "stepperItem", "itemIndex", "color"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelStepperComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sentinel-stepper', template: "<div class=\"stepper-container stepper-background\" *ngIf=\"stepperData && stepperData.items\">\n  <!--Main stepper field-->\n  <div\n    cdkDropList\n    cdkDropListOrientation=\"horizontal\"\n    class=\"stepper-box stepper-scroller-hidden\"\n    [ngClass]=\"{\n      'stepper-background': stepperData.items.length === 1,\n      'stepper-scroller': displayScrollbar,\n      'stepper-box-without-scrollbar': !displayScrollbar\n    }\"\n    (cdkDropListDropped)=\"drop($event)\"\n  >\n    <!--Line between stepper items-->\n    <div class=\"line-space\"></div>\n\n    <!--Stepper item-->\n    <button\n      *ngFor=\"let dataElement of stepperData.items; let index = index; let last = last; let first = first;trackBy: trackByFn\"\n      mat-button\n      class=\"stepper-item-box\"\n      cdkDrag\n      [cdkDragDisabled]=\"!draggable || !selectable || stepperData.items.length - 1 < 1\"\n      [disabled]=\"!selectable || dataElement.state === StepStateEnum.DISABLED\"\n      [ngClass]=\"{ 'stepper-item-first': first, 'stepper-item-last': last, 'draggable': selectable }\"\n      (click)=\"itemSelected(index)\"\n      attr.data-cy=\"{{ dataElement?.id }}\"\n    >\n      <sentinel-stepper-step\n        [stepperItem]=\"dataElement\"\n        [stepperLength]=\"stepperData.items.length - 1\"\n        [itemIndex]=\"index\"\n      >\n      </sentinel-stepper-step>\n    </button>\n  </div>\n</div>\n", styles: ["@media (max-width: 1600px){.stepper-box{min-width:auto!important}.stepper-container{width:auto;min-width:420px}}.stepper-box{min-height:60px;padding:10px 40px;position:relative;background:linear-gradient(to bottom,gainsboro 1%,transparent 0);background-position-y:30px;display:flex;flex-direction:row;justify-content:space-between}.stepper-box-without-scrollbar{background-position-y:40px}.stepper-item-first{margin-left:-40px}.stepper-item-last{margin-right:-40px}.stepper-item-box{max-width:200px;padding-right:1px;background:transparent;font-size:14px;white-space:nowrap;overflow:hidden;text-overflow:ellipsis;flex-direction:row;flex-grow:1;flex-basis:0;box-sizing:border-box;align-items:center;justify-content:space-between}.draggable{cursor:move}.stepper-item-box:first-child{padding:0!important}.stepper-scroller{width:1000px;overflow-x:scroll!important}.stepper-scroller-hidden{overflow-x:visible}.stepper-container{overflow-x:auto}.cdk-drag-preview{box-sizing:border-box;border-radius:4px;box-shadow:0 5px 5px -3px #0003,0 8px 10px 1px #00000024,0 3px 14px 2px #0000001f}.cdk-drag-placeholder{opacity:0}.cdk-drag-animating{transition:transform .25s cubic-bezier(0,0,.2,1)}.stepper-item-box:last-child{border:none}.stepper-box.cdk-drop-list-dragging .stepper-item-box:not(.cdk-drag-placeholder){transition:transform .25s cubic-bezier(0,0,.2,1)}.spacer{flex:1 1 0}.line-space{position:absolute}\n"] }]
        }], propDecorators: { stepperItems: [{
                type: Input
            }], activeIndex: [{
                type: Input
            }], draggable: [{
                type: Input
            }], selectable: [{
                type: Input
            }], indexSelected: [{
                type: Output
            }], stepSwapped: [{
                type: Output
            }], selectedStepSwapped: [{
                type: Output
            }] } });

class SentinelStepperModule {
}
SentinelStepperModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelStepperModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
SentinelStepperModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: SentinelStepperModule, declarations: [StepperStepComponent, SentinelStepperComponent, StepperItemLabelPipe, TruncatePipe], imports: [CommonModule,
        MatButtonModule,
        DragDropModule,
        MatIconModule,
        MatDividerModule,
        MatFormFieldModule,
        ScrollingModule], exports: [SentinelStepperComponent] });
SentinelStepperModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelStepperModule, imports: [CommonModule,
        MatButtonModule,
        DragDropModule,
        MatIconModule,
        MatDividerModule,
        MatFormFieldModule,
        ScrollingModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelStepperModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [StepperStepComponent, SentinelStepperComponent, StepperItemLabelPipe, TruncatePipe],
                    imports: [
                        CommonModule,
                        MatButtonModule,
                        DragDropModule,
                        MatIconModule,
                        MatDividerModule,
                        MatFormFieldModule,
                        ScrollingModule,
                    ],
                    exports: [SentinelStepperComponent],
                }]
        }] });

/*
 * Public API Surface of @sentinel/components/stepper
 */

/**
 * Generated bundle index. Do not edit.
 */

export { SentinelStepperComponent, SentinelStepperModule, StepStateEnum, StepperStateChange };
//# sourceMappingURL=sentinel-components-stepper.mjs.map
