import * as i0 from '@angular/core';
import { Directive, Input, Injectable, EventEmitter, Output, Component, ChangeDetectionStrategy, ViewChild, Pipe, ContentChildren, NgModule } from '@angular/core';
import * as i13 from '@angular/material/sort';
import { MatSort, MatSortModule } from '@angular/material/sort';
import * as i8 from '@angular/material/table';
import { MatTableDataSource, MatTableModule } from '@angular/material/table';
import { Subject, merge, BehaviorSubject, Observable, defer, of } from 'rxjs';
import { SentinelBaseDirective } from '@sentinel/common';
import { map, takeWhile, debounceTime } from 'rxjs/operators';
import { isOffsetPagination, isOffsetEvent, isCursorEvent, OffsetPaginationEvent, isCursorPagination, CursorPaginationEvent } from '@sentinel/common/pagination';
import { SelectionModel } from '@angular/cdk/collections';
import { trackById, trackByIndex } from '@sentinel/common/utils';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i2 from '@angular/material/button';
import { MatButtonModule } from '@angular/material/button';
import * as i3$1 from '@angular/material/icon';
import { MatIconModule } from '@angular/material/icon';
import * as i4 from '@angular/material/tooltip';
import { MatTooltipModule } from '@angular/material/tooltip';
import * as i12 from '@angular/material/checkbox';
import { MatCheckboxModule } from '@angular/material/checkbox';
import * as i14 from '@sentinel/components/error';
import { SentinelErrorModule } from '@sentinel/components/error';
import * as i6 from '@sentinel/components/loading';
import { SentinelLoadingModule } from '@sentinel/components/loading';
import * as i3 from '@angular/material/menu';
import { MatMenuModule } from '@angular/material/menu';
import * as i7 from '@sentinel/components/internal';
import { SentinelLabelModule } from '@sentinel/components/internal';
import * as i2$1 from '@angular/router';
import { RouterModule } from '@angular/router';
import * as i2$2 from '@angular/material/progress-spinner';
import { MatProgressSpinnerModule } from '@angular/material/progress-spinner';
import * as i1$1 from '@angular/forms';
import { FormControl, ReactiveFormsModule } from '@angular/forms';
import * as i2$3 from '@angular/material/form-field';
import { MatFormFieldModule } from '@angular/material/form-field';
import * as i3$2 from '@angular/material/input';
import { MatInputModule } from '@angular/material/input';
import { trigger, state, style, transition, animate } from '@angular/animations';
import * as i1$2 from '@angular/material/paginator';
import { PageEvent, MatPaginatorModule } from '@angular/material/paginator';
import * as i6$1 from '@angular/material/select';
import { MatSelectModule } from '@angular/material/select';
import * as i7$1 from '@angular/material/core';
import { MatProgressBarModule } from '@angular/material/progress-bar';

/**
 * Generic table action event. Contains generic element and row action
 */
class TableActionEvent {
    constructor(element, action) {
        this.element = element;
        this.action = action;
    }
}

class SentinelRowDirective {
    set sentinelRow(value) {
        this._columnId = value;
    }
    get columnId() {
        return this._columnId;
    }
    set sentinelRowTemplate(templateRef) {
        this._template = templateRef;
    }
    get template() {
        return this._template;
    }
}
SentinelRowDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelRowDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive });
SentinelRowDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.12", type: SentinelRowDirective, selector: "[sentinelRow], [sentinelRowTemplate]", inputs: { sentinelRow: "sentinelRow", sentinelRowTemplate: "sentinelRowTemplate" }, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelRowDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[sentinelRow], [sentinelRowTemplate]',
                }]
        }], propDecorators: { sentinelRow: [{
                type: Input
            }], sentinelRowTemplate: [{
                type: Input
            }] } });

function isPageEvent(event) {
    return event.pageIndex !== undefined;
}
function isCursorPageEvent(event) {
    return event.cursor !== undefined;
}

class TableFilterService {
    constructor() {
        this.changeSubject$ = new Subject();
        this.change$ = this.changeSubject$.asObservable();
    }
    update(value) {
        this.changeSubject$.next(value);
    }
}
TableFilterService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: TableFilterService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
TableFilterService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: TableFilterService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: TableFilterService, decorators: [{
            type: Injectable
        }] });

class TableSortService {
    constructor() {
        this.changeSubject$ = new Subject();
        this.change$ = this.changeSubject$.asObservable();
    }
    update(value) {
        this.changeSubject$.next(value);
    }
}
TableSortService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: TableSortService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
TableSortService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: TableSortService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: TableSortService, decorators: [{
            type: Injectable
        }] });

class TablePageService {
    constructor() {
        this.changeSubject$ = new Subject();
        this.change$ = this.changeSubject$.asObservable();
    }
    update(page) {
        this.changeSubject$.next(page);
    }
}
TablePageService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: TablePageService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
TablePageService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: TablePageService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: TablePageService, decorators: [{
            type: Injectable
        }] });

class TableEventService {
    constructor(filterService, sortService, pageService) {
        this.filterService = filterService;
        this.sortService = sortService;
        this.pageService = pageService;
        const filterChange$ = filterService.change$.pipe(map((filterEvent) => this.fromFilterChange(filterEvent)));
        const sortChange$ = sortService.change$.pipe(map((sortEvent) => this.fromSortChange(sortEvent)));
        const pageChange$ = pageService.change$.pipe(map((pageEvent) => this.fromPageChange(pageEvent)));
        this.change$ = merge(filterChange$, sortChange$, pageChange$);
    }
    initPagination(pagination) {
        if (this.currPaginationEvent) {
            this.currPaginationEvent.size = pagination.size;
            if (isOffsetPagination(pagination) && isOffsetEvent(this.currPaginationEvent)) {
                this.currPaginationEvent.page = pagination.page;
            }
        }
        else {
            this.currPaginationEvent = this.createDefaultPaginationEvent(pagination);
        }
    }
    initSort(sort, sortDir) {
        this.currSortEvent = { sort: sort, sortDir: sortDir };
    }
    fromFilterChange(value) {
        this.currFilter = value;
        this.resetPosition();
        return { pagination: this.currPaginationEvent, filter: value, sort: this.currSortEvent };
    }
    fromSortChange(sort) {
        const dir = sort.direction === 'asc' ? 'asc' : 'desc';
        this.currSortEvent.sort = sort.active;
        this.currSortEvent.sortDir = dir;
        if (this.currPaginationEvent) {
            this.currPaginationEvent.sort = sort.active;
            this.currPaginationEvent.sortDir = sort.direction;
            this.resetPosition();
        }
        return { pagination: this.currPaginationEvent, filter: this.currFilter, sort: this.currSortEvent };
    }
    fromPageChange(event) {
        if (this.currPaginationEvent.size !== event.pageSize) {
            this.resetPosition();
        }
        this.currPaginationEvent.size = event.pageSize;
        if (isPageEvent(event) && isOffsetEvent(this.currPaginationEvent)) {
            this.currPaginationEvent.page = event.pageIndex;
        }
        if (isCursorPageEvent(event) && isCursorEvent(this.currPaginationEvent)) {
            this.currPaginationEvent.cursor = event.cursor;
        }
        return { pagination: this.currPaginationEvent, filter: this.currFilter, sort: this.currSortEvent };
    }
    resetPosition() {
        if (this.currPaginationEvent) {
            if (isOffsetEvent(this.currPaginationEvent)) {
                this.currPaginationEvent.page = 0;
            }
            if (isCursorEvent(this.currPaginationEvent)) {
                this.currPaginationEvent.cursor = null;
            }
        }
    }
    createDefaultPaginationEvent(pagination) {
        if (isOffsetPagination(pagination)) {
            return new OffsetPaginationEvent(pagination.page, pagination.size, this.currSortEvent?.sort, this.currSortEvent?.sortDir);
        }
        if (isCursorPagination(pagination)) {
            return new CursorPaginationEvent(null, pagination.size, this.currSortEvent?.sort, this.currSortEvent?.sortDir);
        }
    }
}
TableEventService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: TableEventService, deps: [{ token: TableFilterService }, { token: TableSortService }, { token: TablePageService }], target: i0.ɵɵFactoryTarget.Injectable });
TableEventService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: TableEventService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: TableEventService, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: TableFilterService }, { type: TableSortService }, { type: TablePageService }]; } });

class TableSelectionService {
    constructor() {
        this.rowsCountSubject$ = new BehaviorSubject(0);
        this.changeSubject$ = new Subject();
        this.rowCount$ = this.rowsCountSubject$.asObservable();
        this.change$ = this.changeSubject$.asObservable();
        this.someSelected$ = this.change$.pipe(map((selected) => selected.length > 0));
        this.allSelected$ = merge(this.rowCount$, this.change$).pipe(map(() => this.isAllSelected()));
    }
    toggleSelection(row) {
        this.selection.toggle(row.element);
        this.onSelectionChange();
    }
    /**
     * Emits event when selection is changed
     */
    onSelectionChange() {
        this.changeSubject$.next(this.selection.selected);
    }
    isSelected(row) {
        return this.selection.isSelected(row.element);
    }
    /** True if the number of selected elements matches the total number of rows, false otherwise. */
    isAllSelected() {
        return this.selection.selected.length === this.rowsCountSubject$.getValue();
    }
    /** Selects all rows if they are not all selected; otherwise clears selection. */
    toggleAll(rows) {
        this.isAllSelected() ? this.selection.clear() : rows.forEach((row) => this.selection.select(row.element));
        this.onSelectionChange();
    }
    init(elementsCount, preselected) {
        this.rowsCountSubject$.next(elementsCount);
        this.selection = new SelectionModel(true, []);
        if (preselected && preselected.length > 0) {
            this.selection.select(...preselected);
        }
        this.onSelectionChange();
    }
    onPreselectionChange(preselected) {
        if (!this.selectionAlreadySetup()) {
            this.selection = new SelectionModel(true, preselected);
        }
        else {
            this.selection.select(...preselected);
        }
        this.onSelectionChange();
    }
    selectionAlreadySetup() {
        return this.selection !== null && this.selection !== undefined;
    }
}
TableSelectionService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: TableSelectionService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
TableSelectionService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: TableSelectionService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: TableSelectionService, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return []; } });

class ShowMoreService {
    calculate(pagination, defaultSize) {
        if (isOffsetPagination(pagination)) {
            return this.calculateForOffsetPagination(pagination, defaultSize);
        }
        else if (isCursorPagination(pagination)) {
            return this.calculateForCursorPagination(pagination, defaultSize);
        }
    }
    calculateForOffsetPagination(pagination, defaultSize) {
        if (pagination.page > 0) {
            // should be displayed only on first page because changes in page size resets the page to 0
            return 0;
        }
        const previousPagesElementsCount = pagination.size * pagination.page;
        const alreadyDisplayedCount = previousPagesElementsCount + pagination.numberOfElements;
        const remainingToDisplayCount = pagination.totalElements - alreadyDisplayedCount;
        return Math.min(remainingToDisplayCount, defaultSize);
    }
    calculateForCursorPagination(pagination, defaultSize) {
        // should be displayed only on first page because changes in page size resets the cursor to null
        return pagination.previous === null && pagination.next !== null ? defaultSize : 0;
    }
}

class ActionContainerDirective {
    constructor() {
        this.actionClick = new EventEmitter();
        this.trackByFn = trackById;
    }
    onAction(action) {
        this.actionClick.emit(action);
    }
}
ActionContainerDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: ActionContainerDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive });
ActionContainerDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.12", type: ActionContainerDirective, selector: "[sentinelTableActionContainer]", inputs: { disabled: "disabled", actions: "actions" }, outputs: { actionClick: "actionClick" }, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: ActionContainerDirective, decorators: [{
            type: Directive,
            args: [{ selector: '[sentinelTableActionContainer]' }]
        }], propDecorators: { disabled: [{
                type: Input
            }], actions: [{
                type: Input
            }], actionClick: [{
                type: Output
            }] } });

class ActionMenuComponent extends ActionContainerDirective {
    constructor() {
        super();
    }
}
ActionMenuComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: ActionMenuComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
ActionMenuComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: ActionMenuComponent, selector: "sentinel-action-menu", inputs: { titlecased: "titlecased" }, usesInheritance: true, ngImport: i0, template: "<button\n  mat-icon-button\n  [disabled]=\"disabled\"\n  [matMenuTriggerFor]=\"sentinelTableActionMenu\"\n  aria-label=\"Table actions menu\"\n>\n  <mat-icon>more_vert</mat-icon>\n</button>\n<mat-menu #sentinelTableActionMenu>\n  <ng-container *ngFor=\"let action of actions; trackBy: trackByFn\">\n    <sentinel-loading-overlay [isLoading]=\"action.isLoading$ | async\" [diameter]=\"25\" [strokeWidth]=\"2\">\n      <button\n        mat-menu-item\n        [disabled]=\"disabled || (action?.disabled$ | async) || (action?.isLoading$ | async)\"\n        [matTooltip]=\"action?.tooltip\"\n        (click)=\"onAction(action)\"\n      >\n        <mat-icon>{{ action?.matIcon }}</mat-icon>\n        <sentinel-label [titlecased]=\"titlecased\" [label]=\"action?.label\"></sentinel-label>\n      </button>\n    </sentinel-loading-overlay>\n  </ng-container>\n</mat-menu>\n", styles: [""], dependencies: [{ kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "component", type: i2.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { kind: "component", type: i3.MatMenu, selector: "mat-menu", exportAs: ["matMenu"] }, { kind: "component", type: i3.MatMenuItem, selector: "[mat-menu-item]", inputs: ["disabled", "disableRipple", "role"], exportAs: ["matMenuItem"] }, { kind: "directive", type: i3.MatMenuTrigger, selector: "[mat-menu-trigger-for], [matMenuTriggerFor]", exportAs: ["matMenuTrigger"] }, { kind: "component", type: i3$1.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { kind: "directive", type: i4.MatTooltip, selector: "[matTooltip]", exportAs: ["matTooltip"] }, { kind: "component", type: i6.SentinelLoadingOverlayComponent, selector: "sentinel-loading-overlay", inputs: ["isLoading", "color", "strokeWidth", "diameter"] }, { kind: "component", type: i7.LabelComponent, selector: "sentinel-label", inputs: ["titlecased", "label"] }, { kind: "pipe", type: i1.AsyncPipe, name: "async" }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: ActionMenuComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sentinel-action-menu', changeDetection: ChangeDetectionStrategy.OnPush, template: "<button\n  mat-icon-button\n  [disabled]=\"disabled\"\n  [matMenuTriggerFor]=\"sentinelTableActionMenu\"\n  aria-label=\"Table actions menu\"\n>\n  <mat-icon>more_vert</mat-icon>\n</button>\n<mat-menu #sentinelTableActionMenu>\n  <ng-container *ngFor=\"let action of actions; trackBy: trackByFn\">\n    <sentinel-loading-overlay [isLoading]=\"action.isLoading$ | async\" [diameter]=\"25\" [strokeWidth]=\"2\">\n      <button\n        mat-menu-item\n        [disabled]=\"disabled || (action?.disabled$ | async) || (action?.isLoading$ | async)\"\n        [matTooltip]=\"action?.tooltip\"\n        (click)=\"onAction(action)\"\n      >\n        <mat-icon>{{ action?.matIcon }}</mat-icon>\n        <sentinel-label [titlecased]=\"titlecased\" [label]=\"action?.label\"></sentinel-label>\n      </button>\n    </sentinel-loading-overlay>\n  </ng-container>\n</mat-menu>\n" }]
        }], ctorParameters: function () { return []; }, propDecorators: { titlecased: [{
                type: Input
            }] } });

class ActionButtonComponent {
    constructor() {
        this.actionClicked = new EventEmitter();
    }
    onAction(action) {
        this.actionClicked.emit(action);
    }
}
ActionButtonComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: ActionButtonComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
ActionButtonComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: ActionButtonComponent, selector: "sentinel-action-button", inputs: { mode: "mode", action: "action", disabled: "disabled" }, outputs: { actionClicked: "actionClicked" }, ngImport: i0, template: "<sentinel-loading-overlay [isLoading]=\"action.isLoading$ | async\" [diameter]=\"25\" [strokeWidth]=\"2\">\n  <ng-container [ngSwitch]=\"mode\">\n    <ng-container *ngSwitchCase=\"'icon'\">\n      <ng-container *ngTemplateOutlet=\"iconButtonAction; context: { action: action }\"></ng-container>\n    </ng-container>\n\n    <ng-container *ngSwitchCase=\"'button'\">\n      <ng-container *ngTemplateOutlet=\"simpleButtonAction; context: { action: action }\"></ng-container>\n    </ng-container>\n  </ng-container>\n</sentinel-loading-overlay>\n\n<ng-template #simpleButtonAction let-action=\"action\">\n  <button\n    mat-raised-button\n    [disabled]=\"disabled\"\n    [matTooltip]=\"action?.tooltip\"\n    [color]=\"action?.matColor\"\n    (click)=\"onAction(action)\"\n    attr.data-cy=\"{{ action.id }}\"\n  >\n    {{ action?.label }}\n  </button>\n</ng-template>\n\n<ng-template #iconButtonAction let-action=\"action\">\n  <button\n    mat-icon-button\n    [disabled]=\"disabled\"\n    [matTooltip]=\"action?.tooltip\"\n    [color]=\"action?.matColor\"\n    (click)=\"onAction(action)\"\n    attr.data-cy=\"{{ action.id }}\"\n  >\n    <mat-icon>{{ action?.matIcon }}</mat-icon>\n  </button>\n</ng-template>\n", styles: [""], dependencies: [{ kind: "directive", type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: i1.NgSwitch, selector: "[ngSwitch]", inputs: ["ngSwitch"] }, { kind: "directive", type: i1.NgSwitchCase, selector: "[ngSwitchCase]", inputs: ["ngSwitchCase"] }, { kind: "component", type: i2.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { kind: "component", type: i3$1.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { kind: "directive", type: i4.MatTooltip, selector: "[matTooltip]", exportAs: ["matTooltip"] }, { kind: "component", type: i6.SentinelLoadingOverlayComponent, selector: "sentinel-loading-overlay", inputs: ["isLoading", "color", "strokeWidth", "diameter"] }, { kind: "pipe", type: i1.AsyncPipe, name: "async" }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: ActionButtonComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sentinel-action-button', changeDetection: ChangeDetectionStrategy.OnPush, template: "<sentinel-loading-overlay [isLoading]=\"action.isLoading$ | async\" [diameter]=\"25\" [strokeWidth]=\"2\">\n  <ng-container [ngSwitch]=\"mode\">\n    <ng-container *ngSwitchCase=\"'icon'\">\n      <ng-container *ngTemplateOutlet=\"iconButtonAction; context: { action: action }\"></ng-container>\n    </ng-container>\n\n    <ng-container *ngSwitchCase=\"'button'\">\n      <ng-container *ngTemplateOutlet=\"simpleButtonAction; context: { action: action }\"></ng-container>\n    </ng-container>\n  </ng-container>\n</sentinel-loading-overlay>\n\n<ng-template #simpleButtonAction let-action=\"action\">\n  <button\n    mat-raised-button\n    [disabled]=\"disabled\"\n    [matTooltip]=\"action?.tooltip\"\n    [color]=\"action?.matColor\"\n    (click)=\"onAction(action)\"\n    attr.data-cy=\"{{ action.id }}\"\n  >\n    {{ action?.label }}\n  </button>\n</ng-template>\n\n<ng-template #iconButtonAction let-action=\"action\">\n  <button\n    mat-icon-button\n    [disabled]=\"disabled\"\n    [matTooltip]=\"action?.tooltip\"\n    [color]=\"action?.matColor\"\n    (click)=\"onAction(action)\"\n    attr.data-cy=\"{{ action.id }}\"\n  >\n    <mat-icon>{{ action?.matIcon }}</mat-icon>\n  </button>\n</ng-template>\n" }]
        }], propDecorators: { mode: [{
                type: Input
            }], action: [{
                type: Input
            }], disabled: [{
                type: Input
            }], actionClicked: [{
                type: Output
            }] } });

class ActionButtonContainerComponent extends ActionContainerDirective {
    constructor() {
        super();
    }
}
ActionButtonContainerComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: ActionButtonContainerComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
ActionButtonContainerComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: ActionButtonContainerComponent, selector: "sentinel-action-button-container", inputs: { mode: "mode" }, usesInheritance: true, ngImport: i0, template: "<sentinel-action-button\n  *ngFor=\"let action of actions; trackBy: trackByFn\"\n  [mode]=\"mode\"\n  [action]=\"action\"\n  [disabled]=\"disabled || (action?.disabled$ | async)\"\n  (actionClicked)=\"onAction($event)\"\n>\n</sentinel-action-button>\n", styles: [":host{display:flex}\n"], dependencies: [{ kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "component", type: ActionButtonComponent, selector: "sentinel-action-button", inputs: ["mode", "action", "disabled"], outputs: ["actionClicked"] }, { kind: "pipe", type: i1.AsyncPipe, name: "async" }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: ActionButtonContainerComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sentinel-action-button-container', changeDetection: ChangeDetectionStrategy.OnPush, template: "<sentinel-action-button\n  *ngFor=\"let action of actions; trackBy: trackByFn\"\n  [mode]=\"mode\"\n  [action]=\"action\"\n  [disabled]=\"disabled || (action?.disabled$ | async)\"\n  (actionClicked)=\"onAction($event)\"\n>\n</sentinel-action-button>\n", styles: [":host{display:flex}\n"] }]
        }], ctorParameters: function () { return []; }, propDecorators: { mode: [{
                type: Input
            }] } });

class TableActionsComponent extends ActionContainerDirective {
    constructor() {
        super(...arguments);
        this.displayedActionsCount = 2;
    }
}
TableActionsComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: TableActionsComponent, deps: null, target: i0.ɵɵFactoryTarget.Component });
TableActionsComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: TableActionsComponent, selector: "sentinel-table-actions", inputs: { actionMode: "actionMode", titlecased: "titlecased", displayedActionsCount: "displayedActionsCount" }, usesInheritance: true, ngImport: i0, template: "<sentinel-action-button-container\n  [mode]=\"actionMode\"\n  [disabled]=\"disabled\"\n  [actions]=\"actions | slice: 0: displayedActionsCount\"\n  (actionClick)=\"onAction($event)\"\n>\n</sentinel-action-button-container>\n<div *ngIf=\"actions?.length > displayedActionsCount\">\n  <sentinel-action-menu\n    [titlecased]=\"titlecased\"\n    [disabled]=\"disabled\"\n    [actions]=\"actions | slice: displayedActionsCount\"\n    (actionClick)=\"onAction($event)\"\n  >\n  </sentinel-action-menu>\n</div>\n", styles: [":host{display:flex}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: ActionMenuComponent, selector: "sentinel-action-menu", inputs: ["titlecased"] }, { kind: "component", type: ActionButtonContainerComponent, selector: "sentinel-action-button-container", inputs: ["mode"] }, { kind: "pipe", type: i1.SlicePipe, name: "slice" }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: TableActionsComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sentinel-table-actions', changeDetection: ChangeDetectionStrategy.OnPush, template: "<sentinel-action-button-container\n  [mode]=\"actionMode\"\n  [disabled]=\"disabled\"\n  [actions]=\"actions | slice: 0: displayedActionsCount\"\n  (actionClick)=\"onAction($event)\"\n>\n</sentinel-action-button-container>\n<div *ngIf=\"actions?.length > displayedActionsCount\">\n  <sentinel-action-menu\n    [titlecased]=\"titlecased\"\n    [disabled]=\"disabled\"\n    [actions]=\"actions | slice: displayedActionsCount\"\n    (actionClick)=\"onAction($event)\"\n  >\n  </sentinel-action-menu>\n</div>\n", styles: [":host{display:flex}\n"] }]
        }], propDecorators: { actionMode: [{
                type: Input
            }], titlecased: [{
                type: Input
            }], displayedActionsCount: [{
                type: Input
            }] } });

class TableDataCellLinkComponent {
}
TableDataCellLinkComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: TableDataCellLinkComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
TableDataCellLinkComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: TableDataCellLinkComponent, selector: "sentinel-table-data-cell-link", inputs: { link: "link", disabled: "disabled", label: "label" }, ngImport: i0, template: "<ng-container\n  *ngTemplateOutlet=\"link?.isExternal ? externalLinkCell : internalLinkCell; context: { link: link }\"\n></ng-container>\n\n<ng-template #externalLinkCell let-link=\"link\">\n  <a mat-button color=\"primary\" class=\"link-button\" [disabled]=\"disabled\" [href]=\"link?.url\" [target]=\"link?.target\">\n    {{ label }}\n  </a>\n</ng-template>\n<ng-template #internalLinkCell let-link=\"link\">\n  <a mat-button color=\"primary\" class=\"link-button\" [disabled]=\"disabled\" [routerLink]=\"['/' + link?.url]\">\n    {{ label }}\n  </a>\n</ng-template>\n", styles: ["a.link-button{text-align:left;padding:0;min-width:0}\n"], dependencies: [{ kind: "directive", type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: i2$1.RouterLinkWithHref, selector: "a[routerLink],area[routerLink]", inputs: ["target", "queryParams", "fragment", "queryParamsHandling", "state", "relativeTo", "preserveFragment", "skipLocationChange", "replaceUrl", "routerLink"] }, { kind: "component", type: i2.MatAnchor, selector: "a[mat-button], a[mat-raised-button], a[mat-icon-button], a[mat-fab],             a[mat-mini-fab], a[mat-stroked-button], a[mat-flat-button]", inputs: ["disabled", "disableRipple", "color", "tabIndex"], exportAs: ["matButton", "matAnchor"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: TableDataCellLinkComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sentinel-table-data-cell-link', changeDetection: ChangeDetectionStrategy.OnPush, template: "<ng-container\n  *ngTemplateOutlet=\"link?.isExternal ? externalLinkCell : internalLinkCell; context: { link: link }\"\n></ng-container>\n\n<ng-template #externalLinkCell let-link=\"link\">\n  <a mat-button color=\"primary\" class=\"link-button\" [disabled]=\"disabled\" [href]=\"link?.url\" [target]=\"link?.target\">\n    {{ label }}\n  </a>\n</ng-template>\n<ng-template #internalLinkCell let-link=\"link\">\n  <a mat-button color=\"primary\" class=\"link-button\" [disabled]=\"disabled\" [routerLink]=\"['/' + link?.url]\">\n    {{ label }}\n  </a>\n</ng-template>\n", styles: ["a.link-button{text-align:left;padding:0;min-width:0}\n"] }]
        }], propDecorators: { link: [{
                type: Input
            }], disabled: [{
                type: Input
            }], label: [{
                type: Input
            }] } });

class TableDataCellContentComponent {
    ngOnChanges(changes) {
        if (this.content && 'content' in changes) {
            this.isObservable = this.content instanceof Observable;
        }
    }
}
TableDataCellContentComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: TableDataCellContentComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
TableDataCellContentComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: TableDataCellContentComponent, selector: "sentinel-table-data-cell-content", inputs: { content: "content" }, usesOnChanges: true, ngImport: i0, template: "<!-- CELL CONTAINS SYNCHRONOUS DATA -->\n<div *ngIf=\"!isObservable; else asyncCellContent\">\n  <span>{{ content }}</span>\n</div>\n\n<!-- CELL CONTAINS ASYNCHRONOUS DATA -->\n<ng-template #asyncCellContent>\n  <span *ngIf=\"content | async as asyncData; else loading\">{{ asyncData }}</span>\n</ng-template>\n\n<!-- CELL CONTAINS ASYNCHRONOUS DATA WHICH ARE NOT YET LOADED -->\n<ng-template #loading>\n  <mat-progress-spinner mode=\"indeterminate\" color=\"accent\" diameter=\"20\"></mat-progress-spinner>\n</ng-template>\n", styles: [""], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i2$2.MatProgressSpinner, selector: "mat-progress-spinner, mat-spinner", inputs: ["color", "diameter", "strokeWidth", "mode", "value"], exportAs: ["matProgressSpinner"] }, { kind: "pipe", type: i1.AsyncPipe, name: "async" }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: TableDataCellContentComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sentinel-table-data-cell-content', template: "<!-- CELL CONTAINS SYNCHRONOUS DATA -->\n<div *ngIf=\"!isObservable; else asyncCellContent\">\n  <span>{{ content }}</span>\n</div>\n\n<!-- CELL CONTAINS ASYNCHRONOUS DATA -->\n<ng-template #asyncCellContent>\n  <span *ngIf=\"content | async as asyncData; else loading\">{{ asyncData }}</span>\n</ng-template>\n\n<!-- CELL CONTAINS ASYNCHRONOUS DATA WHICH ARE NOT YET LOADED -->\n<ng-template #loading>\n  <mat-progress-spinner mode=\"indeterminate\" color=\"accent\" diameter=\"20\"></mat-progress-spinner>\n</ng-template>\n" }]
        }], propDecorators: { content: [{
                type: Input
            }] } });

class TableDataCellComponent {
    ngOnChanges(changes) {
        if (this.row && 'row' in changes) {
            this.content = this.row?.element[this.column?.id];
            this.link = this.row.getLink(this.column.id);
            this.hasLink = this.link !== undefined;
        }
    }
}
TableDataCellComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: TableDataCellComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
TableDataCellComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: TableDataCellComponent, selector: "sentinel-table-data-cell", inputs: { row: "row", column: "column", disabled: "disabled" }, usesOnChanges: true, ngImport: i0, template: "<ng-container *ngIf=\"hasLink; else noLink\">\n  <sentinel-table-data-cell-link [link]=\"link\" [disabled]=\"disabled\" [label]=\"content\"> </sentinel-table-data-cell-link>\n</ng-container>\n\n<ng-template #noLink>\n  <sentinel-table-data-cell-content [content]=\"content\"> </sentinel-table-data-cell-content>\n</ng-template>\n", styles: [""], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: TableDataCellLinkComponent, selector: "sentinel-table-data-cell-link", inputs: ["link", "disabled", "label"] }, { kind: "component", type: TableDataCellContentComponent, selector: "sentinel-table-data-cell-content", inputs: ["content"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: TableDataCellComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sentinel-table-data-cell', changeDetection: ChangeDetectionStrategy.OnPush, template: "<ng-container *ngIf=\"hasLink; else noLink\">\n  <sentinel-table-data-cell-link [link]=\"link\" [disabled]=\"disabled\" [label]=\"content\"> </sentinel-table-data-cell-link>\n</ng-container>\n\n<ng-template #noLink>\n  <sentinel-table-data-cell-content [content]=\"content\"> </sentinel-table-data-cell-content>\n</ng-template>\n" }]
        }], propDecorators: { row: [{
                type: Input
            }], column: [{
                type: Input
            }], disabled: [{
                type: Input
            }] } });

class TableFilterComponent extends SentinelBaseDirective {
    constructor() {
        super();
        this.valueChange = new EventEmitter();
        this.filterControl = new FormControl(undefined);
    }
    ngOnInit() {
        this.filterControl.valueChanges
            .pipe(takeWhile(() => this.isAlive), debounceTime(300))
            .subscribe((value) => this.valueChange.emit(value));
    }
    ngOnChanges(changes) {
        if ('disabled' in changes) {
            if (this.disabled) {
                this.filterControl.disable({ emitEvent: false });
            }
            else {
                this.filterControl.enable({ emitEvent: false });
            }
        }
    }
}
TableFilterComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: TableFilterComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
TableFilterComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: TableFilterComponent, selector: "sentinel-table-filter", inputs: { label: "label", disabled: "disabled" }, outputs: { valueChange: "valueChange" }, usesInheritance: true, usesOnChanges: true, ngImport: i0, template: "<mat-form-field>\n  <input matInput [formControl]=\"filterControl\" [placeholder]=\"label\" />\n</mat-form-field>\n", styles: ["mat-form-field{font-size:14px;width:100%}\n"], dependencies: [{ kind: "directive", type: i1$1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1$1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1$1.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }, { kind: "component", type: i2$3.MatFormField, selector: "mat-form-field", inputs: ["color", "appearance", "hideRequiredMarker", "hintLabel", "floatLabel"], exportAs: ["matFormField"] }, { kind: "directive", type: i3$2.MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["disabled", "id", "placeholder", "name", "required", "type", "errorStateMatcher", "aria-describedby", "value", "readonly"], exportAs: ["matInput"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: TableFilterComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sentinel-table-filter', changeDetection: ChangeDetectionStrategy.OnPush, template: "<mat-form-field>\n  <input matInput [formControl]=\"filterControl\" [placeholder]=\"label\" />\n</mat-form-field>\n", styles: ["mat-form-field{font-size:14px;width:100%}\n"] }]
        }], ctorParameters: function () { return []; }, propDecorators: { label: [{
                type: Input
            }], disabled: [{
                type: Input
            }], valueChange: [{
                type: Output
            }] } });

/**
 * Directive enabling dynamic rendering of a component in expanded row detail of the table
 */
class ExpandedRowHostDirective {
    constructor(viewContainerRef) {
        this.viewContainerRef = viewContainerRef;
    }
}
ExpandedRowHostDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: ExpandedRowHostDirective, deps: [{ token: i0.ViewContainerRef }], target: i0.ɵɵFactoryTarget.Directive });
ExpandedRowHostDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.12", type: ExpandedRowHostDirective, selector: "[sentinelExpandedRowHost]", ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: ExpandedRowHostDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[sentinelExpandedRowHost]',
                }]
        }], ctorParameters: function () { return [{ type: i0.ViewContainerRef }]; } });

class TableExpandedRowDetailComponent {
    constructor(componentFactoryResolver) {
        this.componentFactoryResolver = componentFactoryResolver;
    }
    ngOnChanges(changes) {
        if (this.state && 'state' in changes) {
            if (this.state === 'expanded') {
                this.createExpandedRowComponent();
            }
            else {
                this.destroyExpandedRowComponent();
            }
        }
    }
    destroyExpandedRowComponent() {
        this.expandedRowHost?.viewContainerRef?.clear();
    }
    createExpandedRowComponent() {
        const componentFactory = this.componentFactoryResolver.resolveComponentFactory(this.expandConfig.component);
        const vcr = this.expandedRowHost.viewContainerRef;
        vcr.clear();
        const componentRef = vcr.createComponent(componentFactory);
        componentRef.instance.config = this.expandConfig.config;
        componentRef.instance.data = this.expandElement;
    }
}
TableExpandedRowDetailComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: TableExpandedRowDetailComponent, deps: [{ token: i0.ComponentFactoryResolver }], target: i0.ɵɵFactoryTarget.Component });
TableExpandedRowDetailComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: TableExpandedRowDetailComponent, selector: "sentinel-table-expanded-row-detail", inputs: { state: "state", expandConfig: "expandConfig", expandElement: "expandElement" }, viewQueries: [{ propertyName: "expandedRowHost", first: true, predicate: ExpandedRowHostDirective, descendants: true }], usesOnChanges: true, ngImport: i0, template: "<div class=\"element-detail\" [@detailExpand]=\"state\">\n  <ng-template sentinelExpandedRowHost></ng-template>\n</div>\n", styles: [".element-detail{overflow:hidden;display:flex}\n"], dependencies: [{ kind: "directive", type: ExpandedRowHostDirective, selector: "[sentinelExpandedRowHost]" }], animations: [
        trigger('detailExpand', [
            state('collapsed', style({ height: '0px', minHeight: '0' })),
            state('expanded', style({ height: '*' })),
            transition('expanded <=> collapsed', animate('225ms cubic-bezier(0.4, 0.0, 0.2, 1)')),
        ]),
    ] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: TableExpandedRowDetailComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sentinel-table-expanded-row-detail', animations: [
                        trigger('detailExpand', [
                            state('collapsed', style({ height: '0px', minHeight: '0' })),
                            state('expanded', style({ height: '*' })),
                            transition('expanded <=> collapsed', animate('225ms cubic-bezier(0.4, 0.0, 0.2, 1)')),
                        ]),
                    ], template: "<div class=\"element-detail\" [@detailExpand]=\"state\">\n  <ng-template sentinelExpandedRowHost></ng-template>\n</div>\n", styles: [".element-detail{overflow:hidden;display:flex}\n"] }]
        }], ctorParameters: function () { return [{ type: i0.ComponentFactoryResolver }]; }, propDecorators: { state: [{
                type: Input
            }], expandConfig: [{
                type: Input
            }], expandElement: [{
                type: Input
            }], expandedRowHost: [{
                type: ViewChild,
                args: [ExpandedRowHostDirective]
            }] } });

class CursorPageEvent {
    constructor(cursor, pageSize) {
        this.cursor = cursor;
        this.pageSize = pageSize;
    }
}

class TableShowMoreComponent {
    constructor() {
        this.showMore = new EventEmitter();
    }
    onShowMore() {
        this.showMore.emit();
    }
}
TableShowMoreComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: TableShowMoreComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
TableShowMoreComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: TableShowMoreComponent, selector: "sentinel-table-show-more", inputs: { count: "count" }, outputs: { showMore: "showMore" }, ngImport: i0, template: "<div class=\"show-more\">\n  <button mat-button color=\"primary\" (click)=\"onShowMore()\">Show {{ count }} more...</button>\n</div>\n", styles: [""], dependencies: [{ kind: "component", type: i2.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: TableShowMoreComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sentinel-table-show-more', changeDetection: ChangeDetectionStrategy.OnPush, template: "<div class=\"show-more\">\n  <button mat-button color=\"primary\" (click)=\"onShowMore()\">Show {{ count }} more...</button>\n</div>\n" }]
        }], propDecorators: { count: [{
                type: Input
            }], showMore: [{
                type: Output
            }] } });

class CursorPaginatorComponent {
    constructor() {
        this.pageSizeOptions = [];
        this.cursorChange = new EventEmitter();
        this.pageSizeChange = new EventEmitter();
        this.hasNext = false;
        this.hasPrev = false;
    }
    ngOnChanges(changes) {
        if ('prev' in changes) {
            this.hasPrev = this.prev !== undefined && this.prev !== null;
        }
        if ('next' in changes) {
            this.hasNext = this.next !== undefined && this.next !== null;
        }
    }
    onCursorChange(cursor) {
        this.cursorChange.emit(cursor);
    }
    onPageSizeChange(pageSize) {
        this.pageSizeChange.emit(pageSize);
    }
}
CursorPaginatorComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: CursorPaginatorComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
CursorPaginatorComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: CursorPaginatorComponent, selector: "sentinel-cursor-paginator", inputs: { prev: "prev", next: "next", disabled: "disabled", pageSize: "pageSize", length: "length", pageSizeOptions: "pageSizeOptions" }, outputs: { cursorChange: "cursorChange", pageSizeChange: "pageSizeChange" }, usesOnChanges: true, ngImport: i0, template: "<div class=\"cursor-paginator-container\">\n  <div class=\"cursor-paginator\">\n    <div class=\"paginator-size-container\">\n      <span class=\"paginator-size-label\">Items per page:</span>\n      <mat-form-field class=\"paginator-size-select\" appearance=\"legacy\">\n        <mat-select [value]=\"pageSize\" (selectionChange)=\"onPageSizeChange($event.value)\">\n          <mat-option *ngFor=\"let pageSizeOption of pageSizeOptions\"\n                      [disabled]=\"disabled\"\n                      [value]=\"pageSizeOption\">{{ pageSizeOption }}\n          </mat-option>\n        </mat-select>\n      </mat-form-field>\n    </div>\n    <div class=\"paginator-total-container\">\n      <span class=\"\">Total: {{ length }}</span>\n    </div>\n    <div class=\"paginator-cursor-container\">\n      <button mat-icon-button\n              matTooltip=\"Previous page\"\n              [disabled]=\"disabled || !hasPrev\"\n              (click)=\"onCursorChange(prev)\">\n        <mat-icon>chevron_left</mat-icon>\n      </button>\n      <button mat-icon-button\n              matTooltip=\"Next page\"\n              [disabled]=\"disabled || !hasNext\"\n              (click)=\"onCursorChange(next)\">\n        <mat-icon>chevron_right</mat-icon>\n      </button>\n    </div>\n  </div>\n\n</div>\n", styles: [".cursor-paginator-container{display:flex}.cursor-paginator{display:flex;width:100%;justify-content:flex-end;align-items:baseline;padding:0 8px}.paginator-size-label{margin:0 4px}.paginator-size-select{margin:6px 4px 0;width:56px}.paginator-total-container{margin:0 32px 0 24px}\n"], dependencies: [{ kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "component", type: i2.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { kind: "component", type: i3$1.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { kind: "directive", type: i4.MatTooltip, selector: "[matTooltip]", exportAs: ["matTooltip"] }, { kind: "component", type: i2$3.MatFormField, selector: "mat-form-field", inputs: ["color", "appearance", "hideRequiredMarker", "hintLabel", "floatLabel"], exportAs: ["matFormField"] }, { kind: "component", type: i6$1.MatSelect, selector: "mat-select", inputs: ["disabled", "disableRipple", "tabIndex"], exportAs: ["matSelect"] }, { kind: "component", type: i7$1.MatOption, selector: "mat-option", exportAs: ["matOption"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: CursorPaginatorComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sentinel-cursor-paginator', changeDetection: ChangeDetectionStrategy.OnPush, template: "<div class=\"cursor-paginator-container\">\n  <div class=\"cursor-paginator\">\n    <div class=\"paginator-size-container\">\n      <span class=\"paginator-size-label\">Items per page:</span>\n      <mat-form-field class=\"paginator-size-select\" appearance=\"legacy\">\n        <mat-select [value]=\"pageSize\" (selectionChange)=\"onPageSizeChange($event.value)\">\n          <mat-option *ngFor=\"let pageSizeOption of pageSizeOptions\"\n                      [disabled]=\"disabled\"\n                      [value]=\"pageSizeOption\">{{ pageSizeOption }}\n          </mat-option>\n        </mat-select>\n      </mat-form-field>\n    </div>\n    <div class=\"paginator-total-container\">\n      <span class=\"\">Total: {{ length }}</span>\n    </div>\n    <div class=\"paginator-cursor-container\">\n      <button mat-icon-button\n              matTooltip=\"Previous page\"\n              [disabled]=\"disabled || !hasPrev\"\n              (click)=\"onCursorChange(prev)\">\n        <mat-icon>chevron_left</mat-icon>\n      </button>\n      <button mat-icon-button\n              matTooltip=\"Next page\"\n              [disabled]=\"disabled || !hasNext\"\n              (click)=\"onCursorChange(next)\">\n        <mat-icon>chevron_right</mat-icon>\n      </button>\n    </div>\n  </div>\n\n</div>\n", styles: [".cursor-paginator-container{display:flex}.cursor-paginator{display:flex;width:100%;justify-content:flex-end;align-items:baseline;padding:0 8px}.paginator-size-label{margin:0 4px}.paginator-size-select{margin:6px 4px 0;width:56px}.paginator-total-container{margin:0 32px 0 24px}\n"] }]
        }], propDecorators: { prev: [{
                type: Input
            }], next: [{
                type: Input
            }], disabled: [{
                type: Input
            }], pageSize: [{
                type: Input
            }], length: [{
                type: Input
            }], pageSizeOptions: [{
                type: Input
            }], cursorChange: [{
                type: Output
            }], pageSizeChange: [{
                type: Output
            }] } });

class CursorPaginationComponent {
    constructor() {
        this.DEFAULT_PAGE_SIZE_OPTIONS = [5, 10, 25, 100];
        this.paginationChange = new EventEmitter();
        this.pageSizeOptions = this.DEFAULT_PAGE_SIZE_OPTIONS;
    }
    ngOnChanges(changes) {
        if ('pagination' in changes && this.pagination) {
            this.updatePageSizeOptions(this.pagination.size);
        }
    }
    onCursorChange(cursor) {
        this.paginationChange.emit(new CursorPageEvent(cursor, this.pagination?.size));
    }
    onPageSizeChange(pageSize) {
        this.paginationChange.emit(new CursorPageEvent(this.pagination?.curr, pageSize));
    }
    updatePageSizeOptions(selectedSize) {
        if (this.DEFAULT_PAGE_SIZE_OPTIONS.includes(selectedSize)) {
            // selected size matches standard options
            this.pageSizeOptions = this.DEFAULT_PAGE_SIZE_OPTIONS;
        }
        else if (!this.pageSizeOptions.includes(selectedSize)) {
            // new option needs to be added
            this.pageSizeOptions = [...this.DEFAULT_PAGE_SIZE_OPTIONS, this.pagination.size].sort((a, b) => a - b);
        }
    }
}
CursorPaginationComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: CursorPaginationComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
CursorPaginationComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: CursorPaginationComponent, selector: "sentinel-cursor-pagination", inputs: { pagination: "pagination", disabled: "disabled" }, outputs: { paginationChange: "paginationChange" }, usesOnChanges: true, ngImport: i0, template: "<sentinel-cursor-paginator [disabled]=\"disabled\"\n                           [pageSize]=\"pagination?.size\"\n                           [prev]=\"pagination?.previous\"\n                           [next]=\"pagination?.next\"\n                           [length]=\"pagination?.totalElements\"\n                           [pageSizeOptions]=\"pageSizeOptions\"\n                           (cursorChange)=\"onCursorChange($event)\"\n                           (pageSizeChange)=\"onPageSizeChange($event)\"\n></sentinel-cursor-paginator>\n", styles: [""], dependencies: [{ kind: "component", type: CursorPaginatorComponent, selector: "sentinel-cursor-paginator", inputs: ["prev", "next", "disabled", "pageSize", "length", "pageSizeOptions"], outputs: ["cursorChange", "pageSizeChange"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: CursorPaginationComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sentinel-cursor-pagination', changeDetection: ChangeDetectionStrategy.OnPush, template: "<sentinel-cursor-paginator [disabled]=\"disabled\"\n                           [pageSize]=\"pagination?.size\"\n                           [prev]=\"pagination?.previous\"\n                           [next]=\"pagination?.next\"\n                           [length]=\"pagination?.totalElements\"\n                           [pageSizeOptions]=\"pageSizeOptions\"\n                           (cursorChange)=\"onCursorChange($event)\"\n                           (pageSizeChange)=\"onPageSizeChange($event)\"\n></sentinel-cursor-paginator>\n" }]
        }], propDecorators: { pagination: [{
                type: Input
            }], disabled: [{
                type: Input
            }], paginationChange: [{
                type: Output
            }] } });

class OffsetPaginationComponent {
    constructor() {
        this.paginationChange = new EventEmitter();
    }
    onPageEvent(event) {
        this.paginationChange.emit(event);
    }
}
OffsetPaginationComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: OffsetPaginationComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
OffsetPaginationComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: OffsetPaginationComponent, selector: "sentinel-offset-pagination", inputs: { pagination: "pagination", disabled: "disabled" }, outputs: { paginationChange: "paginationChange" }, ngImport: i0, template: "<mat-paginator\n  showFirstLastButtons\n  data-cy=\"paginator\"\n  [disabled]=\"disabled\"\n  [pageSize]=\"pagination.size\"\n  [pageIndex]=\"pagination.page\"\n  [length]=\"pagination?.totalElements\"\n  [pageSizeOptions]=\"[5, 10, 25, 100]\"\n  (page)=\"onPageEvent($event)\"\n>\n</mat-paginator>\n", styles: [""], dependencies: [{ kind: "component", type: i1$2.MatPaginator, selector: "mat-paginator", inputs: ["disabled"], exportAs: ["matPaginator"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: OffsetPaginationComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sentinel-offset-pagination', changeDetection: ChangeDetectionStrategy.OnPush, template: "<mat-paginator\n  showFirstLastButtons\n  data-cy=\"paginator\"\n  [disabled]=\"disabled\"\n  [pageSize]=\"pagination.size\"\n  [pageIndex]=\"pagination.page\"\n  [length]=\"pagination?.totalElements\"\n  [pageSizeOptions]=\"[5, 10, 25, 100]\"\n  (page)=\"onPageEvent($event)\"\n>\n</mat-paginator>\n" }]
        }], propDecorators: { pagination: [{
                type: Input
            }], disabled: [{
                type: Input
            }], paginationChange: [{
                type: Output
            }] } });

class NarrowToOffsetPaginationPipe {
    transform(pagination) {
        if (isOffsetPagination(pagination)) {
            return pagination;
        }
        else {
            throw TypeError('Provided pagination does not implement IOffsetPagination interface');
        }
    }
}
NarrowToOffsetPaginationPipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: NarrowToOffsetPaginationPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
NarrowToOffsetPaginationPipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: NarrowToOffsetPaginationPipe, name: "narrowToOffsetPagination" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: NarrowToOffsetPaginationPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'narrowToOffsetPagination',
                }]
        }] });

class NarrowToCursorPaginationPipe {
    transform(pagination) {
        if (isCursorPagination(pagination)) {
            return pagination;
        }
        else {
            throw TypeError('Provided pagination does not implement ICursorPagination interface');
        }
    }
}
NarrowToCursorPaginationPipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: NarrowToCursorPaginationPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
NarrowToCursorPaginationPipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: NarrowToCursorPaginationPipe, name: "narrowToCursorPagination" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: NarrowToCursorPaginationPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'narrowToCursorPagination',
                }]
        }] });

class TablePaginationComponent {
    constructor() {
        this.paginationChange = new EventEmitter();
    }
    ngOnChanges(changes) {
        if ('pagination' in changes && this.pagination) {
            this.isCursorBased = isCursorPagination(this.pagination);
        }
    }
    onShowMore() {
        const newPageSize = this.pagination.size + this.showMoreCount;
        if (isOffsetPagination(this.pagination)) {
            this.onShowMoreOffsetPagination(this.pagination, newPageSize);
        }
        else if (isCursorPagination(this.pagination)) {
            this.onShowMoreCursorPagination(this.pagination, newPageSize);
        }
    }
    onPaginationChange(event) {
        this.paginationChange.emit(event);
    }
    onShowMoreOffsetPagination(pagination, newPageSize) {
        this.onPaginationChange(this.createPageEvent(pagination, newPageSize));
    }
    onShowMoreCursorPagination(pagination, newPageSize) {
        this.onPaginationChange(new CursorPageEvent(pagination.curr, newPageSize));
    }
    createPageEvent(pagination, newPageSize) {
        const prevPage = Math.max(0, pagination.page - 1);
        const pageEvent = new PageEvent();
        pageEvent.pageIndex = pagination.page;
        pageEvent.previousPageIndex = prevPage;
        pageEvent.length = pagination.totalElements;
        pageEvent.pageSize = newPageSize;
        return pageEvent;
    }
}
TablePaginationComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: TablePaginationComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
TablePaginationComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: TablePaginationComponent, selector: "sentinel-table-pagination", inputs: { pagination: "pagination", showMoreCount: "showMoreCount", disabled: "disabled" }, outputs: { paginationChange: "paginationChange" }, usesOnChanges: true, ngImport: i0, template: "<sentinel-table-show-more\n  *ngIf=\"!disabled && pagination && showMoreCount > 0\"\n  [count]=\"showMoreCount\"\n  (showMore)=\"onShowMore()\"\n>\n</sentinel-table-show-more>\n<ng-container [ngTemplateOutlet]=\"isCursorBased ? cursorBasedPagination : offsetBasedPagination\"></ng-container>\n<ng-template #cursorBasedPagination>\n  <sentinel-cursor-pagination\n    [pagination]=\"pagination | narrowToCursorPagination\"\n    [disabled]=\"disabled\"\n    (paginationChange)=\"onPaginationChange($event)\">\n  </sentinel-cursor-pagination>\n</ng-template>\n\n<ng-template #offsetBasedPagination>\n  <sentinel-offset-pagination\n    [pagination]=\"pagination | narrowToOffsetPagination\"\n    [disabled]=\"disabled\"\n    (paginationChange)=\"onPaginationChange($event)\">\n  </sentinel-offset-pagination>\n</ng-template>\n\n", styles: [""], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: TableShowMoreComponent, selector: "sentinel-table-show-more", inputs: ["count"], outputs: ["showMore"] }, { kind: "component", type: CursorPaginationComponent, selector: "sentinel-cursor-pagination", inputs: ["pagination", "disabled"], outputs: ["paginationChange"] }, { kind: "component", type: OffsetPaginationComponent, selector: "sentinel-offset-pagination", inputs: ["pagination", "disabled"], outputs: ["paginationChange"] }, { kind: "pipe", type: NarrowToOffsetPaginationPipe, name: "narrowToOffsetPagination" }, { kind: "pipe", type: NarrowToCursorPaginationPipe, name: "narrowToCursorPagination" }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: TablePaginationComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sentinel-table-pagination', changeDetection: ChangeDetectionStrategy.OnPush, template: "<sentinel-table-show-more\n  *ngIf=\"!disabled && pagination && showMoreCount > 0\"\n  [count]=\"showMoreCount\"\n  (showMore)=\"onShowMore()\"\n>\n</sentinel-table-show-more>\n<ng-container [ngTemplateOutlet]=\"isCursorBased ? cursorBasedPagination : offsetBasedPagination\"></ng-container>\n<ng-template #cursorBasedPagination>\n  <sentinel-cursor-pagination\n    [pagination]=\"pagination | narrowToCursorPagination\"\n    [disabled]=\"disabled\"\n    (paginationChange)=\"onPaginationChange($event)\">\n  </sentinel-cursor-pagination>\n</ng-template>\n\n<ng-template #offsetBasedPagination>\n  <sentinel-offset-pagination\n    [pagination]=\"pagination | narrowToOffsetPagination\"\n    [disabled]=\"disabled\"\n    (paginationChange)=\"onPaginationChange($event)\">\n  </sentinel-offset-pagination>\n</ng-template>\n\n" }]
        }], propDecorators: { pagination: [{
                type: Input
            }], showMoreCount: [{
                type: Input
            }], disabled: [{
                type: Input
            }], paginationChange: [{
                type: Output
            }] } });

/**
 * Presentational table component in material design. Columns, rows and its behaviour is defined by input data
 * passed to the component through data binding. Table supports displays selected attributes of a data source. Table
 * also supports Observables, so async data can be displayed in table cells. Sorting by selected columns is also supported
 * as well as filtering, pagination and row selection (checkboxes). Each table row can have unique actions (mat button icon)
 * and they can be disabled asynchronously by passing an Observable. Another important feature is row expansion, where row can
 * be expanded by clicking on arrow-like button and row detail component will roll out of the selected row. Detail components
 * are rendered dynamically and efficiently. The detail component must be created and provided by client. Current row is passed
 * to the detail component through `@Input() data` attribute, so make sure to include it in your detail component.
 */
class SentinelTableComponent extends SentinelBaseDirective {
    constructor(filterService, sortService, pageService, eventService, selectionService, showMoreService) {
        super();
        this.filterService = filterService;
        this.sortService = sortService;
        this.pageService = pageService;
        this.eventService = eventService;
        this.selectionService = selectionService;
        this.showMoreService = showMoreService;
        /**
         * Angular material elevation size of the table. Default value is 8. See more at https://material.angular.io/guide/elevation
         */
        this.elevation = 8;
        /**
         * By how much should the pagination be expanded after clicking "Show More" button.
         */
        this.showMoreDefaultSize = 10;
        /**
         * Decides how should the actions be displayed. "Icon" mode displays actions as mat icon components, while "button mode"
         * displays them as a mat button components
         */
        this.actionMode = 'icon';
        /**
         * True if rows should have alternating colors, false otherwise.
         */
        this.alternateRows = false;
        /**
         * True if row actions should be titlecased
         */
        this.titlecasedActions = true;
        /**
         * Number of actions to be displayed in actions column. Actions above the number are hidden in menu
         */
        this.displayedActionsCount = 2;
        /**
         * Function for tracking items in *ngFor. Defaults to tracking by index
         */
        this.trackByFn = trackByIndex;
        /**
         * Emits event when user clicks on row action
         */
        this.rowAction = new EventEmitter();
        /**
         * Emits event when user changes row selection
         */
        this.rowSelection = new EventEmitter();
        /**
         * Emits event when user click on a row
         */
        this.rowClick = new EventEmitter();
        /**
         * Emits event when user expands or collapses expandable row
         */
        this.expandableRowStateChange = new EventEmitter();
        /**
         * Emits event when data refresh for the table is requested (for example change of pagination settings, sort etc)
         */
        this.tableLoad = new EventEmitter();
        this.trackByFnCols = trackByIndex;
        this.displayedColumns = [];
        this.onTryAgain$ = defer(() => this.onTryAgain());
        this.alreadySetup = false;
        this.pageAlreadySetup = false;
    }
    ngOnChanges(changes) {
        if ('data' in changes && (changes['data'].isFirstChange() || !this.alreadySetup) && this.data) {
            this.setup();
            this.onDataChange();
            if (this.data.pagination) {
                this.eventService.initPagination(this.data.pagination);
            }
        }
        if ('data' in changes && !changes['data'].isFirstChange() && this.data) {
            this.onDataChange();
        }
        if ('data' in changes &&
            (changes['data'].isFirstChange() || !this.pageAlreadySetup) &&
            this.data &&
            this.data.pagination) {
            this.eventService.initPagination(this.data.pagination);
            this.pageAlreadySetup = true;
        }
        if ('preselected' in changes && this.preselected && this.preselected.length > 0) {
            this.selectionService.onPreselectionChange(this.preselected);
        }
    }
    ngAfterContentInit() {
        if (this.data) {
            this.createProjectedCells();
        }
    }
    /**
     * Emits event to refresh data for the table. Optionally, adds pagination data and filters
     */
    onTryAgain() {
        const event = {
            pagination: this.eventService.currPaginationEvent,
            filter: this.eventService.currFilter,
        };
        this.onFetchEvent(event);
    }
    /**
     * Emits event when row action is selection
     * @param row row of the selected action
     * @param action action that was selected
     */
    onAction(row, action) {
        this.rowAction.emit(new TableActionEvent(row.element, action));
    }
    onRowClick(row) {
        this.rowClick.emit(row.element);
    }
    /**
     * Opens or closes detail of expandable row
     * @param row row which was toggled
     * @param index index of toggled row
     */
    toggleExpandableRow(row, index) {
        this.expandedElement = this.expandedElement === row.element ? null : row.element;
        const newState = this.expandedElement === null ? 'collapsed' : 'expanded';
        const event = { state: newState, row: row, index: index };
        this.expandableRowStateChange.emit(event);
    }
    onDataChange() {
        this.createDataSource();
        if (!this.actionsColumnAlreadySetup() && this.data.hasActions()) {
            this.setupActions();
        }
    }
    createDataSource() {
        this.dataSource = new MatTableDataSource(this.data.rows);
        if (this.data.selectable) {
            this.selectionService.init(this.data.rows.length, this.preselected);
        }
        if (this.data.pagination) {
            this.showMoreCount = this.showMoreService.calculate(this.data.pagination, this.showMoreDefaultSize);
        }
    }
    setup() {
        this.isExpandable = this.data?.expand !== null && this.data?.expand !== undefined;
        this.setupDisplayedColumns();
        this.createProjectedCells();
        if (this.data.hasSortableColumn()) {
            this.setupSort();
        }
        if (this.data.selectable) {
            this.selectionService.change$
                .pipe(takeWhile(() => this.isAlive))
                .subscribe((selection) => this.rowSelection.emit(selection));
        }
        this.eventService.change$
            .pipe(takeWhile(() => this.isAlive))
            .subscribe((fetchEvent) => this.onFetchEvent(fetchEvent));
        this.alreadySetup = true;
    }
    /**
     * ORDER MATTERS!
     */
    setupDisplayedColumns() {
        if (this.data.selectable) {
            this.displayedColumns.push('select');
        }
        if (this.isExpandable) {
            this.displayedColumns.push('expand');
        }
        this.displayedColumns.push(...this.data.columns.map((col) => col.id));
        if (this.data.hasActions()) {
            this.setupActions();
        }
    }
    setupActions() {
        this.displayedColumns.push('actions');
    }
    setupSort() {
        const initSortName = this.getInitSortName();
        if (initSortName) {
            this.sort.active = initSortName;
            this.sort.start = this.defaultSortDirection ? this.defaultSortDirection : 'asc';
            this.eventService.initSort(initSortName, this.sort.start);
            this.sort.direction = this.sort.start;
        }
    }
    actionsColumnAlreadySetup() {
        return this.displayedColumns.some((column) => column === 'actions');
    }
    getInitSortName() {
        if (this.defaultSortName !== undefined && this.defaultSortName !== null) {
            return this.defaultSortName;
        }
        else {
            const firstSortCol = this.data.columns.find((col) => col.isSortColumn);
            if (firstSortCol !== undefined && this.defaultSortName !== null) {
                return firstSortCol.sortName;
            }
        }
        return null;
    }
    createProjectedCells() {
        if (this.cellDirectives) {
            const cells = {};
            this.cellDirectives.forEach((directive) => {
                if (!this.displayedColumns.includes(directive.columnId)) {
                    console.error('ERROR: No matching id column for *sentinelRow');
                }
                if (cells[directive.columnId]) {
                    console.error('ERROR: *sentinelRow id value must be unique');
                }
                else {
                    cells[directive.columnId] = directive;
                }
            });
            this.projectedCells = cells;
        }
    }
    onFetchEvent(event) {
        this.tableLoad.emit(event);
    }
}
SentinelTableComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelTableComponent, deps: [{ token: TableFilterService }, { token: TableSortService }, { token: TablePageService }, { token: TableEventService }, { token: TableSelectionService }, { token: ShowMoreService }], target: i0.ɵɵFactoryTarget.Component });
SentinelTableComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: SentinelTableComponent, selector: "sentinel-table", inputs: { data: "data", isLoading: "isLoading", elevation: "elevation", preselected: "preselected", hasError: "hasError", defaultSortDirection: "defaultSortDirection", defaultSortName: "defaultSortName", showMoreDefaultSize: "showMoreDefaultSize", actionMode: "actionMode", alternateRows: "alternateRows", titlecasedActions: "titlecasedActions", displayedActionsCount: "displayedActionsCount", trackByFn: "trackByFn" }, outputs: { rowAction: "rowAction", rowSelection: "rowSelection", rowClick: "rowClick", expandableRowStateChange: "expandableRowStateChange", tableLoad: "tableLoad" }, providers: [
        TableSortService,
        TableFilterService,
        TablePageService,
        TableEventService,
        TableSelectionService,
        ShowMoreService,
    ], queries: [{ propertyName: "cellDirectives", predicate: SentinelRowDirective }], viewQueries: [{ propertyName: "sort", first: true, predicate: MatSort, descendants: true, static: true }], usesInheritance: true, usesOnChanges: true, ngImport: i0, template: "<sentinel-table-filter\n  *ngIf=\"data?.filterable\"\n  [disabled]=\"hasError\"\n  [label]=\"data?.filterLabel\"\n  (valueChange)=\"filterService.update($event)\"\n>\n</sentinel-table-filter>\n<sentinel-loading-wrapper [isLoading]=\"isLoading\">\n  <div [ngClass]=\"'mat-elevation-z' + elevation\">\n    <ng-container *sentinelError=\"hasError; tryAgain$: onTryAgain$\"></ng-container>\n    <table\n      [matSortDisabled]=\"hasError\"\n      mat-table\n      matSort\n      (matSortChange)=\"sortService.update($event)\"\n      [dataSource]=\"dataSource\"\n      [trackBy]=\"trackByFn\"\n      [multiTemplateDataRows]=\"isExpandable\"\n    >\n      <!-- EXPANDED COLUMN -->\n      <ng-container matColumnDef=\"expandedDetail\" *ngIf=\"isExpandable\">\n        <td\n          mat-cell\n          *matCellDef=\"let row; let i = dataIndex\"\n          [attr.colspan]=\"displayedColumns.length\"\n          attr.data-cy=\"{{ 'row' + i + '-expanded-row' }}\"\n        >\n          <sentinel-table-expanded-row-detail\n            [state]=\"row?.element === expandedElement ? 'expanded' : 'collapsed'\"\n            [expandConfig]=\"data?.expand\"\n            [expandElement]=\"row?.element\"\n          >\n          </sentinel-table-expanded-row-detail>\n        </td>\n      </ng-container>\n\n      <!-- CHECKBOX COLUMN -->\n      <ng-container matColumnDef=\"select\">\n        <th mat-header-cell disabled=\"true\" *matHeaderCellDef class=\"select\">\n          <mat-checkbox\n            (change)=\"$event ? selectionService.toggleAll(data.rows) : null\"\n            [checked]=\"(selectionService.someSelected$ | async) && (selectionService.allSelected$ | async)\"\n            [disabled]=\"hasError\"\n            [indeterminate]=\"\n              (selectionService.someSelected$ | async) && (selectionService.allSelected$ | async) === false\n            \"\n            class=\"select-all\"\n          >\n          </mat-checkbox>\n        </th>\n        <td mat-cell *matCellDef=\"let row; let i = dataIndex\" class=\"select\" attr.data-cy=\"{{ 'row' + i + '-select' }}\">\n          <mat-checkbox\n            [checked]=\"selectionService.isSelected(row)\"\n            [disabled]=\"row?.selectionDisabled$ ? (hasError || row.selectionDisabled$ | async) : hasError\"\n            (click)=\"$event.stopPropagation()\"\n            (change)=\"$event ? selectionService.toggleSelection(row) : null\"\n          >\n          </mat-checkbox>\n        </td>\n      </ng-container>\n\n      <!-- DYNAMIC COLUMNS -->\n      <ng-container *ngFor=\"let column of data?.columns; let i = index; trackBy: trackByFnCols\" [matColumnDef]=\"column?.id\">\n        <th\n          mat-header-cell\n          disableClear\n          *matHeaderCellDef\n          [mat-sort-header]=\"column.sortName\"\n          [disabled]=\"!column?.isSortColumn\"\n        >\n          {{ column?.label | titlecase }}\n        </th>\n        <td mat-cell *matCellDef=\"let row; let i = dataIndex;\" attr.data-cy=\"{{ 'row' + i + '-' + column?.id }}\">\n          <ng-container *ngIf=\"projectedCells[column?.id]; else sentinelDataCell\">\n            <ng-container\n              [ngTemplateOutlet]=\"projectedCells[column?.id].template\"\n              [ngTemplateOutletContext]=\"{ $implicit: row, disabled: hasError }\"\n            ></ng-container>\n          </ng-container>\n          <ng-template #sentinelDataCell>\n            <sentinel-table-data-cell [row]=\"row\" [column]=\"column\" [disabled]=\"hasError\"> </sentinel-table-data-cell>\n          </ng-template>\n        </td>\n      </ng-container>\n\n      <!-- ACTIONS COLUMN -->\n      <ng-container matColumnDef=\"actions\">\n        <th mat-header-cell disabled=\"true\" *matHeaderCellDef>Actions</th>\n        <td mat-cell *matCellDef=\"let row; let i = dataIndex\" attr.data-cy=\"{{ 'row' + i + '-actions' }}\">\n          <sentinel-table-actions\n            [titlecased]=\"titlecasedActions\"\n            [actions]=\"row?.actions\"\n            [disabled]=\"hasError\"\n            [actionMode]=\"actionMode\"\n            [displayedActionsCount]=\"displayedActionsCount\"\n            (click)=\"$event.stopPropagation()\"\n            (actionClick)=\"onAction(row, $event);\"\n          >\n          </sentinel-table-actions>\n        </td>\n      </ng-container>\n\n      <!-- EXPAND DETAIL -->\n      <ng-container *ngIf=\"isExpandable\" matColumnDef=\"expand\">\n        <th mat-header-cell *matHeaderCellDef class=\"expand\"></th>\n        <td\n          mat-cell\n          *matCellDef=\"let row; let i = dataIndex\"\n          class=\"expand\"\n          attr.data-cy=\"{{ 'row' + i + '-expand-button' }}\"\n        >\n          <button\n            mat-icon-button\n            matTooltip=\"Click to expand detail\"\n            [disabled]=\"hasError\"\n            (click)=\"toggleExpandableRow(row, i); $event.stopPropagation()\"\n          >\n            <mat-icon *ngIf=\"expandedElement === row?.element\">expand_less</mat-icon>\n            <mat-icon *ngIf=\"expandedElement !== row?.element\">expand_more</mat-icon>\n          </button>\n        </td>\n      </ng-container>\n\n      <tr mat-header-row *matHeaderRowDef=\"displayedColumns\"></tr>\n      <!-- The tr odd is not working properly if there are hidden rows (for expanding). In case when rows should\n      alternate and table supports expanding, the alternating rows needs to be selected by different condition (dataIndex) -->\n      <tr\n        mat-row\n        *matRowDef=\"let row; columns: displayedColumns; let i = dataIndex; let odd = odd\"\n        class=\"element-row\"\n        (click)=\"onRowClick(row)\"\n        [ngClass]=\"{\n          alternative: (alternateRows && isExpandable && i % 2) || (alternateRows && !isExpandable && odd),\n          hoverable: row.clickable\n        }\"\n        [class.expanded-row]=\"expandedElement === row?.element\"\n      ></tr>\n      <ng-container *ngIf=\"isExpandable\">\n        <tr mat-row *matRowDef=\"let row; columns: ['expandedDetail']\" class=\"detail-row\"></tr>\n      </ng-container>\n    </table>\n\n    <sentinel-table-pagination\n      *ngIf=\"data?.pagination\"\n      [disabled]=\"hasError\"\n      [pagination]=\"data?.pagination\"\n      [showMoreCount]=\"showMoreCount\"\n      (paginationChange)=\"pageService.update($event)\"\n    >\n    </sentinel-table-pagination>\n  </div>\n</sentinel-loading-wrapper>\n", styles: ["table{width:100%}tr.detail-row{height:0}.detail-row td{border-bottom-width:0}th.expand,th.select,td.expand,td.select{width:25px}.element-row.alternative{background:rgba(0,0,0,.025)}.element-row.hoverable:hover{background:rgba(0,0,0,.075)}\n"], dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: i8.MatTable, selector: "mat-table, table[mat-table]", exportAs: ["matTable"] }, { kind: "directive", type: i8.MatHeaderCellDef, selector: "[matHeaderCellDef]" }, { kind: "directive", type: i8.MatHeaderRowDef, selector: "[matHeaderRowDef]", inputs: ["matHeaderRowDef", "matHeaderRowDefSticky"] }, { kind: "directive", type: i8.MatColumnDef, selector: "[matColumnDef]", inputs: ["sticky", "matColumnDef"] }, { kind: "directive", type: i8.MatCellDef, selector: "[matCellDef]" }, { kind: "directive", type: i8.MatRowDef, selector: "[matRowDef]", inputs: ["matRowDefColumns", "matRowDefWhen"] }, { kind: "directive", type: i8.MatHeaderCell, selector: "mat-header-cell, th[mat-header-cell]" }, { kind: "directive", type: i8.MatCell, selector: "mat-cell, td[mat-cell]" }, { kind: "component", type: i8.MatHeaderRow, selector: "mat-header-row, tr[mat-header-row]", exportAs: ["matHeaderRow"] }, { kind: "component", type: i8.MatRow, selector: "mat-row, tr[mat-row]", exportAs: ["matRow"] }, { kind: "component", type: i2.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { kind: "component", type: i3$1.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { kind: "directive", type: i4.MatTooltip, selector: "[matTooltip]", exportAs: ["matTooltip"] }, { kind: "component", type: i12.MatCheckbox, selector: "mat-checkbox", inputs: ["disableRipple", "color", "tabIndex"], exportAs: ["matCheckbox"] }, { kind: "directive", type: i13.MatSort, selector: "[matSort]", inputs: ["matSortDisabled", "matSortActive", "matSortStart", "matSortDirection", "matSortDisableClear"], outputs: ["matSortChange"], exportAs: ["matSort"] }, { kind: "component", type: i13.MatSortHeader, selector: "[mat-sort-header]", inputs: ["disabled", "mat-sort-header", "arrowPosition", "start", "sortActionDescription", "disableClear"], exportAs: ["matSortHeader"] }, { kind: "directive", type: i14.SentinelErrorDirective, selector: "[sentinelError], [sentinelErrorTryAgain]", inputs: ["sentinelError", "sentinelErrorTryAgain$"] }, { kind: "component", type: i6.SentinelLoadingWrapperComponent, selector: "sentinel-loading-wrapper", inputs: ["isLoading", "color"] }, { kind: "component", type: TableActionsComponent, selector: "sentinel-table-actions", inputs: ["actionMode", "titlecased", "displayedActionsCount"] }, { kind: "component", type: TableDataCellComponent, selector: "sentinel-table-data-cell", inputs: ["row", "column", "disabled"] }, { kind: "component", type: TableFilterComponent, selector: "sentinel-table-filter", inputs: ["label", "disabled"], outputs: ["valueChange"] }, { kind: "component", type: TableExpandedRowDetailComponent, selector: "sentinel-table-expanded-row-detail", inputs: ["state", "expandConfig", "expandElement"] }, { kind: "component", type: TablePaginationComponent, selector: "sentinel-table-pagination", inputs: ["pagination", "showMoreCount", "disabled"], outputs: ["paginationChange"] }, { kind: "pipe", type: i1.AsyncPipe, name: "async" }, { kind: "pipe", type: i1.TitleCasePipe, name: "titlecase" }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelTableComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sentinel-table', changeDetection: ChangeDetectionStrategy.OnPush, providers: [
                        TableSortService,
                        TableFilterService,
                        TablePageService,
                        TableEventService,
                        TableSelectionService,
                        ShowMoreService,
                    ], template: "<sentinel-table-filter\n  *ngIf=\"data?.filterable\"\n  [disabled]=\"hasError\"\n  [label]=\"data?.filterLabel\"\n  (valueChange)=\"filterService.update($event)\"\n>\n</sentinel-table-filter>\n<sentinel-loading-wrapper [isLoading]=\"isLoading\">\n  <div [ngClass]=\"'mat-elevation-z' + elevation\">\n    <ng-container *sentinelError=\"hasError; tryAgain$: onTryAgain$\"></ng-container>\n    <table\n      [matSortDisabled]=\"hasError\"\n      mat-table\n      matSort\n      (matSortChange)=\"sortService.update($event)\"\n      [dataSource]=\"dataSource\"\n      [trackBy]=\"trackByFn\"\n      [multiTemplateDataRows]=\"isExpandable\"\n    >\n      <!-- EXPANDED COLUMN -->\n      <ng-container matColumnDef=\"expandedDetail\" *ngIf=\"isExpandable\">\n        <td\n          mat-cell\n          *matCellDef=\"let row; let i = dataIndex\"\n          [attr.colspan]=\"displayedColumns.length\"\n          attr.data-cy=\"{{ 'row' + i + '-expanded-row' }}\"\n        >\n          <sentinel-table-expanded-row-detail\n            [state]=\"row?.element === expandedElement ? 'expanded' : 'collapsed'\"\n            [expandConfig]=\"data?.expand\"\n            [expandElement]=\"row?.element\"\n          >\n          </sentinel-table-expanded-row-detail>\n        </td>\n      </ng-container>\n\n      <!-- CHECKBOX COLUMN -->\n      <ng-container matColumnDef=\"select\">\n        <th mat-header-cell disabled=\"true\" *matHeaderCellDef class=\"select\">\n          <mat-checkbox\n            (change)=\"$event ? selectionService.toggleAll(data.rows) : null\"\n            [checked]=\"(selectionService.someSelected$ | async) && (selectionService.allSelected$ | async)\"\n            [disabled]=\"hasError\"\n            [indeterminate]=\"\n              (selectionService.someSelected$ | async) && (selectionService.allSelected$ | async) === false\n            \"\n            class=\"select-all\"\n          >\n          </mat-checkbox>\n        </th>\n        <td mat-cell *matCellDef=\"let row; let i = dataIndex\" class=\"select\" attr.data-cy=\"{{ 'row' + i + '-select' }}\">\n          <mat-checkbox\n            [checked]=\"selectionService.isSelected(row)\"\n            [disabled]=\"row?.selectionDisabled$ ? (hasError || row.selectionDisabled$ | async) : hasError\"\n            (click)=\"$event.stopPropagation()\"\n            (change)=\"$event ? selectionService.toggleSelection(row) : null\"\n          >\n          </mat-checkbox>\n        </td>\n      </ng-container>\n\n      <!-- DYNAMIC COLUMNS -->\n      <ng-container *ngFor=\"let column of data?.columns; let i = index; trackBy: trackByFnCols\" [matColumnDef]=\"column?.id\">\n        <th\n          mat-header-cell\n          disableClear\n          *matHeaderCellDef\n          [mat-sort-header]=\"column.sortName\"\n          [disabled]=\"!column?.isSortColumn\"\n        >\n          {{ column?.label | titlecase }}\n        </th>\n        <td mat-cell *matCellDef=\"let row; let i = dataIndex;\" attr.data-cy=\"{{ 'row' + i + '-' + column?.id }}\">\n          <ng-container *ngIf=\"projectedCells[column?.id]; else sentinelDataCell\">\n            <ng-container\n              [ngTemplateOutlet]=\"projectedCells[column?.id].template\"\n              [ngTemplateOutletContext]=\"{ $implicit: row, disabled: hasError }\"\n            ></ng-container>\n          </ng-container>\n          <ng-template #sentinelDataCell>\n            <sentinel-table-data-cell [row]=\"row\" [column]=\"column\" [disabled]=\"hasError\"> </sentinel-table-data-cell>\n          </ng-template>\n        </td>\n      </ng-container>\n\n      <!-- ACTIONS COLUMN -->\n      <ng-container matColumnDef=\"actions\">\n        <th mat-header-cell disabled=\"true\" *matHeaderCellDef>Actions</th>\n        <td mat-cell *matCellDef=\"let row; let i = dataIndex\" attr.data-cy=\"{{ 'row' + i + '-actions' }}\">\n          <sentinel-table-actions\n            [titlecased]=\"titlecasedActions\"\n            [actions]=\"row?.actions\"\n            [disabled]=\"hasError\"\n            [actionMode]=\"actionMode\"\n            [displayedActionsCount]=\"displayedActionsCount\"\n            (click)=\"$event.stopPropagation()\"\n            (actionClick)=\"onAction(row, $event);\"\n          >\n          </sentinel-table-actions>\n        </td>\n      </ng-container>\n\n      <!-- EXPAND DETAIL -->\n      <ng-container *ngIf=\"isExpandable\" matColumnDef=\"expand\">\n        <th mat-header-cell *matHeaderCellDef class=\"expand\"></th>\n        <td\n          mat-cell\n          *matCellDef=\"let row; let i = dataIndex\"\n          class=\"expand\"\n          attr.data-cy=\"{{ 'row' + i + '-expand-button' }}\"\n        >\n          <button\n            mat-icon-button\n            matTooltip=\"Click to expand detail\"\n            [disabled]=\"hasError\"\n            (click)=\"toggleExpandableRow(row, i); $event.stopPropagation()\"\n          >\n            <mat-icon *ngIf=\"expandedElement === row?.element\">expand_less</mat-icon>\n            <mat-icon *ngIf=\"expandedElement !== row?.element\">expand_more</mat-icon>\n          </button>\n        </td>\n      </ng-container>\n\n      <tr mat-header-row *matHeaderRowDef=\"displayedColumns\"></tr>\n      <!-- The tr odd is not working properly if there are hidden rows (for expanding). In case when rows should\n      alternate and table supports expanding, the alternating rows needs to be selected by different condition (dataIndex) -->\n      <tr\n        mat-row\n        *matRowDef=\"let row; columns: displayedColumns; let i = dataIndex; let odd = odd\"\n        class=\"element-row\"\n        (click)=\"onRowClick(row)\"\n        [ngClass]=\"{\n          alternative: (alternateRows && isExpandable && i % 2) || (alternateRows && !isExpandable && odd),\n          hoverable: row.clickable\n        }\"\n        [class.expanded-row]=\"expandedElement === row?.element\"\n      ></tr>\n      <ng-container *ngIf=\"isExpandable\">\n        <tr mat-row *matRowDef=\"let row; columns: ['expandedDetail']\" class=\"detail-row\"></tr>\n      </ng-container>\n    </table>\n\n    <sentinel-table-pagination\n      *ngIf=\"data?.pagination\"\n      [disabled]=\"hasError\"\n      [pagination]=\"data?.pagination\"\n      [showMoreCount]=\"showMoreCount\"\n      (paginationChange)=\"pageService.update($event)\"\n    >\n    </sentinel-table-pagination>\n  </div>\n</sentinel-loading-wrapper>\n", styles: ["table{width:100%}tr.detail-row{height:0}.detail-row td{border-bottom-width:0}th.expand,th.select,td.expand,td.select{width:25px}.element-row.alternative{background:rgba(0,0,0,.025)}.element-row.hoverable:hover{background:rgba(0,0,0,.075)}\n"] }]
        }], ctorParameters: function () { return [{ type: TableFilterService }, { type: TableSortService }, { type: TablePageService }, { type: TableEventService }, { type: TableSelectionService }, { type: ShowMoreService }]; }, propDecorators: { data: [{
                type: Input
            }], isLoading: [{
                type: Input
            }], elevation: [{
                type: Input
            }], preselected: [{
                type: Input
            }], hasError: [{
                type: Input
            }], defaultSortDirection: [{
                type: Input
            }], defaultSortName: [{
                type: Input
            }], showMoreDefaultSize: [{
                type: Input
            }], actionMode: [{
                type: Input
            }], alternateRows: [{
                type: Input
            }], titlecasedActions: [{
                type: Input
            }], displayedActionsCount: [{
                type: Input
            }], trackByFn: [{
                type: Input
            }], rowAction: [{
                type: Output
            }], rowSelection: [{
                type: Output
            }], rowClick: [{
                type: Output
            }], expandableRowStateChange: [{
                type: Output
            }], tableLoad: [{
                type: Output
            }], sort: [{
                type: ViewChild,
                args: [MatSort, { static: true }]
            }], cellDirectives: [{
                type: ContentChildren,
                args: [SentinelRowDirective]
            }] } });

/**
 * Main module of table, containing all necessary imports.
 */
class SentinelTableModule {
}
SentinelTableModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelTableModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
SentinelTableModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: SentinelTableModule, declarations: [SentinelRowDirective,
        SentinelTableComponent,
        ExpandedRowHostDirective,
        TableActionsComponent,
        TableDataCellComponent,
        ActionButtonComponent,
        ActionMenuComponent,
        ActionButtonContainerComponent,
        ActionContainerDirective,
        TableDataCellLinkComponent,
        TableDataCellContentComponent,
        TableFilterComponent,
        TableExpandedRowDetailComponent,
        TableShowMoreComponent,
        TablePaginationComponent,
        CursorPaginationComponent,
        OffsetPaginationComponent,
        NarrowToOffsetPaginationPipe,
        NarrowToCursorPaginationPipe,
        CursorPaginatorComponent], imports: [CommonModule, i2$1.RouterModule, ReactiveFormsModule,
        MatTableModule,
        MatProgressBarModule,
        MatButtonModule,
        MatMenuModule,
        MatIconModule,
        MatProgressSpinnerModule,
        MatTooltipModule,
        MatCheckboxModule,
        MatSortModule,
        MatFormFieldModule,
        MatInputModule,
        MatPaginatorModule,
        SentinelErrorModule,
        SentinelLoadingModule,
        SentinelLabelModule,
        MatSelectModule,
        SentinelLoadingModule], exports: [SentinelTableComponent, SentinelRowDirective] });
SentinelTableModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelTableModule, imports: [CommonModule,
        RouterModule.forChild([]),
        ReactiveFormsModule,
        MatTableModule,
        MatProgressBarModule,
        MatButtonModule,
        MatMenuModule,
        MatIconModule,
        MatProgressSpinnerModule,
        MatTooltipModule,
        MatCheckboxModule,
        MatSortModule,
        MatFormFieldModule,
        MatInputModule,
        MatPaginatorModule,
        SentinelErrorModule,
        SentinelLoadingModule,
        SentinelLabelModule,
        MatSelectModule,
        SentinelLoadingModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelTableModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        SentinelRowDirective,
                        SentinelTableComponent,
                        ExpandedRowHostDirective,
                        TableActionsComponent,
                        TableDataCellComponent,
                        ActionButtonComponent,
                        ActionMenuComponent,
                        ActionButtonContainerComponent,
                        ActionContainerDirective,
                        TableDataCellLinkComponent,
                        TableDataCellContentComponent,
                        TableFilterComponent,
                        TableExpandedRowDetailComponent,
                        TableShowMoreComponent,
                        TablePaginationComponent,
                        CursorPaginationComponent,
                        OffsetPaginationComponent,
                        NarrowToOffsetPaginationPipe,
                        NarrowToCursorPaginationPipe,
                        CursorPaginatorComponent,
                    ],
                    imports: [
                        CommonModule,
                        RouterModule.forChild([]),
                        ReactiveFormsModule,
                        MatTableModule,
                        MatProgressBarModule,
                        MatButtonModule,
                        MatMenuModule,
                        MatIconModule,
                        MatProgressSpinnerModule,
                        MatTooltipModule,
                        MatCheckboxModule,
                        MatSortModule,
                        MatFormFieldModule,
                        MatInputModule,
                        MatPaginatorModule,
                        SentinelErrorModule,
                        SentinelLoadingModule,
                        SentinelLabelModule,
                        MatSelectModule,
                        SentinelLoadingModule,
                    ],
                    exports: [SentinelTableComponent, SentinelRowDirective],
                }]
        }] });

/**
 * Each column you define will be displayed in final table. Make sure that id MATCHES the name of the attribute of the generic
 * element of the row that you want to display in data cells of this column. Sort name is what should be send to backend through
 * pagination as it may not always match with our internal data model and its attributes naming.
 */
class Column {
    constructor(id, label, isSortColumn, sortName = null) {
        this.id = id;
        this.label = label;
        this.isSortColumn = isSortColumn;
        this.sortName = sortName ? sortName : label;
    }
}

/**
 * Main data source for the table. You can set if the table should allow filtering, selection boxes, pagination and actions.
 * It also allows to define expand component which will be displayed after clicking on row.
 */
class SentinelTable {
    constructor(rows, columns) {
        this.rows = [];
        this.columns = [];
        this.rows = rows;
        this.columns = columns;
    }
    /**
     * True if come column is sortable, false otherwise
     */
    hasSortableColumn() {
        return this.columns.some((col) => col.isSortColumn);
    }
    /**
     * True if any row has action, false otherwise
     */
    hasActions() {
        return this.rows.some((row) => row.actions && row.actions.length > 0);
    }
}

class Link {
    constructor(url, target = '_self') {
        this.url = url;
        this.target = target;
        this.isExternal = url.startsWith('https') || url.startsWith('http');
    }
}

/**
 * Abstract row class that allows you to set element whose attributes may be displayed. Make sure that any of the attributes
 * you want to display is either primitive data type or has toString() method to display properly. You can add links
 * to specific columns, then the data cell on current row and matched column will be displayed as link inside <a> element
 * instead of simple text.
 */
class Row {
    constructor(element, actions = [], clickable = false) {
        this.links = new Map();
        this.element = element;
        this.actions = actions;
        this.clickable = clickable;
    }
    /**
     * Adds url link to the row. If the url starts with protocol, <a href> is used to navigate, otherwise [routerLink] is used
     * @param columnId id of column to match data cell in which the link should be displayed
     * @param url url link to navigate to on click
     * @param target <a> target attribute
     */
    addLink(columnId, url, target) {
        this.links.set(columnId, new Link(url, target));
    }
    /**
     * Returns link set to data cell in this row and matching column
     * @param columnId id of a column to match with row (to find exact data cell)
     */
    getLink(columnId) {
        return this.links.get(columnId);
    }
}

/**
 * Class containing row expansion data
 */
class RowExpand {
    constructor(component, config = null) {
        this.component = component;
        this.config = config;
    }
}

function trackByIdTableRow(index, row) {
    return row.element.id;
}

/**
 * Class of row action
 */
class RowAction {
    constructor(id, label, matIcon, matColor, tooltip, disabled$, result$, isLoading$ = of(false)) {
        this.id = id;
        this.label = label;
        this.matIcon = matIcon;
        this.matColor = matColor;
        this.tooltip = tooltip;
        this.disabled$ = disabled$;
        this.result$ = result$;
        this.isLoading$ = isLoading$;
    }
}

class DeleteAction extends RowAction {
    constructor(tooltip, disabled$, result$) {
        super('delete', 'Delete', 'delete', 'warn', tooltip, disabled$, result$);
    }
}

class DownloadAction extends RowAction {
    constructor(tooltip, disabled$, result$) {
        super('download', 'Download', 'cloud_download', 'primary', tooltip, disabled$, result$);
    }
}

class EditAction extends RowAction {
    constructor(tooltip, disabled$, result$) {
        super('edit', 'Edit', 'create', 'primary', tooltip, disabled$, result$);
    }
}

/*
 * Public API Surface of @sentinel/components/table
 */

/**
 * Generated bundle index. Do not edit.
 */

export { Column, DeleteAction, DownloadAction, EditAction, Row, RowAction, RowExpand, SentinelRowDirective, SentinelTable, SentinelTableComponent, SentinelTableModule, TableActionEvent, trackByIdTableRow };
//# sourceMappingURL=sentinel-components-table.mjs.map
