import * as i0 from '@angular/core';
import { EventEmitter, Component, ChangeDetectionStrategy, ViewChild, Input, Output, HostListener, NgModule } from '@angular/core';
import * as i7 from '@angular/material/sidenav';
import { MatDrawer } from '@angular/material/sidenav';
import * as i2 from '@angular/router';
import { NavigationEnd, RouterModule } from '@angular/router';
import { takeWhile, filter, map } from 'rxjs/operators';
import { BaseDirective } from '@sentinel/layout/internal';
import { SentinelBreadcrumbBuilder } from '@sentinel/layout/breadcrumbs';
import * as i6 from '@sentinel/layout/common-components';
import { ScrollContainerComponent, LayoutCommonComponentsSansProvidersModule } from '@sentinel/layout/common-components';
import * as i1 from '@sentinel/layout';
import * as i3 from '@sentinel/layout/notification';
import { NotificationProvidersModule } from '@sentinel/layout/notification';
import * as i4 from '@sentinel/layout/sidebar';
import * as i5 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i8 from '@angular/material/button';
import * as i9 from '@angular/material/icon';

/**
 * Sentinel Layout 1 component. You can use this component as a pre-defined layout for your app.
 */
class SentinelLayout1Component extends BaseDirective {
    constructor(navBarState, router, activeRoute, notificationService, notificationApi, sidebarSizeService, windowSizeService) {
        super();
        this.navBarState = navBarState;
        this.router = router;
        this.activeRoute = activeRoute;
        this.notificationService = notificationService;
        this.notificationApi = notificationApi;
        this.sidebarSizeService = sidebarSizeService;
        this.windowSizeService = windowSizeService;
        /**
         * Decides whether to display two lined toolbar with breadcrumbs or not
         */
        this.withBreadcrumbs = true;
        /**
         * Decides whether to display loading bar / placeholder below the toolbar
         */
        this.withLoading = true;
        /**
         * True if loading bar should be shown, false otherwise
         */
        this.isLoading = false;
        /**
         * Displays scroll to top and scroll to bottom buttons if true
         */
        this.displayScrollButtons = false;
        /**
         * Containers of agendas displayed in sidenav menu
         */
        this.agendaContainers = [];
        /**
         * Whether the content inside the layout should have padding or not
         */
        this.paddedContent = true;
        /**
         * Character(s) dividing individual breadcrumbs
         */
        this.breadcrumbsDivider = '/';
        this.breadcrumbMaxLength = 45;
        /**
         * If set to true, always display sidebar even when it has no injected template
         */
        this.alwaysDisplaySidebar = false;
        /**
         * Emitted if login is requested
         */
        this.login = new EventEmitter();
        /**
         * Emitted if logout is requested
         */
        this.logout = new EventEmitter();
    }
    ngOnInit() {
        this.resolveSidebarHeight();
        this.lastNotification$ = this.notificationService.onNotificationAdded$;
        const navigationEndEvent$ = this.router.events.pipe(takeWhile((_) => this.isAlive), filter((event) => event instanceof NavigationEnd));
        this.breadcrumbs$ = navigationEndEvent$.pipe(takeWhile(() => this.withBreadcrumbs), map(() => this.breadcrumbSelector
            ? SentinelBreadcrumbBuilder.build(this.activeRoute.snapshot, this.breadcrumbSelector)
            : SentinelBreadcrumbBuilder.build(this.activeRoute.snapshot)));
        if (this.displayScrollButtons) {
            navigationEndEvent$.pipe(takeWhile((_) => this.isAlive)).subscribe((_) => this.scrollContainerComponent.clear());
        }
    }
    ngOnChanges(changes) {
        if ('withBreadcrumbs' in changes && this.withBreadcrumbs !== undefined) {
            this.resolveSidebarHeight();
        }
    }
    resolveSidebarHeight() {
        const height = this.withBreadcrumbs ? 'calc(100vh - 90px)' : 'calc(100vh - 50px)';
        this.sidebarSizeService.setHeight(height, true);
    }
    onResize(event) {
        this.windowSizeService.onResize(event.target.innerHeight, event.target.innerWidth);
    }
    /**
     * Emits login event
     */
    onLogin() {
        this.login.emit();
    }
    /**
     * Emits logout event
     */
    onLogout() {
        this.logout.emit();
    }
    /**
     * Closes sidenav if user is on mobile device and the menu is displayed in full width
     * @param agenda selected agenda
     */
    onAgendaSelected(agenda) {
        if (this.navBarState.getIsSmallView()) {
            this.navBarState.toggleState();
        }
    }
    /**
     * Gets new notifications
     */
    onRefreshNotifications() {
        this.notifications$ = this.notificationApi.getAll(0, 5);
    }
}
SentinelLayout1Component.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelLayout1Component, deps: [{ token: i1.NavBarStateService }, { token: i2.Router }, { token: i2.ActivatedRoute }, { token: i3.SentinelNotificationService }, { token: i3.SentinelNotificationApi }, { token: i4.SidebarSizeService }, { token: i1.WindowSizeService }], target: i0.ɵɵFactoryTarget.Component });
SentinelLayout1Component.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: SentinelLayout1Component, selector: "sentinel-layout1", inputs: { breadcrumbSelector: "breadcrumbSelector", withBreadcrumbs: "withBreadcrumbs", withLoading: "withLoading", isLoading: "isLoading", logoSrc: "logoSrc", version: "version", notificationsRoute: "notificationsRoute", userProfileRoute: "userProfileRoute", user: "user", displayScrollButtons: "displayScrollButtons", agendaContainers: "agendaContainers", paddedContent: "paddedContent", breadcrumbsDivider: "breadcrumbsDivider", breadcrumbMaxLength: "breadcrumbMaxLength", alwaysDisplaySidebar: "alwaysDisplaySidebar" }, outputs: { login: "login", logout: "logout" }, host: { listeners: { "window:resize": "onResize($event)" } }, viewQueries: [{ propertyName: "drawer", first: true, predicate: MatDrawer, descendants: true, static: true }, { propertyName: "scrollContainerComponent", first: true, predicate: ScrollContainerComponent, descendants: true }], usesInheritance: true, usesOnChanges: true, ngImport: i0, template: "<mat-drawer-container autosize>\n  <mat-drawer\n    #drawer\n    [mode]=\"(navBarState.isSmallView$ | async) ? 'over' : 'side'\"\n    [opened]=\"(navBarState.state$ | async) === 'expanded'\"\n  >\n    <div *ngIf=\"navBarState.isSmallView$ | async\" class=\"nav-controls\">\n      <button mat-icon-button (click)=\"navBarState.toggleState()\">\n        <mat-icon>close</mat-icon>\n      </button>\n    </div>\n    <div class=\"nav-content\">\n      <sentinel-nav\n        [logoSrc]=\"logoSrc\"\n        [version]=\"version\"\n        [agendaContainers]=\"agendaContainers\"\n        (agendaSelected)=\"onAgendaSelected($event)\"\n      >\n      </sentinel-nav>\n    </div>\n  </mat-drawer>\n  <mat-drawer-content>\n    <sentinel-scroll-container *ngIf=\"displayScrollButtons; else innerContentTemplate\">\n      <ng-container *ngTemplateOutlet=\"innerContentTemplate\"> </ng-container>\n    </sentinel-scroll-container>\n  </mat-drawer-content>\n</mat-drawer-container>\n\n<ng-template #innerContentTemplate>\n  <sentinel-toolbar\n    [withBreadcrumbs]=\"withBreadcrumbs\"\n    [breadcrumbs]=\"breadcrumbs$ | async\"\n    [breadcrumbsDivider]=\"breadcrumbsDivider\"\n    [breadcrumbMaxLength]=\"breadcrumbMaxLength\"\n    [user]=\"user\"\n    [userProfileRoute]=\"userProfileRoute\"\n    [notifications]=\"notifications$ | async\"\n    [lastNotification]=\"lastNotification$ | async\"\n    [notificationsRoute]=\"notificationsRoute\"\n    [displayNavToggle]=\"navBarState.isSmallView$ | async\"\n    (navToggle)=\"navBarState.toggleState()\"\n    (refreshNotifications)=\"onRefreshNotifications()\"\n    (login)=\"onLogin()\"\n    (logout)=\"onLogout()\"\n  >\n    <ng-content select=\"[role=toolbar]\"></ng-content>\n  </sentinel-toolbar>\n  <sentinel-sidebar-page-layout [alwaysDisplaySidebar]=\"alwaysDisplaySidebar\">\n    <sentinel-loading *ngIf=\"withLoading\" [isLoading]=\"isLoading\"></sentinel-loading>\n    <div [ngClass]=\"paddedContent ? 'padded-content' : 'content'\">\n      <ng-content></ng-content>\n    </div>\n  </sentinel-sidebar-page-layout>\n</ng-template>\n", styles: ["mat-drawer-container{min-height:100vh;width:100%}mat-drawer-content{display:flex;flex-direction:column;min-height:100vh}mat-drawer{text-align:center;justify-content:center;width:140px;background-color:#000;background-image:linear-gradient(147deg,#03031F 0%,#141F64 250%)}.nav-content{height:100%;overflow:hidden}.nav-controls{text-align:left;color:#fff}.content{flex:1;padding:0}.padded-content{flex:1;padding:40px}main{display:flex;flex-direction:column}main>*:not(router-outlet){flex:1;display:block}@media (max-width: 748px){mat-drawer{width:100%}}\n"], dependencies: [{ kind: "directive", type: i5.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i5.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i5.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: i6.LoadingComponent, selector: "sentinel-loading", inputs: ["isLoading"] }, { kind: "component", type: i6.ToolbarComponent, selector: "sentinel-toolbar", inputs: ["withBreadcrumbs", "breadcrumbMaxLength", "breadcrumbs", "user", "userProfileRoute", "displayNavToggle", "notifications", "lastNotification", "notificationsRoute", "breadcrumbsDivider"], outputs: ["navToggle", "refreshNotifications", "login", "logout"] }, { kind: "component", type: i6.NavComponent, selector: "sentinel-nav", inputs: ["logoSrc", "version", "agendaContainers"], outputs: ["agendaSelected"] }, { kind: "component", type: i6.ScrollContainerComponent, selector: "sentinel-scroll-container" }, { kind: "component", type: i7.MatDrawer, selector: "mat-drawer", inputs: ["position", "mode", "disableClose", "autoFocus", "opened"], outputs: ["openedChange", "opened", "openedStart", "closed", "closedStart", "positionChanged"], exportAs: ["matDrawer"] }, { kind: "component", type: i7.MatDrawerContainer, selector: "mat-drawer-container", inputs: ["autosize", "hasBackdrop"], outputs: ["backdropClick"], exportAs: ["matDrawerContainer"] }, { kind: "component", type: i7.MatDrawerContent, selector: "mat-drawer-content" }, { kind: "component", type: i8.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { kind: "component", type: i9.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { kind: "component", type: i4.SidebarPageLayoutComponent, selector: "sentinel-sidebar-page-layout", inputs: ["alwaysDisplaySidebar"] }, { kind: "pipe", type: i5.AsyncPipe, name: "async" }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelLayout1Component, decorators: [{
            type: Component,
            args: [{ selector: 'sentinel-layout1', changeDetection: ChangeDetectionStrategy.OnPush, template: "<mat-drawer-container autosize>\n  <mat-drawer\n    #drawer\n    [mode]=\"(navBarState.isSmallView$ | async) ? 'over' : 'side'\"\n    [opened]=\"(navBarState.state$ | async) === 'expanded'\"\n  >\n    <div *ngIf=\"navBarState.isSmallView$ | async\" class=\"nav-controls\">\n      <button mat-icon-button (click)=\"navBarState.toggleState()\">\n        <mat-icon>close</mat-icon>\n      </button>\n    </div>\n    <div class=\"nav-content\">\n      <sentinel-nav\n        [logoSrc]=\"logoSrc\"\n        [version]=\"version\"\n        [agendaContainers]=\"agendaContainers\"\n        (agendaSelected)=\"onAgendaSelected($event)\"\n      >\n      </sentinel-nav>\n    </div>\n  </mat-drawer>\n  <mat-drawer-content>\n    <sentinel-scroll-container *ngIf=\"displayScrollButtons; else innerContentTemplate\">\n      <ng-container *ngTemplateOutlet=\"innerContentTemplate\"> </ng-container>\n    </sentinel-scroll-container>\n  </mat-drawer-content>\n</mat-drawer-container>\n\n<ng-template #innerContentTemplate>\n  <sentinel-toolbar\n    [withBreadcrumbs]=\"withBreadcrumbs\"\n    [breadcrumbs]=\"breadcrumbs$ | async\"\n    [breadcrumbsDivider]=\"breadcrumbsDivider\"\n    [breadcrumbMaxLength]=\"breadcrumbMaxLength\"\n    [user]=\"user\"\n    [userProfileRoute]=\"userProfileRoute\"\n    [notifications]=\"notifications$ | async\"\n    [lastNotification]=\"lastNotification$ | async\"\n    [notificationsRoute]=\"notificationsRoute\"\n    [displayNavToggle]=\"navBarState.isSmallView$ | async\"\n    (navToggle)=\"navBarState.toggleState()\"\n    (refreshNotifications)=\"onRefreshNotifications()\"\n    (login)=\"onLogin()\"\n    (logout)=\"onLogout()\"\n  >\n    <ng-content select=\"[role=toolbar]\"></ng-content>\n  </sentinel-toolbar>\n  <sentinel-sidebar-page-layout [alwaysDisplaySidebar]=\"alwaysDisplaySidebar\">\n    <sentinel-loading *ngIf=\"withLoading\" [isLoading]=\"isLoading\"></sentinel-loading>\n    <div [ngClass]=\"paddedContent ? 'padded-content' : 'content'\">\n      <ng-content></ng-content>\n    </div>\n  </sentinel-sidebar-page-layout>\n</ng-template>\n", styles: ["mat-drawer-container{min-height:100vh;width:100%}mat-drawer-content{display:flex;flex-direction:column;min-height:100vh}mat-drawer{text-align:center;justify-content:center;width:140px;background-color:#000;background-image:linear-gradient(147deg,#03031F 0%,#141F64 250%)}.nav-content{height:100%;overflow:hidden}.nav-controls{text-align:left;color:#fff}.content{flex:1;padding:0}.padded-content{flex:1;padding:40px}main{display:flex;flex-direction:column}main>*:not(router-outlet){flex:1;display:block}@media (max-width: 748px){mat-drawer{width:100%}}\n"] }]
        }], ctorParameters: function () { return [{ type: i1.NavBarStateService }, { type: i2.Router }, { type: i2.ActivatedRoute }, { type: i3.SentinelNotificationService }, { type: i3.SentinelNotificationApi }, { type: i4.SidebarSizeService }, { type: i1.WindowSizeService }]; }, propDecorators: { drawer: [{
                type: ViewChild,
                args: [MatDrawer, { static: true }]
            }], scrollContainerComponent: [{
                type: ViewChild,
                args: [ScrollContainerComponent]
            }], breadcrumbSelector: [{
                type: Input
            }], withBreadcrumbs: [{
                type: Input
            }], withLoading: [{
                type: Input
            }], isLoading: [{
                type: Input
            }], logoSrc: [{
                type: Input
            }], version: [{
                type: Input
            }], notificationsRoute: [{
                type: Input
            }], userProfileRoute: [{
                type: Input
            }], user: [{
                type: Input
            }], displayScrollButtons: [{
                type: Input
            }], agendaContainers: [{
                type: Input
            }], paddedContent: [{
                type: Input
            }], breadcrumbsDivider: [{
                type: Input
            }], breadcrumbMaxLength: [{
                type: Input
            }], alwaysDisplaySidebar: [{
                type: Input
            }], login: [{
                type: Output
            }], logout: [{
                type: Output
            }], onResize: [{
                type: HostListener,
                args: ['window:resize', ['$event']]
            }] } });

class SentinelLayout1SansProvidersModule {
}
SentinelLayout1SansProvidersModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelLayout1SansProvidersModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
SentinelLayout1SansProvidersModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: SentinelLayout1SansProvidersModule, declarations: [SentinelLayout1Component], imports: [CommonModule, RouterModule, LayoutCommonComponentsSansProvidersModule], exports: [SentinelLayout1Component] });
SentinelLayout1SansProvidersModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelLayout1SansProvidersModule, imports: [CommonModule, RouterModule, LayoutCommonComponentsSansProvidersModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelLayout1SansProvidersModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [SentinelLayout1Component],
                    imports: [CommonModule, RouterModule, LayoutCommonComponentsSansProvidersModule],
                    exports: [SentinelLayout1Component],
                }]
        }] });
/**
 * Module containing imports and components for SentinelLayout1
 */
class SentinelLayout1Module {
}
SentinelLayout1Module.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelLayout1Module, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
SentinelLayout1Module.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: SentinelLayout1Module, imports: [CommonModule, RouterModule, NotificationProvidersModule], exports: [SentinelLayout1SansProvidersModule, NotificationProvidersModule] });
SentinelLayout1Module.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelLayout1Module, imports: [CommonModule, RouterModule, NotificationProvidersModule, SentinelLayout1SansProvidersModule, NotificationProvidersModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelLayout1Module, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule, RouterModule, NotificationProvidersModule],
                    exports: [SentinelLayout1SansProvidersModule, NotificationProvidersModule],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { SentinelLayout1Component, SentinelLayout1Module, SentinelLayout1SansProvidersModule };
//# sourceMappingURL=sentinel-layout-layout1.mjs.map
