import * as i0 from '@angular/core';
import { TemplateRef, Injectable, Directive, Input, Component, ChangeDetectionStrategy, ViewChild, NgModule } from '@angular/core';
import * as i7 from '@angular/cdk/portal';
import { TemplatePortal, ComponentPortal, PortalModule } from '@angular/cdk/portal';
import { BehaviorSubject, combineLatest } from 'rxjs';
import * as i4 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i6 from '@angular/material/sidenav';
import { MatDrawer, MatSidenavModule } from '@angular/material/sidenav';
import { distinctUntilChanged, shareReplay, map, tap, delay } from 'rxjs/operators';
import * as i1 from '@sentinel/layout';
import * as i3 from '@angular/material/tooltip';
import { MatTooltipModule } from '@angular/material/tooltip';
import * as i4$1 from '@angular/material/button';
import { MatButtonModule } from '@angular/material/button';
import * as i5 from '@angular/material/icon';
import { MatIconModule } from '@angular/material/icon';
import * as i8 from '@sentinel/common';
import { SLetModule } from '@sentinel/common';

class ContextSidebarService {
    constructor() {
        this.panelPortalSubject$ = new BehaviorSubject(null);
        this.panelPortal$ = this.panelPortalSubject$.asObservable();
    }
    /** Sets the view container ref needed for {@link #setPanelContent}. */
    setViewContainerRef(vcr) {
        this.viewContainerRef = vcr;
        if (this.templateRefWaitingForVcrInit) {
            this.panelPortalSubject$.next(new TemplatePortal(this.templateRefWaitingForVcrInit, this.viewContainerRef));
            this.templateRefWaitingForVcrInit = undefined;
        }
    }
    /** Sets the panel portal to the specified portal. */
    setPanelPortal(panelPortal) {
        this.panelPortalSubject$.next(panelPortal);
    }
    /**
     * Sets the panel content.
     * @param componentOrTemplateRef The component/template reference used.
     */
    setPanelContent(componentOrTemplateRef) {
        if (componentOrTemplateRef instanceof TemplateRef) {
            if (this.viewContainerRef) {
                this.panelPortalSubject$.next(new TemplatePortal(componentOrTemplateRef, this.viewContainerRef));
            }
            else {
                this.templateRefWaitingForVcrInit = componentOrTemplateRef; // in cases where panel content is set before vcr initialization
            }
        }
        else {
            this.panelPortalSubject$.next(new ComponentPortal(componentOrTemplateRef));
        }
    }
    /** Resets the current panel portal. */
    clearPanelPortal() {
        this.sidebar?.close();
        this.panelPortalSubject$.next(null);
    }
    /** Opens the panel with optionally a portal to be set. */
    open(portal) {
        if (portal) {
            this.panelPortalSubject$.next(portal);
        }
        this.sidebar?.open();
    }
    /** Toggles the panel. */
    toggle() {
        this.sidebar?.toggle();
    }
    /** Closes the panel. */
    close() {
        this.sidebar?.close();
    }
}
ContextSidebarService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: ContextSidebarService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
ContextSidebarService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: ContextSidebarService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: ContextSidebarService, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }] });

class ContextSidebarContentDirective {
    constructor(sidebarService) {
        this.sidebarService = sidebarService;
    }
    set sentinelContextSidebarTemplate(templateRef) {
        this._template = templateRef;
        this.sidebarService.setPanelContent(templateRef);
    }
    get template() {
        return this._template;
    }
    ngOnDestroy() {
        this.sidebarService.clearPanelPortal();
    }
}
ContextSidebarContentDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: ContextSidebarContentDirective, deps: [{ token: ContextSidebarService }], target: i0.ɵɵFactoryTarget.Directive });
ContextSidebarContentDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.12", type: ContextSidebarContentDirective, selector: "[sentinelContextSidebarTemplate]", inputs: { sentinelContextSidebarTemplate: "sentinelContextSidebarTemplate" }, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: ContextSidebarContentDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[sentinelContextSidebarTemplate]',
                }]
        }], ctorParameters: function () { return [{ type: ContextSidebarService }]; }, propDecorators: { sentinelContextSidebarTemplate: [{
                type: Input
            }] } });

class SidebarStatePreferenceService {
    constructor() {
        this.PREFERENCE_KEY = 'sentinel_layout_sidebar_state';
    }
    get() {
        const item = localStorage.getItem(this.PREFERENCE_KEY);
        return item ? item : undefined;
    }
    set(state) {
        localStorage.setItem(this.PREFERENCE_KEY, state);
    }
    clear() {
        localStorage.removeItem(this.PREFERENCE_KEY);
    }
}
SidebarStatePreferenceService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SidebarStatePreferenceService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
SidebarStatePreferenceService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SidebarStatePreferenceService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SidebarStatePreferenceService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

class SidebarStateService {
    constructor(windowSizeService, statePreferenceService) {
        this.windowSizeService = windowSizeService;
        this.statePreferenceService = statePreferenceService;
        this.stateSubject$ = new BehaviorSubject(this.statePreferenceService.get() ?? 'expanded');
        this.state$ = this.stateSubject$
            .asObservable()
            .pipe(distinctUntilChanged(), shareReplay({ refCount: true }));
        this.sidebarBreakpointsSubject$ = new BehaviorSubject({
            small: 500,
            medium: 1000,
        });
        this.sidebarBreakpoints$ = this.sidebarBreakpointsSubject$.asObservable();
        this.activeBreakpoint$ = combineLatest([this.windowSizeService.size$, this.sidebarBreakpoints$]).pipe(map((values) => this.resolveBreakpoint(values[0].width, values[1])), distinctUntilChanged(), tap((activeBreakpoint) => this.onBreakpointChange(activeBreakpoint)), tap((activeBreakpoint) => (this.lastActiveBreakpoint = activeBreakpoint)));
    }
    geState() {
        return this.stateSubject$.getValue();
    }
    setState(state) {
        this.stateSubject$.next(state);
    }
    toggleState() {
        const activeBreakpoint = this.getActiveBreakpoint();
        const currState = this.stateSubject$.getValue();
        let newState;
        if (activeBreakpoint === 'small') {
            if (currState === 'expanded') {
                newState = 'collapsed';
            }
            else {
                newState = 'expanded';
            }
        }
        else {
            if (currState === 'expanded') {
                newState = 'semi-collapsed';
            }
            else {
                newState = 'expanded';
            }
        }
        this.stateSubject$.next(newState);
        this.statePreferenceService.set(newState);
    }
    getActiveBreakpoint() {
        return this.lastActiveBreakpoint;
    }
    setBreakpoints(breakpoints) {
        this.sidebarBreakpointsSubject$.next(breakpoints);
    }
    onBreakpointChange(breakpoint) {
        if (this.shouldChangeStateOnBreakpointChange(breakpoint)) {
            if (breakpoint === 'small') {
                this.stateSubject$.next('collapsed');
            }
            if (breakpoint === 'medium') {
                this.stateSubject$.next('semi-collapsed');
            }
            if (breakpoint === 'large') {
                this.stateSubject$.next('expanded');
            }
        }
    }
    resolveBreakpoint(windowWidth, breakpoints) {
        if (windowWidth < breakpoints.small) {
            return 'small';
        }
        else if (windowWidth >= breakpoints.small && windowWidth < breakpoints.medium) {
            return 'medium';
        }
        else {
            return 'large';
        }
    }
    shouldChangeStateOnBreakpointChange(breakpoint) {
        const currState = this.stateSubject$.getValue();
        if (breakpoint === 'small' || currState === 'collapsed') {
            // always collapse on small breakpoint and expand when previously collapsed
            return true;
        }
        const userPreference = this.statePreferenceService.get();
        if (breakpoint === 'medium') {
            return userPreference === undefined || !this.isAgainstUserPreference('semi-collapsed', userPreference);
        }
        return userPreference === undefined || !this.isAgainstUserPreference('expanded', userPreference);
    }
    isAgainstUserPreference(state, preference) {
        return ((state === 'semi-collapsed' && preference === 'expanded') ||
            (state === 'expanded' && preference === 'semi-collapsed'));
    }
}
SidebarStateService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SidebarStateService, deps: [{ token: i1.WindowSizeService }, { token: SidebarStatePreferenceService }], target: i0.ɵɵFactoryTarget.Injectable });
SidebarStateService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SidebarStateService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SidebarStateService, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }], ctorParameters: function () { return [{ type: i1.WindowSizeService }, { type: SidebarStatePreferenceService }]; } });

class SidebarSizeService {
    constructor(sidebarState) {
        this.sidebarState = sidebarState;
        this.DEFAULT_WIDTH = 'min(300px, 100vw)';
        this.DEFAULT_SEMI_COLLAPSED_WIDTH = '60px';
        this.DEFAULT_HEIGHT = 'calc(100vh - 90px)';
        this.sidebarWidthSubject$ = new BehaviorSubject({
            expanded: this.DEFAULT_WIDTH,
            semiCollapsed: this.DEFAULT_SEMI_COLLAPSED_WIDTH,
        });
        this.sidebarHeightSubject$ = new BehaviorSubject(this.DEFAULT_HEIGHT);
        this.sidebarHeight$ = this.sidebarHeightSubject$.asObservable();
        this.sidebarWidth$ = combineLatest([this.sidebarState.state$, this.sidebarWidthSubject$]).pipe(map((values) => this.resolveWidth(values[0], values[1])));
    }
    setWidth(width, changeDefault = false) {
        if (changeDefault) {
            this.DEFAULT_WIDTH = width.expanded;
            this.DEFAULT_SEMI_COLLAPSED_WIDTH = width.semiCollapsed;
        }
        this.sidebarWidthSubject$.next(width);
    }
    setHeight(height, changeDefault = false) {
        if (changeDefault) {
            this.DEFAULT_HEIGHT = height;
        }
        this.sidebarHeightSubject$.next(height);
    }
    clearWidth() {
        this.sidebarWidthSubject$.next({ expanded: this.DEFAULT_WIDTH, semiCollapsed: this.DEFAULT_SEMI_COLLAPSED_WIDTH });
    }
    resolveWidth(state, widthOptions) {
        if (state === 'collapsed') {
            return '0px';
        }
        else if (state === 'semi-collapsed') {
            return widthOptions.semiCollapsed;
        }
        else {
            return widthOptions.expanded;
        }
    }
}
SidebarSizeService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SidebarSizeService, deps: [{ token: SidebarStateService }], target: i0.ɵɵFactoryTarget.Injectable });
SidebarSizeService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SidebarSizeService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SidebarSizeService, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }], ctorParameters: function () { return [{ type: SidebarStateService }]; } });

class SidebarToggleComponent {
    constructor(stateService) {
        this.stateService = stateService;
        this.insideSidebar = false;
        this.state$ = this.stateService.state$;
        this.activeBreakpoint$ = this.stateService.activeBreakpoint$;
    }
    toggleSidebar() {
        this.stateService.toggleState();
    }
}
SidebarToggleComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SidebarToggleComponent, deps: [{ token: SidebarStateService }], target: i0.ɵɵFactoryTarget.Component });
SidebarToggleComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: SidebarToggleComponent, selector: "sentinel-sidebar-toggle", inputs: { insideSidebar: "insideSidebar" }, ngImport: i0, template: "<ng-container *ngIf=\"insideSidebar || (activeBreakpoint$ | async) === 'small'\">\n  <button\n    *ngIf=\"state$ | async as state\"\n    mat-icon-button\n    (click)=\"toggleSidebar()\"\n    [matTooltip]=\"state === 'expanded' ? 'Collapse sidebar' : 'Expand sidebar'\"\n  >\n    <mat-icon>{{ state === 'expanded' ? 'chevron_right' : 'chevron_left' }}</mat-icon>\n  </button>\n</ng-container>\n", styles: [""], dependencies: [{ kind: "directive", type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i3.MatTooltip, selector: "[matTooltip]", exportAs: ["matTooltip"] }, { kind: "component", type: i4$1.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { kind: "component", type: i5.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { kind: "pipe", type: i4.AsyncPipe, name: "async" }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SidebarToggleComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sentinel-sidebar-toggle', changeDetection: ChangeDetectionStrategy.OnPush, template: "<ng-container *ngIf=\"insideSidebar || (activeBreakpoint$ | async) === 'small'\">\n  <button\n    *ngIf=\"state$ | async as state\"\n    mat-icon-button\n    (click)=\"toggleSidebar()\"\n    [matTooltip]=\"state === 'expanded' ? 'Collapse sidebar' : 'Expand sidebar'\"\n  >\n    <mat-icon>{{ state === 'expanded' ? 'chevron_right' : 'chevron_left' }}</mat-icon>\n  </button>\n</ng-container>\n" }]
        }], ctorParameters: function () { return [{ type: SidebarStateService }]; }, propDecorators: { insideSidebar: [{
                type: Input
            }] } });

class SidebarPageLayoutComponent {
    constructor(sizeService, stateService, contextService, vcr) {
        this.sizeService = sizeService;
        this.stateService = stateService;
        this.contextService = contextService;
        this.vcr = vcr;
        this.alwaysDisplaySidebar = false;
        this.TRANSITION_LENGTH_MILLIS = 300;
        this.TRANSITION_STYLE = `width ${this.TRANSITION_LENGTH_MILLIS}ms`;
    }
    ngOnInit() {
        this.initSidebarSize();
        this.initSidebarState();
        this.initSidebarContent();
        this.initSidebarBehaviour();
    }
    toggleSidebar() {
        this.stateService.toggleState();
    }
    initSidebarSize() {
        this.width$ = this.sizeService.sidebarWidth$;
        this.height$ = this.sizeService.sidebarHeight$;
    }
    initSidebarState() {
        // force resize on state change so the browser recalculates positioning of page content when width of sidebar changes
        this.state$ = this.stateService.state$.pipe(tap(() => window.dispatchEvent(new Event('resize'))));
        this.activeBreakpoint$ = this.stateService.activeBreakpoint$;
    }
    initSidebarContent() {
        this.selectedPortal$ = this.contextService.panelPortal$;
        this.contextService.sidebar = this.contextSidebar;
        this.contextService.setViewContainerRef(this.vcr);
    }
    initSidebarBehaviour() {
        this.mode$ = this.activeBreakpoint$.pipe(map((breakpoint) => this.resolveSidebarMode(breakpoint)), distinctUntilChanged());
        // need to set margin of sidebar size to page content to display semi-collapsed sidebar properly
        this.contentMargin$ = combineLatest([this.activeBreakpoint$, this.state$, this.width$]).pipe(map((values) => this.resolveContentMargin(values[0], values[1], values[2])), distinctUntilChanged(), delay(this.TRANSITION_LENGTH_MILLIS + 1) // Delay must be larger than the css transition to detect correct margin
        );
    }
    resolveContentMargin(breakpoint, state, sidebarWidth) {
        if (breakpoint === 'large') {
            return sidebarWidth;
        }
        return breakpoint === 'medium' && state === 'semi-collapsed' ? sidebarWidth : '0';
    }
    resolveSidebarMode(breakpoint) {
        return breakpoint === 'large' ? 'side' : 'over';
    }
}
SidebarPageLayoutComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SidebarPageLayoutComponent, deps: [{ token: SidebarSizeService }, { token: SidebarStateService }, { token: ContextSidebarService }, { token: i0.ViewContainerRef }], target: i0.ɵɵFactoryTarget.Component });
SidebarPageLayoutComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: SidebarPageLayoutComponent, selector: "sentinel-sidebar-page-layout", inputs: { alwaysDisplaySidebar: "alwaysDisplaySidebar" }, viewQueries: [{ propertyName: "contextSidebar", first: true, predicate: MatDrawer, descendants: true, static: true }], ngImport: i0, template: "<ng-container *sLet=\"selectedPortal$ | async as portal\">\n  <mat-drawer-container\n    [hasBackdrop]=\"false\"\n    *ngIf=\"alwaysDisplaySidebar || portal; else pageContent\"\n    [ngStyle]=\"{ height: height$ | async }\"\n  >\n    <mat-drawer\n      *ngIf=\"state$ | async as state\"\n      position=\"end\"\n      [mode]=\"mode$ | async\"\n      [opened]=\"state === 'expanded' || state === 'semi-collapsed'\"\n      [ngClass]=\"state\"\n      [ngStyle]=\"{ width: width$ | async, transition: TRANSITION_STYLE }\"\n    >\n      <div class=\"sidebar-toolbar\" [ngClass]=\"state\">\n        <sentinel-sidebar-toggle [insideSidebar]=\"true\"></sentinel-sidebar-toggle>\n      </div>\n      <ng-template slot=\"sidebar\" [cdkPortalOutlet]=\"portal\"></ng-template>\n    </mat-drawer>\n    <mat-drawer-content [ngStyle]=\"{ marginRight: contentMargin$ | async }\">\n      <ng-container *ngTemplateOutlet=\"pageContent\"></ng-container>\n    </mat-drawer-content>\n  </mat-drawer-container>\n</ng-container>\n\n<ng-template #pageContent>\n  <ng-content></ng-content>\n</ng-template>\n", styles: ["mat-drawer{padding:10px}mat-drawer.semi-collapsed,mat-drawer.collapsed{padding:0}.sidebar-toolbar.semi-collapsed{margin:10px 0;display:flex;justify-content:center;align-items:center}\n"], dependencies: [{ kind: "directive", type: i4.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i4.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: i4.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }, { kind: "component", type: SidebarToggleComponent, selector: "sentinel-sidebar-toggle", inputs: ["insideSidebar"] }, { kind: "component", type: i6.MatDrawer, selector: "mat-drawer", inputs: ["position", "mode", "disableClose", "autoFocus", "opened"], outputs: ["openedChange", "opened", "openedStart", "closed", "closedStart", "positionChanged"], exportAs: ["matDrawer"] }, { kind: "component", type: i6.MatDrawerContainer, selector: "mat-drawer-container", inputs: ["autosize", "hasBackdrop"], outputs: ["backdropClick"], exportAs: ["matDrawerContainer"] }, { kind: "component", type: i6.MatDrawerContent, selector: "mat-drawer-content" }, { kind: "directive", type: i7.CdkPortalOutlet, selector: "[cdkPortalOutlet]", inputs: ["cdkPortalOutlet"], outputs: ["attached"], exportAs: ["cdkPortalOutlet"] }, { kind: "directive", type: i8.SLetDirective, selector: "[sLet]", inputs: ["sLet"] }, { kind: "pipe", type: i4.AsyncPipe, name: "async" }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SidebarPageLayoutComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sentinel-sidebar-page-layout', changeDetection: ChangeDetectionStrategy.OnPush, template: "<ng-container *sLet=\"selectedPortal$ | async as portal\">\n  <mat-drawer-container\n    [hasBackdrop]=\"false\"\n    *ngIf=\"alwaysDisplaySidebar || portal; else pageContent\"\n    [ngStyle]=\"{ height: height$ | async }\"\n  >\n    <mat-drawer\n      *ngIf=\"state$ | async as state\"\n      position=\"end\"\n      [mode]=\"mode$ | async\"\n      [opened]=\"state === 'expanded' || state === 'semi-collapsed'\"\n      [ngClass]=\"state\"\n      [ngStyle]=\"{ width: width$ | async, transition: TRANSITION_STYLE }\"\n    >\n      <div class=\"sidebar-toolbar\" [ngClass]=\"state\">\n        <sentinel-sidebar-toggle [insideSidebar]=\"true\"></sentinel-sidebar-toggle>\n      </div>\n      <ng-template slot=\"sidebar\" [cdkPortalOutlet]=\"portal\"></ng-template>\n    </mat-drawer>\n    <mat-drawer-content [ngStyle]=\"{ marginRight: contentMargin$ | async }\">\n      <ng-container *ngTemplateOutlet=\"pageContent\"></ng-container>\n    </mat-drawer-content>\n  </mat-drawer-container>\n</ng-container>\n\n<ng-template #pageContent>\n  <ng-content></ng-content>\n</ng-template>\n", styles: ["mat-drawer{padding:10px}mat-drawer.semi-collapsed,mat-drawer.collapsed{padding:0}.sidebar-toolbar.semi-collapsed{margin:10px 0;display:flex;justify-content:center;align-items:center}\n"] }]
        }], ctorParameters: function () { return [{ type: SidebarSizeService }, { type: SidebarStateService }, { type: ContextSidebarService }, { type: i0.ViewContainerRef }]; }, propDecorators: { alwaysDisplaySidebar: [{
                type: Input
            }], contextSidebar: [{
                type: ViewChild,
                args: [MatDrawer, { static: true }]
            }] } });

class SentinelSidebarToggleModule {
}
SentinelSidebarToggleModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelSidebarToggleModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
SentinelSidebarToggleModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: SentinelSidebarToggleModule, declarations: [SidebarToggleComponent], imports: [CommonModule, MatTooltipModule, MatButtonModule, MatIconModule], exports: [SidebarToggleComponent] });
SentinelSidebarToggleModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelSidebarToggleModule, imports: [CommonModule, MatTooltipModule, MatButtonModule, MatIconModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelSidebarToggleModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [SidebarToggleComponent],
                    imports: [CommonModule, MatTooltipModule, MatButtonModule, MatIconModule],
                    exports: [SidebarToggleComponent],
                }]
        }] });

class SentinelSidebarCommonModule {
}
SentinelSidebarCommonModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelSidebarCommonModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
SentinelSidebarCommonModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: SentinelSidebarCommonModule, declarations: [ContextSidebarContentDirective], imports: [CommonModule], exports: [ContextSidebarContentDirective] });
SentinelSidebarCommonModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelSidebarCommonModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelSidebarCommonModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [ContextSidebarContentDirective],
                    imports: [CommonModule],
                    exports: [ContextSidebarContentDirective],
                }]
        }] });

class SentinelSidebarPageLayoutModule {
}
SentinelSidebarPageLayoutModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelSidebarPageLayoutModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
SentinelSidebarPageLayoutModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: SentinelSidebarPageLayoutModule, declarations: [SidebarPageLayoutComponent], imports: [CommonModule,
        SentinelSidebarToggleModule,
        SentinelSidebarCommonModule,
        MatSidenavModule,
        PortalModule,
        MatButtonModule,
        MatIconModule,
        MatTooltipModule,
        SLetModule], exports: [SidebarPageLayoutComponent, SentinelSidebarCommonModule] });
SentinelSidebarPageLayoutModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelSidebarPageLayoutModule, imports: [CommonModule,
        SentinelSidebarToggleModule,
        SentinelSidebarCommonModule,
        MatSidenavModule,
        PortalModule,
        MatButtonModule,
        MatIconModule,
        MatTooltipModule,
        SLetModule, SentinelSidebarCommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: SentinelSidebarPageLayoutModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [SidebarPageLayoutComponent],
                    imports: [
                        CommonModule,
                        SentinelSidebarToggleModule,
                        SentinelSidebarCommonModule,
                        MatSidenavModule,
                        PortalModule,
                        MatButtonModule,
                        MatIconModule,
                        MatTooltipModule,
                        SLetModule,
                    ],
                    exports: [SidebarPageLayoutComponent, SentinelSidebarCommonModule],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { ContextSidebarContentDirective, ContextSidebarService, SentinelSidebarCommonModule, SentinelSidebarPageLayoutModule, SentinelSidebarToggleModule, SidebarPageLayoutComponent, SidebarSizeService, SidebarStateService, SidebarToggleComponent };
//# sourceMappingURL=sentinel-layout-sidebar.mjs.map
