import { EventEmitter, OnChanges, OnInit, SimpleChanges } from '@angular/core';
import { UntypedFormArray, UntypedFormGroup } from '@angular/forms';
import { SentinelBaseDirective } from '@sentinel/common';
import { FreeFormItemFormGroup } from './model/free-form-item-form-group';
import { trackByIndex } from '@sentinel/common/utils';
import * as i0 from "@angular/core";
/**
 * Component coupling multiple form inputs with possibility to add more inputs and remove already existing.
 * Suitable for forms where user should input multiple values under some group/topic
 */
export declare class SentinelFreeFormComponent extends SentinelBaseDirective implements OnInit, OnChanges {
    formName: string;
    formPlaceholder: string;
    formData: UntypedFormArray;
    hasHeader: boolean;
    required: boolean;
    /**
     * Emits current state of items on each change of input
     */
    itemsChange: EventEmitter<UntypedFormGroup>;
    trackByFn: typeof trackByIndex;
    freeFormItemFormGroup: FreeFormItemFormGroup;
    get items(): UntypedFormArray;
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Initializes form with default values and placeholders
     */
    initForm(): void;
    /**
     * Adds new input to the form
     */
    addItem(): void;
    /**
     * Removes input
     * @param index index of input in form
     */
    removeItem(index: number): void;
    /**
     * Removes all inputs
     */
    clear(): void;
    onChanged(): void;
    private emitChange;
    static ɵfac: i0.ɵɵFactoryDeclaration<SentinelFreeFormComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SentinelFreeFormComponent, "sentinel-free-form", never, { "formName": "formName"; "formPlaceholder": "formPlaceholder"; "formData": "formData"; "hasHeader": "hasHeader"; "required": "required"; }, { "itemsChange": "itemsChange"; }, never, never, false>;
}
