import { CdkVirtualScrollViewport } from '@angular/cdk/scrolling';
import { EventEmitter, OnChanges, SimpleChanges, TrackByFunction } from '@angular/core';
import { IPaginatedElements, IPaginationEvent } from '@sentinel/common/pagination';
import * as i0 from "@angular/core";
/**
 * Abstract class providing the infinite scroll behaviour for SentinelPaginatedResource. Internally, it expects
 * CdkVirtualScrollViewport to be used in the component's template.
 */
export declare abstract class SentinelInfiniteScrollerDirective<T> implements OnChanges {
    /**
     * Instance of a virtual scroll viewport used in template
     */
    viewport: CdkVirtualScrollViewport;
    /**
     * Current page of the paginated elements to be displayed in the list
     */
    resource: IPaginatedElements<T>;
    /**
     * Attribute name to sort by
     */
    sortByAttribute: string;
    /**
     * Sort direction
     */
    sortDir: 'asc' | 'desc';
    /**
     * True if there was an error getting resource and error message should be displayed
     */
    hasError: boolean;
    /**
     * Pagination page size
     */
    pageSize: number;
    /**
     * True if loading should be displayed, false otherwise. It is changed internally but can be provided
     * from parent component
     */
    isLoading: boolean;
    /**
     * Height (in pxs) of an item displayed in the viewport
     */
    viewPortItemHeight: number;
    /**
     * Maximal height of the viewport
     */
    maxHeight: number;
    /**
     * Function for tracking items in *ngFor. Defaults to tracking by index
     */
    trackByFn?: TrackByFunction<T>;
    /**
     * Emits an event with info about the requested page. The parent component should get the requested data and pass it
     * through resource attribute
     */
    pageChange: EventEmitter<IPaginationEvent>;
    /**
     * True if all resources are displayed (based on pagination and scroll state)
     */
    isEnd: boolean;
    /**
     * All items displayed (current and previous - cached). You should display all of those in your cdk virtual scroll component
     */
    scrollItems: T[];
    /**
     * Current height of the viewport
     */
    viewportHeight: number;
    private cachedPages;
    private lastCursor?;
    /**
     * Updates the state of the component, adds previously not seen resource to the cache.
     * @param changes
     */
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Reloads the page
     */
    reload(): void;
    /**
     * Loads next page
     */
    nextPage(offset: number): void;
    private isAlreadyCached;
    private addPageToCache;
    private refreshCache;
    private isSameAsLastCache;
    private flattenCachedPages;
    private calculateViewportHeight;
    private isFirstPage;
    private isLastPage;
    private onOffsetPaginationReload;
    private onNextOffsetPage;
    private onNextCursorPage;
    static ɵfac: i0.ɵɵFactoryDeclaration<SentinelInfiniteScrollerDirective<any>, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<SentinelInfiniteScrollerDirective<any>, never, never, { "resource": "resource"; "sortByAttribute": "sortByAttribute"; "sortDir": "sortDir"; "hasError": "hasError"; "pageSize": "pageSize"; "isLoading": "isLoading"; "viewPortItemHeight": "viewPortItemHeight"; "maxHeight": "maxHeight"; "trackByFn": "trackByFn"; }, { "pageChange": "pageChange"; }, never, never, false>;
}
