import { EventEmitter, OnChanges, OnInit, SimpleChanges } from '@angular/core';
import { MatDrawer } from '@angular/material/sidenav';
import { ActivatedRoute, Router } from '@angular/router';
import { Observable } from 'rxjs';
import { BaseDirective } from '@sentinel/layout/internal';
import { Agenda, AgendaContainer, SentinelUser, WindowSizeService, NavBarStateService } from '@sentinel/layout';
import { SentinelBreadcrumb } from '@sentinel/layout/breadcrumbs';
import { SentinelNotification, SentinelNotificationApi, SentinelNotificationService } from '@sentinel/layout/notification';
import { ScrollContainerComponent } from '@sentinel/layout/common-components';
import { SidebarSizeService } from '@sentinel/layout/sidebar';
import * as i0 from "@angular/core";
/**
 * Sentinel Layout 1 component. You can use this component as a pre-defined layout for your app.
 */
export declare class SentinelLayout1Component extends BaseDirective implements OnInit, OnChanges {
    navBarState: NavBarStateService;
    private router;
    private activeRoute;
    private notificationService;
    private notificationApi;
    private sidebarSizeService;
    private windowSizeService;
    drawer: MatDrawer;
    scrollContainerComponent: ScrollContainerComponent;
    /**
     * Selector of breadcrumbs from ActiveRoute Data object. Default value is 'breadcrumb'
     */
    breadcrumbSelector?: string;
    /**
     * Decides whether to display two lined toolbar with breadcrumbs or not
     */
    withBreadcrumbs?: boolean;
    /**
     * Decides whether to display loading bar / placeholder below the toolbar
     */
    withLoading?: boolean;
    /**
     * True if loading bar should be shown, false otherwise
     */
    isLoading?: boolean;
    /**
     * Source of the logo show in nav
     */
    logoSrc?: string;
    /**
     * Application version
     */
    version?: string;
    /**
     * Route to notifications overview component
     */
    notificationsRoute?: string;
    /**
     * Optional route to user profile component
     */
    userProfileRoute?: string;
    /**
     * User to display in user menu. No user menu will be displayed if not provided
     */
    user?: SentinelUser;
    /**
     * Displays scroll to top and scroll to bottom buttons if true
     */
    displayScrollButtons?: boolean;
    /**
     * Containers of agendas displayed in sidenav menu
     */
    agendaContainers?: AgendaContainer[];
    /**
     * Whether the content inside the layout should have padding or not
     */
    paddedContent?: boolean;
    /**
     * Character(s) dividing individual breadcrumbs
     */
    breadcrumbsDivider?: string;
    breadcrumbMaxLength: number;
    /**
     * If set to true, always display sidebar even when it has no injected template
     */
    alwaysDisplaySidebar: boolean;
    /**
     * Emitted if login is requested
     */
    login: EventEmitter<void>;
    /**
     * Emitted if logout is requested
     */
    logout: EventEmitter<void>;
    /**
     * Breadcrumbs to display based on current router state
     */
    breadcrumbs$: Observable<SentinelBreadcrumb[]>;
    /**
     * Array of notifications to display in notifications menu
     */
    notifications$: Observable<SentinelNotification[]>;
    /**
     * Last notification emitted
     */
    lastNotification$: Observable<SentinelNotification>;
    constructor(navBarState: NavBarStateService, router: Router, activeRoute: ActivatedRoute, notificationService: SentinelNotificationService, notificationApi: SentinelNotificationApi, sidebarSizeService: SidebarSizeService, windowSizeService: WindowSizeService);
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    private resolveSidebarHeight;
    onResize(event: any): void;
    /**
     * Emits login event
     */
    onLogin(): void;
    /**
     * Emits logout event
     */
    onLogout(): void;
    /**
     * Closes sidenav if user is on mobile device and the menu is displayed in full width
     * @param agenda selected agenda
     */
    onAgendaSelected(agenda: Agenda): void;
    /**
     * Gets new notifications
     */
    onRefreshNotifications(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<SentinelLayout1Component, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SentinelLayout1Component, "sentinel-layout1", never, { "breadcrumbSelector": "breadcrumbSelector"; "withBreadcrumbs": "withBreadcrumbs"; "withLoading": "withLoading"; "isLoading": "isLoading"; "logoSrc": "logoSrc"; "version": "version"; "notificationsRoute": "notificationsRoute"; "userProfileRoute": "userProfileRoute"; "user": "user"; "displayScrollButtons": "displayScrollButtons"; "agendaContainers": "agendaContainers"; "paddedContent": "paddedContent"; "breadcrumbsDivider": "breadcrumbsDivider"; "breadcrumbMaxLength": "breadcrumbMaxLength"; "alwaysDisplaySidebar": "alwaysDisplaySidebar"; }, { "login": "login"; "logout": "logout"; }, never, ["[role=toolbar]", "*"], false>;
}
