import { OAuthService } from 'angular-oauth2-oidc';
import { Observable } from 'rxjs';
import { SentinelAuthProviderConfig } from '../../model/config/sentinel-auth-provider-config';
import { User } from '../../model/user/user';
import { UserRole } from '../../model/user/user-role';
import { SentinelAuthContext } from '../shared/sentinel-auth-context.service';
import { SentinelAuthErrorHandler } from '../shared/sentinel-auth-error-handler.service';
import { SentinelAuthorizationStrategy } from './sentinel-authorization.strategy.service';
import * as i0 from "@angular/core";
/**
 * Main authentication service. Wrapper around OAuthService for OIDC provider login combined with user
 * authorization based on currently injected strategy
 * If used for the first time the correct flow is - configure, login. If it was already
 * configured one time, and oidc client id is stored in localStorage of browser, it is configured automatically.
 * Logout clears configuration and all stored tokens. Service automatically starts silent refreshing service
 * which will check whether OIDC tokens are about to expire and handles acquiring new tokens from OIDC provider silently.
 */
export declare class SentinelAuthService {
    private authContext;
    private errorHandler;
    private authorizationService;
    private oAuthService;
    private activeUser;
    private onActiveUserChangedSubject;
    /**
     * Emits new active user whenever it changes
     */
    activeUser$: Observable<User>;
    constructor(authContext: SentinelAuthContext, errorHandler: SentinelAuthErrorHandler, authorizationService: SentinelAuthorizationStrategy, oAuthService: OAuthService);
    /**
     * Configures the service with OIDC provider config
     * @param providerConfig config of the OIDC provider to use with the service
     */
    configure(providerConfig: SentinelAuthProviderConfig): void;
    /**
     * Logs in with OIDC provider to get token and then tries to authorize using an injected authorization strategy
     */
    login(): Observable<User>;
    /**
     * Logs out active user and clears selected OIDC provider
     */
    logout(): void;
    /**
     * True if user is logged in (authenticated with OIDC provider and authorized (active user with at least one role exists)
     */
    isLoggedIn(): boolean;
    /**
     * Returns logged in user
     */
    getActiveUser(): User;
    /**
     * Returns roles of logged in user
     */
    getRoles(): UserRole[];
    /**
     * Returns authorization header of logged in user
     */
    getActiveUserAuthorizationHeader(): string;
    setActiveUser(user: User): void;
    isAuthenticated(): boolean;
    isAuthorized(): boolean;
    private authenticate;
    private hasSomeRoles;
    static ɵfac: i0.ɵɵFactoryDeclaration<SentinelAuthService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SentinelAuthService>;
}
