# Sentinel List

Kypo list is a component for displaying paginated resources in infinite scroll lists. The component uses Angular CDK Virtual Scroll internally.

## Features

- Infinite scroll behaviour integrated with `PaginatedResource`
- Basic list component
- Selectable list component (radio or checkbox)
- Displays loading
- Displays errors

## Usage

To use in your application:

2. In you module, import `SentinelListModule`
3. In your component

```
@Component({
  ...
})
export class ExampleComponent implements OnInit {

  resource$: Observable<PaginatedResource<ExampleResource>>;
  hasError$: Observable<boolean> = of(false);
  isLoading$: Observable<boolean>;

  constructor(private service: ResourceService) {}

  ngOnInit(): void {
    this.resource$ = this.service.resource$;
    this.isLoading$ = this.service.isLoading$;
    const pagination = new OffsetPagination(0, 100, '', '');
    this.service.get(pagination).pipe(take(1)).subscribe();
  }

  onFetch(pagination: PaginationBaseEvent) {
    this.service.get(pagination).pipe(take(1)).subscribe();
  }
```

4. In your component template

```
  <sentinel-list resourceName="Example resource"
             mode="view"
             pageSize="100"
             [resource]="resource$ | async"
             [hasError]="hasError$ | async"
             [isLoading]="isLoading$ | async"
             (fetch)="onFetch($event)"
             (selectionChange)="onSelectionChange($event)">
  </sentinel-list>
```
