import { EventEmitter } from '@angular/core';
import { MatCheckboxChange } from '@angular/material/checkbox';
import { MatRadioChange } from '@angular/material/radio';
import { SentinelInfiniteScrollerDirective } from '@sentinel/components/infinite-scroll';
import { SentinelListResourceMapping } from './sentinel-list-resource-mapping';
import * as i0 from "@angular/core";
/**
 * Basic component displaying resource in a list with the infinite scroll. It provides selectable behaviour (radio or checkbox)
 */
export declare class SentinelListComponent<T> extends SentinelInfiniteScrollerDirective<T> {
    private readonly DEFAULT_RESOURCE_MAPPING;
    /**
     * Mode of the list
     * View only displays the resource, radio and checkbox adds selection options
     */
    mode: 'view' | 'radio' | 'checkbox';
    /**
     * Name of the resource (title)
     */
    resourceName: string;
    /**
     * Max length of the individual item title/name
     */
    titleMaxLength: any;
    /**
     * Mapping of resource attribute names. Resource is expected to have attributes that can be used as an id and title.
     */
    resourceMapping: SentinelListResourceMapping;
    /**
     * Currently selected resources
     */
    selected: T[];
    /**
     * Emits event on selection change. Emits all currently selected resources
     */
    selectionChange: EventEmitter<T[]>;
    onSelected(selected: T, changeEvent: MatCheckboxChange | MatRadioChange): void;
    private onRadioSelected;
    private onCheckboxSelected;
    static ɵfac: i0.ɵɵFactoryDeclaration<SentinelListComponent<any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SentinelListComponent<any>, "sentinel-list", never, { "mode": "mode"; "resourceName": "resourceName"; "titleMaxLength": "titleMaxLength"; "resourceMapping": "resourceMapping"; "selected": "selected"; }, { "selectionChange": "selectionChange"; }, never, never, false>;
}
