import { ElementRef, EventEmitter, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { Subject } from 'rxjs';
import { MarkdownEditorAction } from './model/actions/markdown-editor-action';
import { ActionService } from './service/action/action.service';
import { MarkdownModeService } from './service/markdown-mode.service';
import { Offset, Pos } from 'caret-pos';
import * as i0 from "@angular/core";
/**
 * Main component of markdown editor
 */
export declare class SentinelMarkdownEditorComponent implements OnInit, OnChanges, OnDestroy {
    actionService: ActionService;
    modeService: MarkdownModeService;
    /**
     * Content of the editor
     */
    content: string;
    /**
     * Watch for keys provided in array
     */
    tagTriggers?: string[];
    /**
     * Subject to dispatch actions from parent component
     */
    actionDispatcher: Subject<MarkdownEditorAction>;
    /**
     * True if the text area should be autosized, false otherwise
     */
    autosize: boolean;
    /**
     * True if the text area should be auto focused, false otherwise
     */
    autofocus: boolean;
    /**
     * True if file upload is supported, false otherwise
     */
    activeFileUpload: boolean;
    /**
     * Event emitter emitting when content changes
     */
    contentChange: EventEmitter<any>;
    /**
     * Emits when one of the watched tag key chars were triggered
     */
    tagTrigger: EventEmitter<string>;
    tagTextChange: EventEmitter<string>;
    positionChange: EventEmitter<Pos>;
    /**
     * Emits file selected to upload
     */
    uploadFiles: EventEmitter<File[]>;
    editorRef: ElementRef;
    files: File[];
    projectedComponentOffset?: Offset;
    private _internalActionSubscription;
    private _externalActionSubscription;
    constructor(actionService: ActionService, modeService: MarkdownModeService);
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    /**
     * Emits changed content
     */
    contentChanged(): void;
    onCaretChange(): void;
    /**
     * Calls service to upload selected files
     */
    onUploadFiles(files?: File[]): void;
    /**
     * Dispatches editor action
     * @param action editor action transforming the current text
     */
    private dispatchAction;
    private getPosition;
    private checkForActiveTag;
    private startsWithTag;
    private findPotentiallyTaggedSubstr;
    private calculateProjectedComponentOffset;
    static ɵfac: i0.ɵɵFactoryDeclaration<SentinelMarkdownEditorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SentinelMarkdownEditorComponent, "sentinel-markdown-editor", never, { "content": "content"; "tagTriggers": "tagTriggers"; "actionDispatcher": "actionDispatcher"; "autosize": "sentinel-markdown-autosize"; "autofocus": "sentinel-markdown-focus"; "activeFileUpload": "sentinel-markdown-file-upload"; }, { "contentChange": "contentChange"; "tagTrigger": "tagTrigger"; "tagTextChange": "tagTextChange"; "positionChange": "positionChange"; "uploadFiles": "uploadFiles"; }, never, ["*"], false>;
}
