import { marked, Renderer, Tokenizer } from 'marked';
import TokenizerExtension = marked.TokenizerExtension;
import RendererExtension = marked.RendererExtension;
import Token = marked.Token;
export declare class MarkedOptions {
    /**
     * A prefix URL for any relative link.
     */
    baseUrl?: string | undefined;
    /**
     * Enable GFM line breaks. This option requires the gfm option to be true.
     */
    breaks?: boolean | undefined;
    /**
     * Add tokenizers and renderers to marked
     */
    extensions?: Array<TokenizerExtension | RendererExtension | (TokenizerExtension & RendererExtension)> | undefined;
    /**
     * Enable GitHub flavored markdown.
     */
    gfm?: boolean | undefined;
    /**
     * Include an id attribute when emitting headings.
     */
    headerIds?: boolean | undefined;
    /**
     * Set the prefix for header tag ids.
     */
    headerPrefix?: string | undefined;
    /**
     * A function to highlight code blocks. The function can either be
     * synchronous (returning a string) or asynchronous (callback invoked
     * with an error if any occurred during highlighting and a string
     * if highlighting was successful)
     */
    highlight?(code: string, lang: string, callback?: (error: any, code?: string) => void): string | void;
    /**
     * Set the prefix for code block classes.
     */
    langPrefix?: string | undefined;
    /**
     * Mangle autolinks (<email@domain.com>).
     */
    mangle?: boolean | undefined;
    /**
     * Conform to obscure parts of markdown.pl as much as possible. Don't fix any of the original markdown bugs or poor behavior.
     */
    pedantic?: boolean | undefined;
    /**
     * Type: object Default: new Renderer()
     *
     * An object containing functions to render tokens to HTML.
     */
    renderer?: Renderer | undefined;
    /**
     * Sanitize the output. Ignore any HTML that has been input.
     */
    sanitize?: boolean | undefined;
    /**
     * Optionally sanitize found HTML with a sanitizer function.
     */
    sanitizer?(html: string): string;
    /**
     * Shows an HTML error message when rendering fails.
     */
    silent?: boolean | undefined;
    /**
     * Use smarter list behavior than the original markdown. May eventually be default with the old behavior moved into pedantic.
     */
    smartLists?: boolean | undefined;
    /**
     * Use "smart" typograhic punctuation for things like quotes and dashes.
     */
    smartypants?: boolean | undefined;
    /**
     * The tokenizer defines how to turn markdown text into tokens.
     */
    tokenizer?: Tokenizer | undefined;
    /**
     * The walkTokens function gets called with every token.
     * Child tokens are called before moving on to sibling tokens.
     * Each token is passed by reference so updates are persisted when passed to the parser.
     * The return value of the function is ignored.
     */
    walkTokens?: ((token: Token) => void) | undefined;
    /**
     * Generate closing slash for self-closing tags (<br/> instead of <br>)
     */
    xhtml?: boolean | undefined;
}
