import { Observable, Subject } from 'rxjs';
import { PaginatedElementsService } from './paginated-elements.service';
import { IPaginatedElements, PaginationBaseEvent } from '@sentinel/common/pagination';
/**
 * Adds polling behaviour to paginated elements service
 */
export declare abstract class PaginatedElementsPollingService<T> extends PaginatedElementsService<T> {
    /**
     * @contract Needs to be updated in onManualResourceRefresh method
     * Last pagination used when requesting new data
     */
    protected lastPagination: PaginationBaseEvent;
    /**
     * Observable triggering retry of polling after it was interrupted (e.g. by error)
     */
    protected retryPolling$: Subject<boolean>;
    private pollPeriod;
    protected constructor(defaultPaginationSize: number, pollPeriod: number);
    /**
     * Performs necessary operations and updates state of the service.
     * @contract Needs to update lastPagination attribute, hasError subject and retry polling
     * if it was previously interrupted
     * @param pagination new requested pagination
     * @param params any other parameters required to update data in your concrete service
     */
    protected onManualResourceRefresh(pagination: PaginationBaseEvent, ...params: any[]): void;
    /**
     * @contract must update resource and hasErrorSubject
     * Implement this to perform a refresh of the resource on polling period
     */
    protected abstract refreshResource(): Observable<IPaginatedElements<T>>;
    /**
     * Creates poll observable using a timer. You can extend the behaviour by piping the observable and applying
     * RxJs operators on it (e.g. takeWhile to stop polling on specific conditions)
     * @param dueTime optionally set a due time when the timer should start. By default it equals to the
     * poll period as it is expected that the first request is made from the service or component
     * using the service (to properly set up pagination and all other possible params like ids etc)
     */
    protected createPoll(dueTime?: number): Observable<IPaginatedElements<T>>;
}
