import { BehaviorSubject, Observable } from 'rxjs';
import { IPaginatedElements } from '@sentinel/common/pagination';
/**
 * Contains subjects and observables typically used when handling paginated data.
 * Subscribe to resource$ to receive latest data updates.
 */
export declare abstract class PaginatedElementsService<T> {
    protected constructor(pageSize?: number);
    protected abstract initSubject(pageSize: number): IPaginatedElements<T>;
    /**
     * True if server returned error response on the latest request, false otherwise
     * Change internally in extending service. Client should subscribe to the observable
     */
    protected hasErrorSubject$: BehaviorSubject<boolean>;
    /**
     * True if server returned error response on the latest request, false otherwise
     * @contract must be updated every time new data are received
     */
    hasError$: Observable<boolean>;
    /**
     * True if response to the latest request was not yet received
     * Change internally in extending service. Client should subscribe to the observable
     */
    protected isLoadingSubject$: BehaviorSubject<boolean>;
    /**
     * True if response to the latest request was not yet received
     * @contract must be updated every time new data are received
     */
    isLoading$: Observable<boolean>;
    /**
     * Paginated resource containing pagination info and retrieved elements of generic type. Change internally in extending service.
     * Client should subscribe to the observable
     * @contract must be updated every time new data are received
     */
    protected resourceSubject$: BehaviorSubject<IPaginatedElements<T>>;
    /**
     * Paginated resource containing pagination info and retrieved elements of generic type. Change internally in extending service.
     * Client should subscribe to the observable
     * @contract must be updated every time new data are received
     */
    resource$: Observable<IPaginatedElements<T>>;
}
