import { ResourceService } from './resource.service';
import { Observable, Subject } from 'rxjs';
/**
 * Adds polling behaviour to resource service
 */
export declare abstract class ResourcePollingService<T> extends ResourceService<T> {
    /**
     * Observable triggering retry of polling after it was interrupted (e.g. by error)
     */
    protected retryPolling$: Subject<boolean>;
    private pollPeriod;
    protected constructor(pollPeriod?: number);
    /**
     * Performs necessary operations and updates state of the service.
     * @contract Needs to update hasError subject and retry polling
     * if it was previously interrupted
     * @param params any other parameters required to update data in your concrete service
     */
    protected onManualResourceRefresh(...params: any[]): void;
    /**
     * @contract must update resource and hasErrorSubject
     * Implement this to perform a refresh of the resource on polling period
     */
    protected abstract refreshResource(): Observable<T>;
    /**
     * Creates poll observable using a timer. You can extend the behaviour by piping the observable and applying
     * RxJs operators on it (e.g. takeWhile to stop polling on specific conditions)
     * @param dueTime optionally set a due time when the timer should start. By default it equals to the
     * poll period as it is expected that the first request is made from the service or component
     * using the service (to properly set up pagination and all other possible params like ids etc)
     */
    protected createPoll(dueTime?: number): Observable<T>;
}
