import { BehaviorSubject, Observable } from 'rxjs';
/**
 * Holds resource state data in an observable.
 * Subscribe to resource$ to receive latest data updates.
 */
export declare abstract class ResourceService<T> {
    /**
     * True if server returned error response on the latest request, false otherwise
     * Change internally in extending service. Client should subscribe to the observable
     */
    protected hasErrorSubject$: BehaviorSubject<boolean>;
    /**
     * True if server returned error response on the latest request, false otherwise
     * @contract must be updated every time new data are received
     */
    hasError$: Observable<boolean>;
    /**
     * True if response to the latest request was not yet received
     * Change internally in extending service. Client should subscribe to the observable
     */
    protected isLoadingSubject$: BehaviorSubject<boolean>;
    /**
     * True if response to the latest request was not yet received
     * @contract must be updated every time new data are received
     */
    isLoading$: Observable<boolean>;
    /**
     * Resource data of generic type. Change internally in extending service.
     * Client should subscribe to the observable
     * @contract must be updated every time new data are received
     */
    protected resourceSubject$: BehaviorSubject<T>;
    /**
     * Resource data of generic type. Change internally in extending service.
     * Client should subscribe to the observable
     * @contract must be updated every time new data are received
     */
    resource$: Observable<T>;
    abstract get(id: number | string): Observable<T>;
}
