import { CdkDragDrop } from '@angular/cdk/drag-drop';
import { EventEmitter, OnChanges, OnInit, SimpleChanges } from '@angular/core';
import { SentinelStepper } from './model/sentinel-stepper';
import { StepperStateChange } from './model/stepper-state-change';
import { StepItem } from './model/step-item';
import { trackById } from '@sentinel/common/utils';
import { StepStateEnum } from './model/step-state.enum';
import * as i0 from "@angular/core";
export declare class SentinelStepperComponent implements OnInit, OnChanges {
    stepperItems: SentinelStepper<StepItem>;
    activeIndex: number;
    draggable: boolean;
    selectable: boolean;
    indexSelected: EventEmitter<number>;
    stepSwapped: EventEmitter<StepperStateChange>;
    selectedStepSwapped: EventEmitter<number>;
    displayScrollbar: boolean;
    activeItemIndex: number;
    stepperData: SentinelStepper<StepItem>;
    trackByFn: typeof trackById;
    StepStateEnum: typeof StepStateEnum;
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Initial settings of stepper. Selects first item as active if stepper is in mode
     * where drag is disabled. Shows scrollbar if stepper has more than 15 items.
     */
    private initStepperSettings;
    /**
     * Optimistic, swap is done by user and it is displayed before swapping on server
     * @param event contains indexes of items which were swapped
     */
    drop(event: CdkDragDrop<string[]>): void;
    /**
     * Swaps items in stepper array
     * @param items array of items
     * @param previousIndex past index from which we want to move item
     * @param currentIndex new index, where we want to move item
     */
    private swapFromTo;
    /**
     * Changes actual item if it changed its position during drag of any items.
     * @param event contains indexes of moved items
     */
    updateActiveItem(event: CdkDragDrop<string[]>): void;
    /**
     * @return true if any of these conditions are met:
     *  1. non-active item with lower index is swapped with active item
     *  2. non-active item with lower index is swapped with non-active item with greater index
     */
    private notActiveLowerItemSwapped;
    /**
     * @return true if any of these conditions are met:
     *  1. non-active item with higher index is swapped with active item
     *  2. non-active item with higher index is swapped with non-active item with lower index
     */
    private notActiveHigherItemSwapped;
    /**
     * @return length of stepper
     */
    private getStepperLength;
    /**
     * Sets stepper item to active state
     * @param index access to proper item in stepper item array
     */
    itemSelected(index: number): void;
    /**
     * Sets item as no longer active element
     * @param index access to proper item in stepper item array
     */
    private itemUnSelected;
    static ɵfac: i0.ɵɵFactoryDeclaration<SentinelStepperComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SentinelStepperComponent, "sentinel-stepper", never, { "stepperItems": "stepperItems"; "activeIndex": "activeIndex"; "draggable": "draggable"; "selectable": "selectable"; }, { "indexSelected": "indexSelected"; "stepSwapped": "stepSwapped"; "selectedStepSwapped": "selectedStepSwapped"; }, never, never, false>;
}
