import { Observable } from 'rxjs';
import { RowAction } from './row-action';
import { Link } from './link';
/**
 * Abstract row class that allows you to set element whose attributes may be displayed. Make sure that any of the attributes
 * you want to display is either primitive data type or has toString() method to display properly. You can add links
 * to specific columns, then the data cell on current row and matched column will be displayed as link inside <a> element
 * instead of simple text.
 */
export declare class Row<T> {
    element: T;
    selectionDisabled$: Observable<boolean>;
    actions: RowAction[];
    clickable: boolean;
    private links;
    constructor(element: T, actions?: RowAction[], clickable?: boolean);
    /**
     * Adds url link to the row. If the url starts with protocol, <a href> is used to navigate, otherwise [routerLink] is used
     * @param columnId id of column to match data cell in which the link should be displayed
     * @param url url link to navigate to on click
     * @param target <a> target attribute
     */
    addLink(columnId: string, url: string, target?: string): void;
    /**
     * Returns link set to data cell in this row and matching column
     * @param columnId id of a column to match with row (to find exact data cell)
     */
    getLink(columnId: string): Link;
}
