# Sentinel Tour guide

## Imports

Import the `SentinelTourGuideModule`. Import `HttpClientModule` and `RouterModule` if not imported yet.

```
@NgModule({
  imports: [
    SentinelTourGuideModule,
    RouterModule,
    HttpClientModule,
  ],
```

Inject the `SentinelTourGuideService` in the component or service from which you want the tour guide to start.
`constructor(private tourService: SentinelTourGuideService) {}`

Calling method `startTour()` will start tour on every visit
`tourService.startTour( *URL link to your json* , *ROUTE - current route of application*, *ELEMENT - ElementRef*)"></button>`

If you want the service to store cookies and automatically open the guide on the first visit then
you should use this method `startTourFirstVisit()`

In order for steps do display correctly it is advised to implement `AfterViewInit` in your component and create
tour inside the `ngAfterViewInit()` or wait until components are loaded.

```
export class AppComponent implements AfterViewInit {
  title = 'my-example-app';
  constructor(private tourService: SentinelTourGuideService, private elementRef: ElementRef) {}

  ngAfterViewInit() {
    this.tourService.startTourFirstVisit( *Url link to your json*, *current route of application*, this.elementRef );
  }
}
```

## Example of JSON configuration file

Place your JSON file in assets/ folder. The JSON should be in this format.

```
{
  "exampleConfig": {
    "anchors": [
      {
        "anchorId": "start.tour",
        "title": "Welcome to the Tour Guide example tour!",
        "content": "Short content",
        "position": {
          "selector": "h1",
          "index": "1"
        }
      },
      {
        "anchorId": "next.tour",
        "title": "Next tour step",
        "content": "Short content",
        "position": {
          "selector": "button",
          "index": "3"
        }
      },
      {
        "anchorId": "end.tour",
        "title": "Last tour step",
        "content": "Element placed at the bottom of the page. Loaded after expansion action.",
        "position": {
          "selector": "button",
          "index": "6"
        }
      }
    ]
  }
}
```

`exampleConfig` Represents tour name. Application supports multiple tours in a single JSON file.

`anchorId` Represents the anchor ID.

`title` Title of the step.

`content` The text used in the step description.

`placement` Consists of `selector` which is html tag that represents step and `index` which is an index to NodeList array.
Can have an optional `nodeName` which is used to identify lazy loaded components and elements. Where `nodeName` represents
`target.nodeName` from `MutationObserver`.

## Classes

### Services

- SentinelTourGuideService - Class gets the Json data and uses them to start the tour. Implementation of the abstract service.
- SentinelTourGuideAbstractService - Abstract class, serves as an interface, contains the following methods:

### Methods

- startTour(url: string, tourIdentifier: string, elementRef: ElementRef) -
  arguments:
  link to the json file, for example 'http://localhost:8080/assets/tour-steps.json'
  tourIdentifier represents an identifier for the tour, because application supports multiple tours in one json file
  elementRef is a wrapper of DOM elements in browser
  Fetches the data from the json server using HttpClient, then uses it to initialize and start the tour.

- startTourFirstVisit(url: string, tourIdentifier: string, elementRef: ElementRef) -
  arguments:
  link to the json file, for example 'http://localhost:8080/assets/tour-steps.json'
  tourIdentifier represents an identifier for the tour, because application supports multiple tours in one json file
  elementRef is a wrapper of DOM elements in browser

      	Checks if a cookie named 'tourGuideCookie' exists. If it exists, does nothing. If it does not, stores the cookie and then starts the tour.

## Dependencies

- [CookieService](https://www.npmjs.com/package/ngx-cookie-service)
