import { ElementRef } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { CookieService } from 'ngx-cookie-service';
import { SentinelTourGuideService } from './sentinel-tour-guide.service';
import { Observable } from 'rxjs';
import { TourInitializationService } from './tour-initialization/tour-initialization.service';
import { MatDialogActions } from '@angular/material/dialog';
import * as i0 from "@angular/core";
export declare class SentinelTourGuideConcreteService extends SentinelTourGuideService {
    private http;
    private cookies;
    private tourLogicService;
    readonly SERVICE_NAME = "TourGuideService";
    readonly JSON_ANCHORS = "anchors";
    readonly COOKIE_NAME: string;
    readonly COOKIE_TEXT = "visited";
    tourActions$: Observable<MatDialogActions>;
    constructor(http: HttpClient, cookies: CookieService, tourLogicService: TourInitializationService);
    /**
     * Method for starting the tour with JSON data from the URL address.
     * @param url URL address of the JSON file from which the data can be fetched from.
     * @param tourIdentifier is used to determine which tour should be loaded from config file. Every tour in config file
     * has unique identifier. If the tour is started on every route change this identifier has to be unique for every tour.
     * Therefore if your route contains specific ids they should be replaced with keyword of your choice. Tour identifier
     * should also match camel Case formatting typical for JSON files.
     * @param elementRef
     */
    startTour(url: string, tourIdentifier: string, elementRef: ElementRef): Observable<MatDialogActions>;
    /**
     * Starts the tour if this is the first visit on the page. In case of subsequents visits does nothing.
     * This method should be used in the NgOnInit method of a component.
     * @param url URL address of the JSON file from which the data can be fetched from.
     * @param tourIdentifier is used to determine which tour should be loaded from config file. Every tour in config file
     * has unique identifier. If the tour is started on every route change this identifier has to be unique for every tour.
     * Therefore if your route contains specific ids they should be replaced with keyword of your choice. Tour identifier
     * should also match camel Case formatting typical for JSON files.
     * @param elementRef
     */
    startTourFirstVisit(url: string, tourIdentifier: string, elementRef: ElementRef): Observable<MatDialogActions>;
    /**
     * Gets data from URL address. Uses HttpClient to get the data. Then uses rxjs operator take to
     * automatically unsubscribe after one emitted value.
     * @param url - URL address of the JSON file from which the data can be fetched from
     * @param tourIdentifier used to determine which tour should be loaded from config file
     */
    private getData;
    private retrieveSteps;
    static ɵfac: i0.ɵɵFactoryDeclaration<SentinelTourGuideConcreteService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SentinelTourGuideConcreteService>;
}
