import { EventEmitter, OnChanges, SimpleChanges } from '@angular/core';
import { SentinelControlItem } from '@sentinel/components/controls';
import { SentinelTable, TableActionEvent, TableLoadEvent } from '@sentinel/components/table';
import { Observable } from 'rxjs';
import { AssignableUser } from './model/assignable-user';
import { DisplayableResource } from './model/displayable-resource';
import { SentinelUserAssignService } from './sentinel-user-assign.service';
import { SentinelResourceSelectorMapping } from '@sentinel/components/resource-selector';
import { SentinelBaseDirective } from '@sentinel/common';
import { trackById } from '@sentinel/common/utils';
import * as i0 from "@angular/core";
/**
 * Reusable component for assignment of users to a resource
 */
export declare class SentinelUserAssignComponent extends SentinelBaseDirective implements OnChanges {
    private usersService;
    /**
     * Resource to which you want to assign
     */
    resource: DisplayableResource;
    /**
     * Id of mat icon displayed in resource card. See @link https://material.io/tools/icons/
     */
    resourceMatIcon: string;
    /**
     * Default pagination size of sentinel table
     */
    defaultPaginationSize: number;
    paginationType: 'cursor' | 'offset';
    /**
     * Custom name for the users which will be assigned to a resource (instead of generic 'Users')
     */
    toAssignTitle: string;
    /**
     * Custom name for the users which are already assigned to a resource (instead of generic 'Users')
     */
    assigneesTitle: string;
    /**
     * Event emitter triggered every time change is made.
     */
    hasUnsavedChanges: EventEmitter<boolean>;
    toAssign: Observable<AssignableUser[]>;
    assignees$: Observable<SentinelTable<AssignableUser>>;
    assigneesTableHasError$: Observable<boolean>;
    isLoadingAssignees$: Observable<boolean>;
    selectedToAssign$: Observable<AssignableUser[]>;
    assignedControls: SentinelControlItem[];
    toAssignControls: SentinelControlItem[];
    searchPlaceholder: string;
    selectorResourceMapping: SentinelResourceSelectorMapping;
    trackByFn: typeof trackById;
    constructor(usersService: SentinelUserAssignService);
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Calls service to get users available to assign
     * @param filterValue filter to apply on users
     */
    getToAssign(filterValue: string): void;
    /**
     * Resolves type of action and calls appropriate handler
     * @param event action event emitted from asignees table
     */
    onAssigneesTableAction(event: TableActionEvent<AssignableUser>): void;
    onControlAction(controlItem: SentinelControlItem): void;
    /**
     * Changes internal state of the selection of users to assign
     * @param selected new state of selection
     */
    onToAssignSelection(selected: AssignableUser[]): void;
    onAssigneesLoadEvent(loadEvent: TableLoadEvent): void;
    /**
     * Changes internal state of the selection of assigned users
     * @param selected new state of selection
     */
    onAssignedSelection(selected: AssignableUser[]): void;
    private init;
    private initTable;
    private initPagination;
    private initAssignedControls;
    private initToAssignControls;
    private initUnsavedChangesEmitter;
    static ɵfac: i0.ɵɵFactoryDeclaration<SentinelUserAssignComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SentinelUserAssignComponent, "sentinel-user-assign", never, { "resource": "resource"; "resourceMatIcon": "resourceMatIcon"; "defaultPaginationSize": "defaultPaginationSize"; "paginationType": "paginationType"; "toAssignTitle": "toAssignTitle"; "assigneesTitle": "assigneesTitle"; }, { "hasUnsavedChanges": "hasUnsavedChanges"; }, never, never, false>;
}
