export type Maybe<T> = T | undefined;
export type InputMaybe<T> = T | null;
export type Exact<T extends { [key: string]: unknown }> = { [K in keyof T]: T[K] };
export type MakeOptional<T, K extends keyof T> = Omit<T, K> & { [SubKey in K]?: Maybe<T[SubKey]> };
export type MakeMaybe<T, K extends keyof T> = Omit<T, K> & { [SubKey in K]: Maybe<T[SubKey]> };
/** All built-in and custom scalars, mapped to their actual values */
export type Scalars = {
  ID: string;
  String: string;
  Boolean: boolean;
  Int: number;
  Float: number;
  /** Date (isoformat) */
  Date: any;
  /** Date with time (isoformat) */
  DateTime: any;
  DatetimeTimestamp: any;
  /** The GenericScalar scalar type represents a generic GraphQL scalar value that could be: List or Object. */
  GenericScalar: any;
  IPv4: any;
  IPv6: any;
  /** String representing JSON */
  JSONString: any;
  LargeJsInt: any;
  UUID: any;
  Upload: any;
};

export type AsnFilter = {
  Name?: InputMaybe<StrFilter>;
  asn?: InputMaybe<IntFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  rir?: InputMaybe<RirFilter>;
  rirId?: InputMaybe<StrawberryIdFilter>;
  siteCount?: InputMaybe<IntFilter>;
  tenant?: InputMaybe<TenantFilter>;
  tenantId?: InputMaybe<StrawberryIdFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type AsnFilterAndFilterEntry = {
  AND: Array<AsnFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type AsnFilterOrFilterEntry = {
  OR: Array<AsnFilter>;
  negate?: Scalars['Boolean'];
};

export type AsnType = AssetFederationBase &
  AssetType & {
    __typename?: 'ASNType';
    Name?: Maybe<Scalars['String']>;
    asn?: Maybe<Scalars['Int']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    lastUpdated?: Maybe<Scalars['DateTime']>;
    netboxUrl?: Maybe<Scalars['String']>;
    rir?: Maybe<RirType>;
    rirId?: Maybe<Scalars['ID']>;
    siteCount?: Maybe<Scalars['Int']>;
    sites: SiteTypeResultSet;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    tenant?: Maybe<TenantType>;
    tenantId?: Maybe<Scalars['ID']>;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
  };

export type AsnTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type AsnTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type AsnTypeResultSet = {
  __typename?: 'ASNTypeResultSet';
  data: Array<AsnType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type AvPair = {
  __typename?: 'AVPair';
  attribute?: Maybe<WellFormedNameAttribute>;
  type?: Maybe<AvPairType>;
  value?: Maybe<Scalars['String']>;
};

export enum AvPairType {
  ANY = 'ANY',
  NA = 'NA',
  VALUE = 'VALUE',
}

export type Activity = {
  content: Scalars['String'];
  created?: Maybe<Scalars['DateTime']>;
  id: Scalars['ID'];
};

export type ActivityFilter1 = {
  content?: InputMaybe<StrFieldFilter>;
  created?: InputMaybe<DateTimeFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  lastUpdated?: InputMaybe<DateTimeFieldFilter>;
  subject?: InputMaybe<StrFieldFilter>;
};

export type ActivityFilter1AndFilterEntry = {
  AND: Array<ActivityFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type ActivityFilter1OrFilterEntry = {
  OR: ActivityFilter1;
  negate?: Scalars['Boolean'];
};

export enum ActivityOrdEnum {
  CONTENT = 'CONTENT',
  CREATED = 'CREATED',
  ID = 'ID',
}

export type ActivityOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: ActivityOrdEnum;
};

export type ActivityPaginated = {
  __typename?: 'ActivityPaginated';
  data: Array<Activity>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type AddressType = {
  __typename?: 'AddressType';
  compressed: Scalars['String'];
  exploded: Scalars['String'];
  isGlobal: Scalars['Boolean'];
  isLinkLocal: Scalars['Boolean'];
  isLoopback: Scalars['Boolean'];
  isMulticast: Scalars['Boolean'];
  isPrivate: Scalars['Boolean'];
  isReserved: Scalars['Boolean'];
  isUnspecified: Scalars['Boolean'];
  maxPrefixlen: Scalars['Int'];
  reversePointer: Scalars['String'];
  version: Scalars['Int'];
};

export type AggregateFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  dateAdded?: InputMaybe<DateTimeFilter>;
  description?: InputMaybe<StrFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  prefix?: InputMaybe<StrFilter>;
  rir?: InputMaybe<RirFilter>;
  rirId?: InputMaybe<StrawberryIdFilter>;
  tenant?: InputMaybe<TenantFilter>;
  tenantId?: InputMaybe<StrawberryIdFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type AggregateFilterAndFilterEntry = {
  AND: Array<AggregateFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type AggregateFilterOrFilterEntry = {
  OR: Array<AggregateFilter>;
  negate?: Scalars['Boolean'];
};

export type AggregateType = AssetFederationBase &
  AssetType & {
    __typename?: 'AggregateType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    dateAdded?: Maybe<Scalars['DateTime']>;
    description?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    lastUpdated?: Maybe<Scalars['DateTime']>;
    netboxUrl?: Maybe<Scalars['String']>;
    prefix?: Maybe<Scalars['String']>;
    rir?: Maybe<RirType>;
    rirId?: Maybe<Scalars['ID']>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    tenant?: Maybe<TenantType>;
    tenantId?: Maybe<Scalars['ID']>;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
  };

export type AggregateTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type AggregateTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type AggregateTypeResultSet = {
  __typename?: 'AggregateTypeResultSet';
  data: Array<AggregateType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type Alias = {
  __typename?: 'Alias';
  groups?: Maybe<TtpGroupNestedList>;
  id: Scalars['ID'];
  malware?: Maybe<MalwareNestedList>;
  tools?: Maybe<ToolNestedList>;
  value: Scalars['String'];
};

export type AliasGroupsArgs = {
  filter?: InputMaybe<Array<TtpGroupFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TtpGroupOrdEnumOrderingEntry>>;
};

export type AliasMalwareArgs = {
  filter?: InputMaybe<Array<MalwareFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<MalwareOrdEnumOrderingEntry>>;
};

export type AliasToolsArgs = {
  filter?: InputMaybe<Array<ToolFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ToolOrdEnumOrderingEntry>>;
};

export type AliasCreate = {
  groups?: InputMaybe<Array<Scalars['ID']>>;
  malware?: InputMaybe<Array<Scalars['ID']>>;
  tools?: InputMaybe<Array<Scalars['ID']>>;
  value: Scalars['String'];
};

export type AliasFilter0 = {
  id?: InputMaybe<StrawberryIdFieldFilter>;
  value?: InputMaybe<StrFieldFilter>;
};

export type AliasFilter0AndFilterEntry = {
  AND: Array<AliasFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type AliasFilter0OrFilterEntry = {
  OR: AliasFilter0;
  negate?: Scalars['Boolean'];
};

export type AliasFilter1 = {
  groups?: InputMaybe<TtpGroupFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  malware?: InputMaybe<MalwareFilter1>;
  tools?: InputMaybe<ToolFilter1>;
  value?: InputMaybe<StrFieldFilter>;
};

export type AliasFilter1AndFilterEntry = {
  AND: Array<AliasFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type AliasFilter1OrFilterEntry = {
  OR: AliasFilter1;
  negate?: Scalars['Boolean'];
};

export type AliasNestedList = {
  __typename?: 'AliasNestedList';
  data: Array<Alias>;
  totalCount: Scalars['Int'];
};

export enum AliasOrdEnum {
  ID = 'ID',
  VALUE = 'VALUE',
}

export type AliasOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: AliasOrdEnum;
};

export type AliasPaginated = {
  __typename?: 'AliasPaginated';
  data: Array<Alias>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type AliasUpdate = {
  groups?: InputMaybe<RelationUpdate>;
  malware?: InputMaybe<RelationUpdate>;
  tools?: InputMaybe<RelationUpdate>;
  value?: InputMaybe<Scalars['String']>;
};

export type AndVertex = {
  __typename?: 'AndVertex';
  orVertex?: Maybe<Array<Maybe<OrVertex>>>;
};

export type AssetCpeVertex = {
  __typename?: 'AssetCPEVertex';
  cpe23fs?: Maybe<Scalars['String']>;
  id?: Maybe<Scalars['String']>;
  targetAVSpecs?: Maybe<Array<Maybe<TargetAvSpecVertex>>>;
  uid?: Maybe<Scalars['String']>;
};

export type AssetFederationBase = {
  assetType: KnownAssetsEnum;
  cases: CaseFederationResult;
  created?: Maybe<Scalars['DateTime']>;
  id: Scalars['ID'];
  lastUpdated?: Maybe<Scalars['DateTime']>;
  tasks: TaskFederationResult;
};

export type AssetFederationBaseCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type AssetFederationBaseTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type AssetFederationBaseFederationResult = {
  __typename?: 'AssetFederationBaseFederationResult';
  data: Array<AssetFederationBase>;
  error?: Maybe<Scalars['String']>;
};

export type AssetFederationBaseFilter = {
  assetId?: InputMaybe<StrawberryIdFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  caseId?: InputMaybe<StrawberryIdFilter>;
  taskId?: InputMaybe<StrawberryIdFilter>;
};

export type AssetFederationBaseFilterAndFilterEntry = {
  AND: Array<AssetFederationBaseFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type AssetFederationBaseFilterOrFilterEntry = {
  OR: Array<AssetFederationBaseFilter>;
  negate?: Scalars['Boolean'];
};

export type AssetFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type AssetFilterAndFilterEntry = {
  AND: Array<AssetFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type AssetFilterOrFilterEntry = {
  OR: Array<AssetFilter>;
  negate?: Scalars['Boolean'];
};

export type AssetInput = {
  assetType: KnownAssetsEnum;
  id: Scalars['ID'];
};

export type AssetType = {
  Name?: Maybe<Scalars['String']>;
  assetType: KnownAssetsEnum;
  created?: Maybe<Scalars['DateTime']>;
  customFieldData: Scalars['JSONString'];
  customFields?: Maybe<Scalars['GenericScalar']>;
  id: Scalars['ID'];
  lastUpdated?: Maybe<Scalars['DateTime']>;
  netboxUrl?: Maybe<Scalars['String']>;
  uniquePrefix: Scalars['String'];
  uuid?: Maybe<Scalars['String']>;
};

export type AssetTypeResultSet = {
  __typename?: 'AssetTypeResultSet';
  data: Array<AssetType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type AssetVertex = {
  __typename?: 'AssetVertex';
  assetCPE?: Maybe<AssetCpeVertex>;
  id?: Maybe<Scalars['String']>;
  name?: Maybe<Scalars['String']>;
  parent?: Maybe<AssetVertex>;
  uid?: Maybe<Scalars['String']>;
};

export type BaseActivity = {
  __typename?: 'BaseActivity';
  content: Scalars['String'];
  created?: Maybe<Scalars['DateTime']>;
  id: Scalars['ID'];
};

export type BaseActivityFilter1 = {
  content?: InputMaybe<StrFieldFilter>;
  created?: InputMaybe<DateTimeFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
};

export type BaseActivityFilter1AndFilterEntry = {
  AND: Array<BaseActivityFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type BaseActivityFilter1OrFilterEntry = {
  OR: BaseActivityFilter1;
  negate?: Scalars['Boolean'];
};

export enum BaseActivityOrdEnum {
  CONTENT = 'CONTENT',
  CREATED = 'CREATED',
  ID = 'ID',
}

export type BaseActivityOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: BaseActivityOrdEnum;
};

export type BaseActivityPaginated = {
  __typename?: 'BaseActivityPaginated';
  data: Array<BaseActivity>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type BaseHashableObservable = HashableObservable &
  Observable & {
    __typename?: 'BaseHashableObservable';
    ctiEntries?: Maybe<ObservableLinkNestedList>;
    description?: Maybe<Scalars['String']>;
    hashes?: Maybe<HashNestedList>;
    id: Scalars['ID'];
    observableType?: Maybe<Scalars['String']>;
    uniqueIdentifier: Scalars['String'];
  };

export type BaseHashableObservableCtiEntriesArgs = {
  filter?: InputMaybe<Array<ObservableLinkFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ObservableLinkOrdEnumOrderingEntry>>;
};

export type BaseHashableObservableHashesArgs = {
  filter?: InputMaybe<Array<HashFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<HashOrdEnumOrderingEntry>>;
};

export type BaseHashableObservableCreate = {
  ctiEntries?: InputMaybe<Array<Scalars['ID']>>;
  description?: InputMaybe<Scalars['String']>;
  hashes?: InputMaybe<Array<Scalars['ID']>>;
};

export type BaseHashableObservableFilter1 = {
  ctiEntries?: InputMaybe<ObservableLinkFilter1>;
  description?: InputMaybe<StrFieldFilter>;
  hashes?: InputMaybe<HashFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  observableType?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type BaseHashableObservableFilter1AndFilterEntry = {
  AND: Array<BaseHashableObservableFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type BaseHashableObservableFilter1OrFilterEntry = {
  OR: BaseHashableObservableFilter1;
  negate?: Scalars['Boolean'];
};

export enum BaseHashableObservableOrdEnum {
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  OBSERVABLE_TYPE = 'OBSERVABLE_TYPE',
  UNIQUE_IDENTIFIER = 'UNIQUE_IDENTIFIER',
}

export type BaseHashableObservableOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: BaseHashableObservableOrdEnum;
};

export type BaseHashableObservablePaginated = {
  __typename?: 'BaseHashableObservablePaginated';
  data: Array<BaseHashableObservable>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type BaseHashableObservableUpdate = {
  ctiEntries?: InputMaybe<RelationUpdate>;
  description?: InputMaybe<Scalars['String']>;
  hashes?: InputMaybe<RelationUpdate>;
};

export type BaseHost = Host &
  Observable & {
    __typename?: 'BaseHost';
    ctiEntries?: Maybe<ObservableLinkNestedList>;
    description?: Maybe<Scalars['String']>;
    emails?: Maybe<EmailAddressNestedList>;
    id: Scalars['ID'];
    observableType?: Maybe<Scalars['String']>;
    uniqueIdentifier: Scalars['String'];
    urls?: Maybe<UrlNestedList>;
  };

export type BaseHostCtiEntriesArgs = {
  filter?: InputMaybe<Array<ObservableLinkFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ObservableLinkOrdEnumOrderingEntry>>;
};

export type BaseHostEmailsArgs = {
  filter?: InputMaybe<Array<EmailAddressFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<EmailAddressOrdEnumOrderingEntry>>;
};

export type BaseHostUrlsArgs = {
  filter?: InputMaybe<Array<UrlFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<UrlOrdEnumOrderingEntry>>;
};

export type BaseHostCreate = {
  ctiEntries?: InputMaybe<Array<Scalars['ID']>>;
  description?: InputMaybe<Scalars['String']>;
  emails?: InputMaybe<Array<Scalars['ID']>>;
  urls?: InputMaybe<Array<Scalars['ID']>>;
};

export type BaseHostFilter1 = {
  ctiEntries?: InputMaybe<ObservableLinkFilter1>;
  description?: InputMaybe<StrFieldFilter>;
  emails?: InputMaybe<EmailAddressFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  observableType?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
  urls?: InputMaybe<UrlFilter1>;
};

export type BaseHostFilter1AndFilterEntry = {
  AND: Array<BaseHostFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type BaseHostFilter1OrFilterEntry = {
  OR: BaseHostFilter1;
  negate?: Scalars['Boolean'];
};

export enum BaseHostOrdEnum {
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  OBSERVABLE_TYPE = 'OBSERVABLE_TYPE',
  UNIQUE_IDENTIFIER = 'UNIQUE_IDENTIFIER',
}

export type BaseHostOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: BaseHostOrdEnum;
};

export type BaseHostPaginated = {
  __typename?: 'BaseHostPaginated';
  data: Array<BaseHost>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type BaseHostUpdate = {
  ctiEntries?: InputMaybe<RelationUpdate>;
  description?: InputMaybe<Scalars['String']>;
  emails?: InputMaybe<RelationUpdate>;
  urls?: InputMaybe<RelationUpdate>;
};

export type BaseObservable = Observable & {
  __typename?: 'BaseObservable';
  ctiEntries?: Maybe<ObservableLinkNestedList>;
  description?: Maybe<Scalars['String']>;
  id: Scalars['ID'];
  observableType?: Maybe<Scalars['String']>;
  uniqueIdentifier: Scalars['String'];
};

export type BaseObservableCtiEntriesArgs = {
  filter?: InputMaybe<Array<ObservableLinkFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ObservableLinkOrdEnumOrderingEntry>>;
};

export type BaseObservableCreate = {
  ctiEntries?: InputMaybe<Array<Scalars['ID']>>;
  description?: InputMaybe<Scalars['String']>;
};

export type BaseObservableFilter1 = {
  ctiEntries?: InputMaybe<ObservableLinkFilter1>;
  description?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  observableType?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type BaseObservableFilter1AndFilterEntry = {
  AND: Array<BaseObservableFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type BaseObservableFilter1OrFilterEntry = {
  OR: BaseObservableFilter1;
  negate?: Scalars['Boolean'];
};

export enum BaseObservableOrdEnum {
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  OBSERVABLE_TYPE = 'OBSERVABLE_TYPE',
  UNIQUE_IDENTIFIER = 'UNIQUE_IDENTIFIER',
}

export type BaseObservableOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: BaseObservableOrdEnum;
};

export type BaseObservablePaginated = {
  __typename?: 'BaseObservablePaginated';
  data: Array<BaseObservable>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type BaseObservableUpdate = {
  ctiEntries?: InputMaybe<RelationUpdate>;
  description?: InputMaybe<Scalars['String']>;
};

export type BaseTaskInputOutput = TaskInputOutput & {
  __typename?: 'BaseTaskInputOutput';
  description?: Maybe<Scalars['String']>;
  id: Scalars['ID'];
  inputOf?: Maybe<Task>;
  outputOf?: Maybe<Task>;
  stringifiedValue?: Maybe<Scalars['String']>;
  type?: Maybe<Scalars['String']>;
};

export type BaseTaskInputOutputCreate = {
  description?: InputMaybe<Scalars['String']>;
  inputOf?: InputMaybe<Scalars['ID']>;
  outputOf?: InputMaybe<Scalars['ID']>;
};

export type BaseTaskInputOutputFilter1 = {
  description?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  inputOf?: InputMaybe<TaskFilter1>;
  outputOf?: InputMaybe<TaskFilter1>;
  type?: InputMaybe<StrFieldFilter>;
};

export type BaseTaskInputOutputFilter1AndFilterEntry = {
  AND: Array<BaseTaskInputOutputFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type BaseTaskInputOutputFilter1OrFilterEntry = {
  OR: BaseTaskInputOutputFilter1;
  negate?: Scalars['Boolean'];
};

export enum BaseTaskInputOutputOrdEnum {
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  TYPE = 'TYPE',
}

export type BaseTaskInputOutputOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: BaseTaskInputOutputOrdEnum;
};

export type BaseTaskInputOutputPaginated = {
  __typename?: 'BaseTaskInputOutputPaginated';
  data: Array<BaseTaskInputOutput>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type BaseTaskInputOutputUpdate = {
  description?: InputMaybe<Scalars['String']>;
  inputOf?: InputMaybe<Scalars['ID']>;
  outputOf?: InputMaybe<Scalars['ID']>;
};

export type BoolFieldFilter = {
  exact?: InputMaybe<Scalars['Boolean']>;
  except_?: InputMaybe<Scalars['Boolean']>;
  isnull?: InputMaybe<Scalars['Boolean']>;
};

export type BoolFilter = {
  exact?: InputMaybe<Scalars['Boolean']>;
  except_?: InputMaybe<Scalars['Boolean']>;
};

export type BoolInputOutput = TaskInputOutput & {
  __typename?: 'BoolInputOutput';
  booleanValue?: Maybe<Scalars['Boolean']>;
  description?: Maybe<Scalars['String']>;
  id: Scalars['ID'];
  inputOf?: Maybe<Task>;
  outputOf?: Maybe<Task>;
  stringifiedValue?: Maybe<Scalars['String']>;
  type?: Maybe<Scalars['String']>;
};

export type BoolInputOutputCreate = {
  booleanValue?: InputMaybe<Scalars['Boolean']>;
  description?: InputMaybe<Scalars['String']>;
  inputOf?: InputMaybe<Scalars['ID']>;
  outputOf?: InputMaybe<Scalars['ID']>;
};

export type BoolInputOutputFilter1 = {
  booleanValue?: InputMaybe<BoolFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  inputOf?: InputMaybe<TaskFilter1>;
  outputOf?: InputMaybe<TaskFilter1>;
  type?: InputMaybe<StrFieldFilter>;
};

export type BoolInputOutputFilter1AndFilterEntry = {
  AND: Array<BoolInputOutputFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type BoolInputOutputFilter1OrFilterEntry = {
  OR: BoolInputOutputFilter1;
  negate?: Scalars['Boolean'];
};

export enum BoolInputOutputOrdEnum {
  BOOLEAN_VALUE = 'BOOLEAN_VALUE',
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  TYPE = 'TYPE',
}

export type BoolInputOutputOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: BoolInputOutputOrdEnum;
};

export type BoolInputOutputPaginated = {
  __typename?: 'BoolInputOutputPaginated';
  data: Array<BoolInputOutput>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type BoolInputOutputUpdate = {
  booleanValue?: InputMaybe<Scalars['Boolean']>;
  description?: InputMaybe<Scalars['String']>;
  inputOf?: InputMaybe<Scalars['ID']>;
  outputOf?: InputMaybe<Scalars['ID']>;
};

export type CtiEntry = {
  __typename?: 'CTIEntry';
  created?: Maybe<Scalars['DateTime']>;
  externalReference?: Maybe<Scalars['String']>;
  id: Scalars['ID'];
  observables?: Maybe<ObservableLinkNestedList>;
  rawData?: Maybe<Scalars['String']>;
  sourceSpecifier?: Maybe<SourceSpecifier>;
  ttps?: Maybe<TtpLinkNestedList>;
};

export type CtiEntryObservablesArgs = {
  filter?: InputMaybe<Array<ObservableLinkFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ObservableLinkOrdEnumOrderingEntry>>;
};

export type CtiEntryTtpsArgs = {
  filter?: InputMaybe<Array<TtpLinkFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TtpLinkOrdEnumOrderingEntry>>;
};

export type CtiEntryCreate = {
  created?: InputMaybe<Scalars['DateTime']>;
  externalReference?: InputMaybe<Scalars['String']>;
  observables?: InputMaybe<Array<Scalars['ID']>>;
  rawData?: InputMaybe<Scalars['String']>;
  sourceSpecifier?: InputMaybe<Scalars['ID']>;
  ttps?: InputMaybe<Array<Scalars['ID']>>;
};

export type CtiEntryFilter0 = {
  created?: InputMaybe<DateTimeFieldFilter>;
  externalReference?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  rawData?: InputMaybe<StrFieldFilter>;
};

export type CtiEntryFilter0AndFilterEntry = {
  AND: Array<CtiEntryFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type CtiEntryFilter0OrFilterEntry = {
  OR: CtiEntryFilter0;
  negate?: Scalars['Boolean'];
};

export type CtiEntryFilter1 = {
  created?: InputMaybe<DateTimeFieldFilter>;
  externalReference?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  observables?: InputMaybe<ObservableLinkFilter1>;
  rawData?: InputMaybe<StrFieldFilter>;
  sourceSpecifier?: InputMaybe<SourceSpecifierFilter1>;
  ttps?: InputMaybe<TtpLinkFilter1>;
};

export type CtiEntryFilter1AndFilterEntry = {
  AND: Array<CtiEntryFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type CtiEntryFilter1OrFilterEntry = {
  OR: CtiEntryFilter1;
  negate?: Scalars['Boolean'];
};

export type CtiEntryInput = {
  externalReference: Scalars['String'];
  rawData?: InputMaybe<Scalars['String']>;
  sourceSpecifierId: Scalars['ID'];
  ttpIds?: InputMaybe<Array<Scalars['String']>>;
};

export type CtiEntryNestedList = {
  __typename?: 'CTIEntryNestedList';
  data: Array<CtiEntry>;
  totalCount: Scalars['Int'];
};

export type CtiEntryNestedListResult = {
  __typename?: 'CTIEntryNestedListResult';
  data?: Maybe<CtiEntry>;
  error?: Maybe<ValidationError>;
};

export enum CtiEntryOrdEnum {
  CREATED = 'CREATED',
  EXTERNAL_REFERENCE = 'EXTERNAL_REFERENCE',
  ID = 'ID',
  RAW_DATA = 'RAW_DATA',
}

export type CtiEntryOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: CtiEntryOrdEnum;
};

export type CtiEntryPaginated = {
  __typename?: 'CTIEntryPaginated';
  data: Array<CtiEntry>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type CtiEntryUpdate = {
  created?: InputMaybe<Scalars['DateTime']>;
  externalReference?: InputMaybe<Scalars['String']>;
  observables?: InputMaybe<RelationUpdate>;
  rawData?: InputMaybe<Scalars['String']>;
  sourceSpecifier?: InputMaybe<Scalars['ID']>;
  ttps?: InputMaybe<RelationUpdate>;
};

export type CableFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  color?: InputMaybe<StrFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  label?: InputMaybe<StrFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  length?: InputMaybe<IntFilter>;
  lengthUnit?: InputMaybe<DcimCableLengthUnitChoicesEnumFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  status?: InputMaybe<DcimCableStatusChoicesEnumFilter>;
  tenant?: InputMaybe<TenantFilter>;
  tenantId?: InputMaybe<StrawberryIdFilter>;
  terminationAId?: InputMaybe<StrawberryIdFilter>;
  terminationAType?: InputMaybe<StrFilter>;
  terminationBId?: InputMaybe<StrawberryIdFilter>;
  terminationBType?: InputMaybe<StrFilter>;
  type?: InputMaybe<DcimCableTypeChoicesEnumFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type CableFilterAndFilterEntry = {
  AND: Array<CableFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type CableFilterOrFilterEntry = {
  OR: Array<CableFilter>;
  negate?: Scalars['Boolean'];
};

export type CableType = AssetFederationBase &
  AssetType & {
    __typename?: 'CableType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    color?: Maybe<Scalars['String']>;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    id: Scalars['ID'];
    label?: Maybe<Scalars['String']>;
    lastUpdated?: Maybe<Scalars['DateTime']>;
    length?: Maybe<Scalars['Int']>;
    lengthUnit?: Maybe<DcimCableLengthUnitChoices>;
    netboxUrl?: Maybe<Scalars['String']>;
    status?: Maybe<DcimCableStatusChoices>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    tenant?: Maybe<TenantType>;
    tenantId?: Maybe<Scalars['ID']>;
    terminationA?: Maybe<AssetType>;
    terminationAId?: Maybe<Scalars['ID']>;
    terminationAType: Scalars['String'];
    terminationB?: Maybe<AssetType>;
    terminationBId?: Maybe<Scalars['ID']>;
    terminationBType: Scalars['String'];
    type?: Maybe<DcimCableTypeChoices>;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
  };

export type CableTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type CableTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type CableTypeResultSet = {
  __typename?: 'CableTypeResultSet';
  data: Array<CableType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type Case = {
  __typename?: 'Case';
  assets: AssetFederationBaseFederationResult;
  assignees?: Maybe<CaseDbUserNestedList>;
  caseFileRoot?: Maybe<Directory>;
  caseIdentifier: Scalars['String'];
  comments?: Maybe<CommentNestedList>;
  created?: Maybe<Scalars['DateTime']>;
  createdBy?: Maybe<CaseDbUser>;
  description?: Maybe<Scalars['String']>;
  dueDate?: Maybe<Scalars['DateTime']>;
  events?: Maybe<EventNestedList>;
  externalReferences?: Maybe<CaseManagementExternalReferenceNestedList>;
  id: Scalars['ID'];
  labels?: Maybe<LabelNestedList>;
  lastUpdated?: Maybe<Scalars['DateTime']>;
  name: Scalars['String'];
  observables: ObservableFederationBaseFederationResult;
  priority: CasePriorityEnum;
  relatedUsers: RelatedUserFederatedTypeFederationResult;
  sourceRelationships?: Maybe<CaseRelationshipNestedList>;
  state?: Maybe<CaseStateEnum>;
  targetRelationships?: Maybe<CaseRelationshipNestedList>;
  ttps: TtpFederationBaseFederationResult;
  type: CaseTypeEnum;
  weight?: Maybe<Scalars['Int']>;
  workflows?: Maybe<WorkflowNestedList>;
};

export type CaseAssetsArgs = {
  filter?: InputMaybe<Array<AssetFederationBaseFilterAndFilterEntry>>;
};

export type CaseAssigneesArgs = {
  filter?: InputMaybe<Array<CaseDbUserFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<CaseDbUserOrdEnumOrderingEntry>>;
};

export type CaseCommentsArgs = {
  filter?: InputMaybe<Array<CommentFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<CommentOrdEnumOrderingEntry>>;
};

export type CaseEventsArgs = {
  filter?: InputMaybe<Array<EventFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<EventOrdEnumOrderingEntry>>;
};

export type CaseExternalReferencesArgs = {
  filter?: InputMaybe<Array<CaseManagementExternalReferenceFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<CaseManagementExternalReferenceOrdEnumOrderingEntry>>;
};

export type CaseLabelsArgs = {
  filter?: InputMaybe<Array<LabelFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<LabelOrdEnumOrderingEntry>>;
};

export type CaseObservablesArgs = {
  filter?: InputMaybe<Array<ObservableFederationBaseFilterAndFilterEntry>>;
};

export type CaseRelatedUsersArgs = {
  filter?: InputMaybe<Array<RelatedUserFederationBaseFilterAndFilterEntry>>;
};

export type CaseSourceRelationshipsArgs = {
  filter?: InputMaybe<Array<CaseRelationshipFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<CaseRelationshipOrdEnumOrderingEntry>>;
};

export type CaseTargetRelationshipsArgs = {
  filter?: InputMaybe<Array<CaseRelationshipFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<CaseRelationshipOrdEnumOrderingEntry>>;
};

export type CaseTtpsArgs = {
  filter?: InputMaybe<Array<TtpFederationBaseFilterAndFilterEntry>>;
};

export type CaseWorkflowsArgs = {
  filter?: InputMaybe<Array<WorkflowFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<WorkflowOrdEnumOrderingEntry>>;
};

export type CaseCreate = {
  assignees?: InputMaybe<Array<Scalars['ID']>>;
  createdBy?: InputMaybe<Scalars['ID']>;
  description?: InputMaybe<Scalars['String']>;
  dueDate?: InputMaybe<Scalars['DateTime']>;
  labels?: InputMaybe<Array<Scalars['ID']>>;
  name: Scalars['String'];
  priority: CasePriorityEnum;
  state?: InputMaybe<CaseStateEnum>;
  type: CaseTypeEnum;
  workflowTemplates?: InputMaybe<Array<WorkflowTemplateInput>>;
};

export type CaseDbRole = {
  __typename?: 'CaseDBRole';
  grantedTo?: Maybe<CaseDbUserNestedList>;
  id: Scalars['ID'];
  name: Scalars['String'];
};

export type CaseDbRoleGrantedToArgs = {
  filter?: InputMaybe<Array<CaseDbUserFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<CaseDbUserOrdEnumOrderingEntry>>;
};

export type CaseDbRoleCreate = {
  grantedTo?: InputMaybe<Array<Scalars['ID']>>;
  name: Scalars['String'];
};

export type CaseDbRoleFilter0 = {
  id?: InputMaybe<StrawberryIdFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
};

export type CaseDbRoleFilter0AndFilterEntry = {
  AND: Array<CaseDbRoleFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type CaseDbRoleFilter0OrFilterEntry = {
  OR: CaseDbRoleFilter0;
  negate?: Scalars['Boolean'];
};

export type CaseDbRoleFilter1 = {
  grantedTo?: InputMaybe<CaseDbUserFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
};

export type CaseDbRoleFilter1AndFilterEntry = {
  AND: Array<CaseDbRoleFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type CaseDbRoleFilter1OrFilterEntry = {
  OR: CaseDbRoleFilter1;
  negate?: Scalars['Boolean'];
};

export type CaseDbRoleNestedList = {
  __typename?: 'CaseDBRoleNestedList';
  data: Array<CaseDbRole>;
  totalCount: Scalars['Int'];
};

export enum CaseDbRoleOrdEnum {
  ID = 'ID',
  NAME = 'NAME',
}

export type CaseDbRoleOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: CaseDbRoleOrdEnum;
};

export type CaseDbRolePaginated = {
  __typename?: 'CaseDBRolePaginated';
  data: Array<CaseDbRole>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type CaseDbRoleUpdate = {
  grantedTo?: InputMaybe<RelationUpdate>;
  name?: InputMaybe<Scalars['String']>;
};

export type CaseDbUser = {
  __typename?: 'CaseDBUser';
  cases?: Maybe<CaseNestedList>;
  comments?: Maybe<CommentNestedList>;
  createdCaseItems?: Maybe<CaseFileItemNestedList>;
  createdCases?: Maybe<CaseNestedList>;
  createdStages?: Maybe<StageNestedList>;
  createdTasks?: Maybe<TaskNestedList>;
  createdWorkflows?: Maybe<WorkflowNestedList>;
  email?: Maybe<Scalars['String']>;
  firstName?: Maybe<Scalars['String']>;
  iconSrc?: Maybe<Scalars['String']>;
  id: Scalars['ID'];
  lastName?: Maybe<Scalars['String']>;
  name: Scalars['String'];
  roles?: Maybe<CaseDbRoleNestedList>;
  stages?: Maybe<StageNestedList>;
  tasks?: Maybe<TaskNestedList>;
  workflows?: Maybe<WorkflowNestedList>;
};

export type CaseDbUserCasesArgs = {
  filter?: InputMaybe<Array<CaseFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<CaseOrdEnumOrderingEntry>>;
};

export type CaseDbUserCommentsArgs = {
  filter?: InputMaybe<Array<CommentFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<CommentOrdEnumOrderingEntry>>;
};

export type CaseDbUserCreatedCaseItemsArgs = {
  filter?: InputMaybe<Array<CaseFileItemFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<CaseFileItemOrdEnumOrderingEntry>>;
};

export type CaseDbUserCreatedCasesArgs = {
  filter?: InputMaybe<Array<CaseFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<CaseOrdEnumOrderingEntry>>;
};

export type CaseDbUserCreatedStagesArgs = {
  filter?: InputMaybe<Array<StageFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<StageOrdEnumOrderingEntry>>;
};

export type CaseDbUserCreatedTasksArgs = {
  filter?: InputMaybe<Array<TaskFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TaskOrdEnumOrderingEntry>>;
};

export type CaseDbUserCreatedWorkflowsArgs = {
  filter?: InputMaybe<Array<WorkflowFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<WorkflowOrdEnumOrderingEntry>>;
};

export type CaseDbUserRolesArgs = {
  filter?: InputMaybe<Array<CaseDbRoleFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<CaseDbRoleOrdEnumOrderingEntry>>;
};

export type CaseDbUserStagesArgs = {
  filter?: InputMaybe<Array<StageFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<StageOrdEnumOrderingEntry>>;
};

export type CaseDbUserTasksArgs = {
  filter?: InputMaybe<Array<TaskFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TaskOrdEnumOrderingEntry>>;
};

export type CaseDbUserWorkflowsArgs = {
  filter?: InputMaybe<Array<WorkflowFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<WorkflowOrdEnumOrderingEntry>>;
};

export type CaseDbUserCreate = {
  cases?: InputMaybe<Array<Scalars['ID']>>;
  comments?: InputMaybe<Array<Scalars['ID']>>;
  createdCaseItems?: InputMaybe<Array<Scalars['ID']>>;
  createdCases?: InputMaybe<Array<Scalars['ID']>>;
  createdStages?: InputMaybe<Array<Scalars['ID']>>;
  createdTasks?: InputMaybe<Array<Scalars['ID']>>;
  createdWorkflows?: InputMaybe<Array<Scalars['ID']>>;
  email?: InputMaybe<Scalars['String']>;
  firstName?: InputMaybe<Scalars['String']>;
  iconSrc?: InputMaybe<Scalars['String']>;
  lastName?: InputMaybe<Scalars['String']>;
  name: Scalars['String'];
  roles?: InputMaybe<Array<Scalars['ID']>>;
  stages?: InputMaybe<Array<Scalars['ID']>>;
  tasks?: InputMaybe<Array<Scalars['ID']>>;
  workflows?: InputMaybe<Array<Scalars['ID']>>;
};

export type CaseDbUserFilter0 = {
  email?: InputMaybe<StrFieldFilter>;
  firstName?: InputMaybe<StrFieldFilter>;
  iconSrc?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  lastName?: InputMaybe<StrFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
};

export type CaseDbUserFilter0AndFilterEntry = {
  AND: Array<CaseDbUserFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type CaseDbUserFilter0OrFilterEntry = {
  OR: CaseDbUserFilter0;
  negate?: Scalars['Boolean'];
};

export type CaseDbUserFilter1 = {
  cases?: InputMaybe<CaseFilter1>;
  comments?: InputMaybe<CommentFilter1>;
  createdCaseItems?: InputMaybe<CaseFileItemFilter1>;
  createdCases?: InputMaybe<CaseFilter1>;
  createdStages?: InputMaybe<StageFilter1>;
  createdTasks?: InputMaybe<TaskFilter1>;
  createdWorkflows?: InputMaybe<WorkflowFilter1>;
  email?: InputMaybe<StrFieldFilter>;
  firstName?: InputMaybe<StrFieldFilter>;
  iconSrc?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  lastName?: InputMaybe<StrFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
  roles?: InputMaybe<CaseDbRoleFilter1>;
  stages?: InputMaybe<StageFilter1>;
  tasks?: InputMaybe<TaskFilter1>;
  workflows?: InputMaybe<WorkflowFilter1>;
};

export type CaseDbUserFilter1AndFilterEntry = {
  AND: Array<CaseDbUserFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type CaseDbUserFilter1OrFilterEntry = {
  OR: CaseDbUserFilter1;
  negate?: Scalars['Boolean'];
};

export type CaseDbUserNestedList = {
  __typename?: 'CaseDBUserNestedList';
  data: Array<CaseDbUser>;
  totalCount: Scalars['Int'];
};

export enum CaseDbUserOrdEnum {
  EMAIL = 'EMAIL',
  FIRST_NAME = 'FIRST_NAME',
  ICON_SRC = 'ICON_SRC',
  ID = 'ID',
  LAST_NAME = 'LAST_NAME',
  NAME = 'NAME',
}

export type CaseDbUserOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: CaseDbUserOrdEnum;
};

export type CaseDbUserPaginated = {
  __typename?: 'CaseDBUserPaginated';
  data: Array<CaseDbUser>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type CaseDbUserUpdate = {
  cases?: InputMaybe<RelationUpdate>;
  comments?: InputMaybe<RelationUpdate>;
  createdCaseItems?: InputMaybe<RelationUpdate>;
  createdCases?: InputMaybe<RelationUpdate>;
  createdStages?: InputMaybe<RelationUpdate>;
  createdTasks?: InputMaybe<RelationUpdate>;
  createdWorkflows?: InputMaybe<RelationUpdate>;
  email?: InputMaybe<Scalars['String']>;
  firstName?: InputMaybe<Scalars['String']>;
  iconSrc?: InputMaybe<Scalars['String']>;
  lastName?: InputMaybe<Scalars['String']>;
  name?: InputMaybe<Scalars['String']>;
  roles?: InputMaybe<RelationUpdate>;
  stages?: InputMaybe<RelationUpdate>;
  tasks?: InputMaybe<RelationUpdate>;
  workflows?: InputMaybe<RelationUpdate>;
};

export type CaseFederationResult = {
  __typename?: 'CaseFederationResult';
  data: Array<Case>;
  error?: Maybe<Scalars['String']>;
};

export type CaseFileItem = CaseFileItemBase | Directory | File;

export type CaseFileItemBase = {
  __typename?: 'CaseFileItemBase';
  created?: Maybe<Scalars['DateTime']>;
  createdBy?: Maybe<CaseDbUser>;
  id: Scalars['ID'];
  name: Scalars['String'];
  parent?: Maybe<Directory>;
  type?: Maybe<Scalars['String']>;
};

export type CaseFileItemBaseCreate = {
  createdBy?: InputMaybe<Scalars['ID']>;
  name: Scalars['String'];
  parent?: InputMaybe<Scalars['ID']>;
};

export type CaseFileItemBaseFilter1 = {
  created?: InputMaybe<DateTimeFieldFilter>;
  createdBy?: InputMaybe<CaseDbUserFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
  parent?: InputMaybe<DirectoryFilter1>;
  type?: InputMaybe<StrFieldFilter>;
};

export type CaseFileItemBaseFilter1AndFilterEntry = {
  AND: Array<CaseFileItemBaseFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type CaseFileItemBaseFilter1OrFilterEntry = {
  OR: CaseFileItemBaseFilter1;
  negate?: Scalars['Boolean'];
};

export enum CaseFileItemBaseOrdEnum {
  CREATED = 'CREATED',
  ID = 'ID',
  NAME = 'NAME',
  TYPE = 'TYPE',
}

export type CaseFileItemBaseOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: CaseFileItemBaseOrdEnum;
};

export type CaseFileItemBasePaginated = {
  __typename?: 'CaseFileItemBasePaginated';
  data: Array<CaseFileItemBase>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type CaseFileItemBaseUpdate = {
  createdBy?: InputMaybe<Scalars['ID']>;
  name?: InputMaybe<Scalars['String']>;
  parent?: InputMaybe<Scalars['ID']>;
};

export type CaseFileItemFilter0 = {
  created?: InputMaybe<DateTimeFieldFilter>;
  displayName?: InputMaybe<StrFieldFilter>;
  extension?: InputMaybe<StrFieldFilter>;
  externalSrc?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
  type?: InputMaybe<StrFieldFilter>;
};

export type CaseFileItemFilter0AndFilterEntry = {
  AND: Array<CaseFileItemFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type CaseFileItemFilter0OrFilterEntry = {
  OR: CaseFileItemFilter0;
  negate?: Scalars['Boolean'];
};

export type CaseFileItemFilter1 = {
  case?: InputMaybe<CaseFilter1>;
  children?: InputMaybe<CaseFileItemFilter1>;
  created?: InputMaybe<DateTimeFieldFilter>;
  createdBy?: InputMaybe<CaseDbUserFilter1>;
  displayName?: InputMaybe<StrFieldFilter>;
  extension?: InputMaybe<StrFieldFilter>;
  externalSrc?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
  parent?: InputMaybe<DirectoryFilter1>;
  type?: InputMaybe<StrFieldFilter>;
};

export type CaseFileItemFilter1AndFilterEntry = {
  AND: Array<CaseFileItemFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type CaseFileItemFilter1OrFilterEntry = {
  OR: CaseFileItemFilter1;
  negate?: Scalars['Boolean'];
};

export type CaseFileItemNestedList = {
  __typename?: 'CaseFileItemNestedList';
  data: Array<CaseFileItem>;
  totalCount: Scalars['Int'];
};

export enum CaseFileItemOrdEnum {
  CREATED = 'CREATED',
  DISPLAY_NAME = 'DISPLAY_NAME',
  EXTENSION = 'EXTENSION',
  EXTERNAL_SRC = 'EXTERNAL_SRC',
  ID = 'ID',
  NAME = 'NAME',
  TYPE = 'TYPE',
}

export type CaseFileItemOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: CaseFileItemOrdEnum;
};

export type CaseFileItemPaginated = {
  __typename?: 'CaseFileItemPaginated';
  data: Array<CaseFileItem>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type CaseFilter = {
  asset?: InputMaybe<AssetFederationBaseFilter>;
  caseId?: InputMaybe<StrawberryIdFilter>;
  observable?: InputMaybe<ObservableFederationBaseFilter>;
  relatedUser?: InputMaybe<RelatedUserFederationBaseFilter>;
  ttp?: InputMaybe<TtpFederationBaseFilter>;
};

export type CaseFilter0 = {
  caseIdentifier?: InputMaybe<StrFieldFilter>;
  created?: InputMaybe<DateTimeFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  dueDate?: InputMaybe<DateTimeFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  lastUpdated?: InputMaybe<DateTimeFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
  priority?: InputMaybe<CasePriorityEnumEnumFieldFilter>;
  state?: InputMaybe<CaseStateEnumEnumFieldFilter>;
  type?: InputMaybe<CaseTypeEnumEnumFieldFilter>;
  weight?: InputMaybe<IntFieldFilter>;
};

export type CaseFilter0AndFilterEntry = {
  AND: Array<CaseFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type CaseFilter0OrFilterEntry = {
  OR: CaseFilter0;
  negate?: Scalars['Boolean'];
};

export type CaseFilter1 = {
  assignees?: InputMaybe<CaseDbUserFilter1>;
  caseFileRoot?: InputMaybe<DirectoryFilter1>;
  caseIdentifier?: InputMaybe<StrFieldFilter>;
  comments?: InputMaybe<CommentFilter1>;
  created?: InputMaybe<DateTimeFieldFilter>;
  createdBy?: InputMaybe<CaseDbUserFilter1>;
  description?: InputMaybe<StrFieldFilter>;
  dueDate?: InputMaybe<DateTimeFieldFilter>;
  events?: InputMaybe<EventFilter1>;
  externalReferences?: InputMaybe<CaseManagementExternalReferenceFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  labels?: InputMaybe<LabelFilter1>;
  lastUpdated?: InputMaybe<DateTimeFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
  priority?: InputMaybe<CasePriorityEnumEnumFieldFilter>;
  sourceRelationships?: InputMaybe<CaseRelationshipFilter1>;
  state?: InputMaybe<CaseStateEnumEnumFieldFilter>;
  targetRelationships?: InputMaybe<CaseRelationshipFilter1>;
  type?: InputMaybe<CaseTypeEnumEnumFieldFilter>;
  weight?: InputMaybe<IntFieldFilter>;
  workflows?: InputMaybe<WorkflowFilter1>;
};

export type CaseFilter1AndFilterEntry = {
  AND: Array<CaseFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type CaseFilter1OrFilterEntry = {
  OR: CaseFilter1;
  negate?: Scalars['Boolean'];
};

export type CaseFilterAndFilterEntry = {
  AND: Array<CaseFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type CaseFilterOrFilterEntry = {
  OR: Array<CaseFilter>;
  negate?: Scalars['Boolean'];
};

export type CaseManagementExternalReference = {
  __typename?: 'CaseManagementExternalReference';
  category: CaseManagementExternalReferenceCategoryEnum;
  created?: Maybe<Scalars['DateTime']>;
  id: Scalars['ID'];
  lastUpdated?: Maybe<Scalars['DateTime']>;
  platform: CaseManagementExternalReferencePlatformEnum;
  relatedCases?: Maybe<CaseNestedList>;
  relatedTasks?: Maybe<TaskNestedList>;
  uniqueIdentifier: Scalars['String'];
  url: Scalars['String'];
};

export type CaseManagementExternalReferenceRelatedCasesArgs = {
  filter?: InputMaybe<Array<CaseFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<CaseOrdEnumOrderingEntry>>;
};

export type CaseManagementExternalReferenceRelatedTasksArgs = {
  filter?: InputMaybe<Array<TaskFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TaskOrdEnumOrderingEntry>>;
};

export enum CaseManagementExternalReferenceCategoryEnum {
  CONVERSATION = 'CONVERSATION',
  INTELLIGENCE = 'INTELLIGENCE',
  TICKET = 'TICKET',
}

export type CaseManagementExternalReferenceCategoryEnumEnumFieldFilter = {
  exact?: InputMaybe<CaseManagementExternalReferenceCategoryEnum>;
  except_?: InputMaybe<CaseManagementExternalReferenceCategoryEnum>;
  in_?: InputMaybe<Array<CaseManagementExternalReferenceCategoryEnum>>;
  isnull?: InputMaybe<Scalars['Boolean']>;
};

export type CaseManagementExternalReferenceCreate = {
  category: CaseManagementExternalReferenceCategoryEnum;
  relatedCases?: InputMaybe<Array<Scalars['ID']>>;
  relatedTasks?: InputMaybe<Array<Scalars['ID']>>;
  url: Scalars['String'];
};

export type CaseManagementExternalReferenceFilter0 = {
  category?: InputMaybe<CaseManagementExternalReferenceCategoryEnumEnumFieldFilter>;
  created?: InputMaybe<DateTimeFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  lastUpdated?: InputMaybe<DateTimeFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
  url?: InputMaybe<StrFieldFilter>;
};

export type CaseManagementExternalReferenceFilter0AndFilterEntry = {
  AND: Array<CaseManagementExternalReferenceFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type CaseManagementExternalReferenceFilter0OrFilterEntry = {
  OR: CaseManagementExternalReferenceFilter0;
  negate?: Scalars['Boolean'];
};

export type CaseManagementExternalReferenceFilter1 = {
  category?: InputMaybe<CaseManagementExternalReferenceCategoryEnumEnumFieldFilter>;
  created?: InputMaybe<DateTimeFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  lastUpdated?: InputMaybe<DateTimeFieldFilter>;
  relatedCases?: InputMaybe<CaseFilter1>;
  relatedTasks?: InputMaybe<TaskFilter1>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
  url?: InputMaybe<StrFieldFilter>;
};

export type CaseManagementExternalReferenceFilter1AndFilterEntry = {
  AND: Array<CaseManagementExternalReferenceFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type CaseManagementExternalReferenceFilter1OrFilterEntry = {
  OR: CaseManagementExternalReferenceFilter1;
  negate?: Scalars['Boolean'];
};

export type CaseManagementExternalReferenceNestedList = {
  __typename?: 'CaseManagementExternalReferenceNestedList';
  data: Array<CaseManagementExternalReference>;
  totalCount: Scalars['Int'];
};

export enum CaseManagementExternalReferenceOrdEnum {
  CATEGORY = 'CATEGORY',
  CREATED = 'CREATED',
  ID = 'ID',
  LAST_UPDATED = 'LAST_UPDATED',
  UNIQUE_IDENTIFIER = 'UNIQUE_IDENTIFIER',
  URL = 'URL',
}

export type CaseManagementExternalReferenceOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: CaseManagementExternalReferenceOrdEnum;
};

export type CaseManagementExternalReferencePaginated = {
  __typename?: 'CaseManagementExternalReferencePaginated';
  data: Array<CaseManagementExternalReference>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export enum CaseManagementExternalReferencePlatformEnum {
  GITHUB = 'GITHUB',
  GITLAB = 'GITLAB',
  JIRA = 'JIRA',
  MATTERMOST = 'MATTERMOST',
  MISP = 'MISP',
  OTHER = 'OTHER',
}

export type CaseManagementExternalReferenceUpdate = {
  category?: InputMaybe<CaseManagementExternalReferenceCategoryEnum>;
  relatedCases?: InputMaybe<RelationUpdate>;
  relatedTasks?: InputMaybe<RelationUpdate>;
  url?: InputMaybe<Scalars['String']>;
};

export type CaseNestedList = {
  __typename?: 'CaseNestedList';
  data: Array<Case>;
  totalCount: Scalars['Int'];
};

export enum CaseOrdEnum {
  CASE_IDENTIFIER = 'CASE_IDENTIFIER',
  CREATED = 'CREATED',
  DESCRIPTION = 'DESCRIPTION',
  DUE_DATE = 'DUE_DATE',
  ID = 'ID',
  LAST_UPDATED = 'LAST_UPDATED',
  NAME = 'NAME',
  PRIORITY = 'PRIORITY',
  STATE = 'STATE',
  TYPE = 'TYPE',
  WEIGHT = 'WEIGHT',
}

export type CaseOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: CaseOrdEnum;
};

export type CasePaginated = {
  __typename?: 'CasePaginated';
  data: Array<Case>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export enum CasePriorityEnum {
  HIGH = 'HIGH',
  LOW = 'LOW',
  MEDIUM = 'MEDIUM',
}

export type CasePriorityEnumEnumFieldFilter = {
  exact?: InputMaybe<CasePriorityEnum>;
  except_?: InputMaybe<CasePriorityEnum>;
  in_?: InputMaybe<Array<CasePriorityEnum>>;
  isnull?: InputMaybe<Scalars['Boolean']>;
};

export type CaseRelationship = {
  __typename?: 'CaseRelationship';
  id: Scalars['ID'];
  source: Case;
  target: Case;
  type: CaseRelationshipTypeEnum;
};

export type CaseRelationshipCreate = {
  source: Scalars['ID'];
  target: Scalars['ID'];
  type: CaseRelationshipTypeEnum;
};

export type CaseRelationshipFilter0 = {
  id?: InputMaybe<StrawberryIdFieldFilter>;
  type?: InputMaybe<CaseRelationshipTypeEnumEnumFieldFilter>;
};

export type CaseRelationshipFilter0AndFilterEntry = {
  AND: Array<CaseRelationshipFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type CaseRelationshipFilter0OrFilterEntry = {
  OR: CaseRelationshipFilter0;
  negate?: Scalars['Boolean'];
};

export type CaseRelationshipFilter1 = {
  id?: InputMaybe<StrawberryIdFieldFilter>;
  source?: InputMaybe<CaseFilter1>;
  target?: InputMaybe<CaseFilter1>;
  type?: InputMaybe<CaseRelationshipTypeEnumEnumFieldFilter>;
};

export type CaseRelationshipFilter1AndFilterEntry = {
  AND: Array<CaseRelationshipFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type CaseRelationshipFilter1OrFilterEntry = {
  OR: CaseRelationshipFilter1;
  negate?: Scalars['Boolean'];
};

export type CaseRelationshipNestedList = {
  __typename?: 'CaseRelationshipNestedList';
  data: Array<CaseRelationship>;
  totalCount: Scalars['Int'];
};

export enum CaseRelationshipOrdEnum {
  ID = 'ID',
  TYPE = 'TYPE',
}

export type CaseRelationshipOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: CaseRelationshipOrdEnum;
};

export type CaseRelationshipPaginated = {
  __typename?: 'CaseRelationshipPaginated';
  data: Array<CaseRelationship>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export enum CaseRelationshipTypeEnum {
  BLOCKS = 'BLOCKS',
  DUPLICATES = 'DUPLICATES',
  FOLLOWS = 'FOLLOWS',
  INCLUDES = 'INCLUDES',
  RELATES = 'RELATES',
  REQUIRES = 'REQUIRES',
}

export type CaseRelationshipTypeEnumEnumFieldFilter = {
  exact?: InputMaybe<CaseRelationshipTypeEnum>;
  except_?: InputMaybe<CaseRelationshipTypeEnum>;
  in_?: InputMaybe<Array<CaseRelationshipTypeEnum>>;
  isnull?: InputMaybe<Scalars['Boolean']>;
};

export type CaseRelationshipUpdate = {
  source?: InputMaybe<Scalars['ID']>;
  target?: InputMaybe<Scalars['ID']>;
  type?: InputMaybe<CaseRelationshipTypeEnum>;
};

export enum CaseStateEnum {
  IN_PROGRESS = 'IN_PROGRESS',
  OPEN = 'OPEN',
  REJECTED = 'REJECTED',
  RESOLVED = 'RESOLVED',
}

export type CaseStateEnumEnumFieldFilter = {
  exact?: InputMaybe<CaseStateEnum>;
  except_?: InputMaybe<CaseStateEnum>;
  in_?: InputMaybe<Array<CaseStateEnum>>;
  isnull?: InputMaybe<Scalars['Boolean']>;
};

export enum CaseTypeEnum {
  ALERT = 'ALERT',
  CAMPAIGN = 'CAMPAIGN',
  INCIDENT = 'INCIDENT',
}

export type CaseTypeEnumEnumFieldFilter = {
  exact?: InputMaybe<CaseTypeEnum>;
  except_?: InputMaybe<CaseTypeEnum>;
  in_?: InputMaybe<Array<CaseTypeEnum>>;
  isnull?: InputMaybe<Scalars['Boolean']>;
};

export type CaseUpdate = {
  assignees?: InputMaybe<RelationUpdate>;
  comments?: InputMaybe<RelationUpdate>;
  createdBy?: InputMaybe<Scalars['ID']>;
  description?: InputMaybe<Scalars['String']>;
  dueDate?: InputMaybe<Scalars['DateTime']>;
  events?: InputMaybe<RelationUpdate>;
  externalReferences?: InputMaybe<RelationUpdate>;
  labels?: InputMaybe<RelationUpdate>;
  name?: InputMaybe<Scalars['String']>;
  priority?: InputMaybe<CasePriorityEnum>;
  sourceRelationships?: InputMaybe<RelationUpdate>;
  state?: InputMaybe<CaseStateEnum>;
  targetRelationships?: InputMaybe<RelationUpdate>;
  type?: InputMaybe<CaseTypeEnum>;
  weight?: InputMaybe<Scalars['Int']>;
  workflows?: InputMaybe<RelationUpdate>;
};

export enum CategoryEnum {
  CIRCUITS = 'CIRCUITS',
  CONNECTIONS = 'CONNECTIONS',
  DEVICES = 'DEVICES',
  IPAM = 'IPAM',
  ORGANIZATION = 'ORGANIZATION',
  OTHER = 'OTHER',
  POWER = 'POWER',
  VIRTUALIZATION = 'VIRTUALIZATION',
  WIRELESS = 'WIRELESS',
}

export type CategoryEnumEnumFilter = {
  exact?: InputMaybe<CategoryEnum>;
  except_?: InputMaybe<CategoryEnum>;
  in_?: InputMaybe<Array<CategoryEnum>>;
};

export type CategoryFilter = {
  assetData?: InputMaybe<MetadataFilter>;
  name?: InputMaybe<CategoryEnumEnumFilter>;
};

export type CategoryFilterAndFilterEntry = {
  AND: Array<CategoryFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type CategoryFilterOrFilterEntry = {
  OR: Array<CategoryFilter>;
  negate?: Scalars['Boolean'];
};

export type CategoryMetadata = {
  __typename?: 'CategoryMetadata';
  assetData: Array<Metadata>;
  name: CategoryEnum;
};

export type CategoryMetadataResultSet = {
  __typename?: 'CategoryMetadataResultSet';
  data: Array<CategoryMetadata>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type CircuitFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  cid?: InputMaybe<StrFilter>;
  comments?: InputMaybe<StrFilter>;
  commitRate?: InputMaybe<IntFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  installDate?: InputMaybe<DateTimeFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  provider?: InputMaybe<ProviderFilter>;
  providerId?: InputMaybe<StrawberryIdFilter>;
  status?: InputMaybe<CircuitsCircuitStatusChoicesEnumFilter>;
  tenant?: InputMaybe<TenantFilter>;
  tenantId?: InputMaybe<StrawberryIdFilter>;
  terminationA?: InputMaybe<CircuitTerminationFilter>;
  terminationAId?: InputMaybe<StrawberryIdFilter>;
  terminationZ?: InputMaybe<CircuitTerminationFilter>;
  terminationZId?: InputMaybe<StrawberryIdFilter>;
  type?: InputMaybe<CircuitTypeFilter>;
  typeId?: InputMaybe<StrawberryIdFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type CircuitFilterAndFilterEntry = {
  AND: Array<CircuitFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type CircuitFilterOrFilterEntry = {
  OR: Array<CircuitFilter>;
  negate?: Scalars['Boolean'];
};

export type CircuitTerminationFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  cable?: InputMaybe<CableFilter>;
  cableId?: InputMaybe<StrawberryIdFilter>;
  circuit?: InputMaybe<CircuitFilter>;
  circuitId?: InputMaybe<StrawberryIdFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  markConnected?: InputMaybe<BoolFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  portSpeed?: InputMaybe<IntFilter>;
  ppInfo?: InputMaybe<StrFilter>;
  providerNetwork?: InputMaybe<ProviderNetworkFilter>;
  providerNetworkId?: InputMaybe<StrawberryIdFilter>;
  site?: InputMaybe<SiteFilter>;
  siteId?: InputMaybe<StrawberryIdFilter>;
  termSide?: InputMaybe<CircuitsCircuitTerminationTermSideChoicesEnumFilter>;
  upstreamSpeed?: InputMaybe<IntFilter>;
  uuid?: InputMaybe<StrFilter>;
  xconnectId?: InputMaybe<StrFilter>;
};

export type CircuitTerminationFilterAndFilterEntry = {
  AND: Array<CircuitTerminationFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type CircuitTerminationFilterOrFilterEntry = {
  OR: Array<CircuitTerminationFilter>;
  negate?: Scalars['Boolean'];
};

export type CircuitTerminationType = AssetFederationBase &
  AssetType & {
    __typename?: 'CircuitTerminationType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cable?: Maybe<CableType>;
    cableId?: Maybe<Scalars['ID']>;
    cases: CaseFederationResult;
    circuit?: Maybe<CircuitType>;
    circuitId?: Maybe<Scalars['ID']>;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    lastUpdated?: Maybe<Scalars['DateTime']>;
    markConnected?: Maybe<Scalars['Boolean']>;
    netboxUrl?: Maybe<Scalars['String']>;
    portSpeed?: Maybe<Scalars['Int']>;
    ppInfo?: Maybe<Scalars['String']>;
    providerNetwork?: Maybe<ProviderNetworkType>;
    providerNetworkId?: Maybe<Scalars['ID']>;
    site?: Maybe<SiteType>;
    siteId?: Maybe<Scalars['ID']>;
    tasks: TaskFederationResult;
    termSide?: Maybe<CircuitsCircuitTerminationTermSideChoices>;
    uniquePrefix: Scalars['String'];
    upstreamSpeed?: Maybe<Scalars['Int']>;
    uuid?: Maybe<Scalars['String']>;
    xconnectId?: Maybe<Scalars['String']>;
  };

export type CircuitTerminationTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type CircuitTerminationTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type CircuitTerminationTypeResultSet = {
  __typename?: 'CircuitTerminationTypeResultSet';
  data: Array<CircuitTerminationType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type CircuitType = AssetFederationBase &
  AssetType & {
    __typename?: 'CircuitType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    cid?: Maybe<Scalars['String']>;
    comments?: Maybe<Scalars['String']>;
    commitRate?: Maybe<Scalars['Int']>;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    installDate?: Maybe<Scalars['DateTime']>;
    lastUpdated?: Maybe<Scalars['DateTime']>;
    netboxUrl?: Maybe<Scalars['String']>;
    provider?: Maybe<ProviderType>;
    providerId?: Maybe<Scalars['ID']>;
    status?: Maybe<CircuitsCircuitStatusChoices>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    tenant?: Maybe<TenantType>;
    tenantId?: Maybe<Scalars['ID']>;
    terminationA?: Maybe<CircuitTerminationType>;
    terminationAId?: Maybe<Scalars['ID']>;
    terminationZ?: Maybe<CircuitTerminationType>;
    terminationZId?: Maybe<Scalars['ID']>;
    terminations: CircuitTerminationTypeResultSet;
    type?: Maybe<CircuitTypeType>;
    typeId?: Maybe<Scalars['ID']>;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
  };

export type CircuitTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type CircuitTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type CircuitTypeFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  circuitsCount?: InputMaybe<IntFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  slug?: InputMaybe<StrFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type CircuitTypeFilterAndFilterEntry = {
  AND: Array<CircuitTypeFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type CircuitTypeFilterOrFilterEntry = {
  OR: Array<CircuitTypeFilter>;
  negate?: Scalars['Boolean'];
};

export type CircuitTypeResultSet = {
  __typename?: 'CircuitTypeResultSet';
  data: Array<CircuitType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type CircuitTypeType = AssetFederationBase &
  AssetType & {
    __typename?: 'CircuitTypeType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    circuits: CircuitTypeResultSet;
    circuitsCount?: Maybe<Scalars['Int']>;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    lastUpdated?: Maybe<Scalars['DateTime']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    slug?: Maybe<Scalars['String']>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
  };

export type CircuitTypeTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type CircuitTypeTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type CircuitTypeTypeResultSet = {
  __typename?: 'CircuitTypeTypeResultSet';
  data: Array<CircuitTypeType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export enum CircuitsCircuitStatusChoices {
  ACTIVE = 'ACTIVE',
  DECOMMISSIONED = 'DECOMMISSIONED',
  DEPROVISIONING = 'DEPROVISIONING',
  OFFLINE = 'OFFLINE',
  PLANNED = 'PLANNED',
  PROVISIONING = 'PROVISIONING',
  UNKNOWN = 'UNKNOWN',
}

export type CircuitsCircuitStatusChoicesEnumFilter = {
  exact?: InputMaybe<CircuitsCircuitStatusChoices>;
  except_?: InputMaybe<CircuitsCircuitStatusChoices>;
  in_?: InputMaybe<Array<CircuitsCircuitStatusChoices>>;
};

export enum CircuitsCircuitTerminationTermSideChoices {
  A = 'A',
  UNKNOWN = 'UNKNOWN',
  Z = 'Z',
}

export type CircuitsCircuitTerminationTermSideChoicesEnumFilter = {
  exact?: InputMaybe<CircuitsCircuitTerminationTermSideChoices>;
  except_?: InputMaybe<CircuitsCircuitTerminationTermSideChoices>;
  in_?: InputMaybe<Array<CircuitsCircuitTerminationTermSideChoices>>;
};

export type ClusterFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  comments?: InputMaybe<StrFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  deviceCount?: InputMaybe<IntFilter>;
  group?: InputMaybe<ClusterGroupFilter>;
  groupId?: InputMaybe<StrawberryIdFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  site?: InputMaybe<SiteFilter>;
  siteId?: InputMaybe<StrawberryIdFilter>;
  tenant?: InputMaybe<TenantFilter>;
  tenantId?: InputMaybe<StrawberryIdFilter>;
  type?: InputMaybe<ClusterTypeFilter>;
  typeId?: InputMaybe<StrawberryIdFilter>;
  uuid?: InputMaybe<StrFilter>;
  virtualmachineCount?: InputMaybe<IntFilter>;
};

export type ClusterFilterAndFilterEntry = {
  AND: Array<ClusterFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type ClusterFilterOrFilterEntry = {
  OR: Array<ClusterFilter>;
  negate?: Scalars['Boolean'];
};

export type ClusterGroupFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  clusterCount?: InputMaybe<IntFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  slug?: InputMaybe<StrFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type ClusterGroupFilterAndFilterEntry = {
  AND: Array<ClusterGroupFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type ClusterGroupFilterOrFilterEntry = {
  OR: Array<ClusterGroupFilter>;
  negate?: Scalars['Boolean'];
};

export type ClusterGroupType = AssetFederationBase &
  AssetType & {
    __typename?: 'ClusterGroupType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    clusterCount?: Maybe<Scalars['Int']>;
    clusters: ClusterTypeResultSet;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    lastUpdated?: Maybe<Scalars['DateTime']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    slug?: Maybe<Scalars['String']>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
  };

export type ClusterGroupTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type ClusterGroupTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type ClusterGroupTypeResultSet = {
  __typename?: 'ClusterGroupTypeResultSet';
  data: Array<ClusterGroupType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type ClusterType = AssetFederationBase &
  AssetType & {
    __typename?: 'ClusterType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    comments?: Maybe<Scalars['String']>;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    deviceCount?: Maybe<Scalars['Int']>;
    devices: DeviceTypeResultSet;
    group?: Maybe<ClusterGroupType>;
    groupId?: Maybe<Scalars['ID']>;
    id: Scalars['ID'];
    lastUpdated?: Maybe<Scalars['DateTime']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    site?: Maybe<SiteType>;
    siteId?: Maybe<Scalars['ID']>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    tenant?: Maybe<TenantType>;
    tenantId?: Maybe<Scalars['ID']>;
    type?: Maybe<ClusterTypeType>;
    typeId?: Maybe<Scalars['ID']>;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
    virtualMachines: VirtualMachineTypeResultSet;
    virtualmachineCount?: Maybe<Scalars['Int']>;
  };

export type ClusterTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type ClusterTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type ClusterTypeFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  clusterCount?: InputMaybe<IntFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  slug?: InputMaybe<StrFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type ClusterTypeFilterAndFilterEntry = {
  AND: Array<ClusterTypeFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type ClusterTypeFilterOrFilterEntry = {
  OR: Array<ClusterTypeFilter>;
  negate?: Scalars['Boolean'];
};

export type ClusterTypeResultSet = {
  __typename?: 'ClusterTypeResultSet';
  data: Array<ClusterType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type ClusterTypeType = AssetFederationBase &
  AssetType & {
    __typename?: 'ClusterTypeType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    clusterCount?: Maybe<Scalars['Int']>;
    clusters: ClusterTypeResultSet;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    lastUpdated?: Maybe<Scalars['DateTime']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    slug?: Maybe<Scalars['String']>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
  };

export type ClusterTypeTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type ClusterTypeTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type ClusterTypeTypeResultSet = {
  __typename?: 'ClusterTypeTypeResultSet';
  data: Array<ClusterTypeType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type Comment = Activity & {
  __typename?: 'Comment';
  author: CaseDbUser;
  case?: Maybe<Case>;
  content: Scalars['String'];
  created?: Maybe<Scalars['DateTime']>;
  id: Scalars['ID'];
  lastUpdated?: Maybe<Scalars['DateTime']>;
  replies?: Maybe<CommentNestedList>;
  replyTo?: Maybe<Comment>;
  subject?: Maybe<Scalars['String']>;
  task?: Maybe<Task>;
};

export type CommentRepliesArgs = {
  filter?: InputMaybe<Array<CommentFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<CommentOrdEnumOrderingEntry>>;
};

export type CommentCreate = {
  author: Scalars['ID'];
  case?: InputMaybe<Scalars['ID']>;
  content: Scalars['String'];
  replies?: InputMaybe<Array<Scalars['ID']>>;
  replyTo?: InputMaybe<Scalars['ID']>;
  subject?: InputMaybe<Scalars['String']>;
  task?: InputMaybe<Scalars['ID']>;
};

export type CommentFilter0 = {
  content?: InputMaybe<StrFieldFilter>;
  created?: InputMaybe<DateTimeFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  lastUpdated?: InputMaybe<DateTimeFieldFilter>;
  subject?: InputMaybe<StrFieldFilter>;
};

export type CommentFilter0AndFilterEntry = {
  AND: Array<CommentFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type CommentFilter0OrFilterEntry = {
  OR: CommentFilter0;
  negate?: Scalars['Boolean'];
};

export type CommentFilter1 = {
  author?: InputMaybe<CaseDbUserFilter1>;
  case?: InputMaybe<CaseFilter1>;
  content?: InputMaybe<StrFieldFilter>;
  created?: InputMaybe<DateTimeFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  lastUpdated?: InputMaybe<DateTimeFieldFilter>;
  replies?: InputMaybe<CommentFilter1>;
  replyTo?: InputMaybe<CommentFilter1>;
  subject?: InputMaybe<StrFieldFilter>;
  task?: InputMaybe<TaskFilter1>;
};

export type CommentFilter1AndFilterEntry = {
  AND: Array<CommentFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type CommentFilter1OrFilterEntry = {
  OR: CommentFilter1;
  negate?: Scalars['Boolean'];
};

export type CommentNestedList = {
  __typename?: 'CommentNestedList';
  data: Array<Comment>;
  totalCount: Scalars['Int'];
};

export enum CommentOrdEnum {
  CONTENT = 'CONTENT',
  CREATED = 'CREATED',
  ID = 'ID',
  LAST_UPDATED = 'LAST_UPDATED',
  SUBJECT = 'SUBJECT',
}

export type CommentOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: CommentOrdEnum;
};

export type CommentPaginated = {
  __typename?: 'CommentPaginated';
  data: Array<Comment>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type CommentUpdate = {
  author?: InputMaybe<Scalars['ID']>;
  case?: InputMaybe<Scalars['ID']>;
  content?: InputMaybe<Scalars['String']>;
  replies?: InputMaybe<RelationUpdate>;
  replyTo?: InputMaybe<Scalars['ID']>;
  subject?: InputMaybe<Scalars['String']>;
  task?: InputMaybe<Scalars['ID']>;
};

export type ConfigInput = {
  negate?: InputMaybe<Scalars['Boolean']>;
  nodes?: InputMaybe<Array<InputMaybe<NodeInput>>>;
  operator?: InputMaybe<ConfigOperator>;
};

export enum ConfigOperator {
  AND = 'AND',
  OR = 'OR',
}

export type ConsolePortFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  cable?: InputMaybe<CableFilter>;
  cableId?: InputMaybe<StrawberryIdFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  device?: InputMaybe<DeviceFilter>;
  deviceId?: InputMaybe<StrawberryIdFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  label?: InputMaybe<StrFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  markConnected?: InputMaybe<BoolFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  speed?: InputMaybe<DcimConsolePortSpeedChoicesEnumFilter>;
  type?: InputMaybe<DcimConsolePortTypeChoicesEnumFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type ConsolePortFilterAndFilterEntry = {
  AND: Array<ConsolePortFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type ConsolePortFilterOrFilterEntry = {
  OR: Array<ConsolePortFilter>;
  negate?: Scalars['Boolean'];
};

export type ConsolePortType = AssetFederationBase &
  AssetType & {
    __typename?: 'ConsolePortType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cable?: Maybe<CableType>;
    cableId?: Maybe<Scalars['ID']>;
    cases: CaseFederationResult;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    device?: Maybe<DeviceType>;
    deviceId?: Maybe<Scalars['ID']>;
    id: Scalars['ID'];
    label?: Maybe<Scalars['String']>;
    lastUpdated?: Maybe<Scalars['DateTime']>;
    markConnected?: Maybe<Scalars['Boolean']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    speed?: Maybe<DcimConsolePortSpeedChoices>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    type?: Maybe<DcimConsolePortTypeChoices>;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
  };

export type ConsolePortTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type ConsolePortTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type ConsolePortTypeResultSet = {
  __typename?: 'ConsolePortTypeResultSet';
  data: Array<ConsolePortType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type ConsoleServerPortFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  cable?: InputMaybe<CableFilter>;
  cableId?: InputMaybe<StrawberryIdFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  device?: InputMaybe<DeviceFilter>;
  deviceId?: InputMaybe<StrawberryIdFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  label?: InputMaybe<StrFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  markConnected?: InputMaybe<BoolFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  speed?: InputMaybe<DcimConsoleServerPortSpeedChoicesEnumFilter>;
  type?: InputMaybe<DcimConsoleServerPortTypeChoicesEnumFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type ConsoleServerPortFilterAndFilterEntry = {
  AND: Array<ConsoleServerPortFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type ConsoleServerPortFilterOrFilterEntry = {
  OR: Array<ConsoleServerPortFilter>;
  negate?: Scalars['Boolean'];
};

export type ConsoleServerPortType = AssetFederationBase &
  AssetType & {
    __typename?: 'ConsoleServerPortType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cable?: Maybe<CableType>;
    cableId?: Maybe<Scalars['ID']>;
    cases: CaseFederationResult;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    device?: Maybe<DeviceType>;
    deviceId?: Maybe<Scalars['ID']>;
    id: Scalars['ID'];
    label?: Maybe<Scalars['String']>;
    lastUpdated?: Maybe<Scalars['DateTime']>;
    markConnected?: Maybe<Scalars['Boolean']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    speed?: Maybe<Scalars['String']>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    type?: Maybe<DcimConsoleServerPortTypeChoices>;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
  };

export type ConsoleServerPortTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type ConsoleServerPortTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type ConsoleServerPortTypeResultSet = {
  __typename?: 'ConsoleServerPortTypeResultSet';
  data: Array<ConsoleServerPortType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type CpeMatchInput = {
  criteria?: InputMaybe<Scalars['String']>;
  matchCriteriaId?: InputMaybe<Scalars['UUID']>;
  versionEndExcluding?: InputMaybe<Scalars['String']>;
  versionEndIncluding?: InputMaybe<Scalars['String']>;
  versionStartExcluding?: InputMaybe<Scalars['String']>;
  versionStartIncluding?: InputMaybe<Scalars['String']>;
  vulnerable?: InputMaybe<Scalars['Boolean']>;
};

export type CreateResult = {
  __typename?: 'CreateResult';
  id: Scalars['ID'];
};

export type CveItemInput = {
  cisaActionDue?: InputMaybe<Scalars['String']>;
  cisaExploitAdd?: InputMaybe<Scalars['String']>;
  cisaRequiredAction?: InputMaybe<Scalars['String']>;
  cisaVulnerabilityName?: InputMaybe<Scalars['String']>;
  configurations?: InputMaybe<Array<InputMaybe<ConfigInput>>>;
  evaluatorComment?: InputMaybe<Scalars['String']>;
  evaluatorImpact?: InputMaybe<Scalars['String']>;
  evaluatorSolution?: InputMaybe<Scalars['String']>;
  id?: InputMaybe<Scalars['String']>;
  lastModified?: InputMaybe<Scalars['String']>;
  published?: InputMaybe<Scalars['String']>;
  sourceIdentifier?: InputMaybe<Scalars['String']>;
  vulnStatus?: InputMaybe<Scalars['String']>;
};

export type CveVertex = {
  __typename?: 'CveVertex';
  cisaActionDue?: Maybe<Scalars['String']>;
  cisaExploitAdd?: Maybe<Scalars['String']>;
  cisaRequiredAction?: Maybe<Scalars['String']>;
  cisaVulnerabilityName?: Maybe<Scalars['String']>;
  evaluatorComment?: Maybe<Scalars['String']>;
  evaluatorImpact?: Maybe<Scalars['String']>;
  evaluatorSolution?: Maybe<Scalars['String']>;
  id?: Maybe<Scalars['String']>;
  lastModified?: Maybe<Scalars['String']>;
  published?: Maybe<Scalars['String']>;
  sourceIdentifier?: Maybe<Scalars['String']>;
  statements?: Maybe<Array<Maybe<StatementVertex>>>;
  uid?: Maybe<Scalars['String']>;
  vulnStatus?: Maybe<Scalars['String']>;
};

export type DataPlatformServiceIpFix = {
  __typename?: 'DataPlatformServiceIPFix';
  applicationid?: Maybe<Scalars['String']>;
  applicationidrev?: Maybe<Scalars['String']>;
  applicationname?: Maybe<Scalars['String']>;
  applicationnamerev?: Maybe<Scalars['String']>;
  bgpdestinationasnumber?: Maybe<Scalars['LargeJsInt']>;
  bgpdestinationasnumberrev?: Maybe<Scalars['LargeJsInt']>;
  bgpsourceasnumber?: Maybe<Scalars['LargeJsInt']>;
  bgpsourceasnumberrev?: Maybe<Scalars['LargeJsInt']>;
  destinationipv4address?: Maybe<Scalars['String']>;
  destinationipv6address?: Maybe<Scalars['String']>;
  destinationtransportport?: Maybe<Scalars['Int']>;
  exporttime?: Maybe<Scalars['LargeJsInt']>;
  flowendmilliseconds?: Maybe<Scalars['LargeJsInt']>;
  flowendmillisecondsrev?: Maybe<Scalars['LargeJsInt']>;
  flowstartmilliseconds?: Maybe<Scalars['LargeJsInt']>;
  flowstartmillisecondsrev?: Maybe<Scalars['LargeJsInt']>;
  icmptypecodeipv4?: Maybe<Scalars['Int']>;
  id: Scalars['ID'];
  ingressinterface?: Maybe<Scalars['LargeJsInt']>;
  ipclassofservice?: Maybe<Scalars['Int']>;
  ipclassofservicerev?: Maybe<Scalars['Int']>;
  ipversion?: Maybe<Scalars['Int']>;
  mplslabelstacksection2?: Maybe<Scalars['String']>;
  mplslabelstacksection2rev?: Maybe<Scalars['String']>;
  mplslabelstacksection3?: Maybe<Scalars['String']>;
  mplslabelstacksection3rev?: Maybe<Scalars['String']>;
  mplslabelstacksection4?: Maybe<Scalars['String']>;
  mplslabelstacksection4rev?: Maybe<Scalars['String']>;
  mplslabelstacksection5?: Maybe<Scalars['String']>;
  mplslabelstacksection5rev?: Maybe<Scalars['String']>;
  mplslabelstacksection6?: Maybe<Scalars['String']>;
  mplslabelstacksection6rev?: Maybe<Scalars['String']>;
  mplslabelstacksection7?: Maybe<Scalars['String']>;
  mplslabelstacksection7rev?: Maybe<Scalars['String']>;
  mplslabelstacksection8?: Maybe<Scalars['String']>;
  mplslabelstacksection8rev?: Maybe<Scalars['String']>;
  mplslabelstacksection9?: Maybe<Scalars['String']>;
  mplslabelstacksection9rev?: Maybe<Scalars['String']>;
  mplslabelstacksection10?: Maybe<Scalars['String']>;
  mplslabelstacksection10rev?: Maybe<Scalars['String']>;
  mplstoplabelstacksection?: Maybe<Scalars['String']>;
  mplstoplabelstacksectionrev?: Maybe<Scalars['String']>;
  msglength?: Maybe<Scalars['Int']>;
  octetdeltacount?: Maybe<Scalars['LargeJsInt']>;
  octetdeltacountrev?: Maybe<Scalars['LargeJsInt']>;
  odid?: Maybe<Scalars['Int']>;
  originalexporteripv6address?: Maybe<Scalars['String']>;
  packetdeltacount?: Maybe<Scalars['LargeJsInt']>;
  packetdeltacountrev?: Maybe<Scalars['LargeJsInt']>;
  protocolidentifier?: Maybe<Scalars['Int']>;
  samplingalgorithm?: Maybe<Scalars['Int']>;
  samplingalgorithmrev?: Maybe<Scalars['Int']>;
  samplinginterval?: Maybe<Scalars['LargeJsInt']>;
  samplingintervalrev?: Maybe<Scalars['LargeJsInt']>;
  seqnumber?: Maybe<Scalars['LargeJsInt']>;
  sourceipv4address?: Maybe<Scalars['String']>;
  sourceipv6address?: Maybe<Scalars['String']>;
  sourcetransportport?: Maybe<Scalars['Int']>;
  srcaddr?: Maybe<Scalars['String']>;
  tcpcontrolbits?: Maybe<Scalars['Int']>;
  tcpcontrolbitsrev?: Maybe<Scalars['Int']>;
  tcpwindowsize?: Maybe<Scalars['Int']>;
  tcpwindowsizerev?: Maybe<Scalars['Int']>;
  templateid?: Maybe<Scalars['Int']>;
  timestamp?: Maybe<Scalars['DatetimeTimestamp']>;
  vlanid?: Maybe<Scalars['Int']>;
  vlanidrev?: Maybe<Scalars['Int']>;
};

export type DataPlatformServiceIpFixCreate = {
  applicationid?: InputMaybe<Scalars['String']>;
  applicationidrev?: InputMaybe<Scalars['String']>;
  applicationname?: InputMaybe<Scalars['String']>;
  applicationnamerev?: InputMaybe<Scalars['String']>;
  bgpdestinationasnumber?: InputMaybe<Scalars['LargeJsInt']>;
  bgpdestinationasnumberrev?: InputMaybe<Scalars['LargeJsInt']>;
  bgpsourceasnumber?: InputMaybe<Scalars['LargeJsInt']>;
  bgpsourceasnumberrev?: InputMaybe<Scalars['LargeJsInt']>;
  destinationipv4address?: InputMaybe<Scalars['String']>;
  destinationipv6address?: InputMaybe<Scalars['String']>;
  destinationtransportport?: InputMaybe<Scalars['Int']>;
  exporttime?: InputMaybe<Scalars['LargeJsInt']>;
  flowendmilliseconds?: InputMaybe<Scalars['LargeJsInt']>;
  flowendmillisecondsrev?: InputMaybe<Scalars['LargeJsInt']>;
  flowstartmilliseconds?: InputMaybe<Scalars['LargeJsInt']>;
  flowstartmillisecondsrev?: InputMaybe<Scalars['LargeJsInt']>;
  icmptypecodeipv4?: InputMaybe<Scalars['Int']>;
  ingressinterface?: InputMaybe<Scalars['LargeJsInt']>;
  ipclassofservice?: InputMaybe<Scalars['Int']>;
  ipclassofservicerev?: InputMaybe<Scalars['Int']>;
  ipversion?: InputMaybe<Scalars['Int']>;
  mplslabelstacksection2?: InputMaybe<Scalars['String']>;
  mplslabelstacksection2rev?: InputMaybe<Scalars['String']>;
  mplslabelstacksection3?: InputMaybe<Scalars['String']>;
  mplslabelstacksection3rev?: InputMaybe<Scalars['String']>;
  mplslabelstacksection4?: InputMaybe<Scalars['String']>;
  mplslabelstacksection4rev?: InputMaybe<Scalars['String']>;
  mplslabelstacksection5?: InputMaybe<Scalars['String']>;
  mplslabelstacksection5rev?: InputMaybe<Scalars['String']>;
  mplslabelstacksection6?: InputMaybe<Scalars['String']>;
  mplslabelstacksection6rev?: InputMaybe<Scalars['String']>;
  mplslabelstacksection7?: InputMaybe<Scalars['String']>;
  mplslabelstacksection7rev?: InputMaybe<Scalars['String']>;
  mplslabelstacksection8?: InputMaybe<Scalars['String']>;
  mplslabelstacksection8rev?: InputMaybe<Scalars['String']>;
  mplslabelstacksection9?: InputMaybe<Scalars['String']>;
  mplslabelstacksection9rev?: InputMaybe<Scalars['String']>;
  mplslabelstacksection10?: InputMaybe<Scalars['String']>;
  mplslabelstacksection10rev?: InputMaybe<Scalars['String']>;
  mplstoplabelstacksection?: InputMaybe<Scalars['String']>;
  mplstoplabelstacksectionrev?: InputMaybe<Scalars['String']>;
  msglength?: InputMaybe<Scalars['Int']>;
  octetdeltacount?: InputMaybe<Scalars['LargeJsInt']>;
  octetdeltacountrev?: InputMaybe<Scalars['LargeJsInt']>;
  odid?: InputMaybe<Scalars['Int']>;
  originalexporteripv6address?: InputMaybe<Scalars['String']>;
  packetdeltacount?: InputMaybe<Scalars['LargeJsInt']>;
  packetdeltacountrev?: InputMaybe<Scalars['LargeJsInt']>;
  protocolidentifier?: InputMaybe<Scalars['Int']>;
  samplingalgorithm?: InputMaybe<Scalars['Int']>;
  samplingalgorithmrev?: InputMaybe<Scalars['Int']>;
  samplinginterval?: InputMaybe<Scalars['LargeJsInt']>;
  samplingintervalrev?: InputMaybe<Scalars['LargeJsInt']>;
  seqnumber?: InputMaybe<Scalars['LargeJsInt']>;
  sourceipv4address?: InputMaybe<Scalars['String']>;
  sourceipv6address?: InputMaybe<Scalars['String']>;
  sourcetransportport?: InputMaybe<Scalars['Int']>;
  srcaddr?: InputMaybe<Scalars['String']>;
  tcpcontrolbits?: InputMaybe<Scalars['Int']>;
  tcpcontrolbitsrev?: InputMaybe<Scalars['Int']>;
  tcpwindowsize?: InputMaybe<Scalars['Int']>;
  tcpwindowsizerev?: InputMaybe<Scalars['Int']>;
  templateid?: InputMaybe<Scalars['Int']>;
  timestamp?: InputMaybe<Scalars['DatetimeTimestamp']>;
  vlanid?: InputMaybe<Scalars['Int']>;
  vlanidrev?: InputMaybe<Scalars['Int']>;
};

export type DataPlatformServiceIpFixFilter1 = {
  applicationid?: InputMaybe<StrFieldFilter>;
  applicationidrev?: InputMaybe<StrFieldFilter>;
  applicationname?: InputMaybe<StrFieldFilter>;
  applicationnamerev?: InputMaybe<StrFieldFilter>;
  bgpdestinationasnumber?: InputMaybe<LargeJsIntFieldFilter>;
  bgpdestinationasnumberrev?: InputMaybe<LargeJsIntFieldFilter>;
  bgpsourceasnumber?: InputMaybe<LargeJsIntFieldFilter>;
  bgpsourceasnumberrev?: InputMaybe<LargeJsIntFieldFilter>;
  destinationipv4address?: InputMaybe<StrFieldFilter>;
  destinationipv6address?: InputMaybe<StrFieldFilter>;
  destinationtransportport?: InputMaybe<IntFieldFilter>;
  exporttime?: InputMaybe<LargeJsIntFieldFilter>;
  flowendmilliseconds?: InputMaybe<LargeJsIntFieldFilter>;
  flowendmillisecondsrev?: InputMaybe<LargeJsIntFieldFilter>;
  flowstartmilliseconds?: InputMaybe<LargeJsIntFieldFilter>;
  flowstartmillisecondsrev?: InputMaybe<LargeJsIntFieldFilter>;
  icmptypecodeipv4?: InputMaybe<IntFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  ingressinterface?: InputMaybe<LargeJsIntFieldFilter>;
  ipclassofservice?: InputMaybe<IntFieldFilter>;
  ipclassofservicerev?: InputMaybe<IntFieldFilter>;
  ipversion?: InputMaybe<IntFieldFilter>;
  mplslabelstacksection2?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection2rev?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection3?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection3rev?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection4?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection4rev?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection5?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection5rev?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection6?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection6rev?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection7?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection7rev?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection8?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection8rev?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection9?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection9rev?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection10?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection10rev?: InputMaybe<StrFieldFilter>;
  mplstoplabelstacksection?: InputMaybe<StrFieldFilter>;
  mplstoplabelstacksectionrev?: InputMaybe<StrFieldFilter>;
  msglength?: InputMaybe<IntFieldFilter>;
  octetdeltacount?: InputMaybe<LargeJsIntFieldFilter>;
  octetdeltacountrev?: InputMaybe<LargeJsIntFieldFilter>;
  odid?: InputMaybe<IntFieldFilter>;
  originalexporteripv6address?: InputMaybe<StrFieldFilter>;
  packetdeltacount?: InputMaybe<LargeJsIntFieldFilter>;
  packetdeltacountrev?: InputMaybe<LargeJsIntFieldFilter>;
  protocolidentifier?: InputMaybe<IntFieldFilter>;
  samplingalgorithm?: InputMaybe<IntFieldFilter>;
  samplingalgorithmrev?: InputMaybe<IntFieldFilter>;
  samplinginterval?: InputMaybe<LargeJsIntFieldFilter>;
  samplingintervalrev?: InputMaybe<LargeJsIntFieldFilter>;
  seqnumber?: InputMaybe<LargeJsIntFieldFilter>;
  sourceipv4address?: InputMaybe<StrFieldFilter>;
  sourceipv6address?: InputMaybe<StrFieldFilter>;
  sourcetransportport?: InputMaybe<IntFieldFilter>;
  srcaddr?: InputMaybe<StrFieldFilter>;
  tcpcontrolbits?: InputMaybe<IntFieldFilter>;
  tcpcontrolbitsrev?: InputMaybe<IntFieldFilter>;
  tcpwindowsize?: InputMaybe<IntFieldFilter>;
  tcpwindowsizerev?: InputMaybe<IntFieldFilter>;
  templateid?: InputMaybe<IntFieldFilter>;
  timestamp?: InputMaybe<DatetimeTimestampFieldFilter>;
  vlanid?: InputMaybe<IntFieldFilter>;
  vlanidrev?: InputMaybe<IntFieldFilter>;
};

export type DataPlatformServiceIpFixFilter1AndFilterEntry = {
  AND: Array<DataPlatformServiceIpFixFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type DataPlatformServiceIpFixFilter1OrFilterEntry = {
  OR: DataPlatformServiceIpFixFilter1;
  negate?: Scalars['Boolean'];
};

export enum DataPlatformServiceIpFixOrdEnum {
  APPLICATIONID = 'APPLICATIONID',
  APPLICATIONIDREV = 'APPLICATIONIDREV',
  APPLICATIONNAME = 'APPLICATIONNAME',
  APPLICATIONNAMEREV = 'APPLICATIONNAMEREV',
  BGPDESTINATIONASNUMBER = 'BGPDESTINATIONASNUMBER',
  BGPDESTINATIONASNUMBERREV = 'BGPDESTINATIONASNUMBERREV',
  BGPSOURCEASNUMBER = 'BGPSOURCEASNUMBER',
  BGPSOURCEASNUMBERREV = 'BGPSOURCEASNUMBERREV',
  DESTINATIONIPV4_ADDRESS = 'DESTINATIONIPV4ADDRESS',
  DESTINATIONIPV6_ADDRESS = 'DESTINATIONIPV6ADDRESS',
  DESTINATIONTRANSPORTPORT = 'DESTINATIONTRANSPORTPORT',
  EXPORTTIME = 'EXPORTTIME',
  FLOWENDMILLISECONDS = 'FLOWENDMILLISECONDS',
  FLOWENDMILLISECONDSREV = 'FLOWENDMILLISECONDSREV',
  FLOWSTARTMILLISECONDS = 'FLOWSTARTMILLISECONDS',
  FLOWSTARTMILLISECONDSREV = 'FLOWSTARTMILLISECONDSREV',
  ICMPTYPECODEIPV4 = 'ICMPTYPECODEIPV4',
  ID = 'ID',
  INGRESSINTERFACE = 'INGRESSINTERFACE',
  IPCLASSOFSERVICE = 'IPCLASSOFSERVICE',
  IPCLASSOFSERVICEREV = 'IPCLASSOFSERVICEREV',
  IPVERSION = 'IPVERSION',
  MPLSLABELSTACKSECTION2 = 'MPLSLABELSTACKSECTION2',
  MPLSLABELSTACKSECTION2_REV = 'MPLSLABELSTACKSECTION2REV',
  MPLSLABELSTACKSECTION3 = 'MPLSLABELSTACKSECTION3',
  MPLSLABELSTACKSECTION3_REV = 'MPLSLABELSTACKSECTION3REV',
  MPLSLABELSTACKSECTION4 = 'MPLSLABELSTACKSECTION4',
  MPLSLABELSTACKSECTION4_REV = 'MPLSLABELSTACKSECTION4REV',
  MPLSLABELSTACKSECTION5 = 'MPLSLABELSTACKSECTION5',
  MPLSLABELSTACKSECTION5_REV = 'MPLSLABELSTACKSECTION5REV',
  MPLSLABELSTACKSECTION6 = 'MPLSLABELSTACKSECTION6',
  MPLSLABELSTACKSECTION6_REV = 'MPLSLABELSTACKSECTION6REV',
  MPLSLABELSTACKSECTION7 = 'MPLSLABELSTACKSECTION7',
  MPLSLABELSTACKSECTION7_REV = 'MPLSLABELSTACKSECTION7REV',
  MPLSLABELSTACKSECTION8 = 'MPLSLABELSTACKSECTION8',
  MPLSLABELSTACKSECTION8_REV = 'MPLSLABELSTACKSECTION8REV',
  MPLSLABELSTACKSECTION9 = 'MPLSLABELSTACKSECTION9',
  MPLSLABELSTACKSECTION9_REV = 'MPLSLABELSTACKSECTION9REV',
  MPLSLABELSTACKSECTION10 = 'MPLSLABELSTACKSECTION10',
  MPLSLABELSTACKSECTION10_REV = 'MPLSLABELSTACKSECTION10REV',
  MPLSTOPLABELSTACKSECTION = 'MPLSTOPLABELSTACKSECTION',
  MPLSTOPLABELSTACKSECTIONREV = 'MPLSTOPLABELSTACKSECTIONREV',
  MSGLENGTH = 'MSGLENGTH',
  OCTETDELTACOUNT = 'OCTETDELTACOUNT',
  OCTETDELTACOUNTREV = 'OCTETDELTACOUNTREV',
  ODID = 'ODID',
  ORIGINALEXPORTERIPV6_ADDRESS = 'ORIGINALEXPORTERIPV6ADDRESS',
  PACKETDELTACOUNT = 'PACKETDELTACOUNT',
  PACKETDELTACOUNTREV = 'PACKETDELTACOUNTREV',
  PROTOCOLIDENTIFIER = 'PROTOCOLIDENTIFIER',
  SAMPLINGALGORITHM = 'SAMPLINGALGORITHM',
  SAMPLINGALGORITHMREV = 'SAMPLINGALGORITHMREV',
  SAMPLINGINTERVAL = 'SAMPLINGINTERVAL',
  SAMPLINGINTERVALREV = 'SAMPLINGINTERVALREV',
  SEQNUMBER = 'SEQNUMBER',
  SOURCEIPV4_ADDRESS = 'SOURCEIPV4ADDRESS',
  SOURCEIPV6_ADDRESS = 'SOURCEIPV6ADDRESS',
  SOURCETRANSPORTPORT = 'SOURCETRANSPORTPORT',
  SRCADDR = 'SRCADDR',
  TCPCONTROLBITS = 'TCPCONTROLBITS',
  TCPCONTROLBITSREV = 'TCPCONTROLBITSREV',
  TCPWINDOWSIZE = 'TCPWINDOWSIZE',
  TCPWINDOWSIZEREV = 'TCPWINDOWSIZEREV',
  TEMPLATEID = 'TEMPLATEID',
  TIMESTAMP = 'TIMESTAMP',
  VLANID = 'VLANID',
  VLANIDREV = 'VLANIDREV',
}

export type DataPlatformServiceIpFixOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: DataPlatformServiceIpFixOrdEnum;
};

export type DataPlatformServiceIpFixPaginated = {
  __typename?: 'DataPlatformServiceIPFixPaginated';
  data: Array<DataPlatformServiceIpFix>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type DataPlatformServiceIpFixUpdate = {
  applicationid?: InputMaybe<Scalars['String']>;
  applicationidrev?: InputMaybe<Scalars['String']>;
  applicationname?: InputMaybe<Scalars['String']>;
  applicationnamerev?: InputMaybe<Scalars['String']>;
  bgpdestinationasnumber?: InputMaybe<Scalars['LargeJsInt']>;
  bgpdestinationasnumberrev?: InputMaybe<Scalars['LargeJsInt']>;
  bgpsourceasnumber?: InputMaybe<Scalars['LargeJsInt']>;
  bgpsourceasnumberrev?: InputMaybe<Scalars['LargeJsInt']>;
  destinationipv4address?: InputMaybe<Scalars['String']>;
  destinationipv6address?: InputMaybe<Scalars['String']>;
  destinationtransportport?: InputMaybe<Scalars['Int']>;
  exporttime?: InputMaybe<Scalars['LargeJsInt']>;
  flowendmilliseconds?: InputMaybe<Scalars['LargeJsInt']>;
  flowendmillisecondsrev?: InputMaybe<Scalars['LargeJsInt']>;
  flowstartmilliseconds?: InputMaybe<Scalars['LargeJsInt']>;
  flowstartmillisecondsrev?: InputMaybe<Scalars['LargeJsInt']>;
  icmptypecodeipv4?: InputMaybe<Scalars['Int']>;
  ingressinterface?: InputMaybe<Scalars['LargeJsInt']>;
  ipclassofservice?: InputMaybe<Scalars['Int']>;
  ipclassofservicerev?: InputMaybe<Scalars['Int']>;
  ipversion?: InputMaybe<Scalars['Int']>;
  mplslabelstacksection2?: InputMaybe<Scalars['String']>;
  mplslabelstacksection2rev?: InputMaybe<Scalars['String']>;
  mplslabelstacksection3?: InputMaybe<Scalars['String']>;
  mplslabelstacksection3rev?: InputMaybe<Scalars['String']>;
  mplslabelstacksection4?: InputMaybe<Scalars['String']>;
  mplslabelstacksection4rev?: InputMaybe<Scalars['String']>;
  mplslabelstacksection5?: InputMaybe<Scalars['String']>;
  mplslabelstacksection5rev?: InputMaybe<Scalars['String']>;
  mplslabelstacksection6?: InputMaybe<Scalars['String']>;
  mplslabelstacksection6rev?: InputMaybe<Scalars['String']>;
  mplslabelstacksection7?: InputMaybe<Scalars['String']>;
  mplslabelstacksection7rev?: InputMaybe<Scalars['String']>;
  mplslabelstacksection8?: InputMaybe<Scalars['String']>;
  mplslabelstacksection8rev?: InputMaybe<Scalars['String']>;
  mplslabelstacksection9?: InputMaybe<Scalars['String']>;
  mplslabelstacksection9rev?: InputMaybe<Scalars['String']>;
  mplslabelstacksection10?: InputMaybe<Scalars['String']>;
  mplslabelstacksection10rev?: InputMaybe<Scalars['String']>;
  mplstoplabelstacksection?: InputMaybe<Scalars['String']>;
  mplstoplabelstacksectionrev?: InputMaybe<Scalars['String']>;
  msglength?: InputMaybe<Scalars['Int']>;
  octetdeltacount?: InputMaybe<Scalars['LargeJsInt']>;
  octetdeltacountrev?: InputMaybe<Scalars['LargeJsInt']>;
  odid?: InputMaybe<Scalars['Int']>;
  originalexporteripv6address?: InputMaybe<Scalars['String']>;
  packetdeltacount?: InputMaybe<Scalars['LargeJsInt']>;
  packetdeltacountrev?: InputMaybe<Scalars['LargeJsInt']>;
  protocolidentifier?: InputMaybe<Scalars['Int']>;
  samplingalgorithm?: InputMaybe<Scalars['Int']>;
  samplingalgorithmrev?: InputMaybe<Scalars['Int']>;
  samplinginterval?: InputMaybe<Scalars['LargeJsInt']>;
  samplingintervalrev?: InputMaybe<Scalars['LargeJsInt']>;
  seqnumber?: InputMaybe<Scalars['LargeJsInt']>;
  sourceipv4address?: InputMaybe<Scalars['String']>;
  sourceipv6address?: InputMaybe<Scalars['String']>;
  sourcetransportport?: InputMaybe<Scalars['Int']>;
  srcaddr?: InputMaybe<Scalars['String']>;
  tcpcontrolbits?: InputMaybe<Scalars['Int']>;
  tcpcontrolbitsrev?: InputMaybe<Scalars['Int']>;
  tcpwindowsize?: InputMaybe<Scalars['Int']>;
  tcpwindowsizerev?: InputMaybe<Scalars['Int']>;
  templateid?: InputMaybe<Scalars['Int']>;
  timestamp?: InputMaybe<Scalars['DatetimeTimestamp']>;
  vlanid?: InputMaybe<Scalars['Int']>;
  vlanidrev?: InputMaybe<Scalars['Int']>;
};

export type DataSource = {
  __typename?: 'DataSource';
  baseUrl?: Maybe<Scalars['String']>;
  description?: Maybe<Scalars['String']>;
  id: Scalars['ID'];
  inSpecifiers?: Maybe<SourceSpecifierNestedList>;
  name: Scalars['String'];
  type: Scalars['String'];
};

export type DataSourceInSpecifiersArgs = {
  filter?: InputMaybe<Array<SourceSpecifierFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<SourceSpecifierOrdEnumOrderingEntry>>;
};

export type DataSourceCreate = {
  baseUrl?: InputMaybe<Scalars['String']>;
  description?: InputMaybe<Scalars['String']>;
  inSpecifiers?: InputMaybe<Array<Scalars['ID']>>;
  name: Scalars['String'];
  type: Scalars['String'];
};

export type DataSourceFilter1 = {
  baseUrl?: InputMaybe<StrFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  inSpecifiers?: InputMaybe<SourceSpecifierFilter1>;
  name?: InputMaybe<StrFieldFilter>;
  type?: InputMaybe<StrFieldFilter>;
};

export type DataSourceFilter1AndFilterEntry = {
  AND: Array<DataSourceFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type DataSourceFilter1OrFilterEntry = {
  OR: DataSourceFilter1;
  negate?: Scalars['Boolean'];
};

export type DataSourceNestedListResult = {
  __typename?: 'DataSourceNestedListResult';
  data?: Maybe<DataSource>;
  error?: Maybe<ValidationError>;
};

export enum DataSourceOrdEnum {
  BASE_URL = 'BASE_URL',
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  NAME = 'NAME',
  TYPE = 'TYPE',
}

export type DataSourceOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: DataSourceOrdEnum;
};

export type DataSourcePaginated = {
  __typename?: 'DataSourcePaginated';
  data: Array<DataSource>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type DataSourceUpdate = {
  baseUrl?: InputMaybe<Scalars['String']>;
  description?: InputMaybe<Scalars['String']>;
  inSpecifiers?: InputMaybe<RelationUpdate>;
  name?: InputMaybe<Scalars['String']>;
  type?: InputMaybe<Scalars['String']>;
};

export type DateInputOutput = TaskInputOutput & {
  __typename?: 'DateInputOutput';
  dateValue?: Maybe<Scalars['Date']>;
  description?: Maybe<Scalars['String']>;
  id: Scalars['ID'];
  inputOf?: Maybe<Task>;
  outputOf?: Maybe<Task>;
  stringifiedValue?: Maybe<Scalars['String']>;
  type?: Maybe<Scalars['String']>;
};

export type DateInputOutputCreate = {
  dateValue?: InputMaybe<Scalars['Date']>;
  description?: InputMaybe<Scalars['String']>;
  inputOf?: InputMaybe<Scalars['ID']>;
  outputOf?: InputMaybe<Scalars['ID']>;
};

export type DateInputOutputFilter1 = {
  dateValue?: InputMaybe<DateTimeFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  inputOf?: InputMaybe<TaskFilter1>;
  outputOf?: InputMaybe<TaskFilter1>;
  type?: InputMaybe<StrFieldFilter>;
};

export type DateInputOutputFilter1AndFilterEntry = {
  AND: Array<DateInputOutputFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type DateInputOutputFilter1OrFilterEntry = {
  OR: DateInputOutputFilter1;
  negate?: Scalars['Boolean'];
};

export enum DateInputOutputOrdEnum {
  DATE_VALUE = 'DATE_VALUE',
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  TYPE = 'TYPE',
}

export type DateInputOutputOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: DateInputOutputOrdEnum;
};

export type DateInputOutputPaginated = {
  __typename?: 'DateInputOutputPaginated';
  data: Array<DateInputOutput>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type DateInputOutputUpdate = {
  dateValue?: InputMaybe<Scalars['Date']>;
  description?: InputMaybe<Scalars['String']>;
  inputOf?: InputMaybe<Scalars['ID']>;
  outputOf?: InputMaybe<Scalars['ID']>;
};

export type DateTimeFieldFilter = {
  exact?: InputMaybe<Scalars['DateTime']>;
  except_?: InputMaybe<Scalars['DateTime']>;
  gt?: InputMaybe<Scalars['DateTime']>;
  gte?: InputMaybe<Scalars['DateTime']>;
  in_?: InputMaybe<Array<Scalars['DateTime']>>;
  isnull?: InputMaybe<Scalars['Boolean']>;
  lt?: InputMaybe<Scalars['DateTime']>;
  lte?: InputMaybe<Scalars['DateTime']>;
};

export type DateTimeFilter = {
  exact?: InputMaybe<Scalars['DateTime']>;
  except_?: InputMaybe<Scalars['DateTime']>;
  gt?: InputMaybe<Scalars['DateTime']>;
  gte?: InputMaybe<Scalars['DateTime']>;
  in_?: InputMaybe<Array<Scalars['DateTime']>>;
  lt?: InputMaybe<Scalars['DateTime']>;
  lte?: InputMaybe<Scalars['DateTime']>;
};

export type DateTimeInputOutput = TaskInputOutput & {
  __typename?: 'DateTimeInputOutput';
  datetimeValue?: Maybe<Scalars['DateTime']>;
  description?: Maybe<Scalars['String']>;
  id: Scalars['ID'];
  inputOf?: Maybe<Task>;
  outputOf?: Maybe<Task>;
  stringifiedValue?: Maybe<Scalars['String']>;
  type?: Maybe<Scalars['String']>;
};

export type DateTimeInputOutputCreate = {
  datetimeValue?: InputMaybe<Scalars['DateTime']>;
  description?: InputMaybe<Scalars['String']>;
  inputOf?: InputMaybe<Scalars['ID']>;
  outputOf?: InputMaybe<Scalars['ID']>;
};

export type DateTimeInputOutputFilter1 = {
  datetimeValue?: InputMaybe<DateTimeFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  inputOf?: InputMaybe<TaskFilter1>;
  outputOf?: InputMaybe<TaskFilter1>;
  type?: InputMaybe<StrFieldFilter>;
};

export type DateTimeInputOutputFilter1AndFilterEntry = {
  AND: Array<DateTimeInputOutputFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type DateTimeInputOutputFilter1OrFilterEntry = {
  OR: DateTimeInputOutputFilter1;
  negate?: Scalars['Boolean'];
};

export enum DateTimeInputOutputOrdEnum {
  DATETIME_VALUE = 'DATETIME_VALUE',
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  TYPE = 'TYPE',
}

export type DateTimeInputOutputOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: DateTimeInputOutputOrdEnum;
};

export type DateTimeInputOutputPaginated = {
  __typename?: 'DateTimeInputOutputPaginated';
  data: Array<DateTimeInputOutput>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type DateTimeInputOutputUpdate = {
  datetimeValue?: InputMaybe<Scalars['DateTime']>;
  description?: InputMaybe<Scalars['String']>;
  inputOf?: InputMaybe<Scalars['ID']>;
  outputOf?: InputMaybe<Scalars['ID']>;
};

export type DatetimeTimestampFieldFilter = {
  exact?: InputMaybe<Scalars['DatetimeTimestamp']>;
  except_?: InputMaybe<Scalars['DatetimeTimestamp']>;
  gt?: InputMaybe<Scalars['DatetimeTimestamp']>;
  gte?: InputMaybe<Scalars['DatetimeTimestamp']>;
  in_?: InputMaybe<Array<Scalars['DatetimeTimestamp']>>;
  isnull?: InputMaybe<Scalars['Boolean']>;
  lt?: InputMaybe<Scalars['DatetimeTimestamp']>;
  lte?: InputMaybe<Scalars['DatetimeTimestamp']>;
};

export enum DcimCableLengthUnitChoices {
  CM = 'CM',
  FT = 'FT',
  IN = 'IN',
  KM = 'KM',
  M = 'M',
  MI = 'MI',
  UNKNOWN = 'UNKNOWN',
}

export type DcimCableLengthUnitChoicesEnumFilter = {
  exact?: InputMaybe<DcimCableLengthUnitChoices>;
  except_?: InputMaybe<DcimCableLengthUnitChoices>;
  in_?: InputMaybe<Array<DcimCableLengthUnitChoices>>;
};

export enum DcimCableStatusChoices {
  CONNECTED = 'CONNECTED',
  DECOMMISSIONING = 'DECOMMISSIONING',
  PLANNED = 'PLANNED',
  UNKNOWN = 'UNKNOWN',
}

export type DcimCableStatusChoicesEnumFilter = {
  exact?: InputMaybe<DcimCableStatusChoices>;
  except_?: InputMaybe<DcimCableStatusChoices>;
  in_?: InputMaybe<Array<DcimCableStatusChoices>>;
};

export enum DcimCableTypeChoices {
  AOC = 'AOC',
  CAT3 = 'CAT3',
  CAT5 = 'CAT5',
  CAT5_E = 'CAT5E',
  CAT6 = 'CAT6',
  CAT6_A = 'CAT6A',
  CAT7 = 'CAT7',
  CAT7_A = 'CAT7A',
  CAT8 = 'CAT8',
  COAXIAL = 'COAXIAL',
  DAC_ACTIVE = 'DAC_ACTIVE',
  DAC_PASSIVE = 'DAC_PASSIVE',
  MMF = 'MMF',
  MMF_OM1 = 'MMF_OM1',
  MMF_OM2 = 'MMF_OM2',
  MMF_OM3 = 'MMF_OM3',
  MMF_OM4 = 'MMF_OM4',
  MMF_OM5 = 'MMF_OM5',
  MRJ21_TRUNK = 'MRJ21_TRUNK',
  POWER = 'POWER',
  SMF = 'SMF',
  SMF_OS1 = 'SMF_OS1',
  SMF_OS2 = 'SMF_OS2',
  UNKNOWN = 'UNKNOWN',
}

export type DcimCableTypeChoicesEnumFilter = {
  exact?: InputMaybe<DcimCableTypeChoices>;
  except_?: InputMaybe<DcimCableTypeChoices>;
  in_?: InputMaybe<Array<DcimCableTypeChoices>>;
};

export enum DcimConsolePortSpeedChoices {
  A_1200 = 'A_1200',
  A_2400 = 'A_2400',
  A_4800 = 'A_4800',
  A_9600 = 'A_9600',
  A_19200 = 'A_19200',
  A_38400 = 'A_38400',
  A_57600 = 'A_57600',
  A_115200 = 'A_115200',
  UNKNOWN = 'UNKNOWN',
}

export type DcimConsolePortSpeedChoicesEnumFilter = {
  exact?: InputMaybe<DcimConsolePortSpeedChoices>;
  except_?: InputMaybe<DcimConsolePortSpeedChoices>;
  in_?: InputMaybe<Array<DcimConsolePortSpeedChoices>>;
};

export enum DcimConsolePortTypeChoices {
  DB_25 = 'DB_25',
  DE_9 = 'DE_9',
  MINI_DIN_8 = 'MINI_DIN_8',
  OTHER = 'OTHER',
  RJ_11 = 'RJ_11',
  RJ_12 = 'RJ_12',
  RJ_45 = 'RJ_45',
  UNKNOWN = 'UNKNOWN',
  USB_A = 'USB_A',
  USB_B = 'USB_B',
  USB_C = 'USB_C',
  USB_MICRO_A = 'USB_MICRO_A',
  USB_MICRO_B = 'USB_MICRO_B',
  USB_MINI_A = 'USB_MINI_A',
  USB_MINI_B = 'USB_MINI_B',
}

export type DcimConsolePortTypeChoicesEnumFilter = {
  exact?: InputMaybe<DcimConsolePortTypeChoices>;
  except_?: InputMaybe<DcimConsolePortTypeChoices>;
  in_?: InputMaybe<Array<DcimConsolePortTypeChoices>>;
};

export enum DcimConsoleServerPortSpeedChoices {
  A_1200 = 'A_1200',
  A_2400 = 'A_2400',
  A_4800 = 'A_4800',
  A_9600 = 'A_9600',
  A_19200 = 'A_19200',
  A_38400 = 'A_38400',
  A_57600 = 'A_57600',
  A_115200 = 'A_115200',
  UNKNOWN = 'UNKNOWN',
}

export type DcimConsoleServerPortSpeedChoicesEnumFilter = {
  exact?: InputMaybe<DcimConsoleServerPortSpeedChoices>;
  except_?: InputMaybe<DcimConsoleServerPortSpeedChoices>;
  in_?: InputMaybe<Array<DcimConsoleServerPortSpeedChoices>>;
};

export enum DcimConsoleServerPortTypeChoices {
  DB_25 = 'DB_25',
  DE_9 = 'DE_9',
  MINI_DIN_8 = 'MINI_DIN_8',
  OTHER = 'OTHER',
  RJ_11 = 'RJ_11',
  RJ_12 = 'RJ_12',
  RJ_45 = 'RJ_45',
  UNKNOWN = 'UNKNOWN',
  USB_A = 'USB_A',
  USB_B = 'USB_B',
  USB_C = 'USB_C',
  USB_MICRO_A = 'USB_MICRO_A',
  USB_MICRO_B = 'USB_MICRO_B',
  USB_MINI_A = 'USB_MINI_A',
  USB_MINI_B = 'USB_MINI_B',
}

export type DcimConsoleServerPortTypeChoicesEnumFilter = {
  exact?: InputMaybe<DcimConsoleServerPortTypeChoices>;
  except_?: InputMaybe<DcimConsoleServerPortTypeChoices>;
  in_?: InputMaybe<Array<DcimConsoleServerPortTypeChoices>>;
};

export enum DcimDeviceFaceChoices {
  FRONT = 'FRONT',
  REAR = 'REAR',
  UNKNOWN = 'UNKNOWN',
}

export type DcimDeviceFaceChoicesEnumFilter = {
  exact?: InputMaybe<DcimDeviceFaceChoices>;
  except_?: InputMaybe<DcimDeviceFaceChoices>;
  in_?: InputMaybe<Array<DcimDeviceFaceChoices>>;
};

export enum DcimDeviceStatusChoices {
  ACTIVE = 'ACTIVE',
  DECOMMISSIONING = 'DECOMMISSIONING',
  FAILED = 'FAILED',
  INVENTORY = 'INVENTORY',
  OFFLINE = 'OFFLINE',
  PLANNED = 'PLANNED',
  STAGED = 'STAGED',
  UNKNOWN = 'UNKNOWN',
}

export type DcimDeviceStatusChoicesEnumFilter = {
  exact?: InputMaybe<DcimDeviceStatusChoices>;
  except_?: InputMaybe<DcimDeviceStatusChoices>;
  in_?: InputMaybe<Array<DcimDeviceStatusChoices>>;
};

export enum DcimDeviceTypeSubdeviceRoleChoices {
  CHILD = 'CHILD',
  PARENT = 'PARENT',
  UNKNOWN = 'UNKNOWN',
}

export type DcimDeviceTypeSubdeviceRoleChoicesEnumFilter = {
  exact?: InputMaybe<DcimDeviceTypeSubdeviceRoleChoices>;
  except_?: InputMaybe<DcimDeviceTypeSubdeviceRoleChoices>;
  in_?: InputMaybe<Array<DcimDeviceTypeSubdeviceRoleChoices>>;
};

export enum DcimFrontPortTypeChoices {
  A_4_P2_C = 'A_4P2C',
  A_4_P4_C = 'A_4P4C',
  A_6_P2_C = 'A_6P2C',
  A_6_P4_C = 'A_6P4C',
  A_6_P6_C = 'A_6P6C',
  A_8_P2_C = 'A_8P2C',
  A_8_P4_C = 'A_8P4C',
  A_8_P6_C = 'A_8P6C',
  A_8_P8_C = 'A_8P8C',
  A_110_PUNCH = 'A_110_PUNCH',
  BNC = 'BNC',
  CS = 'CS',
  F = 'F',
  FC = 'FC',
  GG45 = 'GG45',
  LC = 'LC',
  LC_APC = 'LC_APC',
  LC_PC = 'LC_PC',
  LC_UPC = 'LC_UPC',
  LSH = 'LSH',
  LSH_APC = 'LSH_APC',
  LSH_PC = 'LSH_PC',
  LSH_UPC = 'LSH_UPC',
  MPO = 'MPO',
  MRJ21 = 'MRJ21',
  MTRJ = 'MTRJ',
  N = 'N',
  SC = 'SC',
  SC_APC = 'SC_APC',
  SC_PC = 'SC_PC',
  SC_UPC = 'SC_UPC',
  SMA_905 = 'SMA_905',
  SMA_906 = 'SMA_906',
  SN = 'SN',
  SPLICE = 'SPLICE',
  ST = 'ST',
  TERA_1_P = 'TERA_1P',
  TERA_2_P = 'TERA_2P',
  TERA_4_P = 'TERA_4P',
  UNKNOWN = 'UNKNOWN',
  URM_P2 = 'URM_P2',
  URM_P4 = 'URM_P4',
  URM_P8 = 'URM_P8',
}

export type DcimFrontPortTypeChoicesEnumFilter = {
  exact?: InputMaybe<DcimFrontPortTypeChoices>;
  except_?: InputMaybe<DcimFrontPortTypeChoices>;
  in_?: InputMaybe<Array<DcimFrontPortTypeChoices>>;
};

export enum DcimInterfaceModeChoices {
  ACCESS = 'ACCESS',
  TAGGED = 'TAGGED',
  TAGGED_ALL = 'TAGGED_ALL',
  UNKNOWN = 'UNKNOWN',
}

export type DcimInterfaceModeChoicesEnumFilter = {
  exact?: InputMaybe<DcimInterfaceModeChoices>;
  except_?: InputMaybe<DcimInterfaceModeChoices>;
  in_?: InputMaybe<Array<DcimInterfaceModeChoices>>;
};

export enum DcimInterfaceTypeChoices {
  A_1_GFC_SFP = 'A_1GFC_SFP',
  A_2_GFC_SFP = 'A_2GFC_SFP',
  A_2_5_GBASE_T = 'A_2_5GBASE_T',
  A_4_GFC_SFP = 'A_4GFC_SFP',
  A_5_GBASE_T = 'A_5GBASE_T',
  A_8_GFC_SFPP = 'A_8GFC_SFPP',
  A_10_GBASE_CX4 = 'A_10GBASE_CX4',
  A_10_GBASE_T = 'A_10GBASE_T',
  A_10_GBASE_X_SFPP = 'A_10GBASE_X_SFPP',
  A_10_GBASE_X_X2 = 'A_10GBASE_X_X2',
  A_10_GBASE_X_XENPAK = 'A_10GBASE_X_XENPAK',
  A_10_GBASE_X_XFP = 'A_10GBASE_X_XFP',
  A_16_GFC_SFPP = 'A_16GFC_SFPP',
  A_25_GBASE_X_SFP28 = 'A_25GBASE_X_SFP28',
  A_32_GFC_SFP28 = 'A_32GFC_SFP28',
  A_40_GBASE_X_QSFPP = 'A_40GBASE_X_QSFPP',
  A_50_GBASE_X_SFP28 = 'A_50GBASE_X_SFP28',
  A_50_GBASE_X_SFP56 = 'A_50GBASE_X_SFP56',
  A_64_GFC_QSFPP = 'A_64GFC_QSFPP',
  A_100_BASE_TX = 'A_100BASE_TX',
  A_100_GBASE_X_CFP = 'A_100GBASE_X_CFP',
  A_100_GBASE_X_CFP2 = 'A_100GBASE_X_CFP2',
  A_100_GBASE_X_CFP4 = 'A_100GBASE_X_CFP4',
  A_100_GBASE_X_CPAK = 'A_100GBASE_X_CPAK',
  A_100_GBASE_X_QSFP28 = 'A_100GBASE_X_QSFP28',
  A_128_GFC_QSFP28 = 'A_128GFC_QSFP28',
  A_200_GBASE_X_CFP2 = 'A_200GBASE_X_CFP2',
  A_200_GBASE_X_QSFP56 = 'A_200GBASE_X_QSFP56',
  A_400_GBASE_X_OSFP = 'A_400GBASE_X_OSFP',
  A_400_GBASE_X_QSFPDD = 'A_400GBASE_X_QSFPDD',
  A_1000_BASE_T = 'A_1000BASE_T',
  A_1000_BASE_X_GBIC = 'A_1000BASE_X_GBIC',
  A_1000_BASE_X_SFP = 'A_1000BASE_X_SFP',
  BRIDGE = 'BRIDGE',
  CDMA = 'CDMA',
  CISCO_FLEXSTACK = 'CISCO_FLEXSTACK',
  CISCO_FLEXSTACK_PLUS = 'CISCO_FLEXSTACK_PLUS',
  CISCO_STACKWISE = 'CISCO_STACKWISE',
  CISCO_STACKWISE_80 = 'CISCO_STACKWISE_80',
  CISCO_STACKWISE_160 = 'CISCO_STACKWISE_160',
  CISCO_STACKWISE_320 = 'CISCO_STACKWISE_320',
  CISCO_STACKWISE_480 = 'CISCO_STACKWISE_480',
  CISCO_STACKWISE_PLUS = 'CISCO_STACKWISE_PLUS',
  E1 = 'E1',
  E3 = 'E3',
  EXTREME_SUMMITSTACK = 'EXTREME_SUMMITSTACK',
  EXTREME_SUMMITSTACK_128 = 'EXTREME_SUMMITSTACK_128',
  EXTREME_SUMMITSTACK_256 = 'EXTREME_SUMMITSTACK_256',
  EXTREME_SUMMITSTACK_512 = 'EXTREME_SUMMITSTACK_512',
  GSM = 'GSM',
  IEEE802_11_A = 'IEEE802_11A',
  IEEE802_11_AC = 'IEEE802_11AC',
  IEEE802_11_AD = 'IEEE802_11AD',
  IEEE802_11_AX = 'IEEE802_11AX',
  IEEE802_11_G = 'IEEE802_11G',
  IEEE802_11_N = 'IEEE802_11N',
  IEEE802_15_1 = 'IEEE802_15_1',
  INFINIBAND_DDR = 'INFINIBAND_DDR',
  INFINIBAND_EDR = 'INFINIBAND_EDR',
  INFINIBAND_FDR = 'INFINIBAND_FDR',
  INFINIBAND_FDR10 = 'INFINIBAND_FDR10',
  INFINIBAND_HDR = 'INFINIBAND_HDR',
  INFINIBAND_NDR = 'INFINIBAND_NDR',
  INFINIBAND_QDR = 'INFINIBAND_QDR',
  INFINIBAND_SDR = 'INFINIBAND_SDR',
  INFINIBAND_XDR = 'INFINIBAND_XDR',
  JUNIPER_VCP = 'JUNIPER_VCP',
  LAG = 'LAG',
  LTE = 'LTE',
  OTHER = 'OTHER',
  SONET_OC3 = 'SONET_OC3',
  SONET_OC12 = 'SONET_OC12',
  SONET_OC48 = 'SONET_OC48',
  SONET_OC192 = 'SONET_OC192',
  SONET_OC768 = 'SONET_OC768',
  SONET_OC1920 = 'SONET_OC1920',
  SONET_OC3840 = 'SONET_OC3840',
  T1 = 'T1',
  T3 = 'T3',
  UNKNOWN = 'UNKNOWN',
  VIRTUAL = 'VIRTUAL',
  XDSL = 'XDSL',
}

export type DcimInterfaceTypeChoicesEnumFilter = {
  exact?: InputMaybe<DcimInterfaceTypeChoices>;
  except_?: InputMaybe<DcimInterfaceTypeChoices>;
  in_?: InputMaybe<Array<DcimInterfaceTypeChoices>>;
};

export enum DcimPowerFeedPhaseChoices {
  SINGLE_PHASE = 'SINGLE_PHASE',
  THREE_PHASE = 'THREE_PHASE',
  UNKNOWN = 'UNKNOWN',
}

export type DcimPowerFeedPhaseChoicesEnumFilter = {
  exact?: InputMaybe<DcimPowerFeedPhaseChoices>;
  except_?: InputMaybe<DcimPowerFeedPhaseChoices>;
  in_?: InputMaybe<Array<DcimPowerFeedPhaseChoices>>;
};

export enum DcimPowerFeedStatusChoices {
  ACTIVE = 'ACTIVE',
  FAILED = 'FAILED',
  OFFLINE = 'OFFLINE',
  PLANNED = 'PLANNED',
  UNKNOWN = 'UNKNOWN',
}

export type DcimPowerFeedStatusChoicesEnumFilter = {
  exact?: InputMaybe<DcimPowerFeedStatusChoices>;
  except_?: InputMaybe<DcimPowerFeedStatusChoices>;
  in_?: InputMaybe<Array<DcimPowerFeedStatusChoices>>;
};

export enum DcimPowerFeedSupplyChoices {
  AC = 'AC',
  DC = 'DC',
  UNKNOWN = 'UNKNOWN',
}

export type DcimPowerFeedSupplyChoicesEnumFilter = {
  exact?: InputMaybe<DcimPowerFeedSupplyChoices>;
  except_?: InputMaybe<DcimPowerFeedSupplyChoices>;
  in_?: InputMaybe<Array<DcimPowerFeedSupplyChoices>>;
};

export enum DcimPowerFeedTypeChoices {
  PRIMARY = 'PRIMARY',
  REDUNDANT = 'REDUNDANT',
  UNKNOWN = 'UNKNOWN',
}

export type DcimPowerFeedTypeChoicesEnumFilter = {
  exact?: InputMaybe<DcimPowerFeedTypeChoices>;
  except_?: InputMaybe<DcimPowerFeedTypeChoices>;
  in_?: InputMaybe<Array<DcimPowerFeedTypeChoices>>;
};

export enum DcimPowerOutletFeedLegChoices {
  A = 'A',
  B = 'B',
  C = 'C',
  UNKNOWN = 'UNKNOWN',
}

export type DcimPowerOutletFeedLegChoicesEnumFilter = {
  exact?: InputMaybe<DcimPowerOutletFeedLegChoices>;
  except_?: InputMaybe<DcimPowerOutletFeedLegChoices>;
  in_?: InputMaybe<Array<DcimPowerOutletFeedLegChoices>>;
};

export enum DcimPowerOutletTypeChoices {
  CS6360_C = 'CS6360C',
  CS6364_C = 'CS6364C',
  CS8164_C = 'CS8164C',
  CS8264_C = 'CS8264C',
  CS8364_C = 'CS8364C',
  CS8464_C = 'CS8464C',
  DC_TERMINAL = 'DC_TERMINAL',
  HARDWIRED = 'HARDWIRED',
  HDOT_CX = 'HDOT_CX',
  IEC_60309_2_P_E_4_H = 'IEC_60309_2P_E_4H',
  IEC_60309_2_P_E_6_H = 'IEC_60309_2P_E_6H',
  IEC_60309_2_P_E_9_H = 'IEC_60309_2P_E_9H',
  IEC_60309_3_P_E_4_H = 'IEC_60309_3P_E_4H',
  IEC_60309_3_P_E_6_H = 'IEC_60309_3P_E_6H',
  IEC_60309_3_P_E_9_H = 'IEC_60309_3P_E_9H',
  IEC_60309_3_P_N_E_4_H = 'IEC_60309_3P_N_E_4H',
  IEC_60309_3_P_N_E_6_H = 'IEC_60309_3P_N_E_6H',
  IEC_60309_3_P_N_E_9_H = 'IEC_60309_3P_N_E_9H',
  IEC_60309_P_N_E_4_H = 'IEC_60309_P_N_E_4H',
  IEC_60309_P_N_E_6_H = 'IEC_60309_P_N_E_6H',
  IEC_60309_P_N_E_9_H = 'IEC_60309_P_N_E_9H',
  IEC_60320_C5 = 'IEC_60320_C5',
  IEC_60320_C7 = 'IEC_60320_C7',
  IEC_60320_C13 = 'IEC_60320_C13',
  IEC_60320_C15 = 'IEC_60320_C15',
  IEC_60320_C19 = 'IEC_60320_C19',
  IEC_60320_C21 = 'IEC_60320_C21',
  ITA_E = 'ITA_E',
  ITA_F = 'ITA_F',
  ITA_G = 'ITA_G',
  ITA_H = 'ITA_H',
  ITA_I = 'ITA_I',
  ITA_J = 'ITA_J',
  ITA_K = 'ITA_K',
  ITA_L = 'ITA_L',
  ITA_M = 'ITA_M',
  ITA_MULTI = 'ITA_MULTI',
  ITA_N = 'ITA_N',
  ITA_O = 'ITA_O',
  NEMA_1_15_R = 'NEMA_1_15R',
  NEMA_5_15_R = 'NEMA_5_15R',
  NEMA_5_20_R = 'NEMA_5_20R',
  NEMA_5_30_R = 'NEMA_5_30R',
  NEMA_5_50_R = 'NEMA_5_50R',
  NEMA_6_15_R = 'NEMA_6_15R',
  NEMA_6_20_R = 'NEMA_6_20R',
  NEMA_6_30_R = 'NEMA_6_30R',
  NEMA_6_50_R = 'NEMA_6_50R',
  NEMA_10_30_R = 'NEMA_10_30R',
  NEMA_10_50_R = 'NEMA_10_50R',
  NEMA_14_20_R = 'NEMA_14_20R',
  NEMA_14_30_R = 'NEMA_14_30R',
  NEMA_14_50_R = 'NEMA_14_50R',
  NEMA_14_60_R = 'NEMA_14_60R',
  NEMA_15_15_R = 'NEMA_15_15R',
  NEMA_15_20_R = 'NEMA_15_20R',
  NEMA_15_30_R = 'NEMA_15_30R',
  NEMA_15_50_R = 'NEMA_15_50R',
  NEMA_15_60_R = 'NEMA_15_60R',
  NEMA_L1_15_R = 'NEMA_L1_15R',
  NEMA_L5_15_R = 'NEMA_L5_15R',
  NEMA_L5_20_R = 'NEMA_L5_20R',
  NEMA_L5_30_R = 'NEMA_L5_30R',
  NEMA_L5_50_R = 'NEMA_L5_50R',
  NEMA_L6_15_R = 'NEMA_L6_15R',
  NEMA_L6_20_R = 'NEMA_L6_20R',
  NEMA_L6_30_R = 'NEMA_L6_30R',
  NEMA_L6_50_R = 'NEMA_L6_50R',
  NEMA_L10_30_R = 'NEMA_L10_30R',
  NEMA_L14_20_R = 'NEMA_L14_20R',
  NEMA_L14_30_R = 'NEMA_L14_30R',
  NEMA_L14_50_R = 'NEMA_L14_50R',
  NEMA_L14_60_R = 'NEMA_L14_60R',
  NEMA_L15_20_R = 'NEMA_L15_20R',
  NEMA_L15_30_R = 'NEMA_L15_30R',
  NEMA_L15_50_R = 'NEMA_L15_50R',
  NEMA_L15_60_R = 'NEMA_L15_60R',
  NEMA_L21_20_R = 'NEMA_L21_20R',
  NEMA_L21_30_R = 'NEMA_L21_30R',
  NEMA_L22_30_R = 'NEMA_L22_30R',
  SAF_D_GRID = 'SAF_D_GRID',
  UNKNOWN = 'UNKNOWN',
  USB_A = 'USB_A',
  USB_C = 'USB_C',
  USB_MICRO_B = 'USB_MICRO_B',
}

export type DcimPowerOutletTypeChoicesEnumFilter = {
  exact?: InputMaybe<DcimPowerOutletTypeChoices>;
  except_?: InputMaybe<DcimPowerOutletTypeChoices>;
  in_?: InputMaybe<Array<DcimPowerOutletTypeChoices>>;
};

export enum DcimPowerPortTypeChoices {
  CS6361_C = 'CS6361C',
  CS6365_C = 'CS6365C',
  CS8165_C = 'CS8165C',
  CS8265_C = 'CS8265C',
  CS8365_C = 'CS8365C',
  CS8465_C = 'CS8465C',
  DC_TERMINAL = 'DC_TERMINAL',
  HARDWIRED = 'HARDWIRED',
  IEC_60309_2_P_E_4_H = 'IEC_60309_2P_E_4H',
  IEC_60309_2_P_E_6_H = 'IEC_60309_2P_E_6H',
  IEC_60309_2_P_E_9_H = 'IEC_60309_2P_E_9H',
  IEC_60309_3_P_E_4_H = 'IEC_60309_3P_E_4H',
  IEC_60309_3_P_E_6_H = 'IEC_60309_3P_E_6H',
  IEC_60309_3_P_E_9_H = 'IEC_60309_3P_E_9H',
  IEC_60309_3_P_N_E_4_H = 'IEC_60309_3P_N_E_4H',
  IEC_60309_3_P_N_E_6_H = 'IEC_60309_3P_N_E_6H',
  IEC_60309_3_P_N_E_9_H = 'IEC_60309_3P_N_E_9H',
  IEC_60309_P_N_E_4_H = 'IEC_60309_P_N_E_4H',
  IEC_60309_P_N_E_6_H = 'IEC_60309_P_N_E_6H',
  IEC_60309_P_N_E_9_H = 'IEC_60309_P_N_E_9H',
  IEC_60320_C6 = 'IEC_60320_C6',
  IEC_60320_C8 = 'IEC_60320_C8',
  IEC_60320_C14 = 'IEC_60320_C14',
  IEC_60320_C16 = 'IEC_60320_C16',
  IEC_60320_C20 = 'IEC_60320_C20',
  IEC_60320_C22 = 'IEC_60320_C22',
  ITA_C = 'ITA_C',
  ITA_E = 'ITA_E',
  ITA_EF = 'ITA_EF',
  ITA_F = 'ITA_F',
  ITA_G = 'ITA_G',
  ITA_H = 'ITA_H',
  ITA_I = 'ITA_I',
  ITA_J = 'ITA_J',
  ITA_K = 'ITA_K',
  ITA_L = 'ITA_L',
  ITA_M = 'ITA_M',
  ITA_N = 'ITA_N',
  ITA_O = 'ITA_O',
  NEMA_1_15_R = 'NEMA_1_15R',
  NEMA_5_15_R = 'NEMA_5_15R',
  NEMA_5_20_R = 'NEMA_5_20R',
  NEMA_5_30_R = 'NEMA_5_30R',
  NEMA_5_50_R = 'NEMA_5_50R',
  NEMA_6_15_R = 'NEMA_6_15R',
  NEMA_6_20_R = 'NEMA_6_20R',
  NEMA_6_30_R = 'NEMA_6_30R',
  NEMA_6_50_R = 'NEMA_6_50R',
  NEMA_10_30_R = 'NEMA_10_30R',
  NEMA_10_50_R = 'NEMA_10_50R',
  NEMA_14_20_R = 'NEMA_14_20R',
  NEMA_14_30_R = 'NEMA_14_30R',
  NEMA_14_50_R = 'NEMA_14_50R',
  NEMA_14_60_R = 'NEMA_14_60R',
  NEMA_15_15_R = 'NEMA_15_15R',
  NEMA_15_20_R = 'NEMA_15_20R',
  NEMA_15_30_R = 'NEMA_15_30R',
  NEMA_15_50_R = 'NEMA_15_50R',
  NEMA_15_60_R = 'NEMA_15_60R',
  NEMA_L1_15_R = 'NEMA_L1_15R',
  NEMA_L5_15_R = 'NEMA_L5_15R',
  NEMA_L5_20_R = 'NEMA_L5_20R',
  NEMA_L5_30_R = 'NEMA_L5_30R',
  NEMA_L5_50_R = 'NEMA_L5_50R',
  NEMA_L6_15_R = 'NEMA_L6_15R',
  NEMA_L6_20_R = 'NEMA_L6_20R',
  NEMA_L6_30_R = 'NEMA_L6_30R',
  NEMA_L6_50_R = 'NEMA_L6_50R',
  NEMA_L10_30_R = 'NEMA_L10_30R',
  NEMA_L14_20_R = 'NEMA_L14_20R',
  NEMA_L14_30_R = 'NEMA_L14_30R',
  NEMA_L14_50_R = 'NEMA_L14_50R',
  NEMA_L14_60_R = 'NEMA_L14_60R',
  NEMA_L15_20_R = 'NEMA_L15_20R',
  NEMA_L15_30_R = 'NEMA_L15_30R',
  NEMA_L15_50_R = 'NEMA_L15_50R',
  NEMA_L15_60_R = 'NEMA_L15_60R',
  NEMA_L21_20_R = 'NEMA_L21_20R',
  NEMA_L21_30_R = 'NEMA_L21_30R',
  NEMA_L22_30_R = 'NEMA_L22_30R',
  SAF_D_GRID = 'SAF_D_GRID',
  UNKNOWN = 'UNKNOWN',
  USB_3_B = 'USB_3_B',
  USB_3_MICRO_B = 'USB_3_MICRO_B',
  USB_A = 'USB_A',
  USB_B = 'USB_B',
  USB_C = 'USB_C',
  USB_MICRO_A = 'USB_MICRO_A',
  USB_MICRO_AB = 'USB_MICRO_AB',
  USB_MICRO_B = 'USB_MICRO_B',
  USB_MINI_A = 'USB_MINI_A',
  USB_MINI_B = 'USB_MINI_B',
}

export type DcimPowerPortTypeChoicesEnumFilter = {
  exact?: InputMaybe<DcimPowerPortTypeChoices>;
  except_?: InputMaybe<DcimPowerPortTypeChoices>;
  in_?: InputMaybe<Array<DcimPowerPortTypeChoices>>;
};

export enum DcimRackOuterUnitChoices {
  IN = 'IN',
  MM = 'MM',
  UNKNOWN = 'UNKNOWN',
}

export type DcimRackOuterUnitChoicesEnumFilter = {
  exact?: InputMaybe<DcimRackOuterUnitChoices>;
  except_?: InputMaybe<DcimRackOuterUnitChoices>;
  in_?: InputMaybe<Array<DcimRackOuterUnitChoices>>;
};

export enum DcimRackStatusChoices {
  ACTIVE = 'ACTIVE',
  AVAILABLE = 'AVAILABLE',
  DEPRECATED = 'DEPRECATED',
  PLANNED = 'PLANNED',
  RESERVED = 'RESERVED',
  UNKNOWN = 'UNKNOWN',
}

export type DcimRackStatusChoicesEnumFilter = {
  exact?: InputMaybe<DcimRackStatusChoices>;
  except_?: InputMaybe<DcimRackStatusChoices>;
  in_?: InputMaybe<Array<DcimRackStatusChoices>>;
};

export enum DcimRackTypeChoices {
  A_2_POST_FRAME = 'A_2_POST_FRAME',
  A_4_POST_CABINET = 'A_4_POST_CABINET',
  A_4_POST_FRAME = 'A_4_POST_FRAME',
  UNKNOWN = 'UNKNOWN',
  WALL_CABINET = 'WALL_CABINET',
  WALL_FRAME = 'WALL_FRAME',
}

export type DcimRackTypeChoicesEnumFilter = {
  exact?: InputMaybe<DcimRackTypeChoices>;
  except_?: InputMaybe<DcimRackTypeChoices>;
  in_?: InputMaybe<Array<DcimRackTypeChoices>>;
};

export enum DcimRackWidthChoices {
  A_10 = 'A_10',
  A_19 = 'A_19',
  A_21 = 'A_21',
  A_23 = 'A_23',
  UNKNOWN = 'UNKNOWN',
}

export type DcimRackWidthChoicesEnumFilter = {
  exact?: InputMaybe<DcimRackWidthChoices>;
  except_?: InputMaybe<DcimRackWidthChoices>;
  in_?: InputMaybe<Array<DcimRackWidthChoices>>;
};

export enum DcimRearPortTypeChoices {
  A_4_P2_C = 'A_4P2C',
  A_4_P4_C = 'A_4P4C',
  A_6_P2_C = 'A_6P2C',
  A_6_P4_C = 'A_6P4C',
  A_6_P6_C = 'A_6P6C',
  A_8_P2_C = 'A_8P2C',
  A_8_P4_C = 'A_8P4C',
  A_8_P6_C = 'A_8P6C',
  A_8_P8_C = 'A_8P8C',
  A_110_PUNCH = 'A_110_PUNCH',
  BNC = 'BNC',
  CS = 'CS',
  F = 'F',
  FC = 'FC',
  GG45 = 'GG45',
  LC = 'LC',
  LC_APC = 'LC_APC',
  LC_PC = 'LC_PC',
  LC_UPC = 'LC_UPC',
  LSH = 'LSH',
  LSH_APC = 'LSH_APC',
  LSH_PC = 'LSH_PC',
  LSH_UPC = 'LSH_UPC',
  MPO = 'MPO',
  MRJ21 = 'MRJ21',
  MTRJ = 'MTRJ',
  N = 'N',
  SC = 'SC',
  SC_APC = 'SC_APC',
  SC_PC = 'SC_PC',
  SC_UPC = 'SC_UPC',
  SMA_905 = 'SMA_905',
  SMA_906 = 'SMA_906',
  SN = 'SN',
  SPLICE = 'SPLICE',
  ST = 'ST',
  TERA_1_P = 'TERA_1P',
  TERA_2_P = 'TERA_2P',
  TERA_4_P = 'TERA_4P',
  UNKNOWN = 'UNKNOWN',
  URM_P2 = 'URM_P2',
  URM_P4 = 'URM_P4',
  URM_P8 = 'URM_P8',
}

export type DcimRearPortTypeChoicesEnumFilter = {
  exact?: InputMaybe<DcimRearPortTypeChoices>;
  except_?: InputMaybe<DcimRearPortTypeChoices>;
  in_?: InputMaybe<Array<DcimRearPortTypeChoices>>;
};

export enum DcimSiteStatusChoices {
  ACTIVE = 'ACTIVE',
  DECOMMISSIONING = 'DECOMMISSIONING',
  PLANNED = 'PLANNED',
  RETIRED = 'RETIRED',
  STAGING = 'STAGING',
  UNKNOWN = 'UNKNOWN',
}

export type DcimSiteStatusChoicesEnumFilter = {
  exact?: InputMaybe<DcimSiteStatusChoices>;
  except_?: InputMaybe<DcimSiteStatusChoices>;
  in_?: InputMaybe<Array<DcimSiteStatusChoices>>;
};

export enum DcimSiteTimeZoneChoices {
  AFRICA_ABIDJAN = 'AFRICA_ABIDJAN',
  AFRICA_ACCRA = 'AFRICA_ACCRA',
  AFRICA_ADDIS_ABABA = 'AFRICA_ADDIS_ABABA',
  AFRICA_ALGIERS = 'AFRICA_ALGIERS',
  AFRICA_ASMARA = 'AFRICA_ASMARA',
  AFRICA_BAMAKO = 'AFRICA_BAMAKO',
  AFRICA_BANGUI = 'AFRICA_BANGUI',
  AFRICA_BANJUL = 'AFRICA_BANJUL',
  AFRICA_BISSAU = 'AFRICA_BISSAU',
  AFRICA_BLANTYRE = 'AFRICA_BLANTYRE',
  AFRICA_BRAZZAVILLE = 'AFRICA_BRAZZAVILLE',
  AFRICA_BUJUMBURA = 'AFRICA_BUJUMBURA',
  AFRICA_CAIRO = 'AFRICA_CAIRO',
  AFRICA_CASABLANCA = 'AFRICA_CASABLANCA',
  AFRICA_CEUTA = 'AFRICA_CEUTA',
  AFRICA_CONAKRY = 'AFRICA_CONAKRY',
  AFRICA_DAKAR = 'AFRICA_DAKAR',
  AFRICA_DAR_ES_SALAAM = 'AFRICA_DAR_ES_SALAAM',
  AFRICA_DJIBOUTI = 'AFRICA_DJIBOUTI',
  AFRICA_DOUALA = 'AFRICA_DOUALA',
  AFRICA_EL_AAIUN = 'AFRICA_EL_AAIUN',
  AFRICA_FREETOWN = 'AFRICA_FREETOWN',
  AFRICA_GABORONE = 'AFRICA_GABORONE',
  AFRICA_HARARE = 'AFRICA_HARARE',
  AFRICA_JOHANNESBURG = 'AFRICA_JOHANNESBURG',
  AFRICA_JUBA = 'AFRICA_JUBA',
  AFRICA_KAMPALA = 'AFRICA_KAMPALA',
  AFRICA_KHARTOUM = 'AFRICA_KHARTOUM',
  AFRICA_KIGALI = 'AFRICA_KIGALI',
  AFRICA_KINSHASA = 'AFRICA_KINSHASA',
  AFRICA_LAGOS = 'AFRICA_LAGOS',
  AFRICA_LIBREVILLE = 'AFRICA_LIBREVILLE',
  AFRICA_LOME = 'AFRICA_LOME',
  AFRICA_LUANDA = 'AFRICA_LUANDA',
  AFRICA_LUBUMBASHI = 'AFRICA_LUBUMBASHI',
  AFRICA_LUSAKA = 'AFRICA_LUSAKA',
  AFRICA_MALABO = 'AFRICA_MALABO',
  AFRICA_MAPUTO = 'AFRICA_MAPUTO',
  AFRICA_MASERU = 'AFRICA_MASERU',
  AFRICA_MBABANE = 'AFRICA_MBABANE',
  AFRICA_MOGADISHU = 'AFRICA_MOGADISHU',
  AFRICA_MONROVIA = 'AFRICA_MONROVIA',
  AFRICA_NAIROBI = 'AFRICA_NAIROBI',
  AFRICA_NDJAMENA = 'AFRICA_NDJAMENA',
  AFRICA_NIAMEY = 'AFRICA_NIAMEY',
  AFRICA_NOUAKCHOTT = 'AFRICA_NOUAKCHOTT',
  AFRICA_OUAGADOUGOU = 'AFRICA_OUAGADOUGOU',
  AFRICA_PORTO_NOVO = 'AFRICA_PORTO_NOVO',
  AFRICA_SAO_TOME = 'AFRICA_SAO_TOME',
  AFRICA_TRIPOLI = 'AFRICA_TRIPOLI',
  AFRICA_TUNIS = 'AFRICA_TUNIS',
  AFRICA_WINDHOEK = 'AFRICA_WINDHOEK',
  AMERICA_ADAK = 'AMERICA_ADAK',
  AMERICA_ANCHORAGE = 'AMERICA_ANCHORAGE',
  AMERICA_ANGUILLA = 'AMERICA_ANGUILLA',
  AMERICA_ANTIGUA = 'AMERICA_ANTIGUA',
  AMERICA_ARAGUAINA = 'AMERICA_ARAGUAINA',
  AMERICA_ARGENTINA_BUENOS_AIRES = 'AMERICA_ARGENTINA_BUENOS_AIRES',
  AMERICA_ARGENTINA_CATAMARCA = 'AMERICA_ARGENTINA_CATAMARCA',
  AMERICA_ARGENTINA_CORDOBA = 'AMERICA_ARGENTINA_CORDOBA',
  AMERICA_ARGENTINA_JUJUY = 'AMERICA_ARGENTINA_JUJUY',
  AMERICA_ARGENTINA_LA_RIOJA = 'AMERICA_ARGENTINA_LA_RIOJA',
  AMERICA_ARGENTINA_MENDOZA = 'AMERICA_ARGENTINA_MENDOZA',
  AMERICA_ARGENTINA_RIO_GALLEGOS = 'AMERICA_ARGENTINA_RIO_GALLEGOS',
  AMERICA_ARGENTINA_SALTA = 'AMERICA_ARGENTINA_SALTA',
  AMERICA_ARGENTINA_SAN_JUAN = 'AMERICA_ARGENTINA_SAN_JUAN',
  AMERICA_ARGENTINA_SAN_LUIS = 'AMERICA_ARGENTINA_SAN_LUIS',
  AMERICA_ARGENTINA_TUCUMAN = 'AMERICA_ARGENTINA_TUCUMAN',
  AMERICA_ARGENTINA_USHUAIA = 'AMERICA_ARGENTINA_USHUAIA',
  AMERICA_ARUBA = 'AMERICA_ARUBA',
  AMERICA_ASUNCION = 'AMERICA_ASUNCION',
  AMERICA_ATIKOKAN = 'AMERICA_ATIKOKAN',
  AMERICA_BAHIA = 'AMERICA_BAHIA',
  AMERICA_BAHIA_BANDERAS = 'AMERICA_BAHIA_BANDERAS',
  AMERICA_BARBADOS = 'AMERICA_BARBADOS',
  AMERICA_BELEM = 'AMERICA_BELEM',
  AMERICA_BELIZE = 'AMERICA_BELIZE',
  AMERICA_BLANC_SABLON = 'AMERICA_BLANC_SABLON',
  AMERICA_BOA_VISTA = 'AMERICA_BOA_VISTA',
  AMERICA_BOGOTA = 'AMERICA_BOGOTA',
  AMERICA_BOISE = 'AMERICA_BOISE',
  AMERICA_CAMBRIDGE_BAY = 'AMERICA_CAMBRIDGE_BAY',
  AMERICA_CAMPO_GRANDE = 'AMERICA_CAMPO_GRANDE',
  AMERICA_CANCUN = 'AMERICA_CANCUN',
  AMERICA_CARACAS = 'AMERICA_CARACAS',
  AMERICA_CAYENNE = 'AMERICA_CAYENNE',
  AMERICA_CAYMAN = 'AMERICA_CAYMAN',
  AMERICA_CHICAGO = 'AMERICA_CHICAGO',
  AMERICA_CHIHUAHUA = 'AMERICA_CHIHUAHUA',
  AMERICA_COSTA_RICA = 'AMERICA_COSTA_RICA',
  AMERICA_CRESTON = 'AMERICA_CRESTON',
  AMERICA_CUIABA = 'AMERICA_CUIABA',
  AMERICA_CURACAO = 'AMERICA_CURACAO',
  AMERICA_DANMARKSHAVN = 'AMERICA_DANMARKSHAVN',
  AMERICA_DAWSON = 'AMERICA_DAWSON',
  AMERICA_DAWSON_CREEK = 'AMERICA_DAWSON_CREEK',
  AMERICA_DENVER = 'AMERICA_DENVER',
  AMERICA_DETROIT = 'AMERICA_DETROIT',
  AMERICA_DOMINICA = 'AMERICA_DOMINICA',
  AMERICA_EDMONTON = 'AMERICA_EDMONTON',
  AMERICA_EIRUNEPE = 'AMERICA_EIRUNEPE',
  AMERICA_EL_SALVADOR = 'AMERICA_EL_SALVADOR',
  AMERICA_FORTALEZA = 'AMERICA_FORTALEZA',
  AMERICA_FORT_NELSON = 'AMERICA_FORT_NELSON',
  AMERICA_GLACE_BAY = 'AMERICA_GLACE_BAY',
  AMERICA_GOOSE_BAY = 'AMERICA_GOOSE_BAY',
  AMERICA_GRAND_TURK = 'AMERICA_GRAND_TURK',
  AMERICA_GRENADA = 'AMERICA_GRENADA',
  AMERICA_GUADELOUPE = 'AMERICA_GUADELOUPE',
  AMERICA_GUATEMALA = 'AMERICA_GUATEMALA',
  AMERICA_GUAYAQUIL = 'AMERICA_GUAYAQUIL',
  AMERICA_GUYANA = 'AMERICA_GUYANA',
  AMERICA_HALIFAX = 'AMERICA_HALIFAX',
  AMERICA_HAVANA = 'AMERICA_HAVANA',
  AMERICA_HERMOSILLO = 'AMERICA_HERMOSILLO',
  AMERICA_INDIANA_INDIANAPOLIS = 'AMERICA_INDIANA_INDIANAPOLIS',
  AMERICA_INDIANA_KNOX = 'AMERICA_INDIANA_KNOX',
  AMERICA_INDIANA_MARENGO = 'AMERICA_INDIANA_MARENGO',
  AMERICA_INDIANA_PETERSBURG = 'AMERICA_INDIANA_PETERSBURG',
  AMERICA_INDIANA_TELL_CITY = 'AMERICA_INDIANA_TELL_CITY',
  AMERICA_INDIANA_VEVAY = 'AMERICA_INDIANA_VEVAY',
  AMERICA_INDIANA_VINCENNES = 'AMERICA_INDIANA_VINCENNES',
  AMERICA_INDIANA_WINAMAC = 'AMERICA_INDIANA_WINAMAC',
  AMERICA_INUVIK = 'AMERICA_INUVIK',
  AMERICA_IQALUIT = 'AMERICA_IQALUIT',
  AMERICA_JAMAICA = 'AMERICA_JAMAICA',
  AMERICA_JUNEAU = 'AMERICA_JUNEAU',
  AMERICA_KENTUCKY_LOUISVILLE = 'AMERICA_KENTUCKY_LOUISVILLE',
  AMERICA_KENTUCKY_MONTICELLO = 'AMERICA_KENTUCKY_MONTICELLO',
  AMERICA_KRALENDIJK = 'AMERICA_KRALENDIJK',
  AMERICA_LA_PAZ = 'AMERICA_LA_PAZ',
  AMERICA_LIMA = 'AMERICA_LIMA',
  AMERICA_LOS_ANGELES = 'AMERICA_LOS_ANGELES',
  AMERICA_LOWER_PRINCES = 'AMERICA_LOWER_PRINCES',
  AMERICA_MACEIO = 'AMERICA_MACEIO',
  AMERICA_MANAGUA = 'AMERICA_MANAGUA',
  AMERICA_MANAUS = 'AMERICA_MANAUS',
  AMERICA_MARIGOT = 'AMERICA_MARIGOT',
  AMERICA_MARTINIQUE = 'AMERICA_MARTINIQUE',
  AMERICA_MATAMOROS = 'AMERICA_MATAMOROS',
  AMERICA_MAZATLAN = 'AMERICA_MAZATLAN',
  AMERICA_MENOMINEE = 'AMERICA_MENOMINEE',
  AMERICA_MERIDA = 'AMERICA_MERIDA',
  AMERICA_METLAKATLA = 'AMERICA_METLAKATLA',
  AMERICA_MEXICO_CITY = 'AMERICA_MEXICO_CITY',
  AMERICA_MIQUELON = 'AMERICA_MIQUELON',
  AMERICA_MONCTON = 'AMERICA_MONCTON',
  AMERICA_MONTERREY = 'AMERICA_MONTERREY',
  AMERICA_MONTEVIDEO = 'AMERICA_MONTEVIDEO',
  AMERICA_MONTSERRAT = 'AMERICA_MONTSERRAT',
  AMERICA_NASSAU = 'AMERICA_NASSAU',
  AMERICA_NEW_YORK = 'AMERICA_NEW_YORK',
  AMERICA_NIPIGON = 'AMERICA_NIPIGON',
  AMERICA_NOME = 'AMERICA_NOME',
  AMERICA_NORONHA = 'AMERICA_NORONHA',
  AMERICA_NORTH_DAKOTA_BEULAH = 'AMERICA_NORTH_DAKOTA_BEULAH',
  AMERICA_NORTH_DAKOTA_CENTER = 'AMERICA_NORTH_DAKOTA_CENTER',
  AMERICA_NORTH_DAKOTA_NEW_SALEM = 'AMERICA_NORTH_DAKOTA_NEW_SALEM',
  AMERICA_NUUK = 'AMERICA_NUUK',
  AMERICA_OJINAGA = 'AMERICA_OJINAGA',
  AMERICA_PANAMA = 'AMERICA_PANAMA',
  AMERICA_PANGNIRTUNG = 'AMERICA_PANGNIRTUNG',
  AMERICA_PARAMARIBO = 'AMERICA_PARAMARIBO',
  AMERICA_PHOENIX = 'AMERICA_PHOENIX',
  AMERICA_PORTO_VELHO = 'AMERICA_PORTO_VELHO',
  AMERICA_PORT_AU_PRINCE = 'AMERICA_PORT_AU_PRINCE',
  AMERICA_PORT_OF_SPAIN = 'AMERICA_PORT_OF_SPAIN',
  AMERICA_PUERTO_RICO = 'AMERICA_PUERTO_RICO',
  AMERICA_PUNTA_ARENAS = 'AMERICA_PUNTA_ARENAS',
  AMERICA_RAINY_RIVER = 'AMERICA_RAINY_RIVER',
  AMERICA_RANKIN_INLET = 'AMERICA_RANKIN_INLET',
  AMERICA_RECIFE = 'AMERICA_RECIFE',
  AMERICA_REGINA = 'AMERICA_REGINA',
  AMERICA_RESOLUTE = 'AMERICA_RESOLUTE',
  AMERICA_RIO_BRANCO = 'AMERICA_RIO_BRANCO',
  AMERICA_SANTAREM = 'AMERICA_SANTAREM',
  AMERICA_SANTIAGO = 'AMERICA_SANTIAGO',
  AMERICA_SANTO_DOMINGO = 'AMERICA_SANTO_DOMINGO',
  AMERICA_SAO_PAULO = 'AMERICA_SAO_PAULO',
  AMERICA_SCORESBYSUND = 'AMERICA_SCORESBYSUND',
  AMERICA_SITKA = 'AMERICA_SITKA',
  AMERICA_ST_BARTHELEMY = 'AMERICA_ST_BARTHELEMY',
  AMERICA_ST_JOHNS = 'AMERICA_ST_JOHNS',
  AMERICA_ST_KITTS = 'AMERICA_ST_KITTS',
  AMERICA_ST_LUCIA = 'AMERICA_ST_LUCIA',
  AMERICA_ST_THOMAS = 'AMERICA_ST_THOMAS',
  AMERICA_ST_VINCENT = 'AMERICA_ST_VINCENT',
  AMERICA_SWIFT_CURRENT = 'AMERICA_SWIFT_CURRENT',
  AMERICA_TEGUCIGALPA = 'AMERICA_TEGUCIGALPA',
  AMERICA_THULE = 'AMERICA_THULE',
  AMERICA_THUNDER_BAY = 'AMERICA_THUNDER_BAY',
  AMERICA_TIJUANA = 'AMERICA_TIJUANA',
  AMERICA_TORONTO = 'AMERICA_TORONTO',
  AMERICA_TORTOLA = 'AMERICA_TORTOLA',
  AMERICA_VANCOUVER = 'AMERICA_VANCOUVER',
  AMERICA_WHITEHORSE = 'AMERICA_WHITEHORSE',
  AMERICA_WINNIPEG = 'AMERICA_WINNIPEG',
  AMERICA_YAKUTAT = 'AMERICA_YAKUTAT',
  AMERICA_YELLOWKNIFE = 'AMERICA_YELLOWKNIFE',
  ANTARCTICA_CASEY = 'ANTARCTICA_CASEY',
  ANTARCTICA_DAVIS = 'ANTARCTICA_DAVIS',
  ANTARCTICA_DUMONTDURVILLE = 'ANTARCTICA_DUMONTDURVILLE',
  ANTARCTICA_MACQUARIE = 'ANTARCTICA_MACQUARIE',
  ANTARCTICA_MAWSON = 'ANTARCTICA_MAWSON',
  ANTARCTICA_MCMURDO = 'ANTARCTICA_MCMURDO',
  ANTARCTICA_PALMER = 'ANTARCTICA_PALMER',
  ANTARCTICA_ROTHERA = 'ANTARCTICA_ROTHERA',
  ANTARCTICA_SYOWA = 'ANTARCTICA_SYOWA',
  ANTARCTICA_TROLL = 'ANTARCTICA_TROLL',
  ANTARCTICA_VOSTOK = 'ANTARCTICA_VOSTOK',
  ARCTIC_LONGYEARBYEN = 'ARCTIC_LONGYEARBYEN',
  ASIA_ADEN = 'ASIA_ADEN',
  ASIA_ALMATY = 'ASIA_ALMATY',
  ASIA_AMMAN = 'ASIA_AMMAN',
  ASIA_ANADYR = 'ASIA_ANADYR',
  ASIA_AQTAU = 'ASIA_AQTAU',
  ASIA_AQTOBE = 'ASIA_AQTOBE',
  ASIA_ASHGABAT = 'ASIA_ASHGABAT',
  ASIA_ATYRAU = 'ASIA_ATYRAU',
  ASIA_BAGHDAD = 'ASIA_BAGHDAD',
  ASIA_BAHRAIN = 'ASIA_BAHRAIN',
  ASIA_BAKU = 'ASIA_BAKU',
  ASIA_BANGKOK = 'ASIA_BANGKOK',
  ASIA_BARNAUL = 'ASIA_BARNAUL',
  ASIA_BEIRUT = 'ASIA_BEIRUT',
  ASIA_BISHKEK = 'ASIA_BISHKEK',
  ASIA_BRUNEI = 'ASIA_BRUNEI',
  ASIA_CHITA = 'ASIA_CHITA',
  ASIA_CHOIBALSAN = 'ASIA_CHOIBALSAN',
  ASIA_COLOMBO = 'ASIA_COLOMBO',
  ASIA_DAMASCUS = 'ASIA_DAMASCUS',
  ASIA_DHAKA = 'ASIA_DHAKA',
  ASIA_DILI = 'ASIA_DILI',
  ASIA_DUBAI = 'ASIA_DUBAI',
  ASIA_DUSHANBE = 'ASIA_DUSHANBE',
  ASIA_FAMAGUSTA = 'ASIA_FAMAGUSTA',
  ASIA_GAZA = 'ASIA_GAZA',
  ASIA_HEBRON = 'ASIA_HEBRON',
  ASIA_HONG_KONG = 'ASIA_HONG_KONG',
  ASIA_HOVD = 'ASIA_HOVD',
  ASIA_HO_CHI_MINH = 'ASIA_HO_CHI_MINH',
  ASIA_IRKUTSK = 'ASIA_IRKUTSK',
  ASIA_JAKARTA = 'ASIA_JAKARTA',
  ASIA_JAYAPURA = 'ASIA_JAYAPURA',
  ASIA_JERUSALEM = 'ASIA_JERUSALEM',
  ASIA_KABUL = 'ASIA_KABUL',
  ASIA_KAMCHATKA = 'ASIA_KAMCHATKA',
  ASIA_KARACHI = 'ASIA_KARACHI',
  ASIA_KATHMANDU = 'ASIA_KATHMANDU',
  ASIA_KHANDYGA = 'ASIA_KHANDYGA',
  ASIA_KOLKATA = 'ASIA_KOLKATA',
  ASIA_KRASNOYARSK = 'ASIA_KRASNOYARSK',
  ASIA_KUALA_LUMPUR = 'ASIA_KUALA_LUMPUR',
  ASIA_KUCHING = 'ASIA_KUCHING',
  ASIA_KUWAIT = 'ASIA_KUWAIT',
  ASIA_MACAU = 'ASIA_MACAU',
  ASIA_MAGADAN = 'ASIA_MAGADAN',
  ASIA_MAKASSAR = 'ASIA_MAKASSAR',
  ASIA_MANILA = 'ASIA_MANILA',
  ASIA_MUSCAT = 'ASIA_MUSCAT',
  ASIA_NICOSIA = 'ASIA_NICOSIA',
  ASIA_NOVOKUZNETSK = 'ASIA_NOVOKUZNETSK',
  ASIA_NOVOSIBIRSK = 'ASIA_NOVOSIBIRSK',
  ASIA_OMSK = 'ASIA_OMSK',
  ASIA_ORAL = 'ASIA_ORAL',
  ASIA_PHNOM_PENH = 'ASIA_PHNOM_PENH',
  ASIA_PONTIANAK = 'ASIA_PONTIANAK',
  ASIA_PYONGYANG = 'ASIA_PYONGYANG',
  ASIA_QATAR = 'ASIA_QATAR',
  ASIA_QOSTANAY = 'ASIA_QOSTANAY',
  ASIA_QYZYLORDA = 'ASIA_QYZYLORDA',
  ASIA_RIYADH = 'ASIA_RIYADH',
  ASIA_SAKHALIN = 'ASIA_SAKHALIN',
  ASIA_SAMARKAND = 'ASIA_SAMARKAND',
  ASIA_SEOUL = 'ASIA_SEOUL',
  ASIA_SHANGHAI = 'ASIA_SHANGHAI',
  ASIA_SINGAPORE = 'ASIA_SINGAPORE',
  ASIA_SREDNEKOLYMSK = 'ASIA_SREDNEKOLYMSK',
  ASIA_TAIPEI = 'ASIA_TAIPEI',
  ASIA_TASHKENT = 'ASIA_TASHKENT',
  ASIA_TBILISI = 'ASIA_TBILISI',
  ASIA_TEHRAN = 'ASIA_TEHRAN',
  ASIA_THIMPHU = 'ASIA_THIMPHU',
  ASIA_TOKYO = 'ASIA_TOKYO',
  ASIA_TOMSK = 'ASIA_TOMSK',
  ASIA_ULAANBAATAR = 'ASIA_ULAANBAATAR',
  ASIA_URUMQI = 'ASIA_URUMQI',
  ASIA_UST_NERA = 'ASIA_UST_NERA',
  ASIA_VIENTIANE = 'ASIA_VIENTIANE',
  ASIA_VLADIVOSTOK = 'ASIA_VLADIVOSTOK',
  ASIA_YAKUTSK = 'ASIA_YAKUTSK',
  ASIA_YANGON = 'ASIA_YANGON',
  ASIA_YEKATERINBURG = 'ASIA_YEKATERINBURG',
  ASIA_YEREVAN = 'ASIA_YEREVAN',
  ATLANTIC_AZORES = 'ATLANTIC_AZORES',
  ATLANTIC_BERMUDA = 'ATLANTIC_BERMUDA',
  ATLANTIC_CANARY = 'ATLANTIC_CANARY',
  ATLANTIC_CAPE_VERDE = 'ATLANTIC_CAPE_VERDE',
  ATLANTIC_FAROE = 'ATLANTIC_FAROE',
  ATLANTIC_MADEIRA = 'ATLANTIC_MADEIRA',
  ATLANTIC_REYKJAVIK = 'ATLANTIC_REYKJAVIK',
  ATLANTIC_SOUTH_GEORGIA = 'ATLANTIC_SOUTH_GEORGIA',
  ATLANTIC_STANLEY = 'ATLANTIC_STANLEY',
  ATLANTIC_ST_HELENA = 'ATLANTIC_ST_HELENA',
  AUSTRALIA_ADELAIDE = 'AUSTRALIA_ADELAIDE',
  AUSTRALIA_BRISBANE = 'AUSTRALIA_BRISBANE',
  AUSTRALIA_BROKEN_HILL = 'AUSTRALIA_BROKEN_HILL',
  AUSTRALIA_DARWIN = 'AUSTRALIA_DARWIN',
  AUSTRALIA_EUCLA = 'AUSTRALIA_EUCLA',
  AUSTRALIA_HOBART = 'AUSTRALIA_HOBART',
  AUSTRALIA_LINDEMAN = 'AUSTRALIA_LINDEMAN',
  AUSTRALIA_LORD_HOWE = 'AUSTRALIA_LORD_HOWE',
  AUSTRALIA_MELBOURNE = 'AUSTRALIA_MELBOURNE',
  AUSTRALIA_PERTH = 'AUSTRALIA_PERTH',
  AUSTRALIA_SYDNEY = 'AUSTRALIA_SYDNEY',
  CANADA_ATLANTIC = 'CANADA_ATLANTIC',
  CANADA_CENTRAL = 'CANADA_CENTRAL',
  CANADA_EASTERN = 'CANADA_EASTERN',
  CANADA_MOUNTAIN = 'CANADA_MOUNTAIN',
  CANADA_NEWFOUNDLAND = 'CANADA_NEWFOUNDLAND',
  CANADA_PACIFIC = 'CANADA_PACIFIC',
  EUROPE_AMSTERDAM = 'EUROPE_AMSTERDAM',
  EUROPE_ANDORRA = 'EUROPE_ANDORRA',
  EUROPE_ASTRAKHAN = 'EUROPE_ASTRAKHAN',
  EUROPE_ATHENS = 'EUROPE_ATHENS',
  EUROPE_BELGRADE = 'EUROPE_BELGRADE',
  EUROPE_BERLIN = 'EUROPE_BERLIN',
  EUROPE_BRATISLAVA = 'EUROPE_BRATISLAVA',
  EUROPE_BRUSSELS = 'EUROPE_BRUSSELS',
  EUROPE_BUCHAREST = 'EUROPE_BUCHAREST',
  EUROPE_BUDAPEST = 'EUROPE_BUDAPEST',
  EUROPE_BUSINGEN = 'EUROPE_BUSINGEN',
  EUROPE_CHISINAU = 'EUROPE_CHISINAU',
  EUROPE_COPENHAGEN = 'EUROPE_COPENHAGEN',
  EUROPE_DUBLIN = 'EUROPE_DUBLIN',
  EUROPE_GIBRALTAR = 'EUROPE_GIBRALTAR',
  EUROPE_GUERNSEY = 'EUROPE_GUERNSEY',
  EUROPE_HELSINKI = 'EUROPE_HELSINKI',
  EUROPE_ISLE_OF_MAN = 'EUROPE_ISLE_OF_MAN',
  EUROPE_ISTANBUL = 'EUROPE_ISTANBUL',
  EUROPE_JERSEY = 'EUROPE_JERSEY',
  EUROPE_KALININGRAD = 'EUROPE_KALININGRAD',
  EUROPE_KIEV = 'EUROPE_KIEV',
  EUROPE_KIROV = 'EUROPE_KIROV',
  EUROPE_LISBON = 'EUROPE_LISBON',
  EUROPE_LJUBLJANA = 'EUROPE_LJUBLJANA',
  EUROPE_LONDON = 'EUROPE_LONDON',
  EUROPE_LUXEMBOURG = 'EUROPE_LUXEMBOURG',
  EUROPE_MADRID = 'EUROPE_MADRID',
  EUROPE_MALTA = 'EUROPE_MALTA',
  EUROPE_MARIEHAMN = 'EUROPE_MARIEHAMN',
  EUROPE_MINSK = 'EUROPE_MINSK',
  EUROPE_MONACO = 'EUROPE_MONACO',
  EUROPE_MOSCOW = 'EUROPE_MOSCOW',
  EUROPE_OSLO = 'EUROPE_OSLO',
  EUROPE_PARIS = 'EUROPE_PARIS',
  EUROPE_PODGORICA = 'EUROPE_PODGORICA',
  EUROPE_PRAGUE = 'EUROPE_PRAGUE',
  EUROPE_RIGA = 'EUROPE_RIGA',
  EUROPE_ROME = 'EUROPE_ROME',
  EUROPE_SAMARA = 'EUROPE_SAMARA',
  EUROPE_SAN_MARINO = 'EUROPE_SAN_MARINO',
  EUROPE_SARAJEVO = 'EUROPE_SARAJEVO',
  EUROPE_SARATOV = 'EUROPE_SARATOV',
  EUROPE_SIMFEROPOL = 'EUROPE_SIMFEROPOL',
  EUROPE_SKOPJE = 'EUROPE_SKOPJE',
  EUROPE_SOFIA = 'EUROPE_SOFIA',
  EUROPE_STOCKHOLM = 'EUROPE_STOCKHOLM',
  EUROPE_TALLINN = 'EUROPE_TALLINN',
  EUROPE_TIRANE = 'EUROPE_TIRANE',
  EUROPE_ULYANOVSK = 'EUROPE_ULYANOVSK',
  EUROPE_UZHGOROD = 'EUROPE_UZHGOROD',
  EUROPE_VADUZ = 'EUROPE_VADUZ',
  EUROPE_VATICAN = 'EUROPE_VATICAN',
  EUROPE_VIENNA = 'EUROPE_VIENNA',
  EUROPE_VILNIUS = 'EUROPE_VILNIUS',
  EUROPE_VOLGOGRAD = 'EUROPE_VOLGOGRAD',
  EUROPE_WARSAW = 'EUROPE_WARSAW',
  EUROPE_ZAGREB = 'EUROPE_ZAGREB',
  EUROPE_ZAPOROZHYE = 'EUROPE_ZAPOROZHYE',
  EUROPE_ZURICH = 'EUROPE_ZURICH',
  GMT = 'GMT',
  INDIAN_ANTANANARIVO = 'INDIAN_ANTANANARIVO',
  INDIAN_CHAGOS = 'INDIAN_CHAGOS',
  INDIAN_CHRISTMAS = 'INDIAN_CHRISTMAS',
  INDIAN_COCOS = 'INDIAN_COCOS',
  INDIAN_COMORO = 'INDIAN_COMORO',
  INDIAN_KERGUELEN = 'INDIAN_KERGUELEN',
  INDIAN_MAHE = 'INDIAN_MAHE',
  INDIAN_MALDIVES = 'INDIAN_MALDIVES',
  INDIAN_MAURITIUS = 'INDIAN_MAURITIUS',
  INDIAN_MAYOTTE = 'INDIAN_MAYOTTE',
  INDIAN_REUNION = 'INDIAN_REUNION',
  PACIFIC_APIA = 'PACIFIC_APIA',
  PACIFIC_AUCKLAND = 'PACIFIC_AUCKLAND',
  PACIFIC_BOUGAINVILLE = 'PACIFIC_BOUGAINVILLE',
  PACIFIC_CHATHAM = 'PACIFIC_CHATHAM',
  PACIFIC_CHUUK = 'PACIFIC_CHUUK',
  PACIFIC_EASTER = 'PACIFIC_EASTER',
  PACIFIC_EFATE = 'PACIFIC_EFATE',
  PACIFIC_FAKAOFO = 'PACIFIC_FAKAOFO',
  PACIFIC_FIJI = 'PACIFIC_FIJI',
  PACIFIC_FUNAFUTI = 'PACIFIC_FUNAFUTI',
  PACIFIC_GALAPAGOS = 'PACIFIC_GALAPAGOS',
  PACIFIC_GAMBIER = 'PACIFIC_GAMBIER',
  PACIFIC_GUADALCANAL = 'PACIFIC_GUADALCANAL',
  PACIFIC_GUAM = 'PACIFIC_GUAM',
  PACIFIC_HONOLULU = 'PACIFIC_HONOLULU',
  PACIFIC_KANTON = 'PACIFIC_KANTON',
  PACIFIC_KIRITIMATI = 'PACIFIC_KIRITIMATI',
  PACIFIC_KOSRAE = 'PACIFIC_KOSRAE',
  PACIFIC_KWAJALEIN = 'PACIFIC_KWAJALEIN',
  PACIFIC_MAJURO = 'PACIFIC_MAJURO',
  PACIFIC_MARQUESAS = 'PACIFIC_MARQUESAS',
  PACIFIC_MIDWAY = 'PACIFIC_MIDWAY',
  PACIFIC_NAURU = 'PACIFIC_NAURU',
  PACIFIC_NIUE = 'PACIFIC_NIUE',
  PACIFIC_NORFOLK = 'PACIFIC_NORFOLK',
  PACIFIC_NOUMEA = 'PACIFIC_NOUMEA',
  PACIFIC_PAGO_PAGO = 'PACIFIC_PAGO_PAGO',
  PACIFIC_PALAU = 'PACIFIC_PALAU',
  PACIFIC_PITCAIRN = 'PACIFIC_PITCAIRN',
  PACIFIC_POHNPEI = 'PACIFIC_POHNPEI',
  PACIFIC_PORT_MORESBY = 'PACIFIC_PORT_MORESBY',
  PACIFIC_RAROTONGA = 'PACIFIC_RAROTONGA',
  PACIFIC_SAIPAN = 'PACIFIC_SAIPAN',
  PACIFIC_TAHITI = 'PACIFIC_TAHITI',
  PACIFIC_TARAWA = 'PACIFIC_TARAWA',
  PACIFIC_TONGATAPU = 'PACIFIC_TONGATAPU',
  PACIFIC_WAKE = 'PACIFIC_WAKE',
  PACIFIC_WALLIS = 'PACIFIC_WALLIS',
  UNKNOWN = 'UNKNOWN',
  US_ALASKA = 'US_ALASKA',
  US_ARIZONA = 'US_ARIZONA',
  US_CENTRAL = 'US_CENTRAL',
  US_EASTERN = 'US_EASTERN',
  US_HAWAII = 'US_HAWAII',
  US_MOUNTAIN = 'US_MOUNTAIN',
  US_PACIFIC = 'US_PACIFIC',
  UTC = 'UTC',
}

export type DcimSiteTimeZoneChoicesEnumFilter = {
  exact?: InputMaybe<DcimSiteTimeZoneChoices>;
  except_?: InputMaybe<DcimSiteTimeZoneChoices>;
  in_?: InputMaybe<Array<DcimSiteTimeZoneChoices>>;
};

export type DefCpeMatch = {
  __typename?: 'DefCpeMatch';
  cpe22uri?: Maybe<Scalars['String']>;
  cpe23uri?: Maybe<Scalars['String']>;
  cpeName?: Maybe<DefCpeName>;
  versionEndExcluding?: Maybe<Scalars['String']>;
  versionEndIncluding?: Maybe<Scalars['String']>;
  versionStartExcluding?: Maybe<Scalars['String']>;
  versionStartIncluding?: Maybe<Scalars['String']>;
  vulnerable?: Maybe<Scalars['Boolean']>;
};

export type DefCpeName = {
  __typename?: 'DefCpeName';
  cpe22Uri?: Maybe<Scalars['String']>;
  cpe23Uri?: Maybe<Scalars['String']>;
  lastModifiedDate?: Maybe<Scalars['String']>;
};

export type DefCveItemInput = {
  cve?: InputMaybe<CveItemInput>;
};

export type DefNode = {
  __typename?: 'DefNode';
  children?: Maybe<Array<Maybe<DefNode>>>;
  cpeMatch?: Maybe<Array<Maybe<DefCpeMatch>>>;
  negate?: Maybe<Scalars['String']>;
  operator?: Maybe<Scalars['String']>;
};

export type DeviceBayFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  device?: InputMaybe<DeviceFilter>;
  deviceId?: InputMaybe<StrawberryIdFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  installedDevice?: InputMaybe<DeviceFilter>;
  installedDeviceId?: InputMaybe<StrawberryIdFilter>;
  label?: InputMaybe<StrFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type DeviceBayFilterAndFilterEntry = {
  AND: Array<DeviceBayFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type DeviceBayFilterOrFilterEntry = {
  OR: Array<DeviceBayFilter>;
  negate?: Scalars['Boolean'];
};

export type DeviceBayType = AssetFederationBase &
  AssetType & {
    __typename?: 'DeviceBayType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    device?: Maybe<DeviceType>;
    deviceId?: Maybe<Scalars['ID']>;
    id: Scalars['ID'];
    installedDevice?: Maybe<DeviceType>;
    installedDeviceId?: Maybe<Scalars['ID']>;
    label?: Maybe<Scalars['String']>;
    lastUpdated?: Maybe<Scalars['DateTime']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
  };

export type DeviceBayTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type DeviceBayTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type DeviceBayTypeResultSet = {
  __typename?: 'DeviceBayTypeResultSet';
  data: Array<DeviceBayType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type DeviceFilter = {
  Name?: InputMaybe<StrFilter>;
  assetTag?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  cluster?: InputMaybe<ClusterFilter>;
  clusterId?: InputMaybe<StrawberryIdFilter>;
  comments?: InputMaybe<StrFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  deviceRole?: InputMaybe<DeviceRoleFilter>;
  deviceRoleId?: InputMaybe<StrawberryIdFilter>;
  deviceType?: InputMaybe<DeviceTypeFilter>;
  deviceTypeId?: InputMaybe<StrawberryIdFilter>;
  face?: InputMaybe<DcimDeviceFaceChoicesEnumFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  location?: InputMaybe<LocationFilter>;
  locationId?: InputMaybe<StrawberryIdFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  platform?: InputMaybe<PlatformFilter>;
  platformId?: InputMaybe<StrawberryIdFilter>;
  position?: InputMaybe<IntFilter>;
  primaryIp?: InputMaybe<IpAddressFilter>;
  primaryIp4?: InputMaybe<IpAddressFilter>;
  primaryIp4Id?: InputMaybe<StrawberryIdFilter>;
  primaryIp6?: InputMaybe<IpAddressFilter>;
  primaryIp6Id?: InputMaybe<StrawberryIdFilter>;
  primaryIpId?: InputMaybe<StrawberryIdFilter>;
  rack?: InputMaybe<RackFilter>;
  rackId?: InputMaybe<StrawberryIdFilter>;
  serial?: InputMaybe<StrFilter>;
  site?: InputMaybe<SiteFilter>;
  siteId?: InputMaybe<StrawberryIdFilter>;
  status?: InputMaybe<DcimDeviceStatusChoicesEnumFilter>;
  tenant?: InputMaybe<TenantFilter>;
  tenantId?: InputMaybe<StrawberryIdFilter>;
  uuid?: InputMaybe<StrFilter>;
  vcPosition?: InputMaybe<IntFilter>;
  vcPriority?: InputMaybe<IntFilter>;
  virtualChassis?: InputMaybe<VirtualChassisFilter>;
  virtualChassisId?: InputMaybe<StrawberryIdFilter>;
};

export type DeviceFilterAndFilterEntry = {
  AND: Array<DeviceFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type DeviceFilterOrFilterEntry = {
  OR: Array<DeviceFilter>;
  negate?: Scalars['Boolean'];
};

export type DeviceRoleFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  color?: InputMaybe<StrFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  deviceCount?: InputMaybe<IntFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  slug?: InputMaybe<StrFilter>;
  uuid?: InputMaybe<StrFilter>;
  virtualmachineCount?: InputMaybe<IntFilter>;
  vmRole?: InputMaybe<BoolFilter>;
};

export type DeviceRoleFilterAndFilterEntry = {
  AND: Array<DeviceRoleFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type DeviceRoleFilterOrFilterEntry = {
  OR: Array<DeviceRoleFilter>;
  negate?: Scalars['Boolean'];
};

export type DeviceRoleType = AssetFederationBase &
  AssetType & {
    __typename?: 'DeviceRoleType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    color?: Maybe<Scalars['String']>;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    deviceCount?: Maybe<Scalars['Int']>;
    devices: DeviceTypeResultSet;
    id: Scalars['ID'];
    lastUpdated?: Maybe<Scalars['DateTime']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    slug?: Maybe<Scalars['String']>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
    virtualMachines: VirtualMachineTypeResultSet;
    virtualmachineCount?: Maybe<Scalars['Int']>;
    vmRole?: Maybe<Scalars['Boolean']>;
  };

export type DeviceRoleTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type DeviceRoleTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type DeviceRoleTypeResultSet = {
  __typename?: 'DeviceRoleTypeResultSet';
  data: Array<DeviceRoleType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type DeviceType = AssetFederationBase &
  AssetType & {
    __typename?: 'DeviceType';
    Name?: Maybe<Scalars['String']>;
    assetTag?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    cluster?: Maybe<ClusterType>;
    clusterId?: Maybe<Scalars['ID']>;
    comments?: Maybe<Scalars['String']>;
    consolePorts: ConsolePortTypeResultSet;
    consoleServerPorts: ConsoleServerPortTypeResultSet;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    deviceBays: DeviceBayTypeResultSet;
    deviceRole?: Maybe<DeviceRoleType>;
    deviceRoleId?: Maybe<Scalars['ID']>;
    deviceType?: Maybe<DeviceTypeType>;
    deviceTypeId?: Maybe<Scalars['ID']>;
    face?: Maybe<DcimDeviceFaceChoices>;
    id: Scalars['ID'];
    lastUpdated?: Maybe<Scalars['DateTime']>;
    location?: Maybe<LocationType>;
    locationId?: Maybe<Scalars['ID']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    platform?: Maybe<PlatformType>;
    platformId?: Maybe<Scalars['ID']>;
    position?: Maybe<Scalars['Int']>;
    powerOutlets: PowerOutletTypeResultSet;
    powerPorts: PowerPortTypeResultSet;
    primaryIp?: Maybe<IpAddressType>;
    primaryIp4?: Maybe<IpAddressType>;
    primaryIp4Id?: Maybe<Scalars['ID']>;
    primaryIp6?: Maybe<IpAddressType>;
    primaryIp6Id?: Maybe<Scalars['ID']>;
    primaryIpId?: Maybe<Scalars['ID']>;
    rack?: Maybe<RackType>;
    rackId?: Maybe<Scalars['ID']>;
    serial?: Maybe<Scalars['String']>;
    services: ServiceTypeResultSet;
    site?: Maybe<SiteType>;
    siteId?: Maybe<Scalars['ID']>;
    status?: Maybe<DcimDeviceStatusChoices>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    tenant?: Maybe<TenantType>;
    tenantId?: Maybe<Scalars['ID']>;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
    vcPosition?: Maybe<Scalars['Int']>;
    vcPriority?: Maybe<Scalars['Int']>;
    virtualChassis?: Maybe<VirtualChassisType>;
    virtualChassisId?: Maybe<Scalars['ID']>;
  };

export type DeviceTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type DeviceTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type DeviceTypeFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  comments?: InputMaybe<StrFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  deviceCount?: InputMaybe<IntFilter>;
  frontImage?: InputMaybe<StrFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  isFullDepth?: InputMaybe<BoolFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  manufacturer?: InputMaybe<ManufacturerFilter>;
  manufacturerId?: InputMaybe<StrawberryIdFilter>;
  model?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  partNumber?: InputMaybe<StrFilter>;
  rearImage?: InputMaybe<StrFilter>;
  slug?: InputMaybe<StrFilter>;
  subdeviceRole?: InputMaybe<DcimDeviceTypeSubdeviceRoleChoicesEnumFilter>;
  uHeight?: InputMaybe<IntFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type DeviceTypeFilterAndFilterEntry = {
  AND: Array<DeviceTypeFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type DeviceTypeFilterOrFilterEntry = {
  OR: Array<DeviceTypeFilter>;
  negate?: Scalars['Boolean'];
};

export type DeviceTypeResultSet = {
  __typename?: 'DeviceTypeResultSet';
  data: Array<DeviceType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type DeviceTypeType = AssetFederationBase &
  AssetType & {
    __typename?: 'DeviceTypeType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    comments?: Maybe<Scalars['String']>;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    deviceCount?: Maybe<Scalars['Int']>;
    frontImage?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    instances: DeviceTypeResultSet;
    isFullDepth?: Maybe<Scalars['Boolean']>;
    lastUpdated?: Maybe<Scalars['DateTime']>;
    manufacturer?: Maybe<ManufacturerType>;
    manufacturerId?: Maybe<Scalars['ID']>;
    model?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    partNumber?: Maybe<Scalars['String']>;
    rearImage?: Maybe<Scalars['String']>;
    slug?: Maybe<Scalars['String']>;
    subdeviceRole?: Maybe<DcimDeviceTypeSubdeviceRoleChoices>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    uHeight?: Maybe<Scalars['Int']>;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
  };

export type DeviceTypeTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type DeviceTypeTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type DeviceTypeTypeResultSet = {
  __typename?: 'DeviceTypeTypeResultSet';
  data: Array<DeviceTypeType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type Directory = {
  __typename?: 'Directory';
  case?: Maybe<Case>;
  children?: Maybe<CaseFileItemNestedList>;
  created?: Maybe<Scalars['DateTime']>;
  createdBy?: Maybe<CaseDbUser>;
  id: Scalars['ID'];
  name: Scalars['String'];
  parent?: Maybe<Directory>;
  type?: Maybe<Scalars['String']>;
};

export type DirectoryChildrenArgs = {
  filter?: InputMaybe<Array<CaseFileItemFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<CaseFileItemOrdEnumOrderingEntry>>;
};

export type DirectoryCreate = {
  children?: InputMaybe<Array<Scalars['ID']>>;
  createdBy?: InputMaybe<Scalars['ID']>;
  name: Scalars['String'];
  parent?: InputMaybe<Scalars['ID']>;
};

export type DirectoryFilter1 = {
  case?: InputMaybe<CaseFilter1>;
  children?: InputMaybe<CaseFileItemFilter1>;
  created?: InputMaybe<DateTimeFieldFilter>;
  createdBy?: InputMaybe<CaseDbUserFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
  parent?: InputMaybe<DirectoryFilter1>;
  type?: InputMaybe<StrFieldFilter>;
};

export type DirectoryFilter1AndFilterEntry = {
  AND: Array<DirectoryFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type DirectoryFilter1OrFilterEntry = {
  OR: DirectoryFilter1;
  negate?: Scalars['Boolean'];
};

export enum DirectoryOrdEnum {
  CREATED = 'CREATED',
  ID = 'ID',
  NAME = 'NAME',
  TYPE = 'TYPE',
}

export type DirectoryOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: DirectoryOrdEnum;
};

export type DirectoryPaginated = {
  __typename?: 'DirectoryPaginated';
  data: Array<Directory>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type DirectoryUpdate = {
  children?: InputMaybe<RelationUpdate>;
  createdBy?: InputMaybe<Scalars['ID']>;
  name?: InputMaybe<Scalars['String']>;
  parent?: InputMaybe<Scalars['ID']>;
};

export type DomainInputOutput = TaskInputOutput & {
  __typename?: 'DomainInputOutput';
  description?: Maybe<Scalars['String']>;
  domainValue?: Maybe<Scalars['String']>;
  id: Scalars['ID'];
  inputOf?: Maybe<Task>;
  outputOf?: Maybe<Task>;
  stringifiedValue?: Maybe<Scalars['String']>;
  type?: Maybe<Scalars['String']>;
};

export type DomainInputOutputCreate = {
  description?: InputMaybe<Scalars['String']>;
  domainValue?: InputMaybe<Scalars['String']>;
  inputOf?: InputMaybe<Scalars['ID']>;
  outputOf?: InputMaybe<Scalars['ID']>;
};

export type DomainInputOutputFilter1 = {
  description?: InputMaybe<StrFieldFilter>;
  domainValue?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  inputOf?: InputMaybe<TaskFilter1>;
  outputOf?: InputMaybe<TaskFilter1>;
  type?: InputMaybe<StrFieldFilter>;
};

export type DomainInputOutputFilter1AndFilterEntry = {
  AND: Array<DomainInputOutputFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type DomainInputOutputFilter1OrFilterEntry = {
  OR: DomainInputOutputFilter1;
  negate?: Scalars['Boolean'];
};

export enum DomainInputOutputOrdEnum {
  DESCRIPTION = 'DESCRIPTION',
  DOMAIN_VALUE = 'DOMAIN_VALUE',
  ID = 'ID',
  TYPE = 'TYPE',
}

export type DomainInputOutputOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: DomainInputOutputOrdEnum;
};

export type DomainInputOutputPaginated = {
  __typename?: 'DomainInputOutputPaginated';
  data: Array<DomainInputOutput>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type DomainInputOutputUpdate = {
  description?: InputMaybe<Scalars['String']>;
  domainValue?: InputMaybe<Scalars['String']>;
  inputOf?: InputMaybe<Scalars['ID']>;
  outputOf?: InputMaybe<Scalars['ID']>;
};

export type DomainName = Host &
  Observable &
  ObservableFederationBase & {
    __typename?: 'DomainName';
    cases: CaseFederationResult;
    ctiEntries?: Maybe<ObservableLinkNestedList>;
    description?: Maybe<Scalars['String']>;
    domainName: Scalars['String'];
    domainResolvedFromIps?: Maybe<IpAddressToDomainResolutionNestedList>;
    domainResolvesToIps?: Maybe<DomainToIpAddressResolutionNestedList>;
    emails?: Maybe<EmailAddressNestedList>;
    id: Scalars['ID'];
    observableType?: Maybe<Scalars['String']>;
    observableTypeEnum?: Maybe<KnownObservablesEnum>;
    resolvedFromDomains?: Maybe<DomainToDomainResolutionNestedList>;
    resolvesToDomains?: Maybe<DomainToDomainResolutionNestedList>;
    tasks: TaskFederationResult;
    uniqueIdentifier: Scalars['String'];
    urls?: Maybe<UrlNestedList>;
  };

export type DomainNameCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type DomainNameCtiEntriesArgs = {
  filter?: InputMaybe<Array<ObservableLinkFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ObservableLinkOrdEnumOrderingEntry>>;
};

export type DomainNameDomainResolvedFromIpsArgs = {
  filter?: InputMaybe<Array<IpAddressToDomainResolutionFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<IpAddressToDomainResolutionOrdEnumOrderingEntry>>;
};

export type DomainNameDomainResolvesToIpsArgs = {
  filter?: InputMaybe<Array<DomainToIpAddressResolutionFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<DomainToIpAddressResolutionOrdEnumOrderingEntry>>;
};

export type DomainNameEmailsArgs = {
  filter?: InputMaybe<Array<EmailAddressFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<EmailAddressOrdEnumOrderingEntry>>;
};

export type DomainNameResolvedFromDomainsArgs = {
  filter?: InputMaybe<Array<DomainToDomainResolutionFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<DomainToDomainResolutionOrdEnumOrderingEntry>>;
};

export type DomainNameResolvesToDomainsArgs = {
  filter?: InputMaybe<Array<DomainToDomainResolutionFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<DomainToDomainResolutionOrdEnumOrderingEntry>>;
};

export type DomainNameTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type DomainNameUrlsArgs = {
  filter?: InputMaybe<Array<UrlFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<UrlOrdEnumOrderingEntry>>;
};

export type DomainNameCreate = {
  ctiEntries?: InputMaybe<Array<Scalars['ID']>>;
  description?: InputMaybe<Scalars['String']>;
  domainName: Scalars['String'];
  domainResolvedFromIps?: InputMaybe<Array<Scalars['ID']>>;
  domainResolvesToIps?: InputMaybe<Array<Scalars['ID']>>;
  emails?: InputMaybe<Array<Scalars['ID']>>;
  resolvedFromDomains?: InputMaybe<Array<Scalars['ID']>>;
  resolvesToDomains?: InputMaybe<Array<Scalars['ID']>>;
  urls?: InputMaybe<Array<Scalars['ID']>>;
};

export type DomainNameFilter1 = {
  ctiEntries?: InputMaybe<ObservableLinkFilter1>;
  description?: InputMaybe<StrFieldFilter>;
  domainName?: InputMaybe<StrFieldFilter>;
  domainResolvedFromIps?: InputMaybe<IpAddressToDomainResolutionFilter1>;
  domainResolvesToIps?: InputMaybe<DomainToIpAddressResolutionFilter1>;
  emails?: InputMaybe<EmailAddressFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  observableType?: InputMaybe<StrFieldFilter>;
  resolvedFromDomains?: InputMaybe<DomainToDomainResolutionFilter1>;
  resolvesToDomains?: InputMaybe<DomainToDomainResolutionFilter1>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
  urls?: InputMaybe<UrlFilter1>;
};

export type DomainNameFilter1AndFilterEntry = {
  AND: Array<DomainNameFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type DomainNameFilter1OrFilterEntry = {
  OR: DomainNameFilter1;
  negate?: Scalars['Boolean'];
};

export type DomainNameNestedListResult = {
  __typename?: 'DomainNameNestedListResult';
  data?: Maybe<DomainName>;
  error?: Maybe<ValidationError>;
};

export enum DomainNameOrdEnum {
  DESCRIPTION = 'DESCRIPTION',
  DOMAIN_NAME = 'DOMAIN_NAME',
  ID = 'ID',
  OBSERVABLE_TYPE = 'OBSERVABLE_TYPE',
  UNIQUE_IDENTIFIER = 'UNIQUE_IDENTIFIER',
}

export type DomainNameOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: DomainNameOrdEnum;
};

export type DomainNamePaginated = {
  __typename?: 'DomainNamePaginated';
  data: Array<DomainName>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type DomainNameUpdate = {
  ctiEntries?: InputMaybe<RelationUpdate>;
  description?: InputMaybe<Scalars['String']>;
  domainName?: InputMaybe<Scalars['String']>;
  domainResolvedFromIps?: InputMaybe<RelationUpdate>;
  domainResolvesToIps?: InputMaybe<RelationUpdate>;
  emails?: InputMaybe<RelationUpdate>;
  resolvedFromDomains?: InputMaybe<RelationUpdate>;
  resolvesToDomains?: InputMaybe<RelationUpdate>;
  urls?: InputMaybe<RelationUpdate>;
};

export type DomainToDomainResolution = Observable &
  ObservableFederationBase & {
    __typename?: 'DomainToDomainResolution';
    cases: CaseFederationResult;
    ctiEntries?: Maybe<ObservableLinkNestedList>;
    description?: Maybe<Scalars['String']>;
    domainToDomainFirstSeen?: Maybe<Scalars['DateTime']>;
    domainToDomainLastSeen?: Maybe<Scalars['DateTime']>;
    id: Scalars['ID'];
    observableType?: Maybe<Scalars['String']>;
    observableTypeEnum?: Maybe<KnownObservablesEnum>;
    originalDomain?: Maybe<DomainName>;
    resolutionDomain?: Maybe<DomainName>;
    tasks: TaskFederationResult;
    uniqueIdentifier: Scalars['String'];
  };

export type DomainToDomainResolutionCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type DomainToDomainResolutionCtiEntriesArgs = {
  filter?: InputMaybe<Array<ObservableLinkFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ObservableLinkOrdEnumOrderingEntry>>;
};

export type DomainToDomainResolutionTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type DomainToDomainResolutionCreate = {
  ctiEntries?: InputMaybe<Array<Scalars['ID']>>;
  description?: InputMaybe<Scalars['String']>;
  domainToDomainFirstSeen?: InputMaybe<Scalars['DateTime']>;
  domainToDomainLastSeen?: InputMaybe<Scalars['DateTime']>;
  originalDomain?: InputMaybe<Scalars['ID']>;
  resolutionDomain?: InputMaybe<Scalars['ID']>;
};

export type DomainToDomainResolutionFilter0 = {
  description?: InputMaybe<StrFieldFilter>;
  domainToDomainFirstSeen?: InputMaybe<DateTimeFieldFilter>;
  domainToDomainLastSeen?: InputMaybe<DateTimeFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  observableType?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type DomainToDomainResolutionFilter0AndFilterEntry = {
  AND: Array<DomainToDomainResolutionFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type DomainToDomainResolutionFilter0OrFilterEntry = {
  OR: DomainToDomainResolutionFilter0;
  negate?: Scalars['Boolean'];
};

export type DomainToDomainResolutionFilter1 = {
  ctiEntries?: InputMaybe<ObservableLinkFilter1>;
  description?: InputMaybe<StrFieldFilter>;
  domainToDomainFirstSeen?: InputMaybe<DateTimeFieldFilter>;
  domainToDomainLastSeen?: InputMaybe<DateTimeFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  observableType?: InputMaybe<StrFieldFilter>;
  originalDomain?: InputMaybe<DomainNameFilter1>;
  resolutionDomain?: InputMaybe<DomainNameFilter1>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type DomainToDomainResolutionFilter1AndFilterEntry = {
  AND: Array<DomainToDomainResolutionFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type DomainToDomainResolutionFilter1OrFilterEntry = {
  OR: DomainToDomainResolutionFilter1;
  negate?: Scalars['Boolean'];
};

export type DomainToDomainResolutionNestedList = {
  __typename?: 'DomainToDomainResolutionNestedList';
  data: Array<DomainToDomainResolution>;
  totalCount: Scalars['Int'];
};

export type DomainToDomainResolutionNestedListResult = {
  __typename?: 'DomainToDomainResolutionNestedListResult';
  data?: Maybe<DomainToDomainResolution>;
  error?: Maybe<ValidationError>;
};

export enum DomainToDomainResolutionOrdEnum {
  DESCRIPTION = 'DESCRIPTION',
  DOMAIN_TO_DOMAIN_FIRST_SEEN = 'DOMAIN_TO_DOMAIN_FIRST_SEEN',
  DOMAIN_TO_DOMAIN_LAST_SEEN = 'DOMAIN_TO_DOMAIN_LAST_SEEN',
  ID = 'ID',
  OBSERVABLE_TYPE = 'OBSERVABLE_TYPE',
  UNIQUE_IDENTIFIER = 'UNIQUE_IDENTIFIER',
}

export type DomainToDomainResolutionOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: DomainToDomainResolutionOrdEnum;
};

export type DomainToDomainResolutionPaginated = {
  __typename?: 'DomainToDomainResolutionPaginated';
  data: Array<DomainToDomainResolution>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type DomainToDomainResolutionUpdate = {
  ctiEntries?: InputMaybe<RelationUpdate>;
  description?: InputMaybe<Scalars['String']>;
  domainToDomainFirstSeen?: InputMaybe<Scalars['DateTime']>;
  domainToDomainLastSeen?: InputMaybe<Scalars['DateTime']>;
  originalDomain?: InputMaybe<Scalars['ID']>;
  resolutionDomain?: InputMaybe<Scalars['ID']>;
};

export type DomainToIpAddressResolution = Observable &
  ObservableFederationBase & {
    __typename?: 'DomainToIPAddressResolution';
    cases: CaseFederationResult;
    ctiEntries?: Maybe<ObservableLinkNestedList>;
    description?: Maybe<Scalars['String']>;
    domainToIpFirstSeen?: Maybe<Scalars['DateTime']>;
    domainToIpLastSeen?: Maybe<Scalars['DateTime']>;
    id: Scalars['ID'];
    observableType?: Maybe<Scalars['String']>;
    observableTypeEnum?: Maybe<KnownObservablesEnum>;
    resolvedIpAddress?: Maybe<IpAddress>;
    sourceDomain?: Maybe<DomainName>;
    tasks: TaskFederationResult;
    uniqueIdentifier: Scalars['String'];
  };

export type DomainToIpAddressResolutionCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type DomainToIpAddressResolutionCtiEntriesArgs = {
  filter?: InputMaybe<Array<ObservableLinkFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ObservableLinkOrdEnumOrderingEntry>>;
};

export type DomainToIpAddressResolutionTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type DomainToIpAddressResolutionCreate = {
  ctiEntries?: InputMaybe<Array<Scalars['ID']>>;
  description?: InputMaybe<Scalars['String']>;
  domainToIpFirstSeen?: InputMaybe<Scalars['DateTime']>;
  domainToIpLastSeen?: InputMaybe<Scalars['DateTime']>;
  resolvedIpAddress?: InputMaybe<Scalars['ID']>;
  sourceDomain?: InputMaybe<Scalars['ID']>;
};

export type DomainToIpAddressResolutionFilter0 = {
  description?: InputMaybe<StrFieldFilter>;
  domainToIpFirstSeen?: InputMaybe<DateTimeFieldFilter>;
  domainToIpLastSeen?: InputMaybe<DateTimeFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  observableType?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type DomainToIpAddressResolutionFilter0AndFilterEntry = {
  AND: Array<DomainToIpAddressResolutionFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type DomainToIpAddressResolutionFilter0OrFilterEntry = {
  OR: DomainToIpAddressResolutionFilter0;
  negate?: Scalars['Boolean'];
};

export type DomainToIpAddressResolutionFilter1 = {
  ctiEntries?: InputMaybe<ObservableLinkFilter1>;
  description?: InputMaybe<StrFieldFilter>;
  domainToIpFirstSeen?: InputMaybe<DateTimeFieldFilter>;
  domainToIpLastSeen?: InputMaybe<DateTimeFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  observableType?: InputMaybe<StrFieldFilter>;
  resolvedIpAddress?: InputMaybe<IpAddressFilter1>;
  sourceDomain?: InputMaybe<DomainNameFilter1>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type DomainToIpAddressResolutionFilter1AndFilterEntry = {
  AND: Array<DomainToIpAddressResolutionFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type DomainToIpAddressResolutionFilter1OrFilterEntry = {
  OR: DomainToIpAddressResolutionFilter1;
  negate?: Scalars['Boolean'];
};

export type DomainToIpAddressResolutionNestedList = {
  __typename?: 'DomainToIPAddressResolutionNestedList';
  data: Array<DomainToIpAddressResolution>;
  totalCount: Scalars['Int'];
};

export type DomainToIpAddressResolutionNestedListResult = {
  __typename?: 'DomainToIPAddressResolutionNestedListResult';
  data?: Maybe<DomainToIpAddressResolution>;
  error?: Maybe<ValidationError>;
};

export enum DomainToIpAddressResolutionOrdEnum {
  DESCRIPTION = 'DESCRIPTION',
  DOMAIN_TO_IP_FIRST_SEEN = 'DOMAIN_TO_IP_FIRST_SEEN',
  DOMAIN_TO_IP_LAST_SEEN = 'DOMAIN_TO_IP_LAST_SEEN',
  ID = 'ID',
  OBSERVABLE_TYPE = 'OBSERVABLE_TYPE',
  UNIQUE_IDENTIFIER = 'UNIQUE_IDENTIFIER',
}

export type DomainToIpAddressResolutionOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: DomainToIpAddressResolutionOrdEnum;
};

export type DomainToIpAddressResolutionPaginated = {
  __typename?: 'DomainToIPAddressResolutionPaginated';
  data: Array<DomainToIpAddressResolution>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type DomainToIpAddressResolutionUpdate = {
  ctiEntries?: InputMaybe<RelationUpdate>;
  description?: InputMaybe<Scalars['String']>;
  domainToIpFirstSeen?: InputMaybe<Scalars['DateTime']>;
  domainToIpLastSeen?: InputMaybe<Scalars['DateTime']>;
  resolvedIpAddress?: InputMaybe<Scalars['ID']>;
  sourceDomain?: InputMaybe<Scalars['ID']>;
};

export type EmailAddress = Observable &
  ObservableFederationBase & {
    __typename?: 'EmailAddress';
    cases: CaseFederationResult;
    ctiEntries?: Maybe<ObservableLinkNestedList>;
    description?: Maybe<Scalars['String']>;
    emailAddressHost: Host;
    emailMessages?: Maybe<EmailMessageEmailAddressRelationshipNestedList>;
    id: Scalars['ID'];
    observableType?: Maybe<Scalars['String']>;
    observableTypeEnum?: Maybe<KnownObservablesEnum>;
    rawEmailAddress: Scalars['String'];
    tasks: TaskFederationResult;
    uniqueIdentifier: Scalars['String'];
    username: Scalars['String'];
  };

export type EmailAddressCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type EmailAddressCtiEntriesArgs = {
  filter?: InputMaybe<Array<ObservableLinkFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ObservableLinkOrdEnumOrderingEntry>>;
};

export type EmailAddressEmailMessagesArgs = {
  filter?: InputMaybe<Array<EmailMessageEmailAddressRelationshipFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<EmailMessageEmailAddressRelationshipOrdEnumOrderingEntry>>;
};

export type EmailAddressTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type EmailAddressCreate = {
  ctiEntries?: InputMaybe<Array<Scalars['ID']>>;
  description?: InputMaybe<Scalars['String']>;
  emailAddressHost: Scalars['ID'];
  emailMessages?: InputMaybe<Array<Scalars['ID']>>;
  rawEmailAddress: Scalars['String'];
  username: Scalars['String'];
};

export type EmailAddressFilter0 = {
  description?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  observableType?: InputMaybe<StrFieldFilter>;
  rawEmailAddress?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
  username?: InputMaybe<StrFieldFilter>;
};

export type EmailAddressFilter0AndFilterEntry = {
  AND: Array<EmailAddressFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type EmailAddressFilter0OrFilterEntry = {
  OR: EmailAddressFilter0;
  negate?: Scalars['Boolean'];
};

export type EmailAddressFilter1 = {
  ctiEntries?: InputMaybe<ObservableLinkFilter1>;
  description?: InputMaybe<StrFieldFilter>;
  emailAddressHost?: InputMaybe<HostFilter1>;
  emailMessages?: InputMaybe<EmailMessageEmailAddressRelationshipFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  observableType?: InputMaybe<StrFieldFilter>;
  rawEmailAddress?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
  username?: InputMaybe<StrFieldFilter>;
};

export type EmailAddressFilter1AndFilterEntry = {
  AND: Array<EmailAddressFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type EmailAddressFilter1OrFilterEntry = {
  OR: EmailAddressFilter1;
  negate?: Scalars['Boolean'];
};

export type EmailAddressInput = {
  emailAddress: Scalars['String'];
  emailMessageRelationship: Scalars['String'];
};

export type EmailAddressInputOutput = TaskInputOutput & {
  __typename?: 'EmailAddressInputOutput';
  description?: Maybe<Scalars['String']>;
  emailAddressValue?: Maybe<Scalars['String']>;
  id: Scalars['ID'];
  inputOf?: Maybe<Task>;
  outputOf?: Maybe<Task>;
  stringifiedValue?: Maybe<Scalars['String']>;
  type?: Maybe<Scalars['String']>;
};

export type EmailAddressInputOutputCreate = {
  description?: InputMaybe<Scalars['String']>;
  emailAddressValue?: InputMaybe<Scalars['String']>;
  inputOf?: InputMaybe<Scalars['ID']>;
  outputOf?: InputMaybe<Scalars['ID']>;
};

export type EmailAddressInputOutputFilter1 = {
  description?: InputMaybe<StrFieldFilter>;
  emailAddressValue?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  inputOf?: InputMaybe<TaskFilter1>;
  outputOf?: InputMaybe<TaskFilter1>;
  type?: InputMaybe<StrFieldFilter>;
};

export type EmailAddressInputOutputFilter1AndFilterEntry = {
  AND: Array<EmailAddressInputOutputFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type EmailAddressInputOutputFilter1OrFilterEntry = {
  OR: EmailAddressInputOutputFilter1;
  negate?: Scalars['Boolean'];
};

export enum EmailAddressInputOutputOrdEnum {
  DESCRIPTION = 'DESCRIPTION',
  EMAIL_ADDRESS_VALUE = 'EMAIL_ADDRESS_VALUE',
  ID = 'ID',
  TYPE = 'TYPE',
}

export type EmailAddressInputOutputOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: EmailAddressInputOutputOrdEnum;
};

export type EmailAddressInputOutputPaginated = {
  __typename?: 'EmailAddressInputOutputPaginated';
  data: Array<EmailAddressInputOutput>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type EmailAddressInputOutputUpdate = {
  description?: InputMaybe<Scalars['String']>;
  emailAddressValue?: InputMaybe<Scalars['String']>;
  inputOf?: InputMaybe<Scalars['ID']>;
  outputOf?: InputMaybe<Scalars['ID']>;
};

export type EmailAddressNestedList = {
  __typename?: 'EmailAddressNestedList';
  data: Array<EmailAddress>;
  totalCount: Scalars['Int'];
};

export type EmailAddressNestedListResult = {
  __typename?: 'EmailAddressNestedListResult';
  data?: Maybe<EmailAddress>;
  error?: Maybe<ValidationError>;
};

export enum EmailAddressOrdEnum {
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  OBSERVABLE_TYPE = 'OBSERVABLE_TYPE',
  RAW_EMAIL_ADDRESS = 'RAW_EMAIL_ADDRESS',
  UNIQUE_IDENTIFIER = 'UNIQUE_IDENTIFIER',
  USERNAME = 'USERNAME',
}

export type EmailAddressOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: EmailAddressOrdEnum;
};

export type EmailAddressPaginated = {
  __typename?: 'EmailAddressPaginated';
  data: Array<EmailAddress>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type EmailAddressUpdate = {
  ctiEntries?: InputMaybe<RelationUpdate>;
  description?: InputMaybe<Scalars['String']>;
  emailAddressHost?: InputMaybe<Scalars['ID']>;
  emailMessages?: InputMaybe<RelationUpdate>;
  rawEmailAddress?: InputMaybe<Scalars['String']>;
  username?: InputMaybe<Scalars['String']>;
};

export type EmailHeader = {
  __typename?: 'EmailHeader';
  id: Scalars['ID'];
  key?: Maybe<Scalars['String']>;
  sourceEmailMessages?: Maybe<EmailMessageNestedList>;
  value?: Maybe<Scalars['String']>;
};

export type EmailHeaderSourceEmailMessagesArgs = {
  filter?: InputMaybe<Array<EmailMessageFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<EmailMessageOrdEnumOrderingEntry>>;
};

export type EmailHeaderCreate = {
  key?: InputMaybe<Scalars['String']>;
  sourceEmailMessages?: InputMaybe<Array<Scalars['ID']>>;
  value?: InputMaybe<Scalars['String']>;
};

export type EmailHeaderFilter0 = {
  id?: InputMaybe<StrawberryIdFieldFilter>;
  key?: InputMaybe<StrFieldFilter>;
  value?: InputMaybe<StrFieldFilter>;
};

export type EmailHeaderFilter0AndFilterEntry = {
  AND: Array<EmailHeaderFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type EmailHeaderFilter0OrFilterEntry = {
  OR: EmailHeaderFilter0;
  negate?: Scalars['Boolean'];
};

export type EmailHeaderFilter1 = {
  id?: InputMaybe<StrawberryIdFieldFilter>;
  key?: InputMaybe<StrFieldFilter>;
  sourceEmailMessages?: InputMaybe<EmailMessageFilter1>;
  value?: InputMaybe<StrFieldFilter>;
};

export type EmailHeaderFilter1AndFilterEntry = {
  AND: Array<EmailHeaderFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type EmailHeaderFilter1OrFilterEntry = {
  OR: EmailHeaderFilter1;
  negate?: Scalars['Boolean'];
};

export type EmailHeaderNestedList = {
  __typename?: 'EmailHeaderNestedList';
  data: Array<EmailHeader>;
  totalCount: Scalars['Int'];
};

export enum EmailHeaderOrdEnum {
  ID = 'ID',
  KEY = 'KEY',
  VALUE = 'VALUE',
}

export type EmailHeaderOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: EmailHeaderOrdEnum;
};

export type EmailHeaderPaginated = {
  __typename?: 'EmailHeaderPaginated';
  data: Array<EmailHeader>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type EmailHeaderUpdate = {
  key?: InputMaybe<Scalars['String']>;
  sourceEmailMessages?: InputMaybe<RelationUpdate>;
  value?: InputMaybe<Scalars['String']>;
};

export type EmailMessage = HashableObservable &
  Observable &
  ObservableFederationBase & {
    __typename?: 'EmailMessage';
    body?: Maybe<Scalars['String']>;
    cases: CaseFederationResult;
    ctiEntries?: Maybe<ObservableLinkNestedList>;
    description?: Maybe<Scalars['String']>;
    emailAddresses?: Maybe<EmailMessageEmailAddressRelationshipNestedList>;
    hashes?: Maybe<HashNestedList>;
    headers?: Maybe<EmailHeaderNestedList>;
    id: Scalars['ID'];
    observableType?: Maybe<Scalars['String']>;
    observableTypeEnum?: Maybe<KnownObservablesEnum>;
    parts?: Maybe<EmailMessagePartsRelationshipNestedList>;
    rawReference?: Maybe<Scalars['String']>;
    subject?: Maybe<Scalars['String']>;
    tasks: TaskFederationResult;
    uniqueIdentifier: Scalars['String'];
  };

export type EmailMessageCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type EmailMessageCtiEntriesArgs = {
  filter?: InputMaybe<Array<ObservableLinkFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ObservableLinkOrdEnumOrderingEntry>>;
};

export type EmailMessageEmailAddressesArgs = {
  filter?: InputMaybe<Array<EmailMessageEmailAddressRelationshipFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<EmailMessageEmailAddressRelationshipOrdEnumOrderingEntry>>;
};

export type EmailMessageHashesArgs = {
  filter?: InputMaybe<Array<HashFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<HashOrdEnumOrderingEntry>>;
};

export type EmailMessageHeadersArgs = {
  filter?: InputMaybe<Array<EmailHeaderFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<EmailHeaderOrdEnumOrderingEntry>>;
};

export type EmailMessagePartsArgs = {
  filter?: InputMaybe<Array<EmailMessagePartsRelationshipFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<EmailMessagePartsRelationshipOrdEnumOrderingEntry>>;
};

export type EmailMessageTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type EmailMessageCreate = {
  body?: InputMaybe<Scalars['String']>;
  ctiEntries?: InputMaybe<Array<Scalars['ID']>>;
  description?: InputMaybe<Scalars['String']>;
  emailAddresses?: InputMaybe<Array<Scalars['ID']>>;
  hashes?: InputMaybe<Array<Scalars['ID']>>;
  headers?: InputMaybe<Array<Scalars['ID']>>;
  parts?: InputMaybe<Array<Scalars['ID']>>;
  rawReference?: InputMaybe<Scalars['String']>;
  subject?: InputMaybe<Scalars['String']>;
};

export type EmailMessageEmailAddressRelationship = Observable & {
  __typename?: 'EmailMessageEmailAddressRelationship';
  ctiEntries?: Maybe<ObservableLinkNestedList>;
  description?: Maybe<Scalars['String']>;
  emailAddress: EmailAddress;
  emailMessage: EmailMessage;
  id: Scalars['ID'];
  inHeader?: Maybe<Scalars['String']>;
  observableType?: Maybe<Scalars['String']>;
  uniqueIdentifier: Scalars['String'];
};

export type EmailMessageEmailAddressRelationshipCtiEntriesArgs = {
  filter?: InputMaybe<Array<ObservableLinkFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ObservableLinkOrdEnumOrderingEntry>>;
};

export type EmailMessageEmailAddressRelationshipCreate = {
  ctiEntries?: InputMaybe<Array<Scalars['ID']>>;
  description?: InputMaybe<Scalars['String']>;
  emailAddress: Scalars['ID'];
  emailMessage: Scalars['ID'];
  inHeader?: InputMaybe<Scalars['String']>;
};

export type EmailMessageEmailAddressRelationshipFilter0 = {
  description?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  inHeader?: InputMaybe<StrFieldFilter>;
  observableType?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type EmailMessageEmailAddressRelationshipFilter0AndFilterEntry = {
  AND: Array<EmailMessageEmailAddressRelationshipFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type EmailMessageEmailAddressRelationshipFilter0OrFilterEntry = {
  OR: EmailMessageEmailAddressRelationshipFilter0;
  negate?: Scalars['Boolean'];
};

export type EmailMessageEmailAddressRelationshipFilter1 = {
  ctiEntries?: InputMaybe<ObservableLinkFilter1>;
  description?: InputMaybe<StrFieldFilter>;
  emailAddress?: InputMaybe<EmailAddressFilter1>;
  emailMessage?: InputMaybe<EmailMessageFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  inHeader?: InputMaybe<StrFieldFilter>;
  observableType?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type EmailMessageEmailAddressRelationshipFilter1AndFilterEntry = {
  AND: Array<EmailMessageEmailAddressRelationshipFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type EmailMessageEmailAddressRelationshipFilter1OrFilterEntry = {
  OR: EmailMessageEmailAddressRelationshipFilter1;
  negate?: Scalars['Boolean'];
};

export type EmailMessageEmailAddressRelationshipNestedList = {
  __typename?: 'EmailMessageEmailAddressRelationshipNestedList';
  data: Array<EmailMessageEmailAddressRelationship>;
  totalCount: Scalars['Int'];
};

export enum EmailMessageEmailAddressRelationshipOrdEnum {
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  IN_HEADER = 'IN_HEADER',
  OBSERVABLE_TYPE = 'OBSERVABLE_TYPE',
  UNIQUE_IDENTIFIER = 'UNIQUE_IDENTIFIER',
}

export type EmailMessageEmailAddressRelationshipOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: EmailMessageEmailAddressRelationshipOrdEnum;
};

export type EmailMessageEmailAddressRelationshipPaginated = {
  __typename?: 'EmailMessageEmailAddressRelationshipPaginated';
  data: Array<EmailMessageEmailAddressRelationship>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type EmailMessageEmailAddressRelationshipUpdate = {
  ctiEntries?: InputMaybe<RelationUpdate>;
  description?: InputMaybe<Scalars['String']>;
  emailAddress?: InputMaybe<Scalars['ID']>;
  emailMessage?: InputMaybe<Scalars['ID']>;
  inHeader?: InputMaybe<Scalars['String']>;
};

export type EmailMessageFilter0 = {
  body?: InputMaybe<StrFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  observableType?: InputMaybe<StrFieldFilter>;
  rawReference?: InputMaybe<StrFieldFilter>;
  subject?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type EmailMessageFilter0AndFilterEntry = {
  AND: Array<EmailMessageFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type EmailMessageFilter0OrFilterEntry = {
  OR: EmailMessageFilter0;
  negate?: Scalars['Boolean'];
};

export type EmailMessageFilter1 = {
  body?: InputMaybe<StrFieldFilter>;
  ctiEntries?: InputMaybe<ObservableLinkFilter1>;
  description?: InputMaybe<StrFieldFilter>;
  emailAddresses?: InputMaybe<EmailMessageEmailAddressRelationshipFilter1>;
  hashes?: InputMaybe<HashFilter1>;
  headers?: InputMaybe<EmailHeaderFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  observableType?: InputMaybe<StrFieldFilter>;
  parts?: InputMaybe<EmailMessagePartsRelationshipFilter1>;
  rawReference?: InputMaybe<StrFieldFilter>;
  subject?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type EmailMessageFilter1AndFilterEntry = {
  AND: Array<EmailMessageFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type EmailMessageFilter1OrFilterEntry = {
  OR: EmailMessageFilter1;
  negate?: Scalars['Boolean'];
};

export type EmailMessageInputOutput = TaskInputOutput & {
  __typename?: 'EmailMessageInputOutput';
  description?: Maybe<Scalars['String']>;
  emailMessageValue?: Maybe<Scalars['String']>;
  id: Scalars['ID'];
  inputOf?: Maybe<Task>;
  outputOf?: Maybe<Task>;
  stringifiedValue?: Maybe<Scalars['String']>;
  type?: Maybe<Scalars['String']>;
};

export type EmailMessageInputOutputCreate = {
  description?: InputMaybe<Scalars['String']>;
  emailMessageValue?: InputMaybe<Scalars['String']>;
  inputOf?: InputMaybe<Scalars['ID']>;
  outputOf?: InputMaybe<Scalars['ID']>;
};

export type EmailMessageInputOutputFilter1 = {
  description?: InputMaybe<StrFieldFilter>;
  emailMessageValue?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  inputOf?: InputMaybe<TaskFilter1>;
  outputOf?: InputMaybe<TaskFilter1>;
  type?: InputMaybe<StrFieldFilter>;
};

export type EmailMessageInputOutputFilter1AndFilterEntry = {
  AND: Array<EmailMessageInputOutputFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type EmailMessageInputOutputFilter1OrFilterEntry = {
  OR: EmailMessageInputOutputFilter1;
  negate?: Scalars['Boolean'];
};

export enum EmailMessageInputOutputOrdEnum {
  DESCRIPTION = 'DESCRIPTION',
  EMAIL_MESSAGE_VALUE = 'EMAIL_MESSAGE_VALUE',
  ID = 'ID',
  TYPE = 'TYPE',
}

export type EmailMessageInputOutputOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: EmailMessageInputOutputOrdEnum;
};

export type EmailMessageInputOutputPaginated = {
  __typename?: 'EmailMessageInputOutputPaginated';
  data: Array<EmailMessageInputOutput>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type EmailMessageInputOutputUpdate = {
  description?: InputMaybe<Scalars['String']>;
  emailMessageValue?: InputMaybe<Scalars['String']>;
  inputOf?: InputMaybe<Scalars['ID']>;
  outputOf?: InputMaybe<Scalars['ID']>;
};

export type EmailMessageNestedList = {
  __typename?: 'EmailMessageNestedList';
  data: Array<EmailMessage>;
  totalCount: Scalars['Int'];
};

export type EmailMessageNestedListResult = {
  __typename?: 'EmailMessageNestedListResult';
  data?: Maybe<EmailMessage>;
  error?: Maybe<ValidationError>;
};

export enum EmailMessageOrdEnum {
  BODY = 'BODY',
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  OBSERVABLE_TYPE = 'OBSERVABLE_TYPE',
  RAW_REFERENCE = 'RAW_REFERENCE',
  SUBJECT = 'SUBJECT',
  UNIQUE_IDENTIFIER = 'UNIQUE_IDENTIFIER',
}

export type EmailMessageOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: EmailMessageOrdEnum;
};

export type EmailMessagePaginated = {
  __typename?: 'EmailMessagePaginated';
  data: Array<EmailMessage>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type EmailMessagePartsRelationship = Observable & {
  __typename?: 'EmailMessagePartsRelationship';
  ctiEntries?: Maybe<ObservableLinkNestedList>;
  description?: Maybe<Scalars['String']>;
  file: FileReference;
  id: Scalars['ID'];
  observableType?: Maybe<Scalars['String']>;
  partType?: Maybe<Scalars['String']>;
  sourceEmailMessage: EmailMessage;
  uniqueIdentifier: Scalars['String'];
};

export type EmailMessagePartsRelationshipCtiEntriesArgs = {
  filter?: InputMaybe<Array<ObservableLinkFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ObservableLinkOrdEnumOrderingEntry>>;
};

export type EmailMessagePartsRelationshipCreate = {
  ctiEntries?: InputMaybe<Array<Scalars['ID']>>;
  description?: InputMaybe<Scalars['String']>;
  file: Scalars['ID'];
  partType?: InputMaybe<Scalars['String']>;
  sourceEmailMessage: Scalars['ID'];
};

export type EmailMessagePartsRelationshipFilter0 = {
  description?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  observableType?: InputMaybe<StrFieldFilter>;
  partType?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type EmailMessagePartsRelationshipFilter0AndFilterEntry = {
  AND: Array<EmailMessagePartsRelationshipFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type EmailMessagePartsRelationshipFilter0OrFilterEntry = {
  OR: EmailMessagePartsRelationshipFilter0;
  negate?: Scalars['Boolean'];
};

export type EmailMessagePartsRelationshipFilter1 = {
  ctiEntries?: InputMaybe<ObservableLinkFilter1>;
  description?: InputMaybe<StrFieldFilter>;
  file?: InputMaybe<FileReferenceFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  observableType?: InputMaybe<StrFieldFilter>;
  partType?: InputMaybe<StrFieldFilter>;
  sourceEmailMessage?: InputMaybe<EmailMessageFilter1>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type EmailMessagePartsRelationshipFilter1AndFilterEntry = {
  AND: Array<EmailMessagePartsRelationshipFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type EmailMessagePartsRelationshipFilter1OrFilterEntry = {
  OR: EmailMessagePartsRelationshipFilter1;
  negate?: Scalars['Boolean'];
};

export type EmailMessagePartsRelationshipNestedList = {
  __typename?: 'EmailMessagePartsRelationshipNestedList';
  data: Array<EmailMessagePartsRelationship>;
  totalCount: Scalars['Int'];
};

export enum EmailMessagePartsRelationshipOrdEnum {
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  OBSERVABLE_TYPE = 'OBSERVABLE_TYPE',
  PART_TYPE = 'PART_TYPE',
  UNIQUE_IDENTIFIER = 'UNIQUE_IDENTIFIER',
}

export type EmailMessagePartsRelationshipOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: EmailMessagePartsRelationshipOrdEnum;
};

export type EmailMessagePartsRelationshipPaginated = {
  __typename?: 'EmailMessagePartsRelationshipPaginated';
  data: Array<EmailMessagePartsRelationship>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type EmailMessagePartsRelationshipUpdate = {
  ctiEntries?: InputMaybe<RelationUpdate>;
  description?: InputMaybe<Scalars['String']>;
  file?: InputMaybe<Scalars['ID']>;
  partType?: InputMaybe<Scalars['String']>;
  sourceEmailMessage?: InputMaybe<Scalars['ID']>;
};

export type EmailMessageUpdate = {
  body?: InputMaybe<Scalars['String']>;
  ctiEntries?: InputMaybe<RelationUpdate>;
  description?: InputMaybe<Scalars['String']>;
  emailAddresses?: InputMaybe<RelationUpdate>;
  hashes?: InputMaybe<RelationUpdate>;
  headers?: InputMaybe<RelationUpdate>;
  parts?: InputMaybe<RelationUpdate>;
  rawReference?: InputMaybe<Scalars['String']>;
  subject?: InputMaybe<Scalars['String']>;
};

export type EntryType = {
  __typename?: 'EntryType';
  description?: Maybe<Scalars['String']>;
  id: Scalars['ID'];
  inSpecifiers?: Maybe<SourceSpecifierNestedList>;
  name: Scalars['String'];
};

export type EntryTypeInSpecifiersArgs = {
  filter?: InputMaybe<Array<SourceSpecifierFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<SourceSpecifierOrdEnumOrderingEntry>>;
};

export type EntryTypeCreate = {
  description?: InputMaybe<Scalars['String']>;
  inSpecifiers?: InputMaybe<Array<Scalars['ID']>>;
  name: Scalars['String'];
};

export type EntryTypeFilter1 = {
  description?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  inSpecifiers?: InputMaybe<SourceSpecifierFilter1>;
  name?: InputMaybe<StrFieldFilter>;
};

export type EntryTypeFilter1AndFilterEntry = {
  AND: Array<EntryTypeFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type EntryTypeFilter1OrFilterEntry = {
  OR: EntryTypeFilter1;
  negate?: Scalars['Boolean'];
};

export type EntryTypeNestedListResult = {
  __typename?: 'EntryTypeNestedListResult';
  data?: Maybe<EntryType>;
  error?: Maybe<ValidationError>;
};

export enum EntryTypeOrdEnum {
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  NAME = 'NAME',
}

export type EntryTypeOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: EntryTypeOrdEnum;
};

export type EntryTypePaginated = {
  __typename?: 'EntryTypePaginated';
  data: Array<EntryType>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type EntryTypeUpdate = {
  description?: InputMaybe<Scalars['String']>;
  inSpecifiers?: InputMaybe<RelationUpdate>;
  name?: InputMaybe<Scalars['String']>;
};

export type Event = {
  created?: Maybe<Scalars['DateTime']>;
  description?: Maybe<Scalars['String']>;
  eventTime?: Maybe<Scalars['DateTime']>;
  id: Scalars['ID'];
  name?: Maybe<Scalars['String']>;
  relatedCases?: Maybe<CaseNestedList>;
  relatedTasks?: Maybe<TaskNestedList>;
  type?: Maybe<Scalars['String']>;
  uniqueIdentifier: Scalars['String'];
};

export type EventRelatedCasesArgs = {
  filter?: InputMaybe<Array<CaseFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<CaseOrdEnumOrderingEntry>>;
};

export type EventRelatedTasksArgs = {
  filter?: InputMaybe<Array<TaskFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TaskOrdEnumOrderingEntry>>;
};

export type EventFilter0 = {
  appName?: InputMaybe<StrFieldFilter>;
  created?: InputMaybe<DateTimeFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  eventTime?: InputMaybe<DateTimeFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  message?: InputMaybe<StrFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
  procId?: InputMaybe<IntFieldFilter>;
  type?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type EventFilter0AndFilterEntry = {
  AND: Array<EventFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type EventFilter0OrFilterEntry = {
  OR: EventFilter0;
  negate?: Scalars['Boolean'];
};

export type EventFilter1 = {
  appName?: InputMaybe<StrFieldFilter>;
  created?: InputMaybe<DateTimeFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  eventTime?: InputMaybe<DateTimeFieldFilter>;
  flowData?: InputMaybe<FlowEventDataFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  message?: InputMaybe<StrFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
  procId?: InputMaybe<IntFieldFilter>;
  relatedCases?: InputMaybe<CaseFilter1>;
  relatedTasks?: InputMaybe<TaskFilter1>;
  type?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type EventFilter1AndFilterEntry = {
  AND: Array<EventFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type EventFilter1OrFilterEntry = {
  OR: EventFilter1;
  negate?: Scalars['Boolean'];
};

export type EventNestedList = {
  __typename?: 'EventNestedList';
  data: Array<Event>;
  totalCount: Scalars['Int'];
};

export enum EventOrdEnum {
  CREATED = 'CREATED',
  DESCRIPTION = 'DESCRIPTION',
  EVENT_TIME = 'EVENT_TIME',
  ID = 'ID',
  NAME = 'NAME',
  TYPE = 'TYPE',
  UNIQUE_IDENTIFIER = 'UNIQUE_IDENTIFIER',
}

export type EventOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: EventOrdEnum;
};

export type EventPaginated = {
  __typename?: 'EventPaginated';
  data: Array<Event>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type ExternalReference = {
  __typename?: 'ExternalReference';
  description?: Maybe<Scalars['String']>;
  externalId?: Maybe<Scalars['String']>;
  groups?: Maybe<TtpGroupNestedList>;
  id: Scalars['ID'];
  malware?: Maybe<MalwareNestedList>;
  mitigations?: Maybe<MitigationNestedList>;
  sourceName: Scalars['String'];
  techniqueMitigationRelationships?: Maybe<TechniqueMitigationRelationshipNestedList>;
  tools?: Maybe<ToolNestedList>;
  ttps?: Maybe<IttpNestedList>;
  url?: Maybe<Scalars['String']>;
};

export type ExternalReferenceGroupsArgs = {
  filter?: InputMaybe<Array<TtpGroupFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TtpGroupOrdEnumOrderingEntry>>;
};

export type ExternalReferenceMalwareArgs = {
  filter?: InputMaybe<Array<MalwareFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<MalwareOrdEnumOrderingEntry>>;
};

export type ExternalReferenceMitigationsArgs = {
  filter?: InputMaybe<Array<MitigationFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<MitigationOrdEnumOrderingEntry>>;
};

export type ExternalReferenceTechniqueMitigationRelationshipsArgs = {
  filter?: InputMaybe<Array<TechniqueMitigationRelationshipFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TechniqueMitigationRelationshipOrdEnumOrderingEntry>>;
};

export type ExternalReferenceToolsArgs = {
  filter?: InputMaybe<Array<ToolFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ToolOrdEnumOrderingEntry>>;
};

export type ExternalReferenceTtpsArgs = {
  filter?: InputMaybe<Array<IttpFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<IttpOrdEnumOrderingEntry>>;
};

export type ExternalReferenceCreate = {
  description?: InputMaybe<Scalars['String']>;
  externalId?: InputMaybe<Scalars['String']>;
  groups?: InputMaybe<Array<Scalars['ID']>>;
  malware?: InputMaybe<Array<Scalars['ID']>>;
  mitigations?: InputMaybe<Array<Scalars['ID']>>;
  sourceName: Scalars['String'];
  techniqueMitigationRelationships?: InputMaybe<Array<Scalars['ID']>>;
  tools?: InputMaybe<Array<Scalars['ID']>>;
  ttps?: InputMaybe<Array<Scalars['ID']>>;
  url?: InputMaybe<Scalars['String']>;
};

export type ExternalReferenceFilter0 = {
  description?: InputMaybe<StrFieldFilter>;
  externalId?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  sourceName?: InputMaybe<StrFieldFilter>;
  url?: InputMaybe<StrFieldFilter>;
};

export type ExternalReferenceFilter0AndFilterEntry = {
  AND: Array<ExternalReferenceFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type ExternalReferenceFilter0OrFilterEntry = {
  OR: ExternalReferenceFilter0;
  negate?: Scalars['Boolean'];
};

export type ExternalReferenceFilter1 = {
  description?: InputMaybe<StrFieldFilter>;
  externalId?: InputMaybe<StrFieldFilter>;
  groups?: InputMaybe<TtpGroupFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  malware?: InputMaybe<MalwareFilter1>;
  mitigations?: InputMaybe<MitigationFilter1>;
  sourceName?: InputMaybe<StrFieldFilter>;
  techniqueMitigationRelationships?: InputMaybe<TechniqueMitigationRelationshipFilter1>;
  tools?: InputMaybe<ToolFilter1>;
  ttps?: InputMaybe<IttpFilter1>;
  url?: InputMaybe<StrFieldFilter>;
};

export type ExternalReferenceFilter1AndFilterEntry = {
  AND: Array<ExternalReferenceFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type ExternalReferenceFilter1OrFilterEntry = {
  OR: ExternalReferenceFilter1;
  negate?: Scalars['Boolean'];
};

export type ExternalReferenceNestedList = {
  __typename?: 'ExternalReferenceNestedList';
  data: Array<ExternalReference>;
  totalCount: Scalars['Int'];
};

export enum ExternalReferenceOrdEnum {
  DESCRIPTION = 'DESCRIPTION',
  EXTERNAL_ID = 'EXTERNAL_ID',
  ID = 'ID',
  SOURCE_NAME = 'SOURCE_NAME',
  URL = 'URL',
}

export type ExternalReferenceOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: ExternalReferenceOrdEnum;
};

export type ExternalReferencePaginated = {
  __typename?: 'ExternalReferencePaginated';
  data: Array<ExternalReference>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type ExternalReferenceUpdate = {
  description?: InputMaybe<Scalars['String']>;
  externalId?: InputMaybe<Scalars['String']>;
  groups?: InputMaybe<RelationUpdate>;
  malware?: InputMaybe<RelationUpdate>;
  mitigations?: InputMaybe<RelationUpdate>;
  sourceName?: InputMaybe<Scalars['String']>;
  techniqueMitigationRelationships?: InputMaybe<RelationUpdate>;
  tools?: InputMaybe<RelationUpdate>;
  ttps?: InputMaybe<RelationUpdate>;
  url?: InputMaybe<Scalars['String']>;
};

export type FhrpGroupFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  authKey?: InputMaybe<StrFilter>;
  authType?: InputMaybe<StrFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  groupId?: InputMaybe<IntFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  ipAddressIds?: InputMaybe<StrawberryIdFilter>;
  ipAddresses?: InputMaybe<IpAddressFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  protocol?: InputMaybe<StrFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type FhrpGroupFilterAndFilterEntry = {
  AND: Array<FhrpGroupFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type FhrpGroupFilterOrFilterEntry = {
  OR: Array<FhrpGroupFilter>;
  negate?: Scalars['Boolean'];
};

export type FhrpGroupType = AssetFederationBase &
  AssetType & {
    __typename?: 'FHRPGroupType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    authKey?: Maybe<Scalars['String']>;
    authType?: Maybe<Scalars['String']>;
    cases: CaseFederationResult;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    groupId?: Maybe<Scalars['Int']>;
    id: Scalars['ID'];
    ipAddressIds: Array<Scalars['ID']>;
    ipAddresses: Array<IpAddressType>;
    lastUpdated?: Maybe<Scalars['DateTime']>;
    netboxUrl?: Maybe<Scalars['String']>;
    protocol?: Maybe<Scalars['String']>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
  };

export type FhrpGroupTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type FhrpGroupTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type FhrpGroupTypeResultSet = {
  __typename?: 'FHRPGroupTypeResultSet';
  data: Array<FhrpGroupType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type FactRefVertex = {
  __typename?: 'FactRefVertex';
  cpe23Uri?: Maybe<Scalars['String']>;
  defCpeMatch?: Maybe<DefCpeMatch>;
  sourceAVSpecs?: Maybe<Array<Maybe<SourceAvSpecVertex>>>;
  versionStringRange?: Maybe<StringRange>;
  vulnerable?: Maybe<Scalars['Boolean']>;
};

export type FederatedMutationError = {
  __typename?: 'FederatedMutationError';
  identifier: Scalars['String'];
  message: Scalars['String'];
};

export type FederatedMutationResult = {
  __typename?: 'FederatedMutationResult';
  created: Array<Scalars['String']>;
  errors: Array<FederatedMutationError>;
};

export type File = {
  __typename?: 'File';
  created?: Maybe<Scalars['DateTime']>;
  createdBy?: Maybe<CaseDbUser>;
  displayName?: Maybe<Scalars['String']>;
  extension?: Maybe<Scalars['String']>;
  externalSrc?: Maybe<Scalars['String']>;
  id: Scalars['ID'];
  name: Scalars['String'];
  parent?: Maybe<Directory>;
  src: Scalars['String'];
  type?: Maybe<Scalars['String']>;
};

export type FileCreate = {
  createdBy?: InputMaybe<Scalars['ID']>;
  displayName?: InputMaybe<Scalars['String']>;
  extension?: InputMaybe<Scalars['String']>;
  file: Scalars['Upload'];
  parent?: InputMaybe<Scalars['ID']>;
};

export type FileCreateComment = {
  createdBy?: InputMaybe<Scalars['ID']>;
  displayName?: InputMaybe<Scalars['String']>;
  extension?: InputMaybe<Scalars['String']>;
  file: Scalars['Upload'];
};

export type FileFilter1 = {
  created?: InputMaybe<DateTimeFieldFilter>;
  createdBy?: InputMaybe<CaseDbUserFilter1>;
  displayName?: InputMaybe<StrFieldFilter>;
  extension?: InputMaybe<StrFieldFilter>;
  externalSrc?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
  parent?: InputMaybe<DirectoryFilter1>;
  type?: InputMaybe<StrFieldFilter>;
};

export type FileFilter1AndFilterEntry = {
  AND: Array<FileFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type FileFilter1OrFilterEntry = {
  OR: FileFilter1;
  negate?: Scalars['Boolean'];
};

export type FileInput = {
  description?: InputMaybe<Scalars['String']>;
  emailMessageRelationship?: Scalars['String'];
  hashes?: InputMaybe<Array<HashInput>>;
  name: Scalars['String'];
  reference: Scalars['String'];
};

export type FileInputOutput = TaskInputOutput & {
  __typename?: 'FileInputOutput';
  description?: Maybe<Scalars['String']>;
  fileValue?: Maybe<Scalars['String']>;
  id: Scalars['ID'];
  inputOf?: Maybe<Task>;
  outputOf?: Maybe<Task>;
  stringifiedValue?: Maybe<Scalars['String']>;
  type?: Maybe<Scalars['String']>;
};

export type FileInputOutputCreate = {
  description?: InputMaybe<Scalars['String']>;
  fileValue?: InputMaybe<Scalars['String']>;
  inputOf?: InputMaybe<Scalars['ID']>;
  outputOf?: InputMaybe<Scalars['ID']>;
};

export type FileInputOutputFilter1 = {
  description?: InputMaybe<StrFieldFilter>;
  fileValue?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  inputOf?: InputMaybe<TaskFilter1>;
  outputOf?: InputMaybe<TaskFilter1>;
  type?: InputMaybe<StrFieldFilter>;
};

export type FileInputOutputFilter1AndFilterEntry = {
  AND: Array<FileInputOutputFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type FileInputOutputFilter1OrFilterEntry = {
  OR: FileInputOutputFilter1;
  negate?: Scalars['Boolean'];
};

export enum FileInputOutputOrdEnum {
  DESCRIPTION = 'DESCRIPTION',
  FILE_VALUE = 'FILE_VALUE',
  ID = 'ID',
  TYPE = 'TYPE',
}

export type FileInputOutputOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: FileInputOutputOrdEnum;
};

export type FileInputOutputPaginated = {
  __typename?: 'FileInputOutputPaginated';
  data: Array<FileInputOutput>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type FileInputOutputUpdate = {
  description?: InputMaybe<Scalars['String']>;
  fileValue?: InputMaybe<Scalars['String']>;
  inputOf?: InputMaybe<Scalars['ID']>;
  outputOf?: InputMaybe<Scalars['ID']>;
};

export enum FileOrdEnum {
  CREATED = 'CREATED',
  DISPLAY_NAME = 'DISPLAY_NAME',
  EXTENSION = 'EXTENSION',
  EXTERNAL_SRC = 'EXTERNAL_SRC',
  ID = 'ID',
  NAME = 'NAME',
  TYPE = 'TYPE',
}

export type FileOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: FileOrdEnum;
};

export type FilePaginated = {
  __typename?: 'FilePaginated';
  data: Array<File>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type FileRefCreate = {
  createdBy?: InputMaybe<Scalars['ID']>;
  displayName?: InputMaybe<Scalars['String']>;
  parent?: InputMaybe<Scalars['ID']>;
  source: Scalars['String'];
};

export type FileRefInputOutput = TaskInputOutput & {
  __typename?: 'FileRefInputOutput';
  description?: Maybe<Scalars['String']>;
  fileRefValue?: Maybe<Scalars['String']>;
  id: Scalars['ID'];
  inputOf?: Maybe<Task>;
  outputOf?: Maybe<Task>;
  stringifiedValue?: Maybe<Scalars['String']>;
  type?: Maybe<Scalars['String']>;
};

export type FileRefInputOutputCreate = {
  description?: InputMaybe<Scalars['String']>;
  fileRefValue?: InputMaybe<Scalars['String']>;
  inputOf?: InputMaybe<Scalars['ID']>;
  outputOf?: InputMaybe<Scalars['ID']>;
};

export type FileRefInputOutputFilter1 = {
  description?: InputMaybe<StrFieldFilter>;
  fileRefValue?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  inputOf?: InputMaybe<TaskFilter1>;
  outputOf?: InputMaybe<TaskFilter1>;
  type?: InputMaybe<StrFieldFilter>;
};

export type FileRefInputOutputFilter1AndFilterEntry = {
  AND: Array<FileRefInputOutputFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type FileRefInputOutputFilter1OrFilterEntry = {
  OR: FileRefInputOutputFilter1;
  negate?: Scalars['Boolean'];
};

export enum FileRefInputOutputOrdEnum {
  DESCRIPTION = 'DESCRIPTION',
  FILE_REF_VALUE = 'FILE_REF_VALUE',
  ID = 'ID',
  TYPE = 'TYPE',
}

export type FileRefInputOutputOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: FileRefInputOutputOrdEnum;
};

export type FileRefInputOutputPaginated = {
  __typename?: 'FileRefInputOutputPaginated';
  data: Array<FileRefInputOutput>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type FileRefInputOutputUpdate = {
  description?: InputMaybe<Scalars['String']>;
  fileRefValue?: InputMaybe<Scalars['String']>;
  inputOf?: InputMaybe<Scalars['ID']>;
  outputOf?: InputMaybe<Scalars['ID']>;
};

export type FileReference = HashableObservable &
  Observable &
  ObservableFederationBase & {
    __typename?: 'FileReference';
    attachmentOf?: Maybe<EmailMessagePartsRelationshipNestedList>;
    cases: CaseFederationResult;
    ctiEntries?: Maybe<ObservableLinkNestedList>;
    description?: Maybe<Scalars['String']>;
    hashes?: Maybe<HashNestedList>;
    id: Scalars['ID'];
    name: Scalars['String'];
    observableType?: Maybe<Scalars['String']>;
    observableTypeEnum?: Maybe<KnownObservablesEnum>;
    reference: Scalars['String'];
    tasks: TaskFederationResult;
    uniqueIdentifier: Scalars['String'];
  };

export type FileReferenceAttachmentOfArgs = {
  filter?: InputMaybe<Array<EmailMessagePartsRelationshipFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<EmailMessagePartsRelationshipOrdEnumOrderingEntry>>;
};

export type FileReferenceCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type FileReferenceCtiEntriesArgs = {
  filter?: InputMaybe<Array<ObservableLinkFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ObservableLinkOrdEnumOrderingEntry>>;
};

export type FileReferenceHashesArgs = {
  filter?: InputMaybe<Array<HashFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<HashOrdEnumOrderingEntry>>;
};

export type FileReferenceTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type FileReferenceCreate = {
  attachmentOf?: InputMaybe<Array<Scalars['ID']>>;
  ctiEntries?: InputMaybe<Array<Scalars['ID']>>;
  description?: InputMaybe<Scalars['String']>;
  hashes?: InputMaybe<Array<Scalars['ID']>>;
  name: Scalars['String'];
  reference: Scalars['String'];
};

export type FileReferenceFilter1 = {
  attachmentOf?: InputMaybe<EmailMessagePartsRelationshipFilter1>;
  ctiEntries?: InputMaybe<ObservableLinkFilter1>;
  description?: InputMaybe<StrFieldFilter>;
  hashes?: InputMaybe<HashFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
  observableType?: InputMaybe<StrFieldFilter>;
  reference?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type FileReferenceFilter1AndFilterEntry = {
  AND: Array<FileReferenceFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type FileReferenceFilter1OrFilterEntry = {
  OR: FileReferenceFilter1;
  negate?: Scalars['Boolean'];
};

export type FileReferenceNestedListResult = {
  __typename?: 'FileReferenceNestedListResult';
  data?: Maybe<FileReference>;
  error?: Maybe<ValidationError>;
};

export enum FileReferenceOrdEnum {
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  NAME = 'NAME',
  OBSERVABLE_TYPE = 'OBSERVABLE_TYPE',
  REFERENCE = 'REFERENCE',
  UNIQUE_IDENTIFIER = 'UNIQUE_IDENTIFIER',
}

export type FileReferenceOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: FileReferenceOrdEnum;
};

export type FileReferencePaginated = {
  __typename?: 'FileReferencePaginated';
  data: Array<FileReference>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type FileReferenceUpdate = {
  attachmentOf?: InputMaybe<RelationUpdate>;
  ctiEntries?: InputMaybe<RelationUpdate>;
  description?: InputMaybe<Scalars['String']>;
  hashes?: InputMaybe<RelationUpdate>;
  name?: InputMaybe<Scalars['String']>;
  reference?: InputMaybe<Scalars['String']>;
};

export type FileUpdate = {
  createdBy?: InputMaybe<Scalars['ID']>;
  displayName?: InputMaybe<Scalars['String']>;
  extension?: InputMaybe<Scalars['String']>;
  externalSrc?: InputMaybe<Scalars['String']>;
  name?: InputMaybe<Scalars['String']>;
  parent?: InputMaybe<Scalars['ID']>;
};

export type FloatFieldFilter = {
  exact?: InputMaybe<Scalars['Float']>;
  except_?: InputMaybe<Scalars['Float']>;
  gt?: InputMaybe<Scalars['Float']>;
  gte?: InputMaybe<Scalars['Float']>;
  in_?: InputMaybe<Array<Scalars['Float']>>;
  isnull?: InputMaybe<Scalars['Boolean']>;
  lt?: InputMaybe<Scalars['Float']>;
  lte?: InputMaybe<Scalars['Float']>;
};

export type FloatFilter = {
  exact?: InputMaybe<Scalars['Float']>;
  except_?: InputMaybe<Scalars['Float']>;
  gt?: InputMaybe<Scalars['Float']>;
  gte?: InputMaybe<Scalars['Float']>;
  in_?: InputMaybe<Array<Scalars['Float']>>;
  lt?: InputMaybe<Scalars['Float']>;
  lte?: InputMaybe<Scalars['Float']>;
};

export type FlowEvent = Event & {
  __typename?: 'FlowEvent';
  created?: Maybe<Scalars['DateTime']>;
  description?: Maybe<Scalars['String']>;
  eventTime?: Maybe<Scalars['DateTime']>;
  flowData?: Maybe<FlowEventDataNestedList>;
  id: Scalars['ID'];
  name?: Maybe<Scalars['String']>;
  relatedCases?: Maybe<CaseNestedList>;
  relatedTasks?: Maybe<TaskNestedList>;
  type?: Maybe<Scalars['String']>;
  uniqueIdentifier: Scalars['String'];
};

export type FlowEventFlowDataArgs = {
  filter?: InputMaybe<Array<FlowEventDataFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<FlowEventDataOrdEnumOrderingEntry>>;
};

export type FlowEventRelatedCasesArgs = {
  filter?: InputMaybe<Array<CaseFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<CaseOrdEnumOrderingEntry>>;
};

export type FlowEventRelatedTasksArgs = {
  filter?: InputMaybe<Array<TaskFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TaskOrdEnumOrderingEntry>>;
};

export type FlowEventCreate = {
  created?: InputMaybe<Scalars['DateTime']>;
  description?: InputMaybe<Scalars['String']>;
  eventTime?: InputMaybe<Scalars['DateTime']>;
  flowData?: InputMaybe<Array<Scalars['ID']>>;
  name?: InputMaybe<Scalars['String']>;
  relatedCases?: InputMaybe<Array<Scalars['ID']>>;
  relatedTasks?: InputMaybe<Array<Scalars['ID']>>;
};

export type FlowEventData = {
  __typename?: 'FlowEventData';
  applicationid?: Maybe<Scalars['String']>;
  applicationidrev?: Maybe<Scalars['String']>;
  applicationname?: Maybe<Scalars['String']>;
  applicationnamerev?: Maybe<Scalars['String']>;
  bgpdestinationasnumber?: Maybe<Scalars['LargeJsInt']>;
  bgpdestinationasnumberrev?: Maybe<Scalars['LargeJsInt']>;
  bgpsourceasnumber?: Maybe<Scalars['LargeJsInt']>;
  bgpsourceasnumberrev?: Maybe<Scalars['LargeJsInt']>;
  destinationipv4address?: Maybe<Scalars['String']>;
  destinationipv6address?: Maybe<Scalars['String']>;
  destinationtransportport?: Maybe<Scalars['Int']>;
  flowEvent?: Maybe<FlowEvent>;
  flowendmilliseconds?: Maybe<Scalars['LargeJsInt']>;
  flowendmillisecondsrev?: Maybe<Scalars['LargeJsInt']>;
  flowstartmilliseconds?: Maybe<Scalars['LargeJsInt']>;
  flowstartmillisecondsrev?: Maybe<Scalars['LargeJsInt']>;
  icmptypecodeipv4?: Maybe<Scalars['Int']>;
  id: Scalars['ID'];
  ingressinterface?: Maybe<Scalars['LargeJsInt']>;
  ipclassofservice?: Maybe<Scalars['Int']>;
  ipclassofservicerev?: Maybe<Scalars['Int']>;
  ipversion?: Maybe<Scalars['Int']>;
  mplslabelstacksection2?: Maybe<Scalars['String']>;
  mplslabelstacksection2rev?: Maybe<Scalars['String']>;
  mplslabelstacksection3?: Maybe<Scalars['String']>;
  mplslabelstacksection3rev?: Maybe<Scalars['String']>;
  mplslabelstacksection4?: Maybe<Scalars['String']>;
  mplslabelstacksection4rev?: Maybe<Scalars['String']>;
  mplslabelstacksection5?: Maybe<Scalars['String']>;
  mplslabelstacksection5rev?: Maybe<Scalars['String']>;
  mplslabelstacksection6?: Maybe<Scalars['String']>;
  mplslabelstacksection6rev?: Maybe<Scalars['String']>;
  mplslabelstacksection7?: Maybe<Scalars['String']>;
  mplslabelstacksection7rev?: Maybe<Scalars['String']>;
  mplslabelstacksection8?: Maybe<Scalars['String']>;
  mplslabelstacksection8rev?: Maybe<Scalars['String']>;
  mplslabelstacksection9?: Maybe<Scalars['String']>;
  mplslabelstacksection9rev?: Maybe<Scalars['String']>;
  mplslabelstacksection10?: Maybe<Scalars['String']>;
  mplslabelstacksection10rev?: Maybe<Scalars['String']>;
  mplstoplabelstacksection?: Maybe<Scalars['String']>;
  mplstoplabelstacksectionrev?: Maybe<Scalars['String']>;
  octetdeltacount?: Maybe<Scalars['LargeJsInt']>;
  octetdeltacountrev?: Maybe<Scalars['LargeJsInt']>;
  originalexporteripv6address?: Maybe<Scalars['String']>;
  packetdeltacount?: Maybe<Scalars['LargeJsInt']>;
  packetdeltacountrev?: Maybe<Scalars['LargeJsInt']>;
  protocolidentifier?: Maybe<Scalars['Int']>;
  samplingalgorithm?: Maybe<Scalars['Int']>;
  samplingalgorithmrev?: Maybe<Scalars['Int']>;
  samplinginterval?: Maybe<Scalars['LargeJsInt']>;
  samplingintervalrev?: Maybe<Scalars['LargeJsInt']>;
  sourceipv4address?: Maybe<Scalars['String']>;
  sourceipv6address?: Maybe<Scalars['String']>;
  sourcetransportport?: Maybe<Scalars['Int']>;
  tcpcontrolbits?: Maybe<Scalars['Int']>;
  tcpcontrolbitsrev?: Maybe<Scalars['Int']>;
  tcpwindowsize?: Maybe<Scalars['Int']>;
  tcpwindowsizerev?: Maybe<Scalars['Int']>;
  timestamp?: Maybe<Scalars['DateTime']>;
  vlanid?: Maybe<Scalars['Int']>;
  vlanidrev?: Maybe<Scalars['Int']>;
};

export type FlowEventDataCreate = {
  applicationid?: InputMaybe<Scalars['String']>;
  applicationidrev?: InputMaybe<Scalars['String']>;
  applicationname?: InputMaybe<Scalars['String']>;
  applicationnamerev?: InputMaybe<Scalars['String']>;
  bgpdestinationasnumber?: InputMaybe<Scalars['LargeJsInt']>;
  bgpdestinationasnumberrev?: InputMaybe<Scalars['LargeJsInt']>;
  bgpsourceasnumber?: InputMaybe<Scalars['LargeJsInt']>;
  bgpsourceasnumberrev?: InputMaybe<Scalars['LargeJsInt']>;
  destinationipv4address?: InputMaybe<Scalars['String']>;
  destinationipv6address?: InputMaybe<Scalars['String']>;
  destinationtransportport?: InputMaybe<Scalars['Int']>;
  flowEvent?: InputMaybe<Scalars['ID']>;
  flowendmilliseconds?: InputMaybe<Scalars['LargeJsInt']>;
  flowendmillisecondsrev?: InputMaybe<Scalars['LargeJsInt']>;
  flowstartmilliseconds?: InputMaybe<Scalars['LargeJsInt']>;
  flowstartmillisecondsrev?: InputMaybe<Scalars['LargeJsInt']>;
  icmptypecodeipv4?: InputMaybe<Scalars['Int']>;
  ingressinterface?: InputMaybe<Scalars['LargeJsInt']>;
  ipclassofservice?: InputMaybe<Scalars['Int']>;
  ipclassofservicerev?: InputMaybe<Scalars['Int']>;
  ipversion?: InputMaybe<Scalars['Int']>;
  mplslabelstacksection2?: InputMaybe<Scalars['String']>;
  mplslabelstacksection2rev?: InputMaybe<Scalars['String']>;
  mplslabelstacksection3?: InputMaybe<Scalars['String']>;
  mplslabelstacksection3rev?: InputMaybe<Scalars['String']>;
  mplslabelstacksection4?: InputMaybe<Scalars['String']>;
  mplslabelstacksection4rev?: InputMaybe<Scalars['String']>;
  mplslabelstacksection5?: InputMaybe<Scalars['String']>;
  mplslabelstacksection5rev?: InputMaybe<Scalars['String']>;
  mplslabelstacksection6?: InputMaybe<Scalars['String']>;
  mplslabelstacksection6rev?: InputMaybe<Scalars['String']>;
  mplslabelstacksection7?: InputMaybe<Scalars['String']>;
  mplslabelstacksection7rev?: InputMaybe<Scalars['String']>;
  mplslabelstacksection8?: InputMaybe<Scalars['String']>;
  mplslabelstacksection8rev?: InputMaybe<Scalars['String']>;
  mplslabelstacksection9?: InputMaybe<Scalars['String']>;
  mplslabelstacksection9rev?: InputMaybe<Scalars['String']>;
  mplslabelstacksection10?: InputMaybe<Scalars['String']>;
  mplslabelstacksection10rev?: InputMaybe<Scalars['String']>;
  mplstoplabelstacksection?: InputMaybe<Scalars['String']>;
  mplstoplabelstacksectionrev?: InputMaybe<Scalars['String']>;
  octetdeltacount?: InputMaybe<Scalars['LargeJsInt']>;
  octetdeltacountrev?: InputMaybe<Scalars['LargeJsInt']>;
  originalexporteripv6address?: InputMaybe<Scalars['String']>;
  packetdeltacount?: InputMaybe<Scalars['LargeJsInt']>;
  packetdeltacountrev?: InputMaybe<Scalars['LargeJsInt']>;
  protocolidentifier?: InputMaybe<Scalars['Int']>;
  samplingalgorithm?: InputMaybe<Scalars['Int']>;
  samplingalgorithmrev?: InputMaybe<Scalars['Int']>;
  samplinginterval?: InputMaybe<Scalars['LargeJsInt']>;
  samplingintervalrev?: InputMaybe<Scalars['LargeJsInt']>;
  sourceipv4address?: InputMaybe<Scalars['String']>;
  sourceipv6address?: InputMaybe<Scalars['String']>;
  sourcetransportport?: InputMaybe<Scalars['Int']>;
  tcpcontrolbits?: InputMaybe<Scalars['Int']>;
  tcpcontrolbitsrev?: InputMaybe<Scalars['Int']>;
  tcpwindowsize?: InputMaybe<Scalars['Int']>;
  tcpwindowsizerev?: InputMaybe<Scalars['Int']>;
  timestamp?: InputMaybe<Scalars['DateTime']>;
  vlanid?: InputMaybe<Scalars['Int']>;
  vlanidrev?: InputMaybe<Scalars['Int']>;
};

export type FlowEventDataFilter0 = {
  applicationid?: InputMaybe<StrFieldFilter>;
  applicationidrev?: InputMaybe<StrFieldFilter>;
  applicationname?: InputMaybe<StrFieldFilter>;
  applicationnamerev?: InputMaybe<StrFieldFilter>;
  bgpdestinationasnumber?: InputMaybe<LargeJsIntFieldFilter>;
  bgpdestinationasnumberrev?: InputMaybe<LargeJsIntFieldFilter>;
  bgpsourceasnumber?: InputMaybe<LargeJsIntFieldFilter>;
  bgpsourceasnumberrev?: InputMaybe<LargeJsIntFieldFilter>;
  destinationipv4address?: InputMaybe<StrFieldFilter>;
  destinationipv6address?: InputMaybe<StrFieldFilter>;
  destinationtransportport?: InputMaybe<IntFieldFilter>;
  flowendmilliseconds?: InputMaybe<LargeJsIntFieldFilter>;
  flowendmillisecondsrev?: InputMaybe<LargeJsIntFieldFilter>;
  flowstartmilliseconds?: InputMaybe<LargeJsIntFieldFilter>;
  flowstartmillisecondsrev?: InputMaybe<LargeJsIntFieldFilter>;
  icmptypecodeipv4?: InputMaybe<IntFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  ingressinterface?: InputMaybe<LargeJsIntFieldFilter>;
  ipclassofservice?: InputMaybe<IntFieldFilter>;
  ipclassofservicerev?: InputMaybe<IntFieldFilter>;
  ipversion?: InputMaybe<IntFieldFilter>;
  mplslabelstacksection2?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection2rev?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection3?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection3rev?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection4?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection4rev?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection5?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection5rev?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection6?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection6rev?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection7?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection7rev?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection8?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection8rev?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection9?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection9rev?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection10?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection10rev?: InputMaybe<StrFieldFilter>;
  mplstoplabelstacksection?: InputMaybe<StrFieldFilter>;
  mplstoplabelstacksectionrev?: InputMaybe<StrFieldFilter>;
  octetdeltacount?: InputMaybe<LargeJsIntFieldFilter>;
  octetdeltacountrev?: InputMaybe<LargeJsIntFieldFilter>;
  originalexporteripv6address?: InputMaybe<StrFieldFilter>;
  packetdeltacount?: InputMaybe<LargeJsIntFieldFilter>;
  packetdeltacountrev?: InputMaybe<LargeJsIntFieldFilter>;
  protocolidentifier?: InputMaybe<IntFieldFilter>;
  samplingalgorithm?: InputMaybe<IntFieldFilter>;
  samplingalgorithmrev?: InputMaybe<IntFieldFilter>;
  samplinginterval?: InputMaybe<LargeJsIntFieldFilter>;
  samplingintervalrev?: InputMaybe<LargeJsIntFieldFilter>;
  sourceipv4address?: InputMaybe<StrFieldFilter>;
  sourceipv6address?: InputMaybe<StrFieldFilter>;
  sourcetransportport?: InputMaybe<IntFieldFilter>;
  tcpcontrolbits?: InputMaybe<IntFieldFilter>;
  tcpcontrolbitsrev?: InputMaybe<IntFieldFilter>;
  tcpwindowsize?: InputMaybe<IntFieldFilter>;
  tcpwindowsizerev?: InputMaybe<IntFieldFilter>;
  timestamp?: InputMaybe<DateTimeFieldFilter>;
  vlanid?: InputMaybe<IntFieldFilter>;
  vlanidrev?: InputMaybe<IntFieldFilter>;
};

export type FlowEventDataFilter0AndFilterEntry = {
  AND: Array<FlowEventDataFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type FlowEventDataFilter0OrFilterEntry = {
  OR: FlowEventDataFilter0;
  negate?: Scalars['Boolean'];
};

export type FlowEventDataFilter1 = {
  applicationid?: InputMaybe<StrFieldFilter>;
  applicationidrev?: InputMaybe<StrFieldFilter>;
  applicationname?: InputMaybe<StrFieldFilter>;
  applicationnamerev?: InputMaybe<StrFieldFilter>;
  bgpdestinationasnumber?: InputMaybe<LargeJsIntFieldFilter>;
  bgpdestinationasnumberrev?: InputMaybe<LargeJsIntFieldFilter>;
  bgpsourceasnumber?: InputMaybe<LargeJsIntFieldFilter>;
  bgpsourceasnumberrev?: InputMaybe<LargeJsIntFieldFilter>;
  destinationipv4address?: InputMaybe<StrFieldFilter>;
  destinationipv6address?: InputMaybe<StrFieldFilter>;
  destinationtransportport?: InputMaybe<IntFieldFilter>;
  flowEvent?: InputMaybe<FlowEventFilter1>;
  flowendmilliseconds?: InputMaybe<LargeJsIntFieldFilter>;
  flowendmillisecondsrev?: InputMaybe<LargeJsIntFieldFilter>;
  flowstartmilliseconds?: InputMaybe<LargeJsIntFieldFilter>;
  flowstartmillisecondsrev?: InputMaybe<LargeJsIntFieldFilter>;
  icmptypecodeipv4?: InputMaybe<IntFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  ingressinterface?: InputMaybe<LargeJsIntFieldFilter>;
  ipclassofservice?: InputMaybe<IntFieldFilter>;
  ipclassofservicerev?: InputMaybe<IntFieldFilter>;
  ipversion?: InputMaybe<IntFieldFilter>;
  mplslabelstacksection2?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection2rev?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection3?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection3rev?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection4?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection4rev?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection5?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection5rev?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection6?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection6rev?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection7?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection7rev?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection8?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection8rev?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection9?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection9rev?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection10?: InputMaybe<StrFieldFilter>;
  mplslabelstacksection10rev?: InputMaybe<StrFieldFilter>;
  mplstoplabelstacksection?: InputMaybe<StrFieldFilter>;
  mplstoplabelstacksectionrev?: InputMaybe<StrFieldFilter>;
  octetdeltacount?: InputMaybe<LargeJsIntFieldFilter>;
  octetdeltacountrev?: InputMaybe<LargeJsIntFieldFilter>;
  originalexporteripv6address?: InputMaybe<StrFieldFilter>;
  packetdeltacount?: InputMaybe<LargeJsIntFieldFilter>;
  packetdeltacountrev?: InputMaybe<LargeJsIntFieldFilter>;
  protocolidentifier?: InputMaybe<IntFieldFilter>;
  samplingalgorithm?: InputMaybe<IntFieldFilter>;
  samplingalgorithmrev?: InputMaybe<IntFieldFilter>;
  samplinginterval?: InputMaybe<LargeJsIntFieldFilter>;
  samplingintervalrev?: InputMaybe<LargeJsIntFieldFilter>;
  sourceipv4address?: InputMaybe<StrFieldFilter>;
  sourceipv6address?: InputMaybe<StrFieldFilter>;
  sourcetransportport?: InputMaybe<IntFieldFilter>;
  tcpcontrolbits?: InputMaybe<IntFieldFilter>;
  tcpcontrolbitsrev?: InputMaybe<IntFieldFilter>;
  tcpwindowsize?: InputMaybe<IntFieldFilter>;
  tcpwindowsizerev?: InputMaybe<IntFieldFilter>;
  timestamp?: InputMaybe<DateTimeFieldFilter>;
  vlanid?: InputMaybe<IntFieldFilter>;
  vlanidrev?: InputMaybe<IntFieldFilter>;
};

export type FlowEventDataFilter1AndFilterEntry = {
  AND: Array<FlowEventDataFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type FlowEventDataFilter1OrFilterEntry = {
  OR: FlowEventDataFilter1;
  negate?: Scalars['Boolean'];
};

export type FlowEventDataNestedList = {
  __typename?: 'FlowEventDataNestedList';
  data: Array<FlowEventData>;
  totalCount: Scalars['Int'];
};

export enum FlowEventDataOrdEnum {
  APPLICATIONID = 'APPLICATIONID',
  APPLICATIONIDREV = 'APPLICATIONIDREV',
  APPLICATIONNAME = 'APPLICATIONNAME',
  APPLICATIONNAMEREV = 'APPLICATIONNAMEREV',
  BGPDESTINATIONASNUMBER = 'BGPDESTINATIONASNUMBER',
  BGPDESTINATIONASNUMBERREV = 'BGPDESTINATIONASNUMBERREV',
  BGPSOURCEASNUMBER = 'BGPSOURCEASNUMBER',
  BGPSOURCEASNUMBERREV = 'BGPSOURCEASNUMBERREV',
  DESTINATIONIPV4_ADDRESS = 'DESTINATIONIPV4ADDRESS',
  DESTINATIONIPV6_ADDRESS = 'DESTINATIONIPV6ADDRESS',
  DESTINATIONTRANSPORTPORT = 'DESTINATIONTRANSPORTPORT',
  FLOWENDMILLISECONDS = 'FLOWENDMILLISECONDS',
  FLOWENDMILLISECONDSREV = 'FLOWENDMILLISECONDSREV',
  FLOWSTARTMILLISECONDS = 'FLOWSTARTMILLISECONDS',
  FLOWSTARTMILLISECONDSREV = 'FLOWSTARTMILLISECONDSREV',
  ICMPTYPECODEIPV4 = 'ICMPTYPECODEIPV4',
  ID = 'ID',
  INGRESSINTERFACE = 'INGRESSINTERFACE',
  IPCLASSOFSERVICE = 'IPCLASSOFSERVICE',
  IPCLASSOFSERVICEREV = 'IPCLASSOFSERVICEREV',
  IPVERSION = 'IPVERSION',
  MPLSLABELSTACKSECTION2 = 'MPLSLABELSTACKSECTION2',
  MPLSLABELSTACKSECTION2_REV = 'MPLSLABELSTACKSECTION2REV',
  MPLSLABELSTACKSECTION3 = 'MPLSLABELSTACKSECTION3',
  MPLSLABELSTACKSECTION3_REV = 'MPLSLABELSTACKSECTION3REV',
  MPLSLABELSTACKSECTION4 = 'MPLSLABELSTACKSECTION4',
  MPLSLABELSTACKSECTION4_REV = 'MPLSLABELSTACKSECTION4REV',
  MPLSLABELSTACKSECTION5 = 'MPLSLABELSTACKSECTION5',
  MPLSLABELSTACKSECTION5_REV = 'MPLSLABELSTACKSECTION5REV',
  MPLSLABELSTACKSECTION6 = 'MPLSLABELSTACKSECTION6',
  MPLSLABELSTACKSECTION6_REV = 'MPLSLABELSTACKSECTION6REV',
  MPLSLABELSTACKSECTION7 = 'MPLSLABELSTACKSECTION7',
  MPLSLABELSTACKSECTION7_REV = 'MPLSLABELSTACKSECTION7REV',
  MPLSLABELSTACKSECTION8 = 'MPLSLABELSTACKSECTION8',
  MPLSLABELSTACKSECTION8_REV = 'MPLSLABELSTACKSECTION8REV',
  MPLSLABELSTACKSECTION9 = 'MPLSLABELSTACKSECTION9',
  MPLSLABELSTACKSECTION9_REV = 'MPLSLABELSTACKSECTION9REV',
  MPLSLABELSTACKSECTION10 = 'MPLSLABELSTACKSECTION10',
  MPLSLABELSTACKSECTION10_REV = 'MPLSLABELSTACKSECTION10REV',
  MPLSTOPLABELSTACKSECTION = 'MPLSTOPLABELSTACKSECTION',
  MPLSTOPLABELSTACKSECTIONREV = 'MPLSTOPLABELSTACKSECTIONREV',
  OCTETDELTACOUNT = 'OCTETDELTACOUNT',
  OCTETDELTACOUNTREV = 'OCTETDELTACOUNTREV',
  ORIGINALEXPORTERIPV6_ADDRESS = 'ORIGINALEXPORTERIPV6ADDRESS',
  PACKETDELTACOUNT = 'PACKETDELTACOUNT',
  PACKETDELTACOUNTREV = 'PACKETDELTACOUNTREV',
  PROTOCOLIDENTIFIER = 'PROTOCOLIDENTIFIER',
  SAMPLINGALGORITHM = 'SAMPLINGALGORITHM',
  SAMPLINGALGORITHMREV = 'SAMPLINGALGORITHMREV',
  SAMPLINGINTERVAL = 'SAMPLINGINTERVAL',
  SAMPLINGINTERVALREV = 'SAMPLINGINTERVALREV',
  SOURCEIPV4_ADDRESS = 'SOURCEIPV4ADDRESS',
  SOURCEIPV6_ADDRESS = 'SOURCEIPV6ADDRESS',
  SOURCETRANSPORTPORT = 'SOURCETRANSPORTPORT',
  TCPCONTROLBITS = 'TCPCONTROLBITS',
  TCPCONTROLBITSREV = 'TCPCONTROLBITSREV',
  TCPWINDOWSIZE = 'TCPWINDOWSIZE',
  TCPWINDOWSIZEREV = 'TCPWINDOWSIZEREV',
  TIMESTAMP = 'TIMESTAMP',
  VLANID = 'VLANID',
  VLANIDREV = 'VLANIDREV',
}

export type FlowEventDataOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: FlowEventDataOrdEnum;
};

export type FlowEventDataPaginated = {
  __typename?: 'FlowEventDataPaginated';
  data: Array<FlowEventData>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type FlowEventDataUpdate = {
  applicationid?: InputMaybe<Scalars['String']>;
  applicationidrev?: InputMaybe<Scalars['String']>;
  applicationname?: InputMaybe<Scalars['String']>;
  applicationnamerev?: InputMaybe<Scalars['String']>;
  bgpdestinationasnumber?: InputMaybe<Scalars['LargeJsInt']>;
  bgpdestinationasnumberrev?: InputMaybe<Scalars['LargeJsInt']>;
  bgpsourceasnumber?: InputMaybe<Scalars['LargeJsInt']>;
  bgpsourceasnumberrev?: InputMaybe<Scalars['LargeJsInt']>;
  destinationipv4address?: InputMaybe<Scalars['String']>;
  destinationipv6address?: InputMaybe<Scalars['String']>;
  destinationtransportport?: InputMaybe<Scalars['Int']>;
  flowEvent?: InputMaybe<Scalars['ID']>;
  flowendmilliseconds?: InputMaybe<Scalars['LargeJsInt']>;
  flowendmillisecondsrev?: InputMaybe<Scalars['LargeJsInt']>;
  flowstartmilliseconds?: InputMaybe<Scalars['LargeJsInt']>;
  flowstartmillisecondsrev?: InputMaybe<Scalars['LargeJsInt']>;
  icmptypecodeipv4?: InputMaybe<Scalars['Int']>;
  ingressinterface?: InputMaybe<Scalars['LargeJsInt']>;
  ipclassofservice?: InputMaybe<Scalars['Int']>;
  ipclassofservicerev?: InputMaybe<Scalars['Int']>;
  ipversion?: InputMaybe<Scalars['Int']>;
  mplslabelstacksection2?: InputMaybe<Scalars['String']>;
  mplslabelstacksection2rev?: InputMaybe<Scalars['String']>;
  mplslabelstacksection3?: InputMaybe<Scalars['String']>;
  mplslabelstacksection3rev?: InputMaybe<Scalars['String']>;
  mplslabelstacksection4?: InputMaybe<Scalars['String']>;
  mplslabelstacksection4rev?: InputMaybe<Scalars['String']>;
  mplslabelstacksection5?: InputMaybe<Scalars['String']>;
  mplslabelstacksection5rev?: InputMaybe<Scalars['String']>;
  mplslabelstacksection6?: InputMaybe<Scalars['String']>;
  mplslabelstacksection6rev?: InputMaybe<Scalars['String']>;
  mplslabelstacksection7?: InputMaybe<Scalars['String']>;
  mplslabelstacksection7rev?: InputMaybe<Scalars['String']>;
  mplslabelstacksection8?: InputMaybe<Scalars['String']>;
  mplslabelstacksection8rev?: InputMaybe<Scalars['String']>;
  mplslabelstacksection9?: InputMaybe<Scalars['String']>;
  mplslabelstacksection9rev?: InputMaybe<Scalars['String']>;
  mplslabelstacksection10?: InputMaybe<Scalars['String']>;
  mplslabelstacksection10rev?: InputMaybe<Scalars['String']>;
  mplstoplabelstacksection?: InputMaybe<Scalars['String']>;
  mplstoplabelstacksectionrev?: InputMaybe<Scalars['String']>;
  octetdeltacount?: InputMaybe<Scalars['LargeJsInt']>;
  octetdeltacountrev?: InputMaybe<Scalars['LargeJsInt']>;
  originalexporteripv6address?: InputMaybe<Scalars['String']>;
  packetdeltacount?: InputMaybe<Scalars['LargeJsInt']>;
  packetdeltacountrev?: InputMaybe<Scalars['LargeJsInt']>;
  protocolidentifier?: InputMaybe<Scalars['Int']>;
  samplingalgorithm?: InputMaybe<Scalars['Int']>;
  samplingalgorithmrev?: InputMaybe<Scalars['Int']>;
  samplinginterval?: InputMaybe<Scalars['LargeJsInt']>;
  samplingintervalrev?: InputMaybe<Scalars['LargeJsInt']>;
  sourceipv4address?: InputMaybe<Scalars['String']>;
  sourceipv6address?: InputMaybe<Scalars['String']>;
  sourcetransportport?: InputMaybe<Scalars['Int']>;
  tcpcontrolbits?: InputMaybe<Scalars['Int']>;
  tcpcontrolbitsrev?: InputMaybe<Scalars['Int']>;
  tcpwindowsize?: InputMaybe<Scalars['Int']>;
  tcpwindowsizerev?: InputMaybe<Scalars['Int']>;
  timestamp?: InputMaybe<Scalars['DateTime']>;
  vlanid?: InputMaybe<Scalars['Int']>;
  vlanidrev?: InputMaybe<Scalars['Int']>;
};

export type FlowEventFilter1 = {
  created?: InputMaybe<DateTimeFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  eventTime?: InputMaybe<DateTimeFieldFilter>;
  flowData?: InputMaybe<FlowEventDataFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
  relatedCases?: InputMaybe<CaseFilter1>;
  relatedTasks?: InputMaybe<TaskFilter1>;
  type?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type FlowEventFilter1AndFilterEntry = {
  AND: Array<FlowEventFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type FlowEventFilter1OrFilterEntry = {
  OR: FlowEventFilter1;
  negate?: Scalars['Boolean'];
};

export enum FlowEventOrdEnum {
  CREATED = 'CREATED',
  DESCRIPTION = 'DESCRIPTION',
  EVENT_TIME = 'EVENT_TIME',
  ID = 'ID',
  NAME = 'NAME',
  TYPE = 'TYPE',
  UNIQUE_IDENTIFIER = 'UNIQUE_IDENTIFIER',
}

export type FlowEventOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: FlowEventOrdEnum;
};

export type FlowEventPaginated = {
  __typename?: 'FlowEventPaginated';
  data: Array<FlowEvent>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type FlowEventUpdate = {
  created?: InputMaybe<Scalars['DateTime']>;
  description?: InputMaybe<Scalars['String']>;
  eventTime?: InputMaybe<Scalars['DateTime']>;
  flowData?: InputMaybe<RelationUpdate>;
  name?: InputMaybe<Scalars['String']>;
  relatedCases?: InputMaybe<RelationUpdate>;
  relatedTasks?: InputMaybe<RelationUpdate>;
};

export type FrontPortFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  cable?: InputMaybe<CableFilter>;
  cableId?: InputMaybe<StrawberryIdFilter>;
  color?: InputMaybe<StrFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  device?: InputMaybe<DeviceFilter>;
  deviceId?: InputMaybe<StrawberryIdFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  label?: InputMaybe<StrFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  markConnected?: InputMaybe<IntFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  rearPort?: InputMaybe<RearPortFilter>;
  rearPortId?: InputMaybe<StrawberryIdFilter>;
  rearPortPosition?: InputMaybe<IntFilter>;
  type?: InputMaybe<DcimFrontPortTypeChoicesEnumFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type FrontPortFilterAndFilterEntry = {
  AND: Array<FrontPortFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type FrontPortFilterOrFilterEntry = {
  OR: Array<FrontPortFilter>;
  negate?: Scalars['Boolean'];
};

export type FrontPortType = AssetFederationBase &
  AssetType & {
    __typename?: 'FrontPortType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cable?: Maybe<CableType>;
    cableId?: Maybe<Scalars['ID']>;
    cases: CaseFederationResult;
    color?: Maybe<Scalars['String']>;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    device?: Maybe<DeviceType>;
    deviceId?: Maybe<Scalars['ID']>;
    id: Scalars['ID'];
    label?: Maybe<Scalars['String']>;
    lastUpdated?: Maybe<Scalars['DateTime']>;
    markConnected?: Maybe<Scalars['Int']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    rearPort?: Maybe<RearPortType>;
    rearPortId?: Maybe<Scalars['ID']>;
    rearPortPosition?: Maybe<Scalars['Int']>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    type?: Maybe<DcimFrontPortTypeChoices>;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
  };

export type FrontPortTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type FrontPortTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type FrontPortTypeResultSet = {
  __typename?: 'FrontPortTypeResultSet';
  data: Array<FrontPortType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type GroupProcedure = Ittp &
  TtpFederationBase & {
    __typename?: 'GroupProcedure';
    cases: CaseFederationResult;
    created?: Maybe<Scalars['DateTime']>;
    description?: Maybe<Scalars['String']>;
    externalReferences?: Maybe<ExternalReferenceNestedList>;
    group: TtpGroup;
    groupProcedureName: Scalars['String'];
    groupTechnique: Technique;
    id: Scalars['ID'];
    modified?: Maybe<Scalars['DateTime']>;
    tasks: TaskFederationResult;
    ttpType?: Maybe<Scalars['String']>;
    ttpTypeEnum?: Maybe<KnownTtPsTypesEnum>;
    uniqueIdentifier: Scalars['String'];
  };

export type GroupProcedureCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type GroupProcedureExternalReferencesArgs = {
  filter?: InputMaybe<Array<ExternalReferenceFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ExternalReferenceOrdEnumOrderingEntry>>;
};

export type GroupProcedureTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type GroupProcedureCreate = {
  description?: InputMaybe<Scalars['String']>;
  externalReferences?: InputMaybe<Array<Scalars['ID']>>;
  group: Scalars['ID'];
  groupTechnique: Scalars['ID'];
};

export type GroupProcedureFilter0 = {
  created?: InputMaybe<DateTimeFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  groupProcedureName?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  modified?: InputMaybe<DateTimeFieldFilter>;
  ttpType?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type GroupProcedureFilter0AndFilterEntry = {
  AND: Array<GroupProcedureFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type GroupProcedureFilter0OrFilterEntry = {
  OR: GroupProcedureFilter0;
  negate?: Scalars['Boolean'];
};

export type GroupProcedureFilter1 = {
  created?: InputMaybe<DateTimeFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  externalReferences?: InputMaybe<ExternalReferenceFilter1>;
  group?: InputMaybe<TtpGroupFilter1>;
  groupProcedureName?: InputMaybe<StrFieldFilter>;
  groupTechnique?: InputMaybe<TechniqueFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  modified?: InputMaybe<DateTimeFieldFilter>;
  ttpType?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type GroupProcedureFilter1AndFilterEntry = {
  AND: Array<GroupProcedureFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type GroupProcedureFilter1OrFilterEntry = {
  OR: GroupProcedureFilter1;
  negate?: Scalars['Boolean'];
};

export type GroupProcedureNestedList = {
  __typename?: 'GroupProcedureNestedList';
  data: Array<GroupProcedure>;
  totalCount: Scalars['Int'];
};

export enum GroupProcedureOrdEnum {
  CREATED = 'CREATED',
  DESCRIPTION = 'DESCRIPTION',
  GROUP_PROCEDURE_NAME = 'GROUP_PROCEDURE_NAME',
  ID = 'ID',
  MODIFIED = 'MODIFIED',
  TTP_TYPE = 'TTP_TYPE',
  UNIQUE_IDENTIFIER = 'UNIQUE_IDENTIFIER',
}

export type GroupProcedureOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: GroupProcedureOrdEnum;
};

export type GroupProcedurePaginated = {
  __typename?: 'GroupProcedurePaginated';
  data: Array<GroupProcedure>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type GroupProcedureUpdate = {
  description?: InputMaybe<Scalars['String']>;
  externalReferences?: InputMaybe<RelationUpdate>;
  group?: InputMaybe<Scalars['ID']>;
  groupTechnique?: InputMaybe<Scalars['ID']>;
};

export type Hash = {
  __typename?: 'Hash';
  hashType?: Maybe<Scalars['String']>;
  id: Scalars['ID'];
  observable?: Maybe<Observable>;
  value?: Maybe<Scalars['String']>;
};

export type HashCreate = {
  hashType?: InputMaybe<Scalars['String']>;
  observable?: InputMaybe<Scalars['ID']>;
  value?: InputMaybe<Scalars['String']>;
};

export type HashFilter0 = {
  hashType?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  value?: InputMaybe<StrFieldFilter>;
};

export type HashFilter0AndFilterEntry = {
  AND: Array<HashFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type HashFilter0OrFilterEntry = {
  OR: HashFilter0;
  negate?: Scalars['Boolean'];
};

export type HashFilter1 = {
  hashType?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  observable?: InputMaybe<ObservableFilter1>;
  value?: InputMaybe<StrFieldFilter>;
};

export type HashFilter1AndFilterEntry = {
  AND: Array<HashFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type HashFilter1OrFilterEntry = {
  OR: HashFilter1;
  negate?: Scalars['Boolean'];
};

export type HashInput = {
  hashType: Scalars['String'];
  value: Scalars['String'];
};

export type HashInputOutput = TaskInputOutput & {
  __typename?: 'HashInputOutput';
  description?: Maybe<Scalars['String']>;
  hashValue?: Maybe<Scalars['String']>;
  id: Scalars['ID'];
  inputOf?: Maybe<Task>;
  outputOf?: Maybe<Task>;
  stringifiedValue?: Maybe<Scalars['String']>;
  type?: Maybe<Scalars['String']>;
};

export type HashInputOutputCreate = {
  description?: InputMaybe<Scalars['String']>;
  hashValue?: InputMaybe<Scalars['String']>;
  inputOf?: InputMaybe<Scalars['ID']>;
  outputOf?: InputMaybe<Scalars['ID']>;
};

export type HashInputOutputFilter1 = {
  description?: InputMaybe<StrFieldFilter>;
  hashValue?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  inputOf?: InputMaybe<TaskFilter1>;
  outputOf?: InputMaybe<TaskFilter1>;
  type?: InputMaybe<StrFieldFilter>;
};

export type HashInputOutputFilter1AndFilterEntry = {
  AND: Array<HashInputOutputFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type HashInputOutputFilter1OrFilterEntry = {
  OR: HashInputOutputFilter1;
  negate?: Scalars['Boolean'];
};

export enum HashInputOutputOrdEnum {
  DESCRIPTION = 'DESCRIPTION',
  HASH_VALUE = 'HASH_VALUE',
  ID = 'ID',
  TYPE = 'TYPE',
}

export type HashInputOutputOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: HashInputOutputOrdEnum;
};

export type HashInputOutputPaginated = {
  __typename?: 'HashInputOutputPaginated';
  data: Array<HashInputOutput>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type HashInputOutputUpdate = {
  description?: InputMaybe<Scalars['String']>;
  hashValue?: InputMaybe<Scalars['String']>;
  inputOf?: InputMaybe<Scalars['ID']>;
  outputOf?: InputMaybe<Scalars['ID']>;
};

export type HashNestedList = {
  __typename?: 'HashNestedList';
  data: Array<Hash>;
  totalCount: Scalars['Int'];
};

export enum HashOrdEnum {
  HASH_TYPE = 'HASH_TYPE',
  ID = 'ID',
  VALUE = 'VALUE',
}

export type HashOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: HashOrdEnum;
};

export type HashPaginated = {
  __typename?: 'HashPaginated';
  data: Array<Hash>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type HashUpdate = {
  hashType?: InputMaybe<Scalars['String']>;
  observable?: InputMaybe<Scalars['ID']>;
  value?: InputMaybe<Scalars['String']>;
};

export type HashableObservable = {
  ctiEntries?: Maybe<ObservableLinkNestedList>;
  description?: Maybe<Scalars['String']>;
  hashes?: Maybe<HashNestedList>;
  id: Scalars['ID'];
  observableType?: Maybe<Scalars['String']>;
  uniqueIdentifier: Scalars['String'];
};

export type HashableObservableCtiEntriesArgs = {
  filter?: InputMaybe<Array<ObservableLinkFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ObservableLinkOrdEnumOrderingEntry>>;
};

export type HashableObservableHashesArgs = {
  filter?: InputMaybe<Array<HashFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<HashOrdEnumOrderingEntry>>;
};

export type HashableObservableFilter1 = {
  attachmentOf?: InputMaybe<EmailMessagePartsRelationshipFilter1>;
  body?: InputMaybe<StrFieldFilter>;
  ctiEntries?: InputMaybe<ObservableLinkFilter1>;
  description?: InputMaybe<StrFieldFilter>;
  emailAddresses?: InputMaybe<EmailMessageEmailAddressRelationshipFilter1>;
  hashes?: InputMaybe<HashFilter1>;
  headers?: InputMaybe<EmailHeaderFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
  observableType?: InputMaybe<StrFieldFilter>;
  parts?: InputMaybe<EmailMessagePartsRelationshipFilter1>;
  rawReference?: InputMaybe<StrFieldFilter>;
  reference?: InputMaybe<StrFieldFilter>;
  subject?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type HashableObservableFilter1AndFilterEntry = {
  AND: Array<HashableObservableFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type HashableObservableFilter1OrFilterEntry = {
  OR: HashableObservableFilter1;
  negate?: Scalars['Boolean'];
};

export enum HashableObservableOrdEnum {
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  OBSERVABLE_TYPE = 'OBSERVABLE_TYPE',
  UNIQUE_IDENTIFIER = 'UNIQUE_IDENTIFIER',
}

export type HashableObservableOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: HashableObservableOrdEnum;
};

export type HashableObservablePaginated = {
  __typename?: 'HashableObservablePaginated';
  data: Array<HashableObservable>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type HeaderInput = {
  key: Scalars['String'];
  value: Scalars['String'];
};

export type Host = {
  ctiEntries?: Maybe<ObservableLinkNestedList>;
  description?: Maybe<Scalars['String']>;
  emails?: Maybe<EmailAddressNestedList>;
  id: Scalars['ID'];
  observableType?: Maybe<Scalars['String']>;
  uniqueIdentifier: Scalars['String'];
  urls?: Maybe<UrlNestedList>;
};

export type HostCtiEntriesArgs = {
  filter?: InputMaybe<Array<ObservableLinkFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ObservableLinkOrdEnumOrderingEntry>>;
};

export type HostEmailsArgs = {
  filter?: InputMaybe<Array<EmailAddressFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<EmailAddressOrdEnumOrderingEntry>>;
};

export type HostUrlsArgs = {
  filter?: InputMaybe<Array<UrlFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<UrlOrdEnumOrderingEntry>>;
};

export type HostFilter1 = {
  address?: InputMaybe<NetFieldFilter>;
  ctiEntries?: InputMaybe<ObservableLinkFilter1>;
  description?: InputMaybe<StrFieldFilter>;
  domainName?: InputMaybe<StrFieldFilter>;
  domainResolvedFromIps?: InputMaybe<IpAddressToDomainResolutionFilter1>;
  domainResolvesToIps?: InputMaybe<DomainToIpAddressResolutionFilter1>;
  emails?: InputMaybe<EmailAddressFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  ipResolvedFromDomains?: InputMaybe<DomainToIpAddressResolutionFilter1>;
  ipResolvesToDomains?: InputMaybe<IpAddressToDomainResolutionFilter1>;
  observableType?: InputMaybe<StrFieldFilter>;
  resolvedFromDomains?: InputMaybe<DomainToDomainResolutionFilter1>;
  resolvesToDomains?: InputMaybe<DomainToDomainResolutionFilter1>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
  urls?: InputMaybe<UrlFilter1>;
};

export type HostFilter1AndFilterEntry = {
  AND: Array<HostFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type HostFilter1OrFilterEntry = {
  OR: HostFilter1;
  negate?: Scalars['Boolean'];
};

export enum HostOrdEnum {
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  OBSERVABLE_TYPE = 'OBSERVABLE_TYPE',
  UNIQUE_IDENTIFIER = 'UNIQUE_IDENTIFIER',
}

export type HostOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: HostOrdEnum;
};

export type HostPaginated = {
  __typename?: 'HostPaginated';
  data: Array<Host>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type IpAddress = Host &
  Observable &
  ObservableFederationBase & {
    __typename?: 'IPAddress';
    address: IpNetworkAddressType;
    cases: CaseFederationResult;
    ctiEntries?: Maybe<ObservableLinkNestedList>;
    description?: Maybe<Scalars['String']>;
    emails?: Maybe<EmailAddressNestedList>;
    id: Scalars['ID'];
    ipResolvedFromDomains?: Maybe<DomainToIpAddressResolutionNestedList>;
    ipResolvesToDomains?: Maybe<IpAddressToDomainResolutionNestedList>;
    observableType?: Maybe<Scalars['String']>;
    observableTypeEnum?: Maybe<KnownObservablesEnum>;
    tasks: TaskFederationResult;
    uniqueIdentifier: Scalars['String'];
    urls?: Maybe<UrlNestedList>;
  };

export type IpAddressCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type IpAddressCtiEntriesArgs = {
  filter?: InputMaybe<Array<ObservableLinkFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ObservableLinkOrdEnumOrderingEntry>>;
};

export type IpAddressEmailsArgs = {
  filter?: InputMaybe<Array<EmailAddressFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<EmailAddressOrdEnumOrderingEntry>>;
};

export type IpAddressIpResolvedFromDomainsArgs = {
  filter?: InputMaybe<Array<DomainToIpAddressResolutionFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<DomainToIpAddressResolutionOrdEnumOrderingEntry>>;
};

export type IpAddressIpResolvesToDomainsArgs = {
  filter?: InputMaybe<Array<IpAddressToDomainResolutionFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<IpAddressToDomainResolutionOrdEnumOrderingEntry>>;
};

export type IpAddressTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type IpAddressUrlsArgs = {
  filter?: InputMaybe<Array<UrlFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<UrlOrdEnumOrderingEntry>>;
};

export type IpAddressCreate = {
  address: Scalars['String'];
  ctiEntries?: InputMaybe<Array<Scalars['ID']>>;
  description?: InputMaybe<Scalars['String']>;
  emails?: InputMaybe<Array<Scalars['ID']>>;
  ipResolvedFromDomains?: InputMaybe<Array<Scalars['ID']>>;
  ipResolvesToDomains?: InputMaybe<Array<Scalars['ID']>>;
  urls?: InputMaybe<Array<Scalars['ID']>>;
};

export type IpAddressFilter = {
  Name?: InputMaybe<StrFilter>;
  address?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  assignedObjectId?: InputMaybe<StrawberryIdFilter>;
  assignedObjectType?: InputMaybe<StrFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  dnsName?: InputMaybe<StrFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  natInside?: InputMaybe<IpAddressFilter>;
  natInsideId?: InputMaybe<StrawberryIdFilter>;
  natOutside?: InputMaybe<IpAddressFilter>;
  natOutsideId?: InputMaybe<StrawberryIdFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  role?: InputMaybe<IpamIpAddressRoleChoicesEnumFilter>;
  status?: InputMaybe<IpamIpAddressStatusChoicesEnumFilter>;
  tenant?: InputMaybe<TenantFilter>;
  tenantId?: InputMaybe<StrawberryIdFilter>;
  uuid?: InputMaybe<StrFilter>;
  vrf?: InputMaybe<VrfFilter>;
  vrfId?: InputMaybe<StrawberryIdFilter>;
};

export type IpAddressFilter1 = {
  address?: InputMaybe<NetFieldFilter>;
  ctiEntries?: InputMaybe<ObservableLinkFilter1>;
  description?: InputMaybe<StrFieldFilter>;
  emails?: InputMaybe<EmailAddressFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  ipResolvedFromDomains?: InputMaybe<DomainToIpAddressResolutionFilter1>;
  ipResolvesToDomains?: InputMaybe<IpAddressToDomainResolutionFilter1>;
  observableType?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
  urls?: InputMaybe<UrlFilter1>;
};

export type IpAddressFilter1AndFilterEntry = {
  AND: Array<IpAddressFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type IpAddressFilter1OrFilterEntry = {
  OR: IpAddressFilter1;
  negate?: Scalars['Boolean'];
};

export type IpAddressFilterAndFilterEntry = {
  AND: Array<IpAddressFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type IpAddressFilterOrFilterEntry = {
  OR: Array<IpAddressFilter>;
  negate?: Scalars['Boolean'];
};

export type IpAddressNestedListResult = {
  __typename?: 'IPAddressNestedListResult';
  data?: Maybe<IpAddress>;
  error?: Maybe<ValidationError>;
};

export enum IpAddressOrdEnum {
  ADDRESS = 'ADDRESS',
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  OBSERVABLE_TYPE = 'OBSERVABLE_TYPE',
  UNIQUE_IDENTIFIER = 'UNIQUE_IDENTIFIER',
}

export type IpAddressOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: IpAddressOrdEnum;
};

export type IpAddressPaginated = {
  __typename?: 'IPAddressPaginated';
  data: Array<IpAddress>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type IpAddressToDomainResolution = Observable &
  ObservableFederationBase & {
    __typename?: 'IPAddressToDomainResolution';
    cases: CaseFederationResult;
    ctiEntries?: Maybe<ObservableLinkNestedList>;
    description?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    ipToDomainFirstSeen?: Maybe<Scalars['DateTime']>;
    ipToDomainLastSeen?: Maybe<Scalars['DateTime']>;
    observableType?: Maybe<Scalars['String']>;
    observableTypeEnum?: Maybe<KnownObservablesEnum>;
    resolvedDomain?: Maybe<DomainName>;
    sourceIpAddress?: Maybe<IpAddress>;
    tasks: TaskFederationResult;
    uniqueIdentifier: Scalars['String'];
  };

export type IpAddressToDomainResolutionCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type IpAddressToDomainResolutionCtiEntriesArgs = {
  filter?: InputMaybe<Array<ObservableLinkFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ObservableLinkOrdEnumOrderingEntry>>;
};

export type IpAddressToDomainResolutionTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type IpAddressToDomainResolutionCreate = {
  ctiEntries?: InputMaybe<Array<Scalars['ID']>>;
  description?: InputMaybe<Scalars['String']>;
  ipToDomainFirstSeen?: InputMaybe<Scalars['DateTime']>;
  ipToDomainLastSeen?: InputMaybe<Scalars['DateTime']>;
  resolvedDomain?: InputMaybe<Scalars['ID']>;
  sourceIpAddress?: InputMaybe<Scalars['ID']>;
};

export type IpAddressToDomainResolutionFilter0 = {
  description?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  ipToDomainFirstSeen?: InputMaybe<DateTimeFieldFilter>;
  ipToDomainLastSeen?: InputMaybe<DateTimeFieldFilter>;
  observableType?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type IpAddressToDomainResolutionFilter0AndFilterEntry = {
  AND: Array<IpAddressToDomainResolutionFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type IpAddressToDomainResolutionFilter0OrFilterEntry = {
  OR: IpAddressToDomainResolutionFilter0;
  negate?: Scalars['Boolean'];
};

export type IpAddressToDomainResolutionFilter1 = {
  ctiEntries?: InputMaybe<ObservableLinkFilter1>;
  description?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  ipToDomainFirstSeen?: InputMaybe<DateTimeFieldFilter>;
  ipToDomainLastSeen?: InputMaybe<DateTimeFieldFilter>;
  observableType?: InputMaybe<StrFieldFilter>;
  resolvedDomain?: InputMaybe<DomainNameFilter1>;
  sourceIpAddress?: InputMaybe<IpAddressFilter1>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type IpAddressToDomainResolutionFilter1AndFilterEntry = {
  AND: Array<IpAddressToDomainResolutionFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type IpAddressToDomainResolutionFilter1OrFilterEntry = {
  OR: IpAddressToDomainResolutionFilter1;
  negate?: Scalars['Boolean'];
};

export type IpAddressToDomainResolutionNestedList = {
  __typename?: 'IPAddressToDomainResolutionNestedList';
  data: Array<IpAddressToDomainResolution>;
  totalCount: Scalars['Int'];
};

export type IpAddressToDomainResolutionNestedListResult = {
  __typename?: 'IPAddressToDomainResolutionNestedListResult';
  data?: Maybe<IpAddressToDomainResolution>;
  error?: Maybe<ValidationError>;
};

export enum IpAddressToDomainResolutionOrdEnum {
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  IP_TO_DOMAIN_FIRST_SEEN = 'IP_TO_DOMAIN_FIRST_SEEN',
  IP_TO_DOMAIN_LAST_SEEN = 'IP_TO_DOMAIN_LAST_SEEN',
  OBSERVABLE_TYPE = 'OBSERVABLE_TYPE',
  UNIQUE_IDENTIFIER = 'UNIQUE_IDENTIFIER',
}

export type IpAddressToDomainResolutionOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: IpAddressToDomainResolutionOrdEnum;
};

export type IpAddressToDomainResolutionPaginated = {
  __typename?: 'IPAddressToDomainResolutionPaginated';
  data: Array<IpAddressToDomainResolution>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type IpAddressToDomainResolutionUpdate = {
  ctiEntries?: InputMaybe<RelationUpdate>;
  description?: InputMaybe<Scalars['String']>;
  ipToDomainFirstSeen?: InputMaybe<Scalars['DateTime']>;
  ipToDomainLastSeen?: InputMaybe<Scalars['DateTime']>;
  resolvedDomain?: InputMaybe<Scalars['ID']>;
  sourceIpAddress?: InputMaybe<Scalars['ID']>;
};

export type IpAddressType = AssetFederationBase &
  AssetType & {
    __typename?: 'IPAddressType';
    Name?: Maybe<Scalars['String']>;
    address?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    assignedObject?: Maybe<AssetType>;
    assignedObjectId?: Maybe<Scalars['ID']>;
    assignedObjectType?: Maybe<Scalars['String']>;
    cases: CaseFederationResult;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    dnsName?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    lastUpdated?: Maybe<Scalars['DateTime']>;
    natInside?: Maybe<IpAddressType>;
    natInsideId?: Maybe<Scalars['ID']>;
    natOutside?: Maybe<IpAddressType>;
    natOutsideId?: Maybe<Scalars['ID']>;
    netboxUrl?: Maybe<Scalars['String']>;
    role?: Maybe<IpamIpAddressRoleChoices>;
    services: ServiceTypeResultSet;
    status?: Maybe<IpamIpAddressStatusChoices>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    tenant?: Maybe<TenantType>;
    tenantId?: Maybe<Scalars['ID']>;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
    vrf?: Maybe<VrfType>;
    vrfId?: Maybe<Scalars['ID']>;
  };

export type IpAddressTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type IpAddressTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type IpAddressTypeResultSet = {
  __typename?: 'IPAddressTypeResultSet';
  data: Array<IpAddressType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type IpAddressUpdate = {
  address?: InputMaybe<Scalars['String']>;
  ctiEntries?: InputMaybe<RelationUpdate>;
  description?: InputMaybe<Scalars['String']>;
  emails?: InputMaybe<RelationUpdate>;
  ipResolvedFromDomains?: InputMaybe<RelationUpdate>;
  ipResolvesToDomains?: InputMaybe<RelationUpdate>;
  urls?: InputMaybe<RelationUpdate>;
};

export type IpInputOutput = TaskInputOutput & {
  __typename?: 'IPInputOutput';
  description?: Maybe<Scalars['String']>;
  id: Scalars['ID'];
  inputOf?: Maybe<Task>;
  ipValue?: Maybe<Scalars['String']>;
  outputOf?: Maybe<Task>;
  stringifiedValue?: Maybe<Scalars['String']>;
  type?: Maybe<Scalars['String']>;
};

export type IpInputOutputCreate = {
  description?: InputMaybe<Scalars['String']>;
  inputOf?: InputMaybe<Scalars['ID']>;
  ipValue?: InputMaybe<Scalars['String']>;
  outputOf?: InputMaybe<Scalars['ID']>;
};

export type IpInputOutputFilter1 = {
  description?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  inputOf?: InputMaybe<TaskFilter1>;
  ipValue?: InputMaybe<StrFieldFilter>;
  outputOf?: InputMaybe<TaskFilter1>;
  type?: InputMaybe<StrFieldFilter>;
};

export type IpInputOutputFilter1AndFilterEntry = {
  AND: Array<IpInputOutputFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type IpInputOutputFilter1OrFilterEntry = {
  OR: IpInputOutputFilter1;
  negate?: Scalars['Boolean'];
};

export enum IpInputOutputOrdEnum {
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  IP_VALUE = 'IP_VALUE',
  TYPE = 'TYPE',
}

export type IpInputOutputOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: IpInputOutputOrdEnum;
};

export type IpInputOutputPaginated = {
  __typename?: 'IPInputOutputPaginated';
  data: Array<IpInputOutput>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type IpInputOutputUpdate = {
  description?: InputMaybe<Scalars['String']>;
  inputOf?: InputMaybe<Scalars['ID']>;
  ipValue?: InputMaybe<Scalars['String']>;
  outputOf?: InputMaybe<Scalars['ID']>;
};

export type IpNetworkAddressType = {
  __typename?: 'IPNetworkAddressType';
  compressed: Scalars['String'];
  exploded: Scalars['String'];
  hostmask: AddressType;
  ip: AddressType;
  isGlobal: Scalars['Boolean'];
  isLinkLocal: Scalars['Boolean'];
  isLoopback: Scalars['Boolean'];
  isMulticast: Scalars['Boolean'];
  isPrivate: Scalars['Boolean'];
  isReserved: Scalars['Boolean'];
  isUnspecified: Scalars['Boolean'];
  maxPrefixlen: Scalars['Int'];
  netmask: AddressType;
  network: IpNetworkType;
  reversePointer: Scalars['String'];
  version: Scalars['Int'];
};

export type IpNetworkType = {
  __typename?: 'IPNetworkType';
  broadcastAddress: AddressType;
  compressed: Scalars['String'];
  exploded: Scalars['String'];
  hostmask: AddressType;
  isGlobal: Scalars['Boolean'];
  isLinkLocal: Scalars['Boolean'];
  isLoopback: Scalars['Boolean'];
  isMulticast: Scalars['Boolean'];
  isPrivate: Scalars['Boolean'];
  isReserved: Scalars['Boolean'];
  isUnspecified: Scalars['Boolean'];
  maxPrefixlen: Scalars['Int'];
  netmask: AddressType;
  networkAddress: AddressType;
  prefixlen: Scalars['Int'];
  version: Scalars['Int'];
};

export type IpRangeFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  endAddress?: InputMaybe<StrFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  role?: InputMaybe<RoleFilter>;
  roleId?: InputMaybe<StrawberryIdFilter>;
  size?: InputMaybe<IntFilter>;
  startAddress?: InputMaybe<StrFilter>;
  status?: InputMaybe<IpamIpRangeStatusChoicesEnumFilter>;
  tenant?: InputMaybe<TenantFilter>;
  tenantId?: InputMaybe<StrawberryIdFilter>;
  uuid?: InputMaybe<StrFilter>;
  vrf?: InputMaybe<VrfFilter>;
  vrfId?: InputMaybe<StrawberryIdFilter>;
};

export type IpRangeFilterAndFilterEntry = {
  AND: Array<IpRangeFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type IpRangeFilterOrFilterEntry = {
  OR: Array<IpRangeFilter>;
  negate?: Scalars['Boolean'];
};

export type IpRangeType = AssetFederationBase &
  AssetType & {
    __typename?: 'IPRangeType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    endAddress?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    lastUpdated?: Maybe<Scalars['DateTime']>;
    netboxUrl?: Maybe<Scalars['String']>;
    role?: Maybe<RoleType>;
    roleId?: Maybe<Scalars['ID']>;
    size?: Maybe<Scalars['Int']>;
    startAddress?: Maybe<Scalars['String']>;
    status?: Maybe<IpamIpRangeStatusChoices>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    tenant?: Maybe<TenantType>;
    tenantId?: Maybe<Scalars['ID']>;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
    vrf?: Maybe<VrfType>;
    vrfId?: Maybe<Scalars['ID']>;
  };

export type IpRangeTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type IpRangeTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type IpRangeTypeResultSet = {
  __typename?: 'IPRangeTypeResultSet';
  data: Array<IpRangeType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type Ittp = {
  created?: Maybe<Scalars['DateTime']>;
  description?: Maybe<Scalars['String']>;
  externalReferences?: Maybe<ExternalReferenceNestedList>;
  id: Scalars['ID'];
  modified?: Maybe<Scalars['DateTime']>;
  ttpType?: Maybe<Scalars['String']>;
  uniqueIdentifier: Scalars['String'];
};

export type IttpExternalReferencesArgs = {
  filter?: InputMaybe<Array<ExternalReferenceFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ExternalReferenceOrdEnumOrderingEntry>>;
};

export type IttpFilter0 = {
  created?: InputMaybe<DateTimeFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  groupProcedureName?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  isSubtechnique?: InputMaybe<BoolFieldFilter>;
  malwareProcedureName?: InputMaybe<StrFieldFilter>;
  modified?: InputMaybe<DateTimeFieldFilter>;
  tacticName?: InputMaybe<StrFieldFilter>;
  techniqueName?: InputMaybe<StrFieldFilter>;
  toolProcedureName?: InputMaybe<StrFieldFilter>;
  ttpType?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type IttpFilter0AndFilterEntry = {
  AND: Array<IttpFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type IttpFilter0OrFilterEntry = {
  OR: IttpFilter0;
  negate?: Scalars['Boolean'];
};

export type IttpFilter1 = {
  created?: InputMaybe<DateTimeFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  externalReferences?: InputMaybe<ExternalReferenceFilter1>;
  group?: InputMaybe<TtpGroupFilter1>;
  groupProcedureName?: InputMaybe<StrFieldFilter>;
  groupProcedures?: InputMaybe<GroupProcedureFilter1>;
  groupTechnique?: InputMaybe<TechniqueFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  isSubtechnique?: InputMaybe<BoolFieldFilter>;
  malware?: InputMaybe<MalwareFilter1>;
  malwareProcedureName?: InputMaybe<StrFieldFilter>;
  malwareProcedures?: InputMaybe<MalwareProcedureFilter1>;
  malwareTechnique?: InputMaybe<TechniqueFilter1>;
  mitigations?: InputMaybe<TechniqueMitigationRelationshipFilter1>;
  modified?: InputMaybe<DateTimeFieldFilter>;
  platforms?: InputMaybe<TtpPlatformFilter1>;
  subTechniqueOf?: InputMaybe<TechniqueFilter1>;
  subTechniques?: InputMaybe<TechniqueFilter1>;
  tacticName?: InputMaybe<StrFieldFilter>;
  tactics?: InputMaybe<TacticFilter1>;
  techniqueName?: InputMaybe<StrFieldFilter>;
  techniques?: InputMaybe<TechniqueFilter1>;
  tool?: InputMaybe<ToolFilter1>;
  toolProcedureName?: InputMaybe<StrFieldFilter>;
  toolProcedures?: InputMaybe<ToolProcedureFilter1>;
  toolTechnique?: InputMaybe<TechniqueFilter1>;
  ttpType?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type IttpFilter1AndFilterEntry = {
  AND: Array<IttpFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type IttpFilter1OrFilterEntry = {
  OR: IttpFilter1;
  negate?: Scalars['Boolean'];
};

export type IttpNestedList = {
  __typename?: 'ITTPNestedList';
  data: Array<Ittp>;
  totalCount: Scalars['Int'];
};

export enum IttpOrdEnum {
  CREATED = 'CREATED',
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  MODIFIED = 'MODIFIED',
  TTP_TYPE = 'TTP_TYPE',
  UNIQUE_IDENTIFIER = 'UNIQUE_IDENTIFIER',
}

export type IttpOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: IttpOrdEnum;
};

export type IttpPaginated = {
  __typename?: 'ITTPPaginated';
  data: Array<Ittp>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type IntFieldFilter = {
  exact?: InputMaybe<Scalars['Int']>;
  except_?: InputMaybe<Scalars['Int']>;
  gt?: InputMaybe<Scalars['Int']>;
  gte?: InputMaybe<Scalars['Int']>;
  in_?: InputMaybe<Array<Scalars['Int']>>;
  isnull?: InputMaybe<Scalars['Boolean']>;
  lt?: InputMaybe<Scalars['Int']>;
  lte?: InputMaybe<Scalars['Int']>;
};

export type IntFilter = {
  exact?: InputMaybe<Scalars['Int']>;
  except_?: InputMaybe<Scalars['Int']>;
  gt?: InputMaybe<Scalars['Int']>;
  gte?: InputMaybe<Scalars['Int']>;
  in_?: InputMaybe<Array<Scalars['Int']>>;
  lt?: InputMaybe<Scalars['Int']>;
  lte?: InputMaybe<Scalars['Int']>;
};

export type InterfaceFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  bridge?: InputMaybe<InterfaceFilter>;
  bridgeId?: InputMaybe<StrawberryIdFilter>;
  cable?: InputMaybe<CableFilter>;
  cableId?: InputMaybe<StrawberryIdFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  device?: InputMaybe<DeviceFilter>;
  deviceId?: InputMaybe<StrawberryIdFilter>;
  enabled?: InputMaybe<BoolFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  label?: InputMaybe<StrFilter>;
  lag?: InputMaybe<InterfaceFilter>;
  lagId?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  macAddress?: InputMaybe<StrFilter>;
  markConnected?: InputMaybe<BoolFilter>;
  mgmtOnly?: InputMaybe<BoolFilter>;
  mode?: InputMaybe<DcimInterfaceModeChoicesEnumFilter>;
  mtu?: InputMaybe<IntFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  parent?: InputMaybe<InterfaceFilter>;
  parentId?: InputMaybe<StrawberryIdFilter>;
  taggedVlanIds?: InputMaybe<StrawberryIdFilter>;
  taggedVlans?: InputMaybe<VlanFilter>;
  type?: InputMaybe<DcimInterfaceTypeChoicesEnumFilter>;
  untaggedVlan?: InputMaybe<VlanFilter>;
  untaggedVlanId?: InputMaybe<StrawberryIdFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type InterfaceFilterAndFilterEntry = {
  AND: Array<InterfaceFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type InterfaceFilterOrFilterEntry = {
  OR: Array<InterfaceFilter>;
  negate?: Scalars['Boolean'];
};

export type InterfaceType = AssetFederationBase &
  AssetType & {
    __typename?: 'InterfaceType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    bridge?: Maybe<InterfaceType>;
    bridgeId?: Maybe<Scalars['ID']>;
    cable?: Maybe<CableType>;
    cableId?: Maybe<Scalars['ID']>;
    cases: CaseFederationResult;
    children: InterfaceTypeResultSet;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    device?: Maybe<DeviceType>;
    deviceId?: Maybe<Scalars['ID']>;
    enabled?: Maybe<Scalars['Boolean']>;
    id: Scalars['ID'];
    label?: Maybe<Scalars['String']>;
    lag?: Maybe<InterfaceType>;
    lagId?: Maybe<Scalars['ID']>;
    lastUpdated?: Maybe<Scalars['DateTime']>;
    macAddress?: Maybe<Scalars['String']>;
    markConnected?: Maybe<Scalars['Boolean']>;
    mgmtOnly?: Maybe<Scalars['Boolean']>;
    mode?: Maybe<DcimInterfaceModeChoices>;
    mtu?: Maybe<Scalars['Int']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    parent?: Maybe<InterfaceType>;
    parentId?: Maybe<Scalars['ID']>;
    tagIds: Array<Scalars['ID']>;
    taggedVlanIds: Array<Scalars['ID']>;
    taggedVlans: Array<VlanType>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    type?: Maybe<DcimInterfaceTypeChoices>;
    uniquePrefix: Scalars['String'];
    untaggedVlan?: Maybe<VlanType>;
    untaggedVlanId?: Maybe<Scalars['ID']>;
    uuid?: Maybe<Scalars['String']>;
  };

export type InterfaceTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type InterfaceTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type InterfaceTypeResultSet = {
  __typename?: 'InterfaceTypeResultSet';
  data: Array<InterfaceType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type InventoryItemFilter = {
  Name?: InputMaybe<StrFilter>;
  assetTag?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  device?: InputMaybe<DeviceFilter>;
  deviceId?: InputMaybe<StrawberryIdFilter>;
  discovered?: InputMaybe<BoolFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  label?: InputMaybe<StrFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  manufacturer?: InputMaybe<ManufacturerFilter>;
  manufacturerId?: InputMaybe<StrawberryIdFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  parent?: InputMaybe<InventoryItemFilter>;
  parentId?: InputMaybe<StrawberryIdFilter>;
  partId?: InputMaybe<StrFilter>;
  serial?: InputMaybe<StrFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type InventoryItemFilterAndFilterEntry = {
  AND: Array<InventoryItemFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type InventoryItemFilterOrFilterEntry = {
  OR: Array<InventoryItemFilter>;
  negate?: Scalars['Boolean'];
};

export type InventoryItemType = AssetFederationBase &
  AssetType & {
    __typename?: 'InventoryItemType';
    Name?: Maybe<Scalars['String']>;
    assetTag?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    children: InventoryItemTypeResultSet;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    device?: Maybe<DeviceType>;
    deviceId?: Maybe<Scalars['ID']>;
    discovered?: Maybe<Scalars['Boolean']>;
    id: Scalars['ID'];
    label?: Maybe<Scalars['String']>;
    lastUpdated?: Maybe<Scalars['DateTime']>;
    manufacturer?: Maybe<ManufacturerType>;
    manufacturerId?: Maybe<Scalars['ID']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    parent?: Maybe<InventoryItemType>;
    parentId?: Maybe<Scalars['ID']>;
    partId?: Maybe<Scalars['String']>;
    serial?: Maybe<Scalars['String']>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
  };

export type InventoryItemTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type InventoryItemTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type InventoryItemTypeResultSet = {
  __typename?: 'InventoryItemTypeResultSet';
  data: Array<InventoryItemType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export enum IpamIpAddressRoleChoices {
  ANYCAST = 'ANYCAST',
  CARP = 'CARP',
  GLBP = 'GLBP',
  HSRP = 'HSRP',
  LOOPBACK = 'LOOPBACK',
  SECONDARY = 'SECONDARY',
  UNKNOWN = 'UNKNOWN',
  VIP = 'VIP',
  VRRP = 'VRRP',
}

export type IpamIpAddressRoleChoicesEnumFilter = {
  exact?: InputMaybe<IpamIpAddressRoleChoices>;
  except_?: InputMaybe<IpamIpAddressRoleChoices>;
  in_?: InputMaybe<Array<IpamIpAddressRoleChoices>>;
};

export enum IpamIpAddressStatusChoices {
  ACTIVE = 'ACTIVE',
  DEPRECATED = 'DEPRECATED',
  DHCP = 'DHCP',
  RESERVED = 'RESERVED',
  SLAAC = 'SLAAC',
  UNKNOWN = 'UNKNOWN',
}

export type IpamIpAddressStatusChoicesEnumFilter = {
  exact?: InputMaybe<IpamIpAddressStatusChoices>;
  except_?: InputMaybe<IpamIpAddressStatusChoices>;
  in_?: InputMaybe<Array<IpamIpAddressStatusChoices>>;
};

export enum IpamIpRangeStatusChoices {
  ACTIVE = 'ACTIVE',
  DEPRECATED = 'DEPRECATED',
  RESERVED = 'RESERVED',
  UNKNOWN = 'UNKNOWN',
}

export type IpamIpRangeStatusChoicesEnumFilter = {
  exact?: InputMaybe<IpamIpRangeStatusChoices>;
  except_?: InputMaybe<IpamIpRangeStatusChoices>;
  in_?: InputMaybe<Array<IpamIpRangeStatusChoices>>;
};

export enum IpamPrefixStatusChoices {
  ACTIVE = 'ACTIVE',
  CONTAINER = 'CONTAINER',
  DEPRECATED = 'DEPRECATED',
  RESERVED = 'RESERVED',
  UNKNOWN = 'UNKNOWN',
}

export type IpamPrefixStatusChoicesEnumFilter = {
  exact?: InputMaybe<IpamPrefixStatusChoices>;
  except_?: InputMaybe<IpamPrefixStatusChoices>;
  in_?: InputMaybe<Array<IpamPrefixStatusChoices>>;
};

export enum IpamServiceProtocolChoices {
  SCTP = 'SCTP',
  TCP = 'TCP',
  UDP = 'UDP',
  UNKNOWN = 'UNKNOWN',
}

export type IpamServiceProtocolChoicesEnumFilter = {
  exact?: InputMaybe<IpamServiceProtocolChoices>;
  except_?: InputMaybe<IpamServiceProtocolChoices>;
  in_?: InputMaybe<Array<IpamServiceProtocolChoices>>;
};

export enum IpamVlanStatusChoices {
  ACTIVE = 'ACTIVE',
  DEPRECATED = 'DEPRECATED',
  RESERVED = 'RESERVED',
  UNKNOWN = 'UNKNOWN',
}

export type IpamVlanStatusChoicesEnumFilter = {
  exact?: InputMaybe<IpamVlanStatusChoices>;
  except_?: InputMaybe<IpamVlanStatusChoices>;
  in_?: InputMaybe<Array<IpamVlanStatusChoices>>;
};

export type JsonInputOutput = TaskInputOutput & {
  __typename?: 'JSONInputOutput';
  description?: Maybe<Scalars['String']>;
  id: Scalars['ID'];
  inputOf?: Maybe<Task>;
  jsonFormlySchema?: Maybe<Scalars['String']>;
  jsonInitialValue?: Maybe<Scalars['String']>;
  jsonSchema?: Maybe<Scalars['String']>;
  jsonValue?: Maybe<Scalars['String']>;
  outputOf?: Maybe<Task>;
  stringifiedValue?: Maybe<Scalars['String']>;
  type?: Maybe<Scalars['String']>;
};

export type JsonInputOutputCreate = {
  description?: InputMaybe<Scalars['String']>;
  inputOf?: InputMaybe<Scalars['ID']>;
  jsonFormlySchema?: InputMaybe<Scalars['String']>;
  jsonInitialValue?: InputMaybe<Scalars['String']>;
  jsonSchema?: InputMaybe<Scalars['String']>;
  jsonValue?: InputMaybe<Scalars['String']>;
  outputOf?: InputMaybe<Scalars['ID']>;
};

export type JsonInputOutputFilter1 = {
  description?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  inputOf?: InputMaybe<TaskFilter1>;
  jsonFormlySchema?: InputMaybe<StrFieldFilter>;
  jsonInitialValue?: InputMaybe<StrFieldFilter>;
  jsonSchema?: InputMaybe<StrFieldFilter>;
  jsonValue?: InputMaybe<StrFieldFilter>;
  outputOf?: InputMaybe<TaskFilter1>;
  type?: InputMaybe<StrFieldFilter>;
};

export type JsonInputOutputFilter1AndFilterEntry = {
  AND: Array<JsonInputOutputFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type JsonInputOutputFilter1OrFilterEntry = {
  OR: JsonInputOutputFilter1;
  negate?: Scalars['Boolean'];
};

export enum JsonInputOutputOrdEnum {
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  JSON_FORMLY_SCHEMA = 'JSON_FORMLY_SCHEMA',
  JSON_INITIAL_VALUE = 'JSON_INITIAL_VALUE',
  JSON_SCHEMA = 'JSON_SCHEMA',
  JSON_VALUE = 'JSON_VALUE',
  TYPE = 'TYPE',
}

export type JsonInputOutputOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: JsonInputOutputOrdEnum;
};

export type JsonInputOutputPaginated = {
  __typename?: 'JSONInputOutputPaginated';
  data: Array<JsonInputOutput>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type JsonInputOutputUpdate = {
  description?: InputMaybe<Scalars['String']>;
  inputOf?: InputMaybe<Scalars['ID']>;
  jsonFormlySchema?: InputMaybe<Scalars['String']>;
  jsonInitialValue?: InputMaybe<Scalars['String']>;
  jsonSchema?: InputMaybe<Scalars['String']>;
  jsonValue?: InputMaybe<Scalars['String']>;
  outputOf?: InputMaybe<Scalars['ID']>;
};

export enum KnownAssetsEnum {
  AGGREGATE = 'AGGREGATE',
  ASN = 'ASN',
  ASSET = 'ASSET',
  CABLE = 'CABLE',
  CIRCUIT = 'CIRCUIT',
  CIRCUIT_TERMINATION = 'CIRCUIT_TERMINATION',
  CIRCUIT_TYPE = 'CIRCUIT_TYPE',
  CLUSTER = 'CLUSTER',
  CLUSTER_GROUP = 'CLUSTER_GROUP',
  CLUSTER_TYPE = 'CLUSTER_TYPE',
  CONSOLE_PORT = 'CONSOLE_PORT',
  CONSOLE_PORT_TEMPLATE = 'CONSOLE_PORT_TEMPLATE',
  CONSOLE_SERVER_PORT = 'CONSOLE_SERVER_PORT',
  CONSOLE_SERVER_PORT_TEMPLATE = 'CONSOLE_SERVER_PORT_TEMPLATE',
  CUSTOM_LINK = 'CUSTOM_LINK',
  DEVICE = 'DEVICE',
  DEVICE_BAY = 'DEVICE_BAY',
  DEVICE_BAY_TEMPLATE = 'DEVICE_BAY_TEMPLATE',
  DEVICE_ROLE = 'DEVICE_ROLE',
  DEVICE_TYPE = 'DEVICE_TYPE',
  EXPORT_TEMPLATE = 'EXPORT_TEMPLATE',
  FHRP_GROUP = 'FHRP_GROUP',
  FRONT_PORT = 'FRONT_PORT',
  FRONT_PORT_TEMPLATE = 'FRONT_PORT_TEMPLATE',
  INTERFACE = 'INTERFACE',
  INTERFACE_TEMPLATE = 'INTERFACE_TEMPLATE',
  INVENTORY_ITEM = 'INVENTORY_ITEM',
  IP_ADDRESS = 'IP_ADDRESS',
  IP_RANGE = 'IP_RANGE',
  LOCATION = 'LOCATION',
  MANUFACTURER = 'MANUFACTURER',
  PLATFORM = 'PLATFORM',
  POWER_FEED = 'POWER_FEED',
  POWER_OUTLET = 'POWER_OUTLET',
  POWER_OUTLET_TEMPLATE = 'POWER_OUTLET_TEMPLATE',
  POWER_PANEL = 'POWER_PANEL',
  POWER_PORT = 'POWER_PORT',
  POWER_PORT_TEMPLATE = 'POWER_PORT_TEMPLATE',
  PREFIX = 'PREFIX',
  PROVIDER = 'PROVIDER',
  PROVIDER_NETWORK = 'PROVIDER_NETWORK',
  RACK = 'RACK',
  RACK_RESERVATION = 'RACK_RESERVATION',
  RACK_ROLE = 'RACK_ROLE',
  REAR_PORT = 'REAR_PORT',
  REAR_PORT_TEMPLATE = 'REAR_PORT_TEMPLATE',
  REGION = 'REGION',
  RIR = 'RIR',
  ROLE = 'ROLE',
  ROUTE_TARGET = 'ROUTE_TARGET',
  SERVICE = 'SERVICE',
  SITE = 'SITE',
  SITE_GROUP = 'SITE_GROUP',
  TAG = 'TAG',
  TENANT = 'TENANT',
  TENANT_GROUP = 'TENANT_GROUP',
  UNKNOWN = 'UNKNOWN',
  VIRTUAL_CHASSIS = 'VIRTUAL_CHASSIS',
  VIRTUAL_MACHINE = 'VIRTUAL_MACHINE',
  VLAN = 'VLAN',
  VLAN_GROUP = 'VLAN_GROUP',
  VM_INTERFACE = 'VM_INTERFACE',
  VRF = 'VRF',
  WIRELESS_LAN = 'WIRELESS_LAN',
  WIRELESS_LAN_GROUP = 'WIRELESS_LAN_GROUP',
  WIRELESS_LINK = 'WIRELESS_LINK',
}

export type KnownAssetsEnumEnumFilter = {
  exact?: InputMaybe<KnownAssetsEnum>;
  except_?: InputMaybe<KnownAssetsEnum>;
  in_?: InputMaybe<Array<KnownAssetsEnum>>;
};

export enum KnownInputOutputTypes {
  BOOL = 'BOOL',
  DATE = 'DATE',
  DATETIME = 'DATETIME',
  DOMAIN = 'DOMAIN',
  EMAIL_ADDRESS = 'EMAIL_ADDRESS',
  EMAIL_MESSAGE = 'EMAIL_MESSAGE',
  FILE = 'FILE',
  FILE_REF = 'FILE_REF',
  HASH = 'HASH',
  IP = 'IP',
  JSON = 'JSON',
  OTHER = 'OTHER',
  STRING = 'STRING',
  URL = 'URL',
}

export enum KnownObservablesEnum {
  DOMAIN_NAME = 'DOMAIN_NAME',
  DOMAIN_TO_DOMAIN_RESOLUTION = 'DOMAIN_TO_DOMAIN_RESOLUTION',
  DOMAIN_TO_IP_ADDRESS_RESOLUTION = 'DOMAIN_TO_IP_ADDRESS_RESOLUTION',
  EMAIL_ADDRESS = 'EMAIL_ADDRESS',
  EMAIL_MESSAGE = 'EMAIL_MESSAGE',
  FILE_REFERENCE = 'FILE_REFERENCE',
  IP_ADDRESS = 'IP_ADDRESS',
  IP_ADDRESS_TO_DOMAIN_RESOLUTION = 'IP_ADDRESS_TO_DOMAIN_RESOLUTION',
  OBSERVABLE = 'OBSERVABLE',
  URL = 'URL',
}

export type KnownObservablesEnumEnumFilter = {
  exact?: InputMaybe<KnownObservablesEnum>;
  except_?: InputMaybe<KnownObservablesEnum>;
  in_?: InputMaybe<Array<KnownObservablesEnum>>;
};

export enum KnownTtPsTypesEnum {
  GROUP_PROCEDURE = 'GROUP_PROCEDURE',
  MALWARE_PROCEDURE = 'MALWARE_PROCEDURE',
  TACTIC = 'TACTIC',
  TECHNIQUE = 'TECHNIQUE',
  TOOL_PROCEDURE = 'TOOL_PROCEDURE',
}

export type KnownTtPsTypesEnumEnumFilter = {
  exact?: InputMaybe<KnownTtPsTypesEnum>;
  except_?: InputMaybe<KnownTtPsTypesEnum>;
  in_?: InputMaybe<Array<KnownTtPsTypesEnum>>;
};

export type Label = {
  __typename?: 'Label';
  backgroundColor?: Maybe<Scalars['String']>;
  cases?: Maybe<CaseNestedList>;
  id: Scalars['ID'];
  name: Scalars['String'];
  tasks?: Maybe<TaskNestedList>;
  textColor?: Maybe<Scalars['String']>;
};

export type LabelCasesArgs = {
  filter?: InputMaybe<Array<CaseFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<CaseOrdEnumOrderingEntry>>;
};

export type LabelTasksArgs = {
  filter?: InputMaybe<Array<TaskFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TaskOrdEnumOrderingEntry>>;
};

export type LabelCreate = {
  backgroundColor?: InputMaybe<Scalars['String']>;
  cases?: InputMaybe<Array<Scalars['ID']>>;
  name: Scalars['String'];
  tasks?: InputMaybe<Array<Scalars['ID']>>;
  textColor?: InputMaybe<Scalars['String']>;
};

export type LabelFilter0 = {
  backgroundColor?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
  textColor?: InputMaybe<StrFieldFilter>;
};

export type LabelFilter0AndFilterEntry = {
  AND: Array<LabelFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type LabelFilter0OrFilterEntry = {
  OR: LabelFilter0;
  negate?: Scalars['Boolean'];
};

export type LabelFilter1 = {
  backgroundColor?: InputMaybe<StrFieldFilter>;
  cases?: InputMaybe<CaseFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
  tasks?: InputMaybe<TaskFilter1>;
  textColor?: InputMaybe<StrFieldFilter>;
};

export type LabelFilter1AndFilterEntry = {
  AND: Array<LabelFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type LabelFilter1OrFilterEntry = {
  OR: LabelFilter1;
  negate?: Scalars['Boolean'];
};

export type LabelNestedList = {
  __typename?: 'LabelNestedList';
  data: Array<Label>;
  totalCount: Scalars['Int'];
};

export enum LabelOrdEnum {
  BACKGROUNDCOLOR = 'BACKGROUNDCOLOR',
  ID = 'ID',
  NAME = 'NAME',
  TEXTCOLOR = 'TEXTCOLOR',
}

export type LabelOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: LabelOrdEnum;
};

export type LabelPaginated = {
  __typename?: 'LabelPaginated';
  data: Array<Label>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type LabelUpdate = {
  backgroundColor?: InputMaybe<Scalars['String']>;
  cases?: InputMaybe<RelationUpdate>;
  name?: InputMaybe<Scalars['String']>;
  tasks?: InputMaybe<RelationUpdate>;
  textColor?: InputMaybe<Scalars['String']>;
};

export type LargeJsIntFieldFilter = {
  exact?: InputMaybe<Scalars['LargeJsInt']>;
  except_?: InputMaybe<Scalars['LargeJsInt']>;
  gt?: InputMaybe<Scalars['LargeJsInt']>;
  gte?: InputMaybe<Scalars['LargeJsInt']>;
  in_?: InputMaybe<Array<Scalars['LargeJsInt']>>;
  isnull?: InputMaybe<Scalars['Boolean']>;
  lt?: InputMaybe<Scalars['LargeJsInt']>;
  lte?: InputMaybe<Scalars['LargeJsInt']>;
};

export type LocationFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  deviceCount?: InputMaybe<IntFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  parent?: InputMaybe<LocationFilter>;
  parentId?: InputMaybe<StrawberryIdFilter>;
  rackCount?: InputMaybe<IntFilter>;
  site?: InputMaybe<SiteFilter>;
  siteId?: InputMaybe<StrawberryIdFilter>;
  slug?: InputMaybe<StrFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type LocationFilterAndFilterEntry = {
  AND: Array<LocationFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type LocationFilterOrFilterEntry = {
  OR: Array<LocationFilter>;
  negate?: Scalars['Boolean'];
};

export type LocationType = AssetFederationBase &
  AssetType & {
    __typename?: 'LocationType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    children: LocationTypeResultSet;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    deviceCount?: Maybe<Scalars['Int']>;
    devices: DeviceTypeResultSet;
    id: Scalars['ID'];
    lastUpdated?: Maybe<Scalars['DateTime']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    parent?: Maybe<LocationType>;
    parentId?: Maybe<Scalars['ID']>;
    powerpanelSet: PowerPanelTypeResultSet;
    rackCount?: Maybe<Scalars['Int']>;
    racks: RackTypeResultSet;
    site?: Maybe<SiteType>;
    siteId?: Maybe<Scalars['ID']>;
    slug?: Maybe<Scalars['String']>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
    vlanGroups: VlanGroupTypeResultSet;
  };

export type LocationTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type LocationTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type LocationTypeResultSet = {
  __typename?: 'LocationTypeResultSet';
  data: Array<LocationType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type Malware = {
  __typename?: 'Malware';
  aliases?: Maybe<AliasNestedList>;
  created?: Maybe<Scalars['DateTime']>;
  description?: Maybe<Scalars['String']>;
  externalReferences?: Maybe<ExternalReferenceNestedList>;
  groups?: Maybe<TtpGroupNestedList>;
  id: Scalars['ID'];
  modified?: Maybe<Scalars['DateTime']>;
  name: Scalars['String'];
  platforms?: Maybe<TtpPlatformNestedList>;
  techniquesUsed?: Maybe<MalwareProcedureNestedList>;
};

export type MalwareAliasesArgs = {
  filter?: InputMaybe<Array<AliasFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<AliasOrdEnumOrderingEntry>>;
};

export type MalwareExternalReferencesArgs = {
  filter?: InputMaybe<Array<ExternalReferenceFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ExternalReferenceOrdEnumOrderingEntry>>;
};

export type MalwareGroupsArgs = {
  filter?: InputMaybe<Array<TtpGroupFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TtpGroupOrdEnumOrderingEntry>>;
};

export type MalwarePlatformsArgs = {
  filter?: InputMaybe<Array<TtpPlatformFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TtpPlatformOrdEnumOrderingEntry>>;
};

export type MalwareTechniquesUsedArgs = {
  filter?: InputMaybe<Array<MalwareProcedureFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<MalwareProcedureOrdEnumOrderingEntry>>;
};

export type MalwareCreate = {
  aliases?: InputMaybe<Array<Scalars['ID']>>;
  description?: InputMaybe<Scalars['String']>;
  externalReferences?: InputMaybe<Array<Scalars['ID']>>;
  groups?: InputMaybe<Array<Scalars['ID']>>;
  name: Scalars['String'];
  platforms?: InputMaybe<Array<Scalars['ID']>>;
  techniquesUsed?: InputMaybe<Array<Scalars['ID']>>;
};

export type MalwareFilter0 = {
  created?: InputMaybe<DateTimeFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  modified?: InputMaybe<DateTimeFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
};

export type MalwareFilter0AndFilterEntry = {
  AND: Array<MalwareFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type MalwareFilter0OrFilterEntry = {
  OR: MalwareFilter0;
  negate?: Scalars['Boolean'];
};

export type MalwareFilter1 = {
  aliases?: InputMaybe<AliasFilter1>;
  created?: InputMaybe<DateTimeFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  externalReferences?: InputMaybe<ExternalReferenceFilter1>;
  groups?: InputMaybe<TtpGroupFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  modified?: InputMaybe<DateTimeFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
  platforms?: InputMaybe<TtpPlatformFilter1>;
  techniquesUsed?: InputMaybe<MalwareProcedureFilter1>;
};

export type MalwareFilter1AndFilterEntry = {
  AND: Array<MalwareFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type MalwareFilter1OrFilterEntry = {
  OR: MalwareFilter1;
  negate?: Scalars['Boolean'];
};

export type MalwareNestedList = {
  __typename?: 'MalwareNestedList';
  data: Array<Malware>;
  totalCount: Scalars['Int'];
};

export enum MalwareOrdEnum {
  CREATED = 'CREATED',
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  MODIFIED = 'MODIFIED',
  NAME = 'NAME',
}

export type MalwareOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: MalwareOrdEnum;
};

export type MalwarePaginated = {
  __typename?: 'MalwarePaginated';
  data: Array<Malware>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type MalwareProcedure = Ittp &
  TtpFederationBase & {
    __typename?: 'MalwareProcedure';
    cases: CaseFederationResult;
    created?: Maybe<Scalars['DateTime']>;
    description?: Maybe<Scalars['String']>;
    externalReferences?: Maybe<ExternalReferenceNestedList>;
    id: Scalars['ID'];
    malware: Malware;
    malwareProcedureName: Scalars['String'];
    malwareTechnique: Technique;
    modified?: Maybe<Scalars['DateTime']>;
    tasks: TaskFederationResult;
    ttpType?: Maybe<Scalars['String']>;
    ttpTypeEnum?: Maybe<KnownTtPsTypesEnum>;
    uniqueIdentifier: Scalars['String'];
  };

export type MalwareProcedureCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type MalwareProcedureExternalReferencesArgs = {
  filter?: InputMaybe<Array<ExternalReferenceFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ExternalReferenceOrdEnumOrderingEntry>>;
};

export type MalwareProcedureTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type MalwareProcedureCreate = {
  description?: InputMaybe<Scalars['String']>;
  externalReferences?: InputMaybe<Array<Scalars['ID']>>;
  malware: Scalars['ID'];
  malwareTechnique: Scalars['ID'];
};

export type MalwareProcedureFilter0 = {
  created?: InputMaybe<DateTimeFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  malwareProcedureName?: InputMaybe<StrFieldFilter>;
  modified?: InputMaybe<DateTimeFieldFilter>;
  ttpType?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type MalwareProcedureFilter0AndFilterEntry = {
  AND: Array<MalwareProcedureFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type MalwareProcedureFilter0OrFilterEntry = {
  OR: MalwareProcedureFilter0;
  negate?: Scalars['Boolean'];
};

export type MalwareProcedureFilter1 = {
  created?: InputMaybe<DateTimeFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  externalReferences?: InputMaybe<ExternalReferenceFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  malware?: InputMaybe<MalwareFilter1>;
  malwareProcedureName?: InputMaybe<StrFieldFilter>;
  malwareTechnique?: InputMaybe<TechniqueFilter1>;
  modified?: InputMaybe<DateTimeFieldFilter>;
  ttpType?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type MalwareProcedureFilter1AndFilterEntry = {
  AND: Array<MalwareProcedureFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type MalwareProcedureFilter1OrFilterEntry = {
  OR: MalwareProcedureFilter1;
  negate?: Scalars['Boolean'];
};

export type MalwareProcedureNestedList = {
  __typename?: 'MalwareProcedureNestedList';
  data: Array<MalwareProcedure>;
  totalCount: Scalars['Int'];
};

export enum MalwareProcedureOrdEnum {
  CREATED = 'CREATED',
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  MALWARE_PROCEDURE_NAME = 'MALWARE_PROCEDURE_NAME',
  MODIFIED = 'MODIFIED',
  TTP_TYPE = 'TTP_TYPE',
  UNIQUE_IDENTIFIER = 'UNIQUE_IDENTIFIER',
}

export type MalwareProcedureOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: MalwareProcedureOrdEnum;
};

export type MalwareProcedurePaginated = {
  __typename?: 'MalwareProcedurePaginated';
  data: Array<MalwareProcedure>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type MalwareProcedureUpdate = {
  description?: InputMaybe<Scalars['String']>;
  externalReferences?: InputMaybe<RelationUpdate>;
  malware?: InputMaybe<Scalars['ID']>;
  malwareTechnique?: InputMaybe<Scalars['ID']>;
};

export type MalwareUpdate = {
  aliases?: InputMaybe<RelationUpdate>;
  description?: InputMaybe<Scalars['String']>;
  externalReferences?: InputMaybe<RelationUpdate>;
  groups?: InputMaybe<RelationUpdate>;
  name?: InputMaybe<Scalars['String']>;
  platforms?: InputMaybe<RelationUpdate>;
  techniquesUsed?: InputMaybe<RelationUpdate>;
};

export type ManufacturerFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  devicetypeCount?: InputMaybe<IntFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  inventoryitemCount?: InputMaybe<IntFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  platformCount?: InputMaybe<IntFilter>;
  slug?: InputMaybe<StrFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type ManufacturerFilterAndFilterEntry = {
  AND: Array<ManufacturerFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type ManufacturerFilterOrFilterEntry = {
  OR: Array<ManufacturerFilter>;
  negate?: Scalars['Boolean'];
};

export type ManufacturerType = AssetFederationBase &
  AssetType & {
    __typename?: 'ManufacturerType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    deviceTypes: DeviceTypeTypeResultSet;
    devicetypeCount?: Maybe<Scalars['Int']>;
    id: Scalars['ID'];
    inventoryItems: InventoryItemTypeResultSet;
    inventoryitemCount?: Maybe<Scalars['Int']>;
    lastUpdated?: Maybe<Scalars['DateTime']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    platformCount?: Maybe<Scalars['Int']>;
    platforms: PlatformTypeResultSet;
    slug?: Maybe<Scalars['String']>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
  };

export type ManufacturerTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type ManufacturerTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type ManufacturerTypeResultSet = {
  __typename?: 'ManufacturerTypeResultSet';
  data: Array<ManufacturerType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type MatchResult = {
  __typename?: 'MatchResult';
  x_Cve?: Maybe<CveVertex>;
  x_RootAsset?: Maybe<AssetVertex>;
  x_Statement?: Maybe<StatementVertex>;
};

export type Metadata = {
  __typename?: 'Metadata';
  assetType: KnownAssetsEnum;
  instances: Scalars['Int'];
};

export type MetadataFilter = {
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  instances?: InputMaybe<IntFilter>;
};

export type MetadataFilterAndFilterEntry = {
  AND: Array<MetadataFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type MetadataFilterOrFilterEntry = {
  OR: Array<MetadataFilter>;
  negate?: Scalars['Boolean'];
};

export type MetadataResultSet = {
  __typename?: 'MetadataResultSet';
  data: Array<Metadata>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type Mitigation = {
  __typename?: 'Mitigation';
  created?: Maybe<Scalars['DateTime']>;
  description?: Maybe<Scalars['String']>;
  externalReferences?: Maybe<ExternalReferenceNestedList>;
  id: Scalars['ID'];
  modified?: Maybe<Scalars['DateTime']>;
  name: Scalars['String'];
  techniques?: Maybe<TechniqueMitigationRelationshipNestedList>;
};

export type MitigationExternalReferencesArgs = {
  filter?: InputMaybe<Array<ExternalReferenceFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ExternalReferenceOrdEnumOrderingEntry>>;
};

export type MitigationTechniquesArgs = {
  filter?: InputMaybe<Array<TechniqueMitigationRelationshipFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TechniqueMitigationRelationshipOrdEnumOrderingEntry>>;
};

export type MitigationCreate = {
  description?: InputMaybe<Scalars['String']>;
  externalReferences?: InputMaybe<Array<Scalars['ID']>>;
  name: Scalars['String'];
  techniques?: InputMaybe<Array<Scalars['ID']>>;
};

export type MitigationFilter0 = {
  created?: InputMaybe<DateTimeFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  modified?: InputMaybe<DateTimeFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
};

export type MitigationFilter0AndFilterEntry = {
  AND: Array<MitigationFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type MitigationFilter0OrFilterEntry = {
  OR: MitigationFilter0;
  negate?: Scalars['Boolean'];
};

export type MitigationFilter1 = {
  created?: InputMaybe<DateTimeFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  externalReferences?: InputMaybe<ExternalReferenceFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  modified?: InputMaybe<DateTimeFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
  techniques?: InputMaybe<TechniqueMitigationRelationshipFilter1>;
};

export type MitigationFilter1AndFilterEntry = {
  AND: Array<MitigationFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type MitigationFilter1OrFilterEntry = {
  OR: MitigationFilter1;
  negate?: Scalars['Boolean'];
};

export type MitigationNestedList = {
  __typename?: 'MitigationNestedList';
  data: Array<Mitigation>;
  totalCount: Scalars['Int'];
};

export enum MitigationOrdEnum {
  CREATED = 'CREATED',
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  MODIFIED = 'MODIFIED',
  NAME = 'NAME',
}

export type MitigationOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: MitigationOrdEnum;
};

export type MitigationPaginated = {
  __typename?: 'MitigationPaginated';
  data: Array<Mitigation>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type MitigationUpdate = {
  description?: InputMaybe<Scalars['String']>;
  externalReferences?: InputMaybe<RelationUpdate>;
  name?: InputMaybe<Scalars['String']>;
  techniques?: InputMaybe<RelationUpdate>;
};

export type MutateResult = {
  __typename?: 'MutateResult';
  id?: Maybe<Scalars['ID']>;
};

export type Mutation = {
  __typename?: 'Mutation';
  addAsset?: Maybe<AssetVertex>;
  addAssetToTask: FederatedMutationResult;
  addAssetToTaskBulk: FederatedMutationResult;
  addAssets?: Maybe<Scalars['Boolean']>;
  addCve?: Maybe<CveVertex>;
  addCves?: Maybe<Scalars['Boolean']>;
  addObservableToTask: FederatedMutationResult;
  addObservableToTaskBulk: FederatedMutationResult;
  addRelatedUsersToTask: FederatedMutationResult;
  addTtpToTask: FederatedMutationResult;
  addTtpToTaskBulk: FederatedMutationResult;
  /**
   * Create a single Alias instance from the input data.
   *
   * Arguments:
   * - **data** (_AliasCreate_): Data to be used when creating the new instance.
   */
  createAlias: CreateResult;
  /**
   * Create multiple Alias instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[AliasCreate]_): List of data to be used when creating new instances.
   */
  createAliasBulk: Array<CreateResult>;
  /**
   * Create a single BaseHashableObservable instance from the input data.
   *
   * Arguments:
   * - **data** (_BaseHashableObservableCreate_): Data to be used when creating the new instance.
   */
  createBaseHashableObservable: CreateResult;
  /**
   * Create multiple BaseHashableObservable instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[BaseHashableObservableCreate]_): List of data to be used when creating new instances.
   */
  createBaseHashableObservableBulk: Array<CreateResult>;
  /**
   * Create a single BaseHost instance from the input data.
   *
   * Arguments:
   * - **data** (_BaseHostCreate_): Data to be used when creating the new instance.
   */
  createBaseHost: CreateResult;
  /**
   * Create multiple BaseHost instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[BaseHostCreate]_): List of data to be used when creating new instances.
   */
  createBaseHostBulk: Array<CreateResult>;
  /**
   * Create a single BaseObservable instance from the input data.
   *
   * Arguments:
   * - **data** (_BaseObservableCreate_): Data to be used when creating the new instance.
   */
  createBaseObservable: CreateResult;
  /**
   * Create multiple BaseObservable instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[BaseObservableCreate]_): List of data to be used when creating new instances.
   */
  createBaseObservableBulk: Array<CreateResult>;
  /**
   * Create a single BaseTaskInputOutput instance from the input data.
   *
   * Arguments:
   * - **data** (_BaseTaskInputOutputCreate_): Data to be used when creating the new instance.
   */
  createBaseTaskInputOutput: CreateResult;
  /**
   * Create multiple BaseTaskInputOutput instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[BaseTaskInputOutputCreate]_): List of data to be used when creating new instances.
   */
  createBaseTaskInputOutputBulk: Array<CreateResult>;
  /**
   * Create a single BoolInputOutput instance from the input data.
   *
   * Arguments:
   * - **data** (_BoolInputOutputCreate_): Data to be used when creating the new instance.
   */
  createBoolInputOutput: CreateResult;
  /**
   * Create multiple BoolInputOutput instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[BoolInputOutputCreate]_): List of data to be used when creating new instances.
   */
  createBoolInputOutputBulk: Array<CreateResult>;
  createCase: MutationResult;
  createCaseBulk: Array<CreateResult>;
  /**
   * Create a single CaseDBRole instance from the input data.
   *
   * Arguments:
   * - **data** (_CaseDBRoleCreate_): Data to be used when creating the new instance.
   */
  createCaseDbRole: CreateResult;
  /**
   * Create multiple CaseDBRole instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[CaseDBRoleCreate]_): List of data to be used when creating new instances.
   */
  createCaseDbRoleBulk: Array<CreateResult>;
  /**
   * Create a single CaseDBUser instance from the input data.
   *
   * Arguments:
   * - **data** (_CaseDBUserCreate_): Data to be used when creating the new instance.
   */
  createCaseDbUser: CreateResult;
  /**
   * Create multiple CaseDBUser instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[CaseDBUserCreate]_): List of data to be used when creating new instances.
   */
  createCaseDbUserBulk: Array<CreateResult>;
  /**
   * Create a single CaseFileItemBase instance from the input data.
   *
   * Arguments:
   * - **data** (_CaseFileItemBaseCreate_): Data to be used when creating the new instance.
   */
  createCaseFileItemBase: CreateResult;
  /**
   * Create multiple CaseFileItemBase instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[CaseFileItemBaseCreate]_): List of data to be used when creating new instances.
   */
  createCaseFileItemBaseBulk: Array<CreateResult>;
  /**
   * Create a single CaseManagementExternalReference instance from the input data.
   *
   * Arguments:
   * - **data** (_CaseManagementExternalReferenceCreate_): Data to be used when creating the new instance.
   */
  createCaseManagementExternalReference: CreateResult;
  /**
   * Create multiple CaseManagementExternalReference instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[CaseManagementExternalReferenceCreate]_): List of data to be used when creating new instances.
   */
  createCaseManagementExternalReferenceBulk: Array<CreateResult>;
  /**
   * Create a single CaseRelationship instance from the input data.
   *
   * Arguments:
   * - **data** (_CaseRelationshipCreate_): Data to be used when creating the new instance.
   */
  createCaseRelationship: CreateResult;
  /**
   * Create multiple CaseRelationship instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[CaseRelationshipCreate]_): List of data to be used when creating new instances.
   */
  createCaseRelationshipBulk: Array<CreateResult>;
  /**
   * Create a single Comment instance from the input data.
   *
   * Arguments:
   * - **data** (_CommentCreate_): Data to be used when creating the new instance.
   */
  createComment: CreateResult;
  /**
   * Create multiple Comment instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[CommentCreate]_): List of data to be used when creating new instances.
   */
  createCommentBulk: Array<CreateResult>;
  /**
   * Create a single CTIEntry instance from the input data.
   *
   * Arguments:
   * - **data** (_CTIEntryCreate_): Data to be used when creating the new instance.
   */
  createCtiEntry: CreateResult;
  /**
   * Create multiple CTIEntry instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[CTIEntryCreate]_): List of data to be used when creating new instances.
   */
  createCtiEntryBulk: Array<CreateResult>;
  /**
   * Create a single DataPlatformServiceIPFix instance from the input data.
   *
   * Arguments:
   * - **data** (_DataPlatformServiceIPFixCreate_): Data to be used when creating the new instance.
   */
  createDataPlatformServiceIpFix: CreateResult;
  /**
   * Create multiple DataPlatformServiceIPFix instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[DataPlatformServiceIPFixCreate]_): List of data to be used when creating new instances.
   */
  createDataPlatformServiceIpFixBulk: Array<CreateResult>;
  /**
   * Create a single DataSource instance from the input data.
   *
   * Arguments:
   * - **data** (_DataSourceCreate_): Data to be used when creating the new instance.
   */
  createDataSource: CreateResult;
  /**
   * Create multiple DataSource instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[DataSourceCreate]_): List of data to be used when creating new instances.
   */
  createDataSourceBulk: Array<CreateResult>;
  /**
   * Create a single DateInputOutput instance from the input data.
   *
   * Arguments:
   * - **data** (_DateInputOutputCreate_): Data to be used when creating the new instance.
   */
  createDateInputOutput: CreateResult;
  /**
   * Create multiple DateInputOutput instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[DateInputOutputCreate]_): List of data to be used when creating new instances.
   */
  createDateInputOutputBulk: Array<CreateResult>;
  /**
   * Create a single DateTimeInputOutput instance from the input data.
   *
   * Arguments:
   * - **data** (_DateTimeInputOutputCreate_): Data to be used when creating the new instance.
   */
  createDateTimeInputOutput: CreateResult;
  /**
   * Create multiple DateTimeInputOutput instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[DateTimeInputOutputCreate]_): List of data to be used when creating new instances.
   */
  createDateTimeInputOutputBulk: Array<CreateResult>;
  /**
   * Create a single Directory instance from the input data.
   *
   * Arguments:
   * - **data** (_DirectoryCreate_): Data to be used when creating the new instance.
   */
  createDirectory: CreateResult;
  /**
   * Create multiple Directory instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[DirectoryCreate]_): List of data to be used when creating new instances.
   */
  createDirectoryBulk: Array<CreateResult>;
  /**
   * Create a single DomainInputOutput instance from the input data.
   *
   * Arguments:
   * - **data** (_DomainInputOutputCreate_): Data to be used when creating the new instance.
   */
  createDomainInputOutput: CreateResult;
  /**
   * Create multiple DomainInputOutput instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[DomainInputOutputCreate]_): List of data to be used when creating new instances.
   */
  createDomainInputOutputBulk: Array<CreateResult>;
  /**
   * Create a single DomainName instance from the input data.
   *
   * Arguments:
   * - **data** (_DomainNameCreate_): Data to be used when creating the new instance.
   */
  createDomainName: CreateResult;
  /**
   * Create multiple DomainName instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[DomainNameCreate]_): List of data to be used when creating new instances.
   */
  createDomainNameBulk: Array<CreateResult>;
  /**
   * Create a single DomainToDomainResolution instance from the input data.
   *
   * Arguments:
   * - **data** (_DomainToDomainResolutionCreate_): Data to be used when creating the new instance.
   */
  createDomainToDomainResolution: CreateResult;
  /**
   * Create multiple DomainToDomainResolution instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[DomainToDomainResolutionCreate]_): List of data to be used when creating new instances.
   */
  createDomainToDomainResolutionBulk: Array<CreateResult>;
  /**
   * Create a single DomainToIPAddressResolution instance from the input data.
   *
   * Arguments:
   * - **data** (_DomainToIPAddressResolutionCreate_): Data to be used when creating the new instance.
   */
  createDomainToIpAddressResolution: CreateResult;
  /**
   * Create multiple DomainToIPAddressResolution instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[DomainToIPAddressResolutionCreate]_): List of data to be used when creating new instances.
   */
  createDomainToIpAddressResolutionBulk: Array<CreateResult>;
  /**
   * Create a single EmailAddress instance from the input data.
   *
   * Arguments:
   * - **data** (_EmailAddressCreate_): Data to be used when creating the new instance.
   */
  createEmailAddress: CreateResult;
  /**
   * Create multiple EmailAddress instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[EmailAddressCreate]_): List of data to be used when creating new instances.
   */
  createEmailAddressBulk: Array<CreateResult>;
  /**
   * Create a single EmailAddressInputOutput instance from the input data.
   *
   * Arguments:
   * - **data** (_EmailAddressInputOutputCreate_): Data to be used when creating the new instance.
   */
  createEmailAddressInputOutput: CreateResult;
  /**
   * Create multiple EmailAddressInputOutput instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[EmailAddressInputOutputCreate]_): List of data to be used when creating new instances.
   */
  createEmailAddressInputOutputBulk: Array<CreateResult>;
  /**
   * Create a single EmailHeader instance from the input data.
   *
   * Arguments:
   * - **data** (_EmailHeaderCreate_): Data to be used when creating the new instance.
   */
  createEmailHeader: CreateResult;
  /**
   * Create multiple EmailHeader instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[EmailHeaderCreate]_): List of data to be used when creating new instances.
   */
  createEmailHeaderBulk: Array<CreateResult>;
  /**
   * Create a single EmailMessage instance from the input data.
   *
   * Arguments:
   * - **data** (_EmailMessageCreate_): Data to be used when creating the new instance.
   */
  createEmailMessage: CreateResult;
  /**
   * Create multiple EmailMessage instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[EmailMessageCreate]_): List of data to be used when creating new instances.
   */
  createEmailMessageBulk: Array<CreateResult>;
  /**
   * Create a single EmailMessageEmailAddressRelationship instance from the input data.
   *
   * Arguments:
   * - **data** (_EmailMessageEmailAddressRelationshipCreate_): Data to be used when creating the new instance.
   */
  createEmailMessageEmailAddressRelationship: CreateResult;
  /**
   * Create multiple EmailMessageEmailAddressRelationship instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[EmailMessageEmailAddressRelationshipCreate]_): List of data to be used when creating new instances.
   */
  createEmailMessageEmailAddressRelationshipBulk: Array<CreateResult>;
  /**
   * Create a single EmailMessageInputOutput instance from the input data.
   *
   * Arguments:
   * - **data** (_EmailMessageInputOutputCreate_): Data to be used when creating the new instance.
   */
  createEmailMessageInputOutput: CreateResult;
  /**
   * Create multiple EmailMessageInputOutput instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[EmailMessageInputOutputCreate]_): List of data to be used when creating new instances.
   */
  createEmailMessageInputOutputBulk: Array<CreateResult>;
  /**
   * Create a single EmailMessagePartsRelationship instance from the input data.
   *
   * Arguments:
   * - **data** (_EmailMessagePartsRelationshipCreate_): Data to be used when creating the new instance.
   */
  createEmailMessagePartsRelationship: CreateResult;
  /**
   * Create multiple EmailMessagePartsRelationship instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[EmailMessagePartsRelationshipCreate]_): List of data to be used when creating new instances.
   */
  createEmailMessagePartsRelationshipBulk: Array<CreateResult>;
  /**
   * Create a single EntryType instance from the input data.
   *
   * Arguments:
   * - **data** (_EntryTypeCreate_): Data to be used when creating the new instance.
   */
  createEntryType: CreateResult;
  /**
   * Create multiple EntryType instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[EntryTypeCreate]_): List of data to be used when creating new instances.
   */
  createEntryTypeBulk: Array<CreateResult>;
  /**
   * Create a single ExternalReference instance from the input data.
   *
   * Arguments:
   * - **data** (_ExternalReferenceCreate_): Data to be used when creating the new instance.
   */
  createExternalReference: CreateResult;
  /**
   * Create multiple ExternalReference instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[ExternalReferenceCreate]_): List of data to be used when creating new instances.
   */
  createExternalReferenceBulk: Array<CreateResult>;
  createFile?: Maybe<MutationResult>;
  createFileBulk?: Maybe<Array<MutationResult>>;
  createFileFromCommentInCase?: Maybe<MutationResultField>;
  createFileFromCommentInTask?: Maybe<MutationResultField>;
  /**
   * Create a single FileInputOutput instance from the input data.
   *
   * Arguments:
   * - **data** (_FileInputOutputCreate_): Data to be used when creating the new instance.
   */
  createFileInputOutput: CreateResult;
  /**
   * Create multiple FileInputOutput instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[FileInputOutputCreate]_): List of data to be used when creating new instances.
   */
  createFileInputOutputBulk: Array<CreateResult>;
  createFileRef?: Maybe<MutationResult>;
  /**
   * Create a single FileRefInputOutput instance from the input data.
   *
   * Arguments:
   * - **data** (_FileRefInputOutputCreate_): Data to be used when creating the new instance.
   */
  createFileRefInputOutput: CreateResult;
  /**
   * Create multiple FileRefInputOutput instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[FileRefInputOutputCreate]_): List of data to be used when creating new instances.
   */
  createFileRefInputOutputBulk: Array<CreateResult>;
  /**
   * Create a single FileReference instance from the input data.
   *
   * Arguments:
   * - **data** (_FileReferenceCreate_): Data to be used when creating the new instance.
   */
  createFileReference: CreateResult;
  /**
   * Create multiple FileReference instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[FileReferenceCreate]_): List of data to be used when creating new instances.
   */
  createFileReferenceBulk: Array<CreateResult>;
  /**
   * Create a single FlowEvent instance from the input data.
   *
   * Arguments:
   * - **data** (_FlowEventCreate_): Data to be used when creating the new instance.
   */
  createFlowEvent: CreateResult;
  /**
   * Create multiple FlowEvent instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[FlowEventCreate]_): List of data to be used when creating new instances.
   */
  createFlowEventBulk: Array<CreateResult>;
  /**
   * Create a single FlowEventData instance from the input data.
   *
   * Arguments:
   * - **data** (_FlowEventDataCreate_): Data to be used when creating the new instance.
   */
  createFlowEventData: CreateResult;
  /**
   * Create multiple FlowEventData instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[FlowEventDataCreate]_): List of data to be used when creating new instances.
   */
  createFlowEventDataBulk: Array<CreateResult>;
  /**
   * Create a single GroupProcedure instance from the input data.
   *
   * Arguments:
   * - **data** (_GroupProcedureCreate_): Data to be used when creating the new instance.
   */
  createGroupProcedure: CreateResult;
  /**
   * Create multiple GroupProcedure instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[GroupProcedureCreate]_): List of data to be used when creating new instances.
   */
  createGroupProcedureBulk: Array<CreateResult>;
  /**
   * Create a single Hash instance from the input data.
   *
   * Arguments:
   * - **data** (_HashCreate_): Data to be used when creating the new instance.
   */
  createHash: CreateResult;
  /**
   * Create multiple Hash instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[HashCreate]_): List of data to be used when creating new instances.
   */
  createHashBulk: Array<CreateResult>;
  /**
   * Create a single HashInputOutput instance from the input data.
   *
   * Arguments:
   * - **data** (_HashInputOutputCreate_): Data to be used when creating the new instance.
   */
  createHashInputOutput: CreateResult;
  /**
   * Create multiple HashInputOutput instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[HashInputOutputCreate]_): List of data to be used when creating new instances.
   */
  createHashInputOutputBulk: Array<CreateResult>;
  /**
   * Create a single IPAddress instance from the input data.
   *
   * Arguments:
   * - **data** (_IPAddressCreate_): Data to be used when creating the new instance.
   */
  createIpAddress: CreateResult;
  /**
   * Create multiple IPAddress instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[IPAddressCreate]_): List of data to be used when creating new instances.
   */
  createIpAddressBulk: Array<CreateResult>;
  /**
   * Create a single IPAddressToDomainResolution instance from the input data.
   *
   * Arguments:
   * - **data** (_IPAddressToDomainResolutionCreate_): Data to be used when creating the new instance.
   */
  createIpAddressToDomainResolution: CreateResult;
  /**
   * Create multiple IPAddressToDomainResolution instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[IPAddressToDomainResolutionCreate]_): List of data to be used when creating new instances.
   */
  createIpAddressToDomainResolutionBulk: Array<CreateResult>;
  /**
   * Create a single IPInputOutput instance from the input data.
   *
   * Arguments:
   * - **data** (_IPInputOutputCreate_): Data to be used when creating the new instance.
   */
  createIpInputOutput: CreateResult;
  /**
   * Create multiple IPInputOutput instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[IPInputOutputCreate]_): List of data to be used when creating new instances.
   */
  createIpInputOutputBulk: Array<CreateResult>;
  /**
   * Create a single JSONInputOutput instance from the input data.
   *
   * Arguments:
   * - **data** (_JSONInputOutputCreate_): Data to be used when creating the new instance.
   */
  createJsonInputOutput: CreateResult;
  /**
   * Create multiple JSONInputOutput instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[JSONInputOutputCreate]_): List of data to be used when creating new instances.
   */
  createJsonInputOutputBulk: Array<CreateResult>;
  /**
   * Create a single Label instance from the input data.
   *
   * Arguments:
   * - **data** (_LabelCreate_): Data to be used when creating the new instance.
   */
  createLabel: CreateResult;
  /**
   * Create multiple Label instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[LabelCreate]_): List of data to be used when creating new instances.
   */
  createLabelBulk: Array<CreateResult>;
  /**
   * Create a single Malware instance from the input data.
   *
   * Arguments:
   * - **data** (_MalwareCreate_): Data to be used when creating the new instance.
   */
  createMalware: CreateResult;
  /**
   * Create multiple Malware instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[MalwareCreate]_): List of data to be used when creating new instances.
   */
  createMalwareBulk: Array<CreateResult>;
  /**
   * Create a single MalwareProcedure instance from the input data.
   *
   * Arguments:
   * - **data** (_MalwareProcedureCreate_): Data to be used when creating the new instance.
   */
  createMalwareProcedure: CreateResult;
  /**
   * Create multiple MalwareProcedure instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[MalwareProcedureCreate]_): List of data to be used when creating new instances.
   */
  createMalwareProcedureBulk: Array<CreateResult>;
  /**
   * Create a single Mitigation instance from the input data.
   *
   * Arguments:
   * - **data** (_MitigationCreate_): Data to be used when creating the new instance.
   */
  createMitigation: CreateResult;
  /**
   * Create multiple Mitigation instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[MitigationCreate]_): List of data to be used when creating new instances.
   */
  createMitigationBulk: Array<CreateResult>;
  /**
   * Create a single ObservableLink instance from the input data.
   *
   * Arguments:
   * - **data** (_ObservableLinkCreate_): Data to be used when creating the new instance.
   */
  createObservableLink: CreateResult;
  /**
   * Create multiple ObservableLink instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[ObservableLinkCreate]_): List of data to be used when creating new instances.
   */
  createObservableLinkBulk: Array<CreateResult>;
  /**
   * Create a single SourceSpecifier instance from the input data.
   *
   * Arguments:
   * - **data** (_SourceSpecifierCreate_): Data to be used when creating the new instance.
   */
  createSourceSpecifier: CreateResult;
  /**
   * Create multiple SourceSpecifier instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[SourceSpecifierCreate]_): List of data to be used when creating new instances.
   */
  createSourceSpecifierBulk: Array<CreateResult>;
  /**
   * Create a single Stage instance from the input data.
   *
   * Arguments:
   * - **data** (_StageCreate_): Data to be used when creating the new instance.
   */
  createStage: CreateResult;
  /**
   * Create multiple Stage instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[StageCreate]_): List of data to be used when creating new instances.
   */
  createStageBulk: Array<CreateResult>;
  /**
   * Create a single StorageEvent instance from the input data.
   *
   * Arguments:
   * - **data** (_StorageEventCreate_): Data to be used when creating the new instance.
   */
  createStorageEvent: CreateResult;
  /**
   * Create multiple StorageEvent instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[StorageEventCreate]_): List of data to be used when creating new instances.
   */
  createStorageEventBulk: Array<CreateResult>;
  /**
   * Create a single StringInputOutput instance from the input data.
   *
   * Arguments:
   * - **data** (_StringInputOutputCreate_): Data to be used when creating the new instance.
   */
  createStringInputOutput: CreateResult;
  /**
   * Create multiple StringInputOutput instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[StringInputOutputCreate]_): List of data to be used when creating new instances.
   */
  createStringInputOutputBulk: Array<CreateResult>;
  createSubtechnique?: Maybe<MutateResult>;
  createSubtechniqueBulk?: Maybe<Array<MutateResult>>;
  /**
   * Create a single Tactic instance from the input data.
   *
   * Arguments:
   * - **data** (_TacticCreate_): Data to be used when creating the new instance.
   */
  createTactic: CreateResult;
  /**
   * Create multiple Tactic instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[TacticCreate]_): List of data to be used when creating new instances.
   */
  createTacticBulk: Array<CreateResult>;
  createTask: MutationResult;
  createTaskBulk?: Maybe<Array<MutationResult>>;
  createTaskFromTemplate: MutationResult;
  createTaskInput?: Maybe<MutationResult>;
  createTaskOutput?: Maybe<MutationResult>;
  createTaskParentless: MutationResult;
  createTaskParentlessBulk?: Maybe<Array<MutationResult>>;
  /**
   * Create a single TaskReference instance from the input data.
   *
   * Arguments:
   * - **data** (_TaskReferenceCreate_): Data to be used when creating the new instance.
   */
  createTaskReference: CreateResult;
  /**
   * Create multiple TaskReference instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[TaskReferenceCreate]_): List of data to be used when creating new instances.
   */
  createTaskReferenceBulk: Array<CreateResult>;
  /**
   * Create a single TaskRelationship instance from the input data.
   *
   * Arguments:
   * - **data** (_TaskRelationshipCreate_): Data to be used when creating the new instance.
   */
  createTaskRelationship: CreateResult;
  /**
   * Create multiple TaskRelationship instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[TaskRelationshipCreate]_): List of data to be used when creating new instances.
   */
  createTaskRelationshipBulk: Array<CreateResult>;
  createTaskTemplate: MutationResult;
  createTaskTemplateBulk?: Maybe<Array<MutationResult>>;
  /**
   * Create a single Technique instance from the input data.
   *
   * Arguments:
   * - **data** (_TechniqueCreate_): Data to be used when creating the new instance.
   */
  createTechnique: CreateResult;
  /**
   * Create multiple Technique instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[TechniqueCreate]_): List of data to be used when creating new instances.
   */
  createTechniqueBulk: Array<CreateResult>;
  /**
   * Create a single TechniqueMitigationRelationship instance from the input data.
   *
   * Arguments:
   * - **data** (_TechniqueMitigationRelationshipCreate_): Data to be used when creating the new instance.
   */
  createTechniqueMitigationRelationship: CreateResult;
  /**
   * Create multiple TechniqueMitigationRelationship instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[TechniqueMitigationRelationshipCreate]_): List of data to be used when creating new instances.
   */
  createTechniqueMitigationRelationshipBulk: Array<CreateResult>;
  createTemplateFromTask: MutationResult;
  createTemplateFromWorkflow: MutationResult;
  /**
   * Create a single Tool instance from the input data.
   *
   * Arguments:
   * - **data** (_ToolCreate_): Data to be used when creating the new instance.
   */
  createTool: CreateResult;
  /**
   * Create multiple Tool instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[ToolCreate]_): List of data to be used when creating new instances.
   */
  createToolBulk: Array<CreateResult>;
  /**
   * Create a single ToolProcedure instance from the input data.
   *
   * Arguments:
   * - **data** (_ToolProcedureCreate_): Data to be used when creating the new instance.
   */
  createToolProcedure: CreateResult;
  /**
   * Create multiple ToolProcedure instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[ToolProcedureCreate]_): List of data to be used when creating new instances.
   */
  createToolProcedureBulk: Array<CreateResult>;
  /**
   * Create a single TTPGroup instance from the input data.
   *
   * Arguments:
   * - **data** (_TTPGroupCreate_): Data to be used when creating the new instance.
   */
  createTtpGroup: CreateResult;
  /**
   * Create multiple TTPGroup instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[TTPGroupCreate]_): List of data to be used when creating new instances.
   */
  createTtpGroupBulk: Array<CreateResult>;
  /**
   * Create a single TTPLink instance from the input data.
   *
   * Arguments:
   * - **data** (_TTPLinkCreate_): Data to be used when creating the new instance.
   */
  createTtpLink: CreateResult;
  /**
   * Create multiple TTPLink instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[TTPLinkCreate]_): List of data to be used when creating new instances.
   */
  createTtpLinkBulk: Array<CreateResult>;
  /**
   * Create a single TTPMeta instance from the input data.
   *
   * Arguments:
   * - **data** (_TTPMetaCreate_): Data to be used when creating the new instance.
   */
  createTtpMeta: CreateResult;
  /**
   * Create multiple TTPMeta instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[TTPMetaCreate]_): List of data to be used when creating new instances.
   */
  createTtpMetaBulk: Array<CreateResult>;
  /**
   * Create a single TTPPlatform instance from the input data.
   *
   * Arguments:
   * - **data** (_TTPPlatformCreate_): Data to be used when creating the new instance.
   */
  createTtpPlatform: CreateResult;
  /**
   * Create multiple TTPPlatform instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[TTPPlatformCreate]_): List of data to be used when creating new instances.
   */
  createTtpPlatformBulk: Array<CreateResult>;
  /**
   * Create a single URL instance from the input data.
   *
   * Arguments:
   * - **data** (_URLCreate_): Data to be used when creating the new instance.
   */
  createUrl: CreateResult;
  /**
   * Create multiple URL instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[URLCreate]_): List of data to be used when creating new instances.
   */
  createUrlBulk: Array<CreateResult>;
  /**
   * Create a single URLFragment instance from the input data.
   *
   * Arguments:
   * - **data** (_URLFragmentCreate_): Data to be used when creating the new instance.
   */
  createUrlFragment: CreateResult;
  /**
   * Create multiple URLFragment instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[URLFragmentCreate]_): List of data to be used when creating new instances.
   */
  createUrlFragmentBulk: Array<CreateResult>;
  /**
   * Create a single URLInputOutput instance from the input data.
   *
   * Arguments:
   * - **data** (_URLInputOutputCreate_): Data to be used when creating the new instance.
   */
  createUrlInputOutput: CreateResult;
  /**
   * Create multiple URLInputOutput instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[URLInputOutputCreate]_): List of data to be used when creating new instances.
   */
  createUrlInputOutputBulk: Array<CreateResult>;
  /**
   * Create a single URLPath instance from the input data.
   *
   * Arguments:
   * - **data** (_URLPathCreate_): Data to be used when creating the new instance.
   */
  createUrlPath: CreateResult;
  /**
   * Create multiple URLPath instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[URLPathCreate]_): List of data to be used when creating new instances.
   */
  createUrlPathBulk: Array<CreateResult>;
  /**
   * Create a single URLQuery instance from the input data.
   *
   * Arguments:
   * - **data** (_URLQueryCreate_): Data to be used when creating the new instance.
   */
  createUrlQuery: CreateResult;
  /**
   * Create multiple URLQuery instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[URLQueryCreate]_): List of data to be used when creating new instances.
   */
  createUrlQueryBulk: Array<CreateResult>;
  /**
   * Create a single URLQueryParam instance from the input data.
   *
   * Arguments:
   * - **data** (_URLQueryParamCreate_): Data to be used when creating the new instance.
   */
  createUrlQueryParam: CreateResult;
  /**
   * Create multiple URLQueryParam instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[URLQueryParamCreate]_): List of data to be used when creating new instances.
   */
  createUrlQueryParamBulk: Array<CreateResult>;
  /**
   * Create a single UserIPAccountingModel instance from the input data.
   *
   * Arguments:
   * - **data** (_UserIPAccountingModelCreate_): Data to be used when creating the new instance.
   */
  createUserIpAccountingModel: CreateResult;
  /**
   * Create multiple UserIPAccountingModel instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[UserIPAccountingModelCreate]_): List of data to be used when creating new instances.
   */
  createUserIpAccountingModelBulk: Array<CreateResult>;
  /**
   * Create a single Workflow instance from the input data.
   *
   * Arguments:
   * - **data** (_WorkflowCreate_): Data to be used when creating the new instance.
   */
  createWorkflow: CreateResult;
  /**
   * Create multiple Workflow instances from the input data.
   *
   * Arguments:
   * - **data_list** (_[WorkflowCreate]_): List of data to be used when creating new instances.
   */
  createWorkflowBulk: Array<CreateResult>;
  createWorkflowFromTemplate: MutationResult;
  createWorkflowTemplate: MutationResult;
  createWorkflowTemplateBulk?: Maybe<Array<MutationResult>>;
  /**
   * Delete a single Alias.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteAlias: MutateResult;
  /**
   * Delete multiple Alias.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteAliasBulk: Array<MutateResult>;
  /**
   * Delete a single BaseHashableObservable.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteBaseHashableObservable: MutateResult;
  /**
   * Delete multiple BaseHashableObservable.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteBaseHashableObservableBulk: Array<MutateResult>;
  /**
   * Delete a single BaseHost.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteBaseHost: MutateResult;
  /**
   * Delete multiple BaseHost.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteBaseHostBulk: Array<MutateResult>;
  /**
   * Delete a single BaseObservable.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteBaseObservable: MutateResult;
  /**
   * Delete multiple BaseObservable.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteBaseObservableBulk: Array<MutateResult>;
  /**
   * Delete a single BaseTaskInputOutput.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteBaseTaskInputOutput: MutateResult;
  /**
   * Delete multiple BaseTaskInputOutput.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteBaseTaskInputOutputBulk: Array<MutateResult>;
  /**
   * Delete a single BoolInputOutput.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteBoolInputOutput: MutateResult;
  /**
   * Delete multiple BoolInputOutput.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteBoolInputOutputBulk: Array<MutateResult>;
  /**
   * Delete a single Case.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteCase: MutateResult;
  /**
   * Delete multiple Case.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteCaseBulk: Array<MutateResult>;
  /**
   * Delete a single CaseDBRole.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteCaseDbRole: MutateResult;
  /**
   * Delete multiple CaseDBRole.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteCaseDbRoleBulk: Array<MutateResult>;
  /**
   * Delete a single CaseDBUser.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteCaseDbUser: MutateResult;
  /**
   * Delete multiple CaseDBUser.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteCaseDbUserBulk: Array<MutateResult>;
  /**
   * Delete a single CaseFileItemBase.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteCaseFileItemBase: MutateResult;
  /**
   * Delete multiple CaseFileItemBase.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteCaseFileItemBaseBulk: Array<MutateResult>;
  /**
   * Delete a single CaseManagementExternalReference.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteCaseManagementExternalReference: MutateResult;
  /**
   * Delete multiple CaseManagementExternalReference.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteCaseManagementExternalReferenceBulk: Array<MutateResult>;
  /**
   * Delete a single CaseRelationship.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteCaseRelationship: MutateResult;
  /**
   * Delete multiple CaseRelationship.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteCaseRelationshipBulk: Array<MutateResult>;
  /**
   * Delete a single Comment.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteComment: MutateResult;
  /**
   * Delete multiple Comment.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteCommentBulk: Array<MutateResult>;
  /**
   * Delete a single CTIEntry.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteCtiEntry: MutateResult;
  /**
   * Delete multiple CTIEntry.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteCtiEntryBulk: Array<MutateResult>;
  /**
   * Delete a single DataPlatformServiceIPFix.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteDataPlatformServiceIpFix: MutateResult;
  /**
   * Delete multiple DataPlatformServiceIPFix.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteDataPlatformServiceIpFixBulk: Array<MutateResult>;
  /**
   * Delete a single DataSource.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteDataSource: MutateResult;
  /**
   * Delete multiple DataSource.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteDataSourceBulk: Array<MutateResult>;
  /**
   * Delete a single DateInputOutput.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteDateInputOutput: MutateResult;
  /**
   * Delete multiple DateInputOutput.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteDateInputOutputBulk: Array<MutateResult>;
  /**
   * Delete a single DateTimeInputOutput.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteDateTimeInputOutput: MutateResult;
  /**
   * Delete multiple DateTimeInputOutput.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteDateTimeInputOutputBulk: Array<MutateResult>;
  /**
   * Delete a single Directory.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteDirectory: MutateResult;
  /**
   * Delete multiple Directory.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteDirectoryBulk: Array<MutateResult>;
  /**
   * Delete a single DomainInputOutput.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteDomainInputOutput: MutateResult;
  /**
   * Delete multiple DomainInputOutput.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteDomainInputOutputBulk: Array<MutateResult>;
  /**
   * Delete a single DomainName.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteDomainName: MutateResult;
  /**
   * Delete multiple DomainName.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteDomainNameBulk: Array<MutateResult>;
  /**
   * Delete a single DomainToDomainResolution.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteDomainToDomainResolution: MutateResult;
  /**
   * Delete multiple DomainToDomainResolution.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteDomainToDomainResolutionBulk: Array<MutateResult>;
  /**
   * Delete a single DomainToIPAddressResolution.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteDomainToIpAddressResolution: MutateResult;
  /**
   * Delete multiple DomainToIPAddressResolution.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteDomainToIpAddressResolutionBulk: Array<MutateResult>;
  /**
   * Delete a single EmailAddress.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteEmailAddress: MutateResult;
  /**
   * Delete multiple EmailAddress.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteEmailAddressBulk: Array<MutateResult>;
  /**
   * Delete a single EmailAddressInputOutput.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteEmailAddressInputOutput: MutateResult;
  /**
   * Delete multiple EmailAddressInputOutput.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteEmailAddressInputOutputBulk: Array<MutateResult>;
  /**
   * Delete a single EmailHeader.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteEmailHeader: MutateResult;
  /**
   * Delete multiple EmailHeader.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteEmailHeaderBulk: Array<MutateResult>;
  /**
   * Delete a single EmailMessage.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteEmailMessage: MutateResult;
  /**
   * Delete multiple EmailMessage.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteEmailMessageBulk: Array<MutateResult>;
  /**
   * Delete a single EmailMessageEmailAddressRelationship.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteEmailMessageEmailAddressRelationship: MutateResult;
  /**
   * Delete multiple EmailMessageEmailAddressRelationship.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteEmailMessageEmailAddressRelationshipBulk: Array<MutateResult>;
  /**
   * Delete a single EmailMessageInputOutput.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteEmailMessageInputOutput: MutateResult;
  /**
   * Delete multiple EmailMessageInputOutput.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteEmailMessageInputOutputBulk: Array<MutateResult>;
  /**
   * Delete a single EmailMessagePartsRelationship.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteEmailMessagePartsRelationship: MutateResult;
  /**
   * Delete multiple EmailMessagePartsRelationship.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteEmailMessagePartsRelationshipBulk: Array<MutateResult>;
  /**
   * Delete a single EntryType.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteEntryType: MutateResult;
  /**
   * Delete multiple EntryType.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteEntryTypeBulk: Array<MutateResult>;
  /**
   * Delete a single ExternalReference.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteExternalReference: MutateResult;
  /**
   * Delete multiple ExternalReference.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteExternalReferenceBulk: Array<MutateResult>;
  /**
   * Delete a single File.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteFile: MutateResult;
  /**
   * Delete multiple File.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteFileBulk: Array<MutateResult>;
  /**
   * Delete a single FileInputOutput.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteFileInputOutput: MutateResult;
  /**
   * Delete multiple FileInputOutput.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteFileInputOutputBulk: Array<MutateResult>;
  /**
   * Delete a single FileRefInputOutput.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteFileRefInputOutput: MutateResult;
  /**
   * Delete multiple FileRefInputOutput.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteFileRefInputOutputBulk: Array<MutateResult>;
  /**
   * Delete a single FileReference.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteFileReference: MutateResult;
  /**
   * Delete multiple FileReference.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteFileReferenceBulk: Array<MutateResult>;
  /**
   * Delete a single FlowEvent.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteFlowEvent: MutateResult;
  /**
   * Delete multiple FlowEvent.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteFlowEventBulk: Array<MutateResult>;
  /**
   * Delete a single FlowEventData.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteFlowEventData: MutateResult;
  /**
   * Delete multiple FlowEventData.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteFlowEventDataBulk: Array<MutateResult>;
  /**
   * Delete a single GroupProcedure.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteGroupProcedure: MutateResult;
  /**
   * Delete multiple GroupProcedure.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteGroupProcedureBulk: Array<MutateResult>;
  /**
   * Delete a single Hash.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteHash: MutateResult;
  /**
   * Delete multiple Hash.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteHashBulk: Array<MutateResult>;
  /**
   * Delete a single HashInputOutput.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteHashInputOutput: MutateResult;
  /**
   * Delete multiple HashInputOutput.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteHashInputOutputBulk: Array<MutateResult>;
  /**
   * Delete a single IPAddress.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteIpAddress: MutateResult;
  /**
   * Delete multiple IPAddress.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteIpAddressBulk: Array<MutateResult>;
  /**
   * Delete a single IPAddressToDomainResolution.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteIpAddressToDomainResolution: MutateResult;
  /**
   * Delete multiple IPAddressToDomainResolution.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteIpAddressToDomainResolutionBulk: Array<MutateResult>;
  /**
   * Delete a single IPInputOutput.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteIpInputOutput: MutateResult;
  /**
   * Delete multiple IPInputOutput.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteIpInputOutputBulk: Array<MutateResult>;
  /**
   * Delete a single JSONInputOutput.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteJsonInputOutput: MutateResult;
  /**
   * Delete multiple JSONInputOutput.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteJsonInputOutputBulk: Array<MutateResult>;
  /**
   * Delete a single Label.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteLabel: MutateResult;
  /**
   * Delete multiple Label.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteLabelBulk: Array<MutateResult>;
  /**
   * Delete a single Malware.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteMalware: MutateResult;
  /**
   * Delete multiple Malware.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteMalwareBulk: Array<MutateResult>;
  /**
   * Delete a single MalwareProcedure.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteMalwareProcedure: MutateResult;
  /**
   * Delete multiple MalwareProcedure.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteMalwareProcedureBulk: Array<MutateResult>;
  /**
   * Delete a single Mitigation.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteMitigation: MutateResult;
  /**
   * Delete multiple Mitigation.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteMitigationBulk: Array<MutateResult>;
  /**
   * Delete a single ObservableLink.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteObservableLink: MutateResult;
  /**
   * Delete multiple ObservableLink.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteObservableLinkBulk: Array<MutateResult>;
  /**
   * Delete a single SourceSpecifier.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteSourceSpecifier: MutateResult;
  /**
   * Delete multiple SourceSpecifier.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteSourceSpecifierBulk: Array<MutateResult>;
  /**
   * Delete a single Stage.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteStage: MutateResult;
  /**
   * Delete multiple Stage.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteStageBulk: Array<MutateResult>;
  /**
   * Delete a single StorageEvent.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteStorageEvent: MutateResult;
  /**
   * Delete multiple StorageEvent.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteStorageEventBulk: Array<MutateResult>;
  /**
   * Delete a single StringInputOutput.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteStringInputOutput: MutateResult;
  /**
   * Delete multiple StringInputOutput.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteStringInputOutputBulk: Array<MutateResult>;
  /**
   * Delete a single Tactic.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteTactic: MutateResult;
  /**
   * Delete multiple Tactic.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteTacticBulk: Array<MutateResult>;
  /**
   * Delete a single Task.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteTask: MutateResult;
  /**
   * Delete multiple Task.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteTaskBulk: Array<MutateResult>;
  /**
   * Delete a single TaskReference.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteTaskReference: MutateResult;
  /**
   * Delete multiple TaskReference.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteTaskReferenceBulk: Array<MutateResult>;
  /**
   * Delete a single TaskRelationship.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteTaskRelationship: MutateResult;
  /**
   * Delete multiple TaskRelationship.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteTaskRelationshipBulk: Array<MutateResult>;
  /**
   * Delete a single TaskTemplate.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteTaskTemplate: MutateResult;
  /**
   * Delete multiple TaskTemplate.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteTaskTemplateBulk: Array<MutateResult>;
  /**
   * Delete a single Technique.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteTechnique: MutateResult;
  /**
   * Delete multiple Technique.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteTechniqueBulk: Array<MutateResult>;
  /**
   * Delete a single TechniqueMitigationRelationship.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteTechniqueMitigationRelationship: MutateResult;
  /**
   * Delete multiple TechniqueMitigationRelationship.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteTechniqueMitigationRelationshipBulk: Array<MutateResult>;
  /**
   * Delete a single Tool.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteTool: MutateResult;
  /**
   * Delete multiple Tool.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteToolBulk: Array<MutateResult>;
  /**
   * Delete a single ToolProcedure.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteToolProcedure: MutateResult;
  /**
   * Delete multiple ToolProcedure.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteToolProcedureBulk: Array<MutateResult>;
  /**
   * Delete a single TTPGroup.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteTtpGroup: MutateResult;
  /**
   * Delete multiple TTPGroup.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteTtpGroupBulk: Array<MutateResult>;
  /**
   * Delete a single TTPLink.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteTtpLink: MutateResult;
  /**
   * Delete multiple TTPLink.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteTtpLinkBulk: Array<MutateResult>;
  /**
   * Delete a single TTPMeta.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteTtpMeta: MutateResult;
  /**
   * Delete multiple TTPMeta.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteTtpMetaBulk: Array<MutateResult>;
  /**
   * Delete a single TTPPlatform.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteTtpPlatform: MutateResult;
  /**
   * Delete multiple TTPPlatform.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteTtpPlatformBulk: Array<MutateResult>;
  /**
   * Delete a single URL.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteUrl: MutateResult;
  /**
   * Delete multiple URL.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteUrlBulk: Array<MutateResult>;
  /**
   * Delete a single URLFragment.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteUrlFragment: MutateResult;
  /**
   * Delete multiple URLFragment.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteUrlFragmentBulk: Array<MutateResult>;
  /**
   * Delete a single URLInputOutput.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteUrlInputOutput: MutateResult;
  /**
   * Delete multiple URLInputOutput.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteUrlInputOutputBulk: Array<MutateResult>;
  /**
   * Delete a single URLPath.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteUrlPath: MutateResult;
  /**
   * Delete multiple URLPath.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteUrlPathBulk: Array<MutateResult>;
  /**
   * Delete a single URLQuery.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteUrlQuery: MutateResult;
  /**
   * Delete multiple URLQuery.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteUrlQueryBulk: Array<MutateResult>;
  /**
   * Delete a single URLQueryParam.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteUrlQueryParam: MutateResult;
  /**
   * Delete multiple URLQueryParam.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteUrlQueryParamBulk: Array<MutateResult>;
  /**
   * Delete a single UserIPAccountingModel.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteUserIpAccountingModel: MutateResult;
  /**
   * Delete multiple UserIPAccountingModel.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteUserIpAccountingModelBulk: Array<MutateResult>;
  /**
   * Delete a single Workflow.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteWorkflow: MutateResult;
  /**
   * Delete multiple Workflow.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteWorkflowBulk: Array<MutateResult>;
  /**
   * Delete a single WorkflowTemplate.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to delete.
   */
  deleteWorkflowTemplate: MutateResult;
  /**
   * Delete multiple WorkflowTemplate.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifiers of instances to delete.
   */
  deleteWorkflowTemplateBulk: Array<MutateResult>;
  getOrCreateCtiEntry: CtiEntryNestedListResult;
  getOrCreateDataSource: DataSourceNestedListResult;
  getOrCreateDomainName: DomainNameNestedListResult;
  getOrCreateDomainToDomainResolution: DomainToDomainResolutionNestedListResult;
  getOrCreateDomainToIpResolution: DomainToIpAddressResolutionNestedListResult;
  getOrCreateEmailAddress: EmailAddressNestedListResult;
  getOrCreateEmailMessage: EmailMessageNestedListResult;
  getOrCreateEntryType: EntryTypeNestedListResult;
  getOrCreateFileReference: FileReferenceNestedListResult;
  getOrCreateIpAddress: IpAddressNestedListResult;
  getOrCreateIpToDomainResolution: IpAddressToDomainResolutionNestedListResult;
  getOrCreateSourceSpecifier: SourceSpecifierNestedListResult;
  getOrCreateTtpMeta: TtpMetaNestedListResult;
  getOrCreateUrl: UrlNestedListResult;
  rejectCase: MutationResult;
  rejectStage: MutationResult;
  rejectTask: MutationResult;
  rejectWorkflow: MutationResult;
  removeAllAssets?: Maybe<Scalars['Boolean']>;
  removeAllCve?: Maybe<Scalars['Boolean']>;
  removeAsset?: Maybe<Scalars['Boolean']>;
  removeCve?: Maybe<Scalars['Boolean']>;
  resolveCase: MutationResult;
  resolveTask: MutationResult;
  resolveTaskWithDecision: MutationResult;
  setTaskFileInput?: Maybe<MutationResult>;
  setTaskFileOutput?: Maybe<MutationResult>;
  setTaskInput?: Maybe<MutationResult>;
  setTaskOutput?: Maybe<MutationResult>;
  skipTask: MutationResult;
  triggerTask: Scalars['String'];
  /**
   * Update a single Alias instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_AliasUpdate_): Data to be used when updating an existing instance.
   */
  updateAlias: MutateResult;
  /**
   * Update multiple Alias instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[AliasUpdate]_): List of data to be used when updating
   * instances. Must be provided in the same order as the ids.
   */
  updateAliasBulk: Array<MutateResult>;
  /**
   * Update a single BaseHashableObservable instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_BaseHashableObservableUpdate_): Data to be used when updating an existing instance.
   */
  updateBaseHashableObservable: MutateResult;
  /**
   * Update multiple BaseHashableObservable instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[BaseHashableObservableUpdate]_): List of data to be used
   * when updating instances. Must be provided in the same order as the ids.
   */
  updateBaseHashableObservableBulk: Array<MutateResult>;
  /**
   * Update a single BaseHost instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_BaseHostUpdate_): Data to be used when updating an existing instance.
   */
  updateBaseHost: MutateResult;
  /**
   * Update multiple BaseHost instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[BaseHostUpdate]_): List of data to be used when updating
   * instances. Must be provided in the same order as the ids.
   */
  updateBaseHostBulk: Array<MutateResult>;
  /**
   * Update a single BaseObservable instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_BaseObservableUpdate_): Data to be used when updating an existing instance.
   */
  updateBaseObservable: MutateResult;
  /**
   * Update multiple BaseObservable instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[BaseObservableUpdate]_): List of data to be used when
   * updating instances. Must be provided in the same order as the ids.
   */
  updateBaseObservableBulk: Array<MutateResult>;
  /**
   * Update a single BaseTaskInputOutput instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_BaseTaskInputOutputUpdate_): Data to be used when updating an existing instance.
   */
  updateBaseTaskInputOutput: MutateResult;
  /**
   * Update multiple BaseTaskInputOutput instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[BaseTaskInputOutputUpdate]_): List of data to be used when
   * updating instances. Must be provided in the same order as the ids.
   */
  updateBaseTaskInputOutputBulk: Array<MutateResult>;
  /**
   * Update a single BoolInputOutput instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_BoolInputOutputUpdate_): Data to be used when updating an existing instance.
   */
  updateBoolInputOutput: MutateResult;
  /**
   * Update multiple BoolInputOutput instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[BoolInputOutputUpdate]_): List of data to be used when
   * updating instances. Must be provided in the same order as the ids.
   */
  updateBoolInputOutputBulk: Array<MutateResult>;
  /**
   * Update a single Case instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_CaseUpdate_): Data to be used when updating an existing instance.
   */
  updateCase: MutateResult;
  /**
   * Update multiple Case instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[CaseUpdate]_): List of data to be used when updating
   * instances. Must be provided in the same order as the ids.
   */
  updateCaseBulk: Array<MutateResult>;
  /**
   * Update a single CaseDBRole instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_CaseDBRoleUpdate_): Data to be used when updating an existing instance.
   */
  updateCaseDbRole: MutateResult;
  /**
   * Update multiple CaseDBRole instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[CaseDBRoleUpdate]_): List of data to be used when updating
   * instances. Must be provided in the same order as the ids.
   */
  updateCaseDbRoleBulk: Array<MutateResult>;
  /**
   * Update a single CaseDBUser instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_CaseDBUserUpdate_): Data to be used when updating an existing instance.
   */
  updateCaseDbUser: MutateResult;
  /**
   * Update multiple CaseDBUser instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[CaseDBUserUpdate]_): List of data to be used when updating
   * instances. Must be provided in the same order as the ids.
   */
  updateCaseDbUserBulk: Array<MutateResult>;
  /**
   * Update a single CaseFileItemBase instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_CaseFileItemBaseUpdate_): Data to be used when updating an existing instance.
   */
  updateCaseFileItemBase: MutateResult;
  /**
   * Update multiple CaseFileItemBase instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[CaseFileItemBaseUpdate]_): List of data to be used when
   * updating instances. Must be provided in the same order as the ids.
   */
  updateCaseFileItemBaseBulk: Array<MutateResult>;
  /**
   * Update a single CaseManagementExternalReference instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_CaseManagementExternalReferenceUpdate_): Data to be used when updating an existing instance.
   */
  updateCaseManagementExternalReference: MutateResult;
  /**
   * Update multiple CaseManagementExternalReference instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[CaseManagementExternalReferenceUpdate]_): List of data to
   * be used when updating instances. Must be provided in the same order as the ids.
   */
  updateCaseManagementExternalReferenceBulk: Array<MutateResult>;
  /**
   * Update a single CaseRelationship instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_CaseRelationshipUpdate_): Data to be used when updating an existing instance.
   */
  updateCaseRelationship: MutateResult;
  /**
   * Update multiple CaseRelationship instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[CaseRelationshipUpdate]_): List of data to be used when
   * updating instances. Must be provided in the same order as the ids.
   */
  updateCaseRelationshipBulk: Array<MutateResult>;
  /**
   * Update a single Comment instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_CommentUpdate_): Data to be used when updating an existing instance.
   */
  updateComment: MutateResult;
  /**
   * Update multiple Comment instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[CommentUpdate]_): List of data to be used when updating
   * instances. Must be provided in the same order as the ids.
   */
  updateCommentBulk: Array<MutateResult>;
  /**
   * Update a single CTIEntry instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_CTIEntryUpdate_): Data to be used when updating an existing instance.
   */
  updateCtiEntry: MutateResult;
  /**
   * Update multiple CTIEntry instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[CTIEntryUpdate]_): List of data to be used when updating
   * instances. Must be provided in the same order as the ids.
   */
  updateCtiEntryBulk: Array<MutateResult>;
  /**
   * Update a single DataPlatformServiceIPFix instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_DataPlatformServiceIPFixUpdate_): Data to be used when updating an existing instance.
   */
  updateDataPlatformServiceIpFix: MutateResult;
  /**
   * Update multiple DataPlatformServiceIPFix instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[DataPlatformServiceIPFixUpdate]_): List of data to be used
   * when updating instances. Must be provided in the same order as the ids.
   */
  updateDataPlatformServiceIpFixBulk: Array<MutateResult>;
  /**
   * Update a single DataSource instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_DataSourceUpdate_): Data to be used when updating an existing instance.
   */
  updateDataSource: MutateResult;
  /**
   * Update multiple DataSource instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[DataSourceUpdate]_): List of data to be used when updating
   * instances. Must be provided in the same order as the ids.
   */
  updateDataSourceBulk: Array<MutateResult>;
  /**
   * Update a single DateInputOutput instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_DateInputOutputUpdate_): Data to be used when updating an existing instance.
   */
  updateDateInputOutput: MutateResult;
  /**
   * Update multiple DateInputOutput instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[DateInputOutputUpdate]_): List of data to be used when
   * updating instances. Must be provided in the same order as the ids.
   */
  updateDateInputOutputBulk: Array<MutateResult>;
  /**
   * Update a single DateTimeInputOutput instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_DateTimeInputOutputUpdate_): Data to be used when updating an existing instance.
   */
  updateDateTimeInputOutput: MutateResult;
  /**
   * Update multiple DateTimeInputOutput instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[DateTimeInputOutputUpdate]_): List of data to be used when
   * updating instances. Must be provided in the same order as the ids.
   */
  updateDateTimeInputOutputBulk: Array<MutateResult>;
  /**
   * Update a single Directory instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_DirectoryUpdate_): Data to be used when updating an existing instance.
   */
  updateDirectory: MutateResult;
  /**
   * Update multiple Directory instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[DirectoryUpdate]_): List of data to be used when updating
   * instances. Must be provided in the same order as the ids.
   */
  updateDirectoryBulk: Array<MutateResult>;
  /**
   * Update a single DomainInputOutput instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_DomainInputOutputUpdate_): Data to be used when updating an existing instance.
   */
  updateDomainInputOutput: MutateResult;
  /**
   * Update multiple DomainInputOutput instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[DomainInputOutputUpdate]_): List of data to be used when
   * updating instances. Must be provided in the same order as the ids.
   */
  updateDomainInputOutputBulk: Array<MutateResult>;
  /**
   * Update a single DomainName instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_DomainNameUpdate_): Data to be used when updating an existing instance.
   */
  updateDomainName: MutateResult;
  /**
   * Update multiple DomainName instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[DomainNameUpdate]_): List of data to be used when updating
   * instances. Must be provided in the same order as the ids.
   */
  updateDomainNameBulk: Array<MutateResult>;
  /**
   * Update a single DomainToDomainResolution instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_DomainToDomainResolutionUpdate_): Data to be used when updating an existing instance.
   */
  updateDomainToDomainResolution: MutateResult;
  /**
   * Update multiple DomainToDomainResolution instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[DomainToDomainResolutionUpdate]_): List of data to be used
   * when updating instances. Must be provided in the same order as the ids.
   */
  updateDomainToDomainResolutionBulk: Array<MutateResult>;
  /**
   * Update a single DomainToIPAddressResolution instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_DomainToIPAddressResolutionUpdate_): Data to be used when updating an existing instance.
   */
  updateDomainToIpAddressResolution: MutateResult;
  /**
   * Update multiple DomainToIPAddressResolution instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[DomainToIPAddressResolutionUpdate]_): List of data to be
   * used when updating instances. Must be provided in the same order as the ids.
   */
  updateDomainToIpAddressResolutionBulk: Array<MutateResult>;
  /**
   * Update a single EmailAddress instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_EmailAddressUpdate_): Data to be used when updating an existing instance.
   */
  updateEmailAddress: MutateResult;
  /**
   * Update multiple EmailAddress instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[EmailAddressUpdate]_): List of data to be used when
   * updating instances. Must be provided in the same order as the ids.
   */
  updateEmailAddressBulk: Array<MutateResult>;
  /**
   * Update a single EmailAddressInputOutput instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_EmailAddressInputOutputUpdate_): Data to be used when updating an existing instance.
   */
  updateEmailAddressInputOutput: MutateResult;
  /**
   * Update multiple EmailAddressInputOutput instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[EmailAddressInputOutputUpdate]_): List of data to be used
   * when updating instances. Must be provided in the same order as the ids.
   */
  updateEmailAddressInputOutputBulk: Array<MutateResult>;
  /**
   * Update a single EmailHeader instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_EmailHeaderUpdate_): Data to be used when updating an existing instance.
   */
  updateEmailHeader: MutateResult;
  /**
   * Update multiple EmailHeader instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[EmailHeaderUpdate]_): List of data to be used when updating
   * instances. Must be provided in the same order as the ids.
   */
  updateEmailHeaderBulk: Array<MutateResult>;
  /**
   * Update a single EmailMessage instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_EmailMessageUpdate_): Data to be used when updating an existing instance.
   */
  updateEmailMessage: MutateResult;
  /**
   * Update multiple EmailMessage instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[EmailMessageUpdate]_): List of data to be used when
   * updating instances. Must be provided in the same order as the ids.
   */
  updateEmailMessageBulk: Array<MutateResult>;
  /**
   * Update a single EmailMessageEmailAddressRelationship instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_EmailMessageEmailAddressRelationshipUpdate_): Data to be used when updating an existing instance.
   */
  updateEmailMessageEmailAddressRelationship: MutateResult;
  /**
   * Update multiple EmailMessageEmailAddressRelationship instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[EmailMessageEmailAddressRelationshipUpdate]_): List of data
   * to be used when updating instances. Must be provided in the same order as the ids.
   */
  updateEmailMessageEmailAddressRelationshipBulk: Array<MutateResult>;
  /**
   * Update a single EmailMessageInputOutput instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_EmailMessageInputOutputUpdate_): Data to be used when updating an existing instance.
   */
  updateEmailMessageInputOutput: MutateResult;
  /**
   * Update multiple EmailMessageInputOutput instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[EmailMessageInputOutputUpdate]_): List of data to be used
   * when updating instances. Must be provided in the same order as the ids.
   */
  updateEmailMessageInputOutputBulk: Array<MutateResult>;
  /**
   * Update a single EmailMessagePartsRelationship instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_EmailMessagePartsRelationshipUpdate_): Data to be used when updating an existing instance.
   */
  updateEmailMessagePartsRelationship: MutateResult;
  /**
   * Update multiple EmailMessagePartsRelationship instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[EmailMessagePartsRelationshipUpdate]_): List of data to be
   * used when updating instances. Must be provided in the same order as the ids.
   */
  updateEmailMessagePartsRelationshipBulk: Array<MutateResult>;
  /**
   * Update a single EntryType instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_EntryTypeUpdate_): Data to be used when updating an existing instance.
   */
  updateEntryType: MutateResult;
  /**
   * Update multiple EntryType instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[EntryTypeUpdate]_): List of data to be used when updating
   * instances. Must be provided in the same order as the ids.
   */
  updateEntryTypeBulk: Array<MutateResult>;
  /**
   * Update a single ExternalReference instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_ExternalReferenceUpdate_): Data to be used when updating an existing instance.
   */
  updateExternalReference: MutateResult;
  /**
   * Update multiple ExternalReference instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[ExternalReferenceUpdate]_): List of data to be used when
   * updating instances. Must be provided in the same order as the ids.
   */
  updateExternalReferenceBulk: Array<MutateResult>;
  /**
   * Update a single File instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_FileUpdate_): Data to be used when updating an existing instance.
   */
  updateFile: MutateResult;
  /**
   * Update multiple File instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[FileUpdate]_): List of data to be used when updating
   * instances. Must be provided in the same order as the ids.
   */
  updateFileBulk: Array<MutateResult>;
  /**
   * Update a single FileInputOutput instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_FileInputOutputUpdate_): Data to be used when updating an existing instance.
   */
  updateFileInputOutput: MutateResult;
  /**
   * Update multiple FileInputOutput instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[FileInputOutputUpdate]_): List of data to be used when
   * updating instances. Must be provided in the same order as the ids.
   */
  updateFileInputOutputBulk: Array<MutateResult>;
  /**
   * Update a single FileRefInputOutput instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_FileRefInputOutputUpdate_): Data to be used when updating an existing instance.
   */
  updateFileRefInputOutput: MutateResult;
  /**
   * Update multiple FileRefInputOutput instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[FileRefInputOutputUpdate]_): List of data to be used when
   * updating instances. Must be provided in the same order as the ids.
   */
  updateFileRefInputOutputBulk: Array<MutateResult>;
  /**
   * Update a single FileReference instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_FileReferenceUpdate_): Data to be used when updating an existing instance.
   */
  updateFileReference: MutateResult;
  /**
   * Update multiple FileReference instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[FileReferenceUpdate]_): List of data to be used when
   * updating instances. Must be provided in the same order as the ids.
   */
  updateFileReferenceBulk: Array<MutateResult>;
  /**
   * Update a single FlowEvent instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_FlowEventUpdate_): Data to be used when updating an existing instance.
   */
  updateFlowEvent: MutateResult;
  /**
   * Update multiple FlowEvent instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[FlowEventUpdate]_): List of data to be used when updating
   * instances. Must be provided in the same order as the ids.
   */
  updateFlowEventBulk: Array<MutateResult>;
  /**
   * Update a single FlowEventData instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_FlowEventDataUpdate_): Data to be used when updating an existing instance.
   */
  updateFlowEventData: MutateResult;
  /**
   * Update multiple FlowEventData instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[FlowEventDataUpdate]_): List of data to be used when
   * updating instances. Must be provided in the same order as the ids.
   */
  updateFlowEventDataBulk: Array<MutateResult>;
  /**
   * Update a single GroupProcedure instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_GroupProcedureUpdate_): Data to be used when updating an existing instance.
   */
  updateGroupProcedure: MutateResult;
  /**
   * Update multiple GroupProcedure instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[GroupProcedureUpdate]_): List of data to be used when
   * updating instances. Must be provided in the same order as the ids.
   */
  updateGroupProcedureBulk: Array<MutateResult>;
  /**
   * Update a single Hash instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_HashUpdate_): Data to be used when updating an existing instance.
   */
  updateHash: MutateResult;
  /**
   * Update multiple Hash instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[HashUpdate]_): List of data to be used when updating
   * instances. Must be provided in the same order as the ids.
   */
  updateHashBulk: Array<MutateResult>;
  /**
   * Update a single HashInputOutput instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_HashInputOutputUpdate_): Data to be used when updating an existing instance.
   */
  updateHashInputOutput: MutateResult;
  /**
   * Update multiple HashInputOutput instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[HashInputOutputUpdate]_): List of data to be used when
   * updating instances. Must be provided in the same order as the ids.
   */
  updateHashInputOutputBulk: Array<MutateResult>;
  /**
   * Update a single IPAddress instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_IPAddressUpdate_): Data to be used when updating an existing instance.
   */
  updateIpAddress: MutateResult;
  /**
   * Update multiple IPAddress instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[IPAddressUpdate]_): List of data to be used when updating
   * instances. Must be provided in the same order as the ids.
   */
  updateIpAddressBulk: Array<MutateResult>;
  /**
   * Update a single IPAddressToDomainResolution instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_IPAddressToDomainResolutionUpdate_): Data to be used when updating an existing instance.
   */
  updateIpAddressToDomainResolution: MutateResult;
  /**
   * Update multiple IPAddressToDomainResolution instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[IPAddressToDomainResolutionUpdate]_): List of data to be
   * used when updating instances. Must be provided in the same order as the ids.
   */
  updateIpAddressToDomainResolutionBulk: Array<MutateResult>;
  /**
   * Update a single IPInputOutput instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_IPInputOutputUpdate_): Data to be used when updating an existing instance.
   */
  updateIpInputOutput: MutateResult;
  /**
   * Update multiple IPInputOutput instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[IPInputOutputUpdate]_): List of data to be used when
   * updating instances. Must be provided in the same order as the ids.
   */
  updateIpInputOutputBulk: Array<MutateResult>;
  /**
   * Update a single JSONInputOutput instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_JSONInputOutputUpdate_): Data to be used when updating an existing instance.
   */
  updateJsonInputOutput: MutateResult;
  /**
   * Update multiple JSONInputOutput instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[JSONInputOutputUpdate]_): List of data to be used when
   * updating instances. Must be provided in the same order as the ids.
   */
  updateJsonInputOutputBulk: Array<MutateResult>;
  /**
   * Update a single Label instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_LabelUpdate_): Data to be used when updating an existing instance.
   */
  updateLabel: MutateResult;
  /**
   * Update multiple Label instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[LabelUpdate]_): List of data to be used when updating
   * instances. Must be provided in the same order as the ids.
   */
  updateLabelBulk: Array<MutateResult>;
  /**
   * Update a single Malware instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_MalwareUpdate_): Data to be used when updating an existing instance.
   */
  updateMalware: MutateResult;
  /**
   * Update multiple Malware instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[MalwareUpdate]_): List of data to be used when updating
   * instances. Must be provided in the same order as the ids.
   */
  updateMalwareBulk: Array<MutateResult>;
  /**
   * Update a single MalwareProcedure instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_MalwareProcedureUpdate_): Data to be used when updating an existing instance.
   */
  updateMalwareProcedure: MutateResult;
  /**
   * Update multiple MalwareProcedure instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[MalwareProcedureUpdate]_): List of data to be used when
   * updating instances. Must be provided in the same order as the ids.
   */
  updateMalwareProcedureBulk: Array<MutateResult>;
  /**
   * Update a single Mitigation instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_MitigationUpdate_): Data to be used when updating an existing instance.
   */
  updateMitigation: MutateResult;
  /**
   * Update multiple Mitigation instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[MitigationUpdate]_): List of data to be used when updating
   * instances. Must be provided in the same order as the ids.
   */
  updateMitigationBulk: Array<MutateResult>;
  /**
   * Update a single ObservableLink instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_ObservableLinkUpdate_): Data to be used when updating an existing instance.
   */
  updateObservableLink: MutateResult;
  /**
   * Update multiple ObservableLink instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[ObservableLinkUpdate]_): List of data to be used when
   * updating instances. Must be provided in the same order as the ids.
   */
  updateObservableLinkBulk: Array<MutateResult>;
  updateOutputFromBlockingTasks: MutationResult;
  /**
   * Update a single SourceSpecifier instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_SourceSpecifierUpdate_): Data to be used when updating an existing instance.
   */
  updateSourceSpecifier: MutateResult;
  /**
   * Update multiple SourceSpecifier instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[SourceSpecifierUpdate]_): List of data to be used when
   * updating instances. Must be provided in the same order as the ids.
   */
  updateSourceSpecifierBulk: Array<MutateResult>;
  /**
   * Update a single Stage instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_StageUpdate_): Data to be used when updating an existing instance.
   */
  updateStage: MutateResult;
  /**
   * Update multiple Stage instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[StageUpdate]_): List of data to be used when updating
   * instances. Must be provided in the same order as the ids.
   */
  updateStageBulk: Array<MutateResult>;
  /**
   * Update a single StorageEvent instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_StorageEventUpdate_): Data to be used when updating an existing instance.
   */
  updateStorageEvent: MutateResult;
  /**
   * Update multiple StorageEvent instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[StorageEventUpdate]_): List of data to be used when
   * updating instances. Must be provided in the same order as the ids.
   */
  updateStorageEventBulk: Array<MutateResult>;
  /**
   * Update a single StringInputOutput instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_StringInputOutputUpdate_): Data to be used when updating an existing instance.
   */
  updateStringInputOutput: MutateResult;
  /**
   * Update multiple StringInputOutput instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[StringInputOutputUpdate]_): List of data to be used when
   * updating instances. Must be provided in the same order as the ids.
   */
  updateStringInputOutputBulk: Array<MutateResult>;
  /**
   * Update a single Tactic instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_TacticUpdate_): Data to be used when updating an existing instance.
   */
  updateTactic: MutateResult;
  /**
   * Update multiple Tactic instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[TacticUpdate]_): List of data to be used when updating
   * instances. Must be provided in the same order as the ids.
   */
  updateTacticBulk: Array<MutateResult>;
  /**
   * Update a single Task instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_TaskUpdate_): Data to be used when updating an existing instance.
   */
  updateTask: MutateResult;
  /**
   * Update multiple Task instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[TaskUpdate]_): List of data to be used when updating
   * instances. Must be provided in the same order as the ids.
   */
  updateTaskBulk: Array<MutateResult>;
  /**
   * Update a single TaskReference instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_TaskReferenceUpdate_): Data to be used when updating an existing instance.
   */
  updateTaskReference: MutateResult;
  /**
   * Update multiple TaskReference instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[TaskReferenceUpdate]_): List of data to be used when
   * updating instances. Must be provided in the same order as the ids.
   */
  updateTaskReferenceBulk: Array<MutateResult>;
  /**
   * Update a single TaskRelationship instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_TaskRelationshipUpdate_): Data to be used when updating an existing instance.
   */
  updateTaskRelationship: MutateResult;
  /**
   * Update multiple TaskRelationship instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[TaskRelationshipUpdate]_): List of data to be used when
   * updating instances. Must be provided in the same order as the ids.
   */
  updateTaskRelationshipBulk: Array<MutateResult>;
  /**
   * Update a single TaskTemplate instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_TaskTemplateUpdate_): Data to be used when updating an existing instance.
   */
  updateTaskTemplate: MutateResult;
  /**
   * Update multiple TaskTemplate instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[TaskTemplateUpdate]_): List of data to be used when
   * updating instances. Must be provided in the same order as the ids.
   */
  updateTaskTemplateBulk: Array<MutateResult>;
  /**
   * Update a single Technique instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_TechniqueUpdate_): Data to be used when updating an existing instance.
   */
  updateTechnique: MutateResult;
  /**
   * Update multiple Technique instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[TechniqueUpdate]_): List of data to be used when updating
   * instances. Must be provided in the same order as the ids.
   */
  updateTechniqueBulk: Array<MutateResult>;
  /**
   * Update a single TechniqueMitigationRelationship instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_TechniqueMitigationRelationshipUpdate_): Data to be used when updating an existing instance.
   */
  updateTechniqueMitigationRelationship: MutateResult;
  /**
   * Update multiple TechniqueMitigationRelationship instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[TechniqueMitigationRelationshipUpdate]_): List of data to
   * be used when updating instances. Must be provided in the same order as the ids.
   */
  updateTechniqueMitigationRelationshipBulk: Array<MutateResult>;
  /**
   * Update a single Tool instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_ToolUpdate_): Data to be used when updating an existing instance.
   */
  updateTool: MutateResult;
  /**
   * Update multiple Tool instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[ToolUpdate]_): List of data to be used when updating
   * instances. Must be provided in the same order as the ids.
   */
  updateToolBulk: Array<MutateResult>;
  /**
   * Update a single ToolProcedure instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_ToolProcedureUpdate_): Data to be used when updating an existing instance.
   */
  updateToolProcedure: MutateResult;
  /**
   * Update multiple ToolProcedure instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[ToolProcedureUpdate]_): List of data to be used when
   * updating instances. Must be provided in the same order as the ids.
   */
  updateToolProcedureBulk: Array<MutateResult>;
  /**
   * Update a single TTPGroup instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_TTPGroupUpdate_): Data to be used when updating an existing instance.
   */
  updateTtpGroup: MutateResult;
  /**
   * Update multiple TTPGroup instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[TTPGroupUpdate]_): List of data to be used when updating
   * instances. Must be provided in the same order as the ids.
   */
  updateTtpGroupBulk: Array<MutateResult>;
  /**
   * Update a single TTPLink instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_TTPLinkUpdate_): Data to be used when updating an existing instance.
   */
  updateTtpLink: MutateResult;
  /**
   * Update multiple TTPLink instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[TTPLinkUpdate]_): List of data to be used when updating
   * instances. Must be provided in the same order as the ids.
   */
  updateTtpLinkBulk: Array<MutateResult>;
  /**
   * Update a single TTPMeta instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_TTPMetaUpdate_): Data to be used when updating an existing instance.
   */
  updateTtpMeta: MutateResult;
  /**
   * Update multiple TTPMeta instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[TTPMetaUpdate]_): List of data to be used when updating
   * instances. Must be provided in the same order as the ids.
   */
  updateTtpMetaBulk: Array<MutateResult>;
  /**
   * Update a single TTPPlatform instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_TTPPlatformUpdate_): Data to be used when updating an existing instance.
   */
  updateTtpPlatform: MutateResult;
  /**
   * Update multiple TTPPlatform instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[TTPPlatformUpdate]_): List of data to be used when updating
   * instances. Must be provided in the same order as the ids.
   */
  updateTtpPlatformBulk: Array<MutateResult>;
  /**
   * Update a single URL instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_URLUpdate_): Data to be used when updating an existing instance.
   */
  updateUrl: MutateResult;
  /**
   * Update multiple URL instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[URLUpdate]_): List of data to be used when updating
   * instances. Must be provided in the same order as the ids.
   */
  updateUrlBulk: Array<MutateResult>;
  /**
   * Update a single URLFragment instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_URLFragmentUpdate_): Data to be used when updating an existing instance.
   */
  updateUrlFragment: MutateResult;
  /**
   * Update multiple URLFragment instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[URLFragmentUpdate]_): List of data to be used when updating
   * instances. Must be provided in the same order as the ids.
   */
  updateUrlFragmentBulk: Array<MutateResult>;
  /**
   * Update a single URLInputOutput instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_URLInputOutputUpdate_): Data to be used when updating an existing instance.
   */
  updateUrlInputOutput: MutateResult;
  /**
   * Update multiple URLInputOutput instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[URLInputOutputUpdate]_): List of data to be used when
   * updating instances. Must be provided in the same order as the ids.
   */
  updateUrlInputOutputBulk: Array<MutateResult>;
  /**
   * Update a single URLPath instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_URLPathUpdate_): Data to be used when updating an existing instance.
   */
  updateUrlPath: MutateResult;
  /**
   * Update multiple URLPath instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[URLPathUpdate]_): List of data to be used when updating
   * instances. Must be provided in the same order as the ids.
   */
  updateUrlPathBulk: Array<MutateResult>;
  /**
   * Update a single URLQuery instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_URLQueryUpdate_): Data to be used when updating an existing instance.
   */
  updateUrlQuery: MutateResult;
  /**
   * Update multiple URLQuery instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[URLQueryUpdate]_): List of data to be used when updating
   * instances. Must be provided in the same order as the ids.
   */
  updateUrlQueryBulk: Array<MutateResult>;
  /**
   * Update a single URLQueryParam instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_URLQueryParamUpdate_): Data to be used when updating an existing instance.
   */
  updateUrlQueryParam: MutateResult;
  /**
   * Update multiple URLQueryParam instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[URLQueryParamUpdate]_): List of data to be used when
   * updating instances. Must be provided in the same order as the ids.
   */
  updateUrlQueryParamBulk: Array<MutateResult>;
  /**
   * Update a single UserIPAccountingModel instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_UserIPAccountingModelUpdate_): Data to be used when updating an existing instance.
   */
  updateUserIpAccountingModel: MutateResult;
  /**
   * Update multiple UserIPAccountingModel instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[UserIPAccountingModelUpdate]_): List of data to be used
   * when updating instances. Must be provided in the same order as the ids.
   */
  updateUserIpAccountingModelBulk: Array<MutateResult>;
  /**
   * Update a single Workflow instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_WorkflowUpdate_): Data to be used when updating an existing instance.
   */
  updateWorkflow: MutateResult;
  /**
   * Update multiple Workflow instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[WorkflowUpdate]_): List of data to be used when updating
   * instances. Must be provided in the same order as the ids.
   */
  updateWorkflowBulk: Array<MutateResult>;
  /**
   * Update a single WorkflowTemplate instance with the input data.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the instance to update.
   * - **data** (_WorkflowTemplateUpdate_): Data to be used when updating an existing instance.
   */
  updateWorkflowTemplate: MutateResult;
  /**
   * Update multiple WorkflowTemplate instances with the input data.
   *
   * Arguments:
   * - **ids** (_[ID!]!_): List of identifier of instances to update.
   * - **data_list** (_[WorkflowTemplateUpdate]_): List of data to be used when
   * updating instances. Must be provided in the same order as the ids.
   */
  updateWorkflowTemplateBulk: Array<MutateResult>;
  uploadTaskTemplate: MutationResult;
  uploadWorkflowTemplate: MutationResult;
};

export type MutationAddAssetArgs = {
  simpleAsset?: InputMaybe<SimpleAssetInput>;
};

export type MutationAddAssetToTaskArgs = {
  asset: AssetInput;
  task: TaskInput;
};

export type MutationAddAssetToTaskBulkArgs = {
  assets: Array<AssetInput>;
  task: TaskInput;
};

export type MutationAddAssetsArgs = {
  simpleAssets?: InputMaybe<Array<InputMaybe<SimpleAssetInput>>>;
};

export type MutationAddCveArgs = {
  cveItem?: InputMaybe<DefCveItemInput>;
};

export type MutationAddCvesArgs = {
  cveItems?: InputMaybe<Array<InputMaybe<DefCveItemInput>>>;
};

export type MutationAddObservableToTaskArgs = {
  observable: ObservableInput;
  task: TaskInput;
};

export type MutationAddObservableToTaskBulkArgs = {
  observables: Array<ObservableInput>;
  task: TaskInput;
};

export type MutationAddRelatedUsersToTaskArgs = {
  task: TaskInput;
  users: Array<Scalars['ID']>;
};

export type MutationAddTtpToTaskArgs = {
  task: TaskInput;
  ttp: TtpInput;
};

export type MutationAddTtpToTaskBulkArgs = {
  task: TaskInput;
  ttps: Array<TtpInput>;
};

export type MutationCreateAliasArgs = {
  data: AliasCreate;
};

export type MutationCreateAliasBulkArgs = {
  dataList: Array<AliasCreate>;
};

export type MutationCreateBaseHashableObservableArgs = {
  data: BaseHashableObservableCreate;
};

export type MutationCreateBaseHashableObservableBulkArgs = {
  dataList: Array<BaseHashableObservableCreate>;
};

export type MutationCreateBaseHostArgs = {
  data: BaseHostCreate;
};

export type MutationCreateBaseHostBulkArgs = {
  dataList: Array<BaseHostCreate>;
};

export type MutationCreateBaseObservableArgs = {
  data: BaseObservableCreate;
};

export type MutationCreateBaseObservableBulkArgs = {
  dataList: Array<BaseObservableCreate>;
};

export type MutationCreateBaseTaskInputOutputArgs = {
  data: BaseTaskInputOutputCreate;
};

export type MutationCreateBaseTaskInputOutputBulkArgs = {
  dataList: Array<BaseTaskInputOutputCreate>;
};

export type MutationCreateBoolInputOutputArgs = {
  data: BoolInputOutputCreate;
};

export type MutationCreateBoolInputOutputBulkArgs = {
  dataList: Array<BoolInputOutputCreate>;
};

export type MutationCreateCaseArgs = {
  data: CaseCreate;
};

export type MutationCreateCaseBulkArgs = {
  dataList: Array<CaseCreate>;
};

export type MutationCreateCaseDbRoleArgs = {
  data: CaseDbRoleCreate;
};

export type MutationCreateCaseDbRoleBulkArgs = {
  dataList: Array<CaseDbRoleCreate>;
};

export type MutationCreateCaseDbUserArgs = {
  data: CaseDbUserCreate;
};

export type MutationCreateCaseDbUserBulkArgs = {
  dataList: Array<CaseDbUserCreate>;
};

export type MutationCreateCaseFileItemBaseArgs = {
  data: CaseFileItemBaseCreate;
};

export type MutationCreateCaseFileItemBaseBulkArgs = {
  dataList: Array<CaseFileItemBaseCreate>;
};

export type MutationCreateCaseManagementExternalReferenceArgs = {
  data: CaseManagementExternalReferenceCreate;
};

export type MutationCreateCaseManagementExternalReferenceBulkArgs = {
  dataList: Array<CaseManagementExternalReferenceCreate>;
};

export type MutationCreateCaseRelationshipArgs = {
  data: CaseRelationshipCreate;
};

export type MutationCreateCaseRelationshipBulkArgs = {
  dataList: Array<CaseRelationshipCreate>;
};

export type MutationCreateCommentArgs = {
  data: CommentCreate;
};

export type MutationCreateCommentBulkArgs = {
  dataList: Array<CommentCreate>;
};

export type MutationCreateCtiEntryArgs = {
  data: CtiEntryCreate;
};

export type MutationCreateCtiEntryBulkArgs = {
  dataList: Array<CtiEntryCreate>;
};

export type MutationCreateDataPlatformServiceIpFixArgs = {
  data: DataPlatformServiceIpFixCreate;
};

export type MutationCreateDataPlatformServiceIpFixBulkArgs = {
  dataList: Array<DataPlatformServiceIpFixCreate>;
};

export type MutationCreateDataSourceArgs = {
  data: DataSourceCreate;
};

export type MutationCreateDataSourceBulkArgs = {
  dataList: Array<DataSourceCreate>;
};

export type MutationCreateDateInputOutputArgs = {
  data: DateInputOutputCreate;
};

export type MutationCreateDateInputOutputBulkArgs = {
  dataList: Array<DateInputOutputCreate>;
};

export type MutationCreateDateTimeInputOutputArgs = {
  data: DateTimeInputOutputCreate;
};

export type MutationCreateDateTimeInputOutputBulkArgs = {
  dataList: Array<DateTimeInputOutputCreate>;
};

export type MutationCreateDirectoryArgs = {
  data: DirectoryCreate;
};

export type MutationCreateDirectoryBulkArgs = {
  dataList: Array<DirectoryCreate>;
};

export type MutationCreateDomainInputOutputArgs = {
  data: DomainInputOutputCreate;
};

export type MutationCreateDomainInputOutputBulkArgs = {
  dataList: Array<DomainInputOutputCreate>;
};

export type MutationCreateDomainNameArgs = {
  data: DomainNameCreate;
};

export type MutationCreateDomainNameBulkArgs = {
  dataList: Array<DomainNameCreate>;
};

export type MutationCreateDomainToDomainResolutionArgs = {
  data: DomainToDomainResolutionCreate;
};

export type MutationCreateDomainToDomainResolutionBulkArgs = {
  dataList: Array<DomainToDomainResolutionCreate>;
};

export type MutationCreateDomainToIpAddressResolutionArgs = {
  data: DomainToIpAddressResolutionCreate;
};

export type MutationCreateDomainToIpAddressResolutionBulkArgs = {
  dataList: Array<DomainToIpAddressResolutionCreate>;
};

export type MutationCreateEmailAddressArgs = {
  data: EmailAddressCreate;
};

export type MutationCreateEmailAddressBulkArgs = {
  dataList: Array<EmailAddressCreate>;
};

export type MutationCreateEmailAddressInputOutputArgs = {
  data: EmailAddressInputOutputCreate;
};

export type MutationCreateEmailAddressInputOutputBulkArgs = {
  dataList: Array<EmailAddressInputOutputCreate>;
};

export type MutationCreateEmailHeaderArgs = {
  data: EmailHeaderCreate;
};

export type MutationCreateEmailHeaderBulkArgs = {
  dataList: Array<EmailHeaderCreate>;
};

export type MutationCreateEmailMessageArgs = {
  data: EmailMessageCreate;
};

export type MutationCreateEmailMessageBulkArgs = {
  dataList: Array<EmailMessageCreate>;
};

export type MutationCreateEmailMessageEmailAddressRelationshipArgs = {
  data: EmailMessageEmailAddressRelationshipCreate;
};

export type MutationCreateEmailMessageEmailAddressRelationshipBulkArgs = {
  dataList: Array<EmailMessageEmailAddressRelationshipCreate>;
};

export type MutationCreateEmailMessageInputOutputArgs = {
  data: EmailMessageInputOutputCreate;
};

export type MutationCreateEmailMessageInputOutputBulkArgs = {
  dataList: Array<EmailMessageInputOutputCreate>;
};

export type MutationCreateEmailMessagePartsRelationshipArgs = {
  data: EmailMessagePartsRelationshipCreate;
};

export type MutationCreateEmailMessagePartsRelationshipBulkArgs = {
  dataList: Array<EmailMessagePartsRelationshipCreate>;
};

export type MutationCreateEntryTypeArgs = {
  data: EntryTypeCreate;
};

export type MutationCreateEntryTypeBulkArgs = {
  dataList: Array<EntryTypeCreate>;
};

export type MutationCreateExternalReferenceArgs = {
  data: ExternalReferenceCreate;
};

export type MutationCreateExternalReferenceBulkArgs = {
  dataList: Array<ExternalReferenceCreate>;
};

export type MutationCreateFileArgs = {
  data: FileCreate;
};

export type MutationCreateFileBulkArgs = {
  dataList: Array<FileCreate>;
};

export type MutationCreateFileFromCommentInCaseArgs = {
  caseId: Scalars['ID'];
  data: FileCreateComment;
};

export type MutationCreateFileFromCommentInTaskArgs = {
  data: FileCreateComment;
  taskId: Scalars['ID'];
};

export type MutationCreateFileInputOutputArgs = {
  data: FileInputOutputCreate;
};

export type MutationCreateFileInputOutputBulkArgs = {
  dataList: Array<FileInputOutputCreate>;
};

export type MutationCreateFileRefArgs = {
  data: FileRefCreate;
};

export type MutationCreateFileRefInputOutputArgs = {
  data: FileRefInputOutputCreate;
};

export type MutationCreateFileRefInputOutputBulkArgs = {
  dataList: Array<FileRefInputOutputCreate>;
};

export type MutationCreateFileReferenceArgs = {
  data: FileReferenceCreate;
};

export type MutationCreateFileReferenceBulkArgs = {
  dataList: Array<FileReferenceCreate>;
};

export type MutationCreateFlowEventArgs = {
  data: FlowEventCreate;
};

export type MutationCreateFlowEventBulkArgs = {
  dataList: Array<FlowEventCreate>;
};

export type MutationCreateFlowEventDataArgs = {
  data: FlowEventDataCreate;
};

export type MutationCreateFlowEventDataBulkArgs = {
  dataList: Array<FlowEventDataCreate>;
};

export type MutationCreateGroupProcedureArgs = {
  data: GroupProcedureCreate;
};

export type MutationCreateGroupProcedureBulkArgs = {
  dataList: Array<GroupProcedureCreate>;
};

export type MutationCreateHashArgs = {
  data: HashCreate;
};

export type MutationCreateHashBulkArgs = {
  dataList: Array<HashCreate>;
};

export type MutationCreateHashInputOutputArgs = {
  data: HashInputOutputCreate;
};

export type MutationCreateHashInputOutputBulkArgs = {
  dataList: Array<HashInputOutputCreate>;
};

export type MutationCreateIpAddressArgs = {
  data: IpAddressCreate;
};

export type MutationCreateIpAddressBulkArgs = {
  dataList: Array<IpAddressCreate>;
};

export type MutationCreateIpAddressToDomainResolutionArgs = {
  data: IpAddressToDomainResolutionCreate;
};

export type MutationCreateIpAddressToDomainResolutionBulkArgs = {
  dataList: Array<IpAddressToDomainResolutionCreate>;
};

export type MutationCreateIpInputOutputArgs = {
  data: IpInputOutputCreate;
};

export type MutationCreateIpInputOutputBulkArgs = {
  dataList: Array<IpInputOutputCreate>;
};

export type MutationCreateJsonInputOutputArgs = {
  data: JsonInputOutputCreate;
};

export type MutationCreateJsonInputOutputBulkArgs = {
  dataList: Array<JsonInputOutputCreate>;
};

export type MutationCreateLabelArgs = {
  data: LabelCreate;
};

export type MutationCreateLabelBulkArgs = {
  dataList: Array<LabelCreate>;
};

export type MutationCreateMalwareArgs = {
  data: MalwareCreate;
};

export type MutationCreateMalwareBulkArgs = {
  dataList: Array<MalwareCreate>;
};

export type MutationCreateMalwareProcedureArgs = {
  data: MalwareProcedureCreate;
};

export type MutationCreateMalwareProcedureBulkArgs = {
  dataList: Array<MalwareProcedureCreate>;
};

export type MutationCreateMitigationArgs = {
  data: MitigationCreate;
};

export type MutationCreateMitigationBulkArgs = {
  dataList: Array<MitigationCreate>;
};

export type MutationCreateObservableLinkArgs = {
  data: ObservableLinkCreate;
};

export type MutationCreateObservableLinkBulkArgs = {
  dataList: Array<ObservableLinkCreate>;
};

export type MutationCreateSourceSpecifierArgs = {
  data: SourceSpecifierCreate;
};

export type MutationCreateSourceSpecifierBulkArgs = {
  dataList: Array<SourceSpecifierCreate>;
};

export type MutationCreateStageArgs = {
  data: StageCreate;
};

export type MutationCreateStageBulkArgs = {
  dataList: Array<StageCreate>;
};

export type MutationCreateStorageEventArgs = {
  data: StorageEventCreate;
};

export type MutationCreateStorageEventBulkArgs = {
  dataList: Array<StorageEventCreate>;
};

export type MutationCreateStringInputOutputArgs = {
  data: StringInputOutputCreate;
};

export type MutationCreateStringInputOutputBulkArgs = {
  dataList: Array<StringInputOutputCreate>;
};

export type MutationCreateSubtechniqueArgs = {
  data: TechniqueCreate;
};

export type MutationCreateSubtechniqueBulkArgs = {
  dataList: Array<TechniqueCreate>;
};

export type MutationCreateTacticArgs = {
  data: TacticCreate;
};

export type MutationCreateTacticBulkArgs = {
  dataList: Array<TacticCreate>;
};

export type MutationCreateTaskArgs = {
  inputFile?: InputMaybe<Scalars['Upload']>;
  task: TaskCreate;
};

export type MutationCreateTaskBulkArgs = {
  dataList: Array<TaskCreateBulk>;
};

export type MutationCreateTaskFromTemplateArgs = {
  stageId: Scalars['ID'];
  taskName?: InputMaybe<Scalars['String']>;
  taskTemplateId: Scalars['ID'];
};

export type MutationCreateTaskInputArgs = {
  description?: InputMaybe<Scalars['String']>;
  id: Scalars['ID'];
  inputFormat?: InputMaybe<Scalars['String']>;
  inputType: KnownInputOutputTypes;
};

export type MutationCreateTaskOutputArgs = {
  description?: InputMaybe<Scalars['String']>;
  id: Scalars['ID'];
  outputFormat?: InputMaybe<Scalars['String']>;
  outputType: KnownInputOutputTypes;
};

export type MutationCreateTaskParentlessArgs = {
  inputFile?: InputMaybe<Scalars['Upload']>;
  task: TaskCreateParentless;
};

export type MutationCreateTaskParentlessBulkArgs = {
  dataList: Array<TaskCreateParentlessBulk>;
};

export type MutationCreateTaskReferenceArgs = {
  data: TaskReferenceCreate;
};

export type MutationCreateTaskReferenceBulkArgs = {
  dataList: Array<TaskReferenceCreate>;
};

export type MutationCreateTaskRelationshipArgs = {
  data: TaskRelationshipCreate;
};

export type MutationCreateTaskRelationshipBulkArgs = {
  dataList: Array<TaskRelationshipCreate>;
};

export type MutationCreateTaskTemplateArgs = {
  data: TemplateCreate;
};

export type MutationCreateTaskTemplateBulkArgs = {
  dataList: Array<TemplateCreate>;
};

export type MutationCreateTechniqueArgs = {
  data: TechniqueCreate;
};

export type MutationCreateTechniqueBulkArgs = {
  dataList: Array<TechniqueCreate>;
};

export type MutationCreateTechniqueMitigationRelationshipArgs = {
  data: TechniqueMitigationRelationshipCreate;
};

export type MutationCreateTechniqueMitigationRelationshipBulkArgs = {
  dataList: Array<TechniqueMitigationRelationshipCreate>;
};

export type MutationCreateTemplateFromTaskArgs = {
  taskId: Scalars['ID'];
};

export type MutationCreateTemplateFromWorkflowArgs = {
  workflowId: Scalars['ID'];
};

export type MutationCreateToolArgs = {
  data: ToolCreate;
};

export type MutationCreateToolBulkArgs = {
  dataList: Array<ToolCreate>;
};

export type MutationCreateToolProcedureArgs = {
  data: ToolProcedureCreate;
};

export type MutationCreateToolProcedureBulkArgs = {
  dataList: Array<ToolProcedureCreate>;
};

export type MutationCreateTtpGroupArgs = {
  data: TtpGroupCreate;
};

export type MutationCreateTtpGroupBulkArgs = {
  dataList: Array<TtpGroupCreate>;
};

export type MutationCreateTtpLinkArgs = {
  data: TtpLinkCreate;
};

export type MutationCreateTtpLinkBulkArgs = {
  dataList: Array<TtpLinkCreate>;
};

export type MutationCreateTtpMetaArgs = {
  data: TtpMetaCreate;
};

export type MutationCreateTtpMetaBulkArgs = {
  dataList: Array<TtpMetaCreate>;
};

export type MutationCreateTtpPlatformArgs = {
  data: TtpPlatformCreate;
};

export type MutationCreateTtpPlatformBulkArgs = {
  dataList: Array<TtpPlatformCreate>;
};

export type MutationCreateUrlArgs = {
  data: UrlCreate;
};

export type MutationCreateUrlBulkArgs = {
  dataList: Array<UrlCreate>;
};

export type MutationCreateUrlFragmentArgs = {
  data: UrlFragmentCreate;
};

export type MutationCreateUrlFragmentBulkArgs = {
  dataList: Array<UrlFragmentCreate>;
};

export type MutationCreateUrlInputOutputArgs = {
  data: UrlInputOutputCreate;
};

export type MutationCreateUrlInputOutputBulkArgs = {
  dataList: Array<UrlInputOutputCreate>;
};

export type MutationCreateUrlPathArgs = {
  data: UrlPathCreate;
};

export type MutationCreateUrlPathBulkArgs = {
  dataList: Array<UrlPathCreate>;
};

export type MutationCreateUrlQueryArgs = {
  data: UrlQueryCreate;
};

export type MutationCreateUrlQueryBulkArgs = {
  dataList: Array<UrlQueryCreate>;
};

export type MutationCreateUrlQueryParamArgs = {
  data: UrlQueryParamCreate;
};

export type MutationCreateUrlQueryParamBulkArgs = {
  dataList: Array<UrlQueryParamCreate>;
};

export type MutationCreateUserIpAccountingModelArgs = {
  data: UserIpAccountingModelCreate;
};

export type MutationCreateUserIpAccountingModelBulkArgs = {
  dataList: Array<UserIpAccountingModelCreate>;
};

export type MutationCreateWorkflowArgs = {
  data: WorkflowCreate;
};

export type MutationCreateWorkflowBulkArgs = {
  dataList: Array<WorkflowCreate>;
};

export type MutationCreateWorkflowFromTemplateArgs = {
  caseId: Scalars['ID'];
  workflowName?: InputMaybe<Scalars['String']>;
  workflowTemplateId: Scalars['ID'];
};

export type MutationCreateWorkflowTemplateArgs = {
  data: TemplateCreate;
};

export type MutationCreateWorkflowTemplateBulkArgs = {
  dataList: Array<TemplateCreate>;
};

export type MutationDeleteAliasArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteAliasBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteBaseHashableObservableArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteBaseHashableObservableBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteBaseHostArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteBaseHostBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteBaseObservableArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteBaseObservableBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteBaseTaskInputOutputArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteBaseTaskInputOutputBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteBoolInputOutputArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteBoolInputOutputBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteCaseArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteCaseBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteCaseDbRoleArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteCaseDbRoleBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteCaseDbUserArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteCaseDbUserBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteCaseFileItemBaseArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteCaseFileItemBaseBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteCaseManagementExternalReferenceArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteCaseManagementExternalReferenceBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteCaseRelationshipArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteCaseRelationshipBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteCommentArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteCommentBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteCtiEntryArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteCtiEntryBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteDataPlatformServiceIpFixArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteDataPlatformServiceIpFixBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteDataSourceArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteDataSourceBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteDateInputOutputArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteDateInputOutputBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteDateTimeInputOutputArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteDateTimeInputOutputBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteDirectoryArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteDirectoryBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteDomainInputOutputArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteDomainInputOutputBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteDomainNameArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteDomainNameBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteDomainToDomainResolutionArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteDomainToDomainResolutionBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteDomainToIpAddressResolutionArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteDomainToIpAddressResolutionBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteEmailAddressArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteEmailAddressBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteEmailAddressInputOutputArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteEmailAddressInputOutputBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteEmailHeaderArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteEmailHeaderBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteEmailMessageArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteEmailMessageBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteEmailMessageEmailAddressRelationshipArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteEmailMessageEmailAddressRelationshipBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteEmailMessageInputOutputArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteEmailMessageInputOutputBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteEmailMessagePartsRelationshipArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteEmailMessagePartsRelationshipBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteEntryTypeArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteEntryTypeBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteExternalReferenceArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteExternalReferenceBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteFileArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteFileBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteFileInputOutputArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteFileInputOutputBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteFileRefInputOutputArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteFileRefInputOutputBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteFileReferenceArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteFileReferenceBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteFlowEventArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteFlowEventBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteFlowEventDataArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteFlowEventDataBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteGroupProcedureArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteGroupProcedureBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteHashArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteHashBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteHashInputOutputArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteHashInputOutputBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteIpAddressArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteIpAddressBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteIpAddressToDomainResolutionArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteIpAddressToDomainResolutionBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteIpInputOutputArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteIpInputOutputBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteJsonInputOutputArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteJsonInputOutputBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteLabelArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteLabelBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteMalwareArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteMalwareBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteMalwareProcedureArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteMalwareProcedureBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteMitigationArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteMitigationBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteObservableLinkArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteObservableLinkBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteSourceSpecifierArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteSourceSpecifierBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteStageArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteStageBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteStorageEventArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteStorageEventBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteStringInputOutputArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteStringInputOutputBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteTacticArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteTacticBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteTaskArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteTaskBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteTaskReferenceArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteTaskReferenceBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteTaskRelationshipArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteTaskRelationshipBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteTaskTemplateArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteTaskTemplateBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteTechniqueArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteTechniqueBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteTechniqueMitigationRelationshipArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteTechniqueMitigationRelationshipBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteToolArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteToolBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteToolProcedureArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteToolProcedureBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteTtpGroupArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteTtpGroupBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteTtpLinkArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteTtpLinkBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteTtpMetaArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteTtpMetaBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteTtpPlatformArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteTtpPlatformBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteUrlArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteUrlBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteUrlFragmentArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteUrlFragmentBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteUrlInputOutputArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteUrlInputOutputBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteUrlPathArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteUrlPathBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteUrlQueryArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteUrlQueryBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteUrlQueryParamArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteUrlQueryParamBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteUserIpAccountingModelArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteUserIpAccountingModelBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteWorkflowArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteWorkflowBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationDeleteWorkflowTemplateArgs = {
  id: Scalars['ID'];
};

export type MutationDeleteWorkflowTemplateBulkArgs = {
  ids: Array<Scalars['ID']>;
};

export type MutationGetOrCreateCtiEntryArgs = {
  externalReference: Scalars['String'];
  observableId?: InputMaybe<Scalars['ID']>;
  rawData?: InputMaybe<Scalars['String']>;
  sourceSpecifierId: Scalars['ID'];
};

export type MutationGetOrCreateDataSourceArgs = {
  baseUrl: Scalars['String'];
  dataSourceType: Scalars['String'];
  description: Scalars['String'];
  name: Scalars['String'];
};

export type MutationGetOrCreateDomainNameArgs = {
  ctiEntries: Array<CtiEntryInput>;
  domainName: Scalars['String'];
};

export type MutationGetOrCreateDomainToDomainResolutionArgs = {
  ctiEntries: Array<CtiEntryInput>;
  firstSeen?: InputMaybe<Scalars['DateTime']>;
  lastSeen?: InputMaybe<Scalars['DateTime']>;
  resolvedDomain: Scalars['String'];
  sourceDomain: Scalars['String'];
};

export type MutationGetOrCreateDomainToIpResolutionArgs = {
  ctiEntries: Array<CtiEntryInput>;
  firstSeen?: InputMaybe<Scalars['DateTime']>;
  lastSeen?: InputMaybe<Scalars['DateTime']>;
  resolvedIp: Scalars['String'];
  sourceDomain: Scalars['String'];
};

export type MutationGetOrCreateEmailAddressArgs = {
  ctiEntries: Array<CtiEntryInput>;
  emailAddress: Scalars['String'];
};

export type MutationGetOrCreateEmailMessageArgs = {
  addresses: Array<EmailAddressInput>;
  attachments?: InputMaybe<Array<FileInput>>;
  body?: InputMaybe<Scalars['String']>;
  ctiEntries: Array<CtiEntryInput>;
  hashes: Array<HashInput>;
  headers: Array<HeaderInput>;
  reference: Scalars['String'];
  subject: Scalars['String'];
};

export type MutationGetOrCreateEntryTypeArgs = {
  description?: InputMaybe<Scalars['String']>;
  name: Scalars['String'];
};

export type MutationGetOrCreateFileReferenceArgs = {
  ctiEntries: Array<CtiEntryInput>;
  description?: InputMaybe<Scalars['String']>;
  hashes: Array<HashInput>;
  name: Scalars['String'];
  reference: Scalars['String'];
};

export type MutationGetOrCreateIpAddressArgs = {
  ctiEntries: Array<CtiEntryInput>;
  ip: Scalars['String'];
};

export type MutationGetOrCreateIpToDomainResolutionArgs = {
  ctiEntries: Array<CtiEntryInput>;
  firstSeen?: InputMaybe<Scalars['DateTime']>;
  lastSeen?: InputMaybe<Scalars['DateTime']>;
  resolvedDomain: Scalars['String'];
  sourceIp: Scalars['String'];
};

export type MutationGetOrCreateSourceSpecifierArgs = {
  dataSourceId: Scalars['ID'];
  entryTypeId: Scalars['ID'];
  sourceUuid?: InputMaybe<Scalars['String']>;
};

export type MutationGetOrCreateTtpMetaArgs = {
  description?: InputMaybe<Scalars['String']>;
  ttpId: Scalars['String'];
};

export type MutationGetOrCreateUrlArgs = {
  ctiEntries: Array<CtiEntryInput>;
  url: Scalars['String'];
};

export type MutationRejectCaseArgs = {
  caseId: Scalars['ID'];
};

export type MutationRejectStageArgs = {
  stageId: Scalars['ID'];
};

export type MutationRejectTaskArgs = {
  taskId: Scalars['ID'];
};

export type MutationRejectWorkflowArgs = {
  workflowId: Scalars['ID'];
};

export type MutationRemoveAssetArgs = {
  assetUID?: InputMaybe<Scalars['String']>;
};

export type MutationRemoveCveArgs = {
  cveUID?: InputMaybe<Scalars['String']>;
};

export type MutationResolveCaseArgs = {
  caseId: Scalars['ID'];
};

export type MutationResolveTaskArgs = {
  taskId: Scalars['ID'];
};

export type MutationResolveTaskWithDecisionArgs = {
  decision: Scalars['Boolean'];
  taskId: Scalars['ID'];
};

export type MutationSetTaskFileInputArgs = {
  fileInput: Scalars['Upload'];
  id: Scalars['ID'];
};

export type MutationSetTaskFileOutputArgs = {
  fileOutput: Scalars['Upload'];
  id: Scalars['ID'];
};

export type MutationSetTaskInputArgs = {
  id: Scalars['ID'];
  input: Scalars['String'];
};

export type MutationSetTaskOutputArgs = {
  id: Scalars['ID'];
  output: Scalars['String'];
};

export type MutationSkipTaskArgs = {
  taskId: Scalars['ID'];
};

export type MutationTriggerTaskArgs = {
  taskId: Scalars['ID'];
};

export type MutationUpdateAliasArgs = {
  data: AliasUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateAliasBulkArgs = {
  data: AliasUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateBaseHashableObservableArgs = {
  data: BaseHashableObservableUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateBaseHashableObservableBulkArgs = {
  data: BaseHashableObservableUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateBaseHostArgs = {
  data: BaseHostUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateBaseHostBulkArgs = {
  data: BaseHostUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateBaseObservableArgs = {
  data: BaseObservableUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateBaseObservableBulkArgs = {
  data: BaseObservableUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateBaseTaskInputOutputArgs = {
  data: BaseTaskInputOutputUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateBaseTaskInputOutputBulkArgs = {
  data: BaseTaskInputOutputUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateBoolInputOutputArgs = {
  data: BoolInputOutputUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateBoolInputOutputBulkArgs = {
  data: BoolInputOutputUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateCaseArgs = {
  data: CaseUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateCaseBulkArgs = {
  data: CaseUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateCaseDbRoleArgs = {
  data: CaseDbRoleUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateCaseDbRoleBulkArgs = {
  data: CaseDbRoleUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateCaseDbUserArgs = {
  data: CaseDbUserUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateCaseDbUserBulkArgs = {
  data: CaseDbUserUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateCaseFileItemBaseArgs = {
  data: CaseFileItemBaseUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateCaseFileItemBaseBulkArgs = {
  data: CaseFileItemBaseUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateCaseManagementExternalReferenceArgs = {
  data: CaseManagementExternalReferenceUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateCaseManagementExternalReferenceBulkArgs = {
  data: CaseManagementExternalReferenceUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateCaseRelationshipArgs = {
  data: CaseRelationshipUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateCaseRelationshipBulkArgs = {
  data: CaseRelationshipUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateCommentArgs = {
  data: CommentUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateCommentBulkArgs = {
  data: CommentUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateCtiEntryArgs = {
  data: CtiEntryUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateCtiEntryBulkArgs = {
  data: CtiEntryUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateDataPlatformServiceIpFixArgs = {
  data: DataPlatformServiceIpFixUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateDataPlatformServiceIpFixBulkArgs = {
  data: DataPlatformServiceIpFixUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateDataSourceArgs = {
  data: DataSourceUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateDataSourceBulkArgs = {
  data: DataSourceUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateDateInputOutputArgs = {
  data: DateInputOutputUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateDateInputOutputBulkArgs = {
  data: DateInputOutputUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateDateTimeInputOutputArgs = {
  data: DateTimeInputOutputUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateDateTimeInputOutputBulkArgs = {
  data: DateTimeInputOutputUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateDirectoryArgs = {
  data: DirectoryUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateDirectoryBulkArgs = {
  data: DirectoryUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateDomainInputOutputArgs = {
  data: DomainInputOutputUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateDomainInputOutputBulkArgs = {
  data: DomainInputOutputUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateDomainNameArgs = {
  data: DomainNameUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateDomainNameBulkArgs = {
  data: DomainNameUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateDomainToDomainResolutionArgs = {
  data: DomainToDomainResolutionUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateDomainToDomainResolutionBulkArgs = {
  data: DomainToDomainResolutionUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateDomainToIpAddressResolutionArgs = {
  data: DomainToIpAddressResolutionUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateDomainToIpAddressResolutionBulkArgs = {
  data: DomainToIpAddressResolutionUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateEmailAddressArgs = {
  data: EmailAddressUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateEmailAddressBulkArgs = {
  data: EmailAddressUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateEmailAddressInputOutputArgs = {
  data: EmailAddressInputOutputUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateEmailAddressInputOutputBulkArgs = {
  data: EmailAddressInputOutputUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateEmailHeaderArgs = {
  data: EmailHeaderUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateEmailHeaderBulkArgs = {
  data: EmailHeaderUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateEmailMessageArgs = {
  data: EmailMessageUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateEmailMessageBulkArgs = {
  data: EmailMessageUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateEmailMessageEmailAddressRelationshipArgs = {
  data: EmailMessageEmailAddressRelationshipUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateEmailMessageEmailAddressRelationshipBulkArgs = {
  data: EmailMessageEmailAddressRelationshipUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateEmailMessageInputOutputArgs = {
  data: EmailMessageInputOutputUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateEmailMessageInputOutputBulkArgs = {
  data: EmailMessageInputOutputUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateEmailMessagePartsRelationshipArgs = {
  data: EmailMessagePartsRelationshipUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateEmailMessagePartsRelationshipBulkArgs = {
  data: EmailMessagePartsRelationshipUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateEntryTypeArgs = {
  data: EntryTypeUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateEntryTypeBulkArgs = {
  data: EntryTypeUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateExternalReferenceArgs = {
  data: ExternalReferenceUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateExternalReferenceBulkArgs = {
  data: ExternalReferenceUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateFileArgs = {
  data: FileUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateFileBulkArgs = {
  data: FileUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateFileInputOutputArgs = {
  data: FileInputOutputUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateFileInputOutputBulkArgs = {
  data: FileInputOutputUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateFileRefInputOutputArgs = {
  data: FileRefInputOutputUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateFileRefInputOutputBulkArgs = {
  data: FileRefInputOutputUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateFileReferenceArgs = {
  data: FileReferenceUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateFileReferenceBulkArgs = {
  data: FileReferenceUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateFlowEventArgs = {
  data: FlowEventUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateFlowEventBulkArgs = {
  data: FlowEventUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateFlowEventDataArgs = {
  data: FlowEventDataUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateFlowEventDataBulkArgs = {
  data: FlowEventDataUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateGroupProcedureArgs = {
  data: GroupProcedureUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateGroupProcedureBulkArgs = {
  data: GroupProcedureUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateHashArgs = {
  data: HashUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateHashBulkArgs = {
  data: HashUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateHashInputOutputArgs = {
  data: HashInputOutputUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateHashInputOutputBulkArgs = {
  data: HashInputOutputUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateIpAddressArgs = {
  data: IpAddressUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateIpAddressBulkArgs = {
  data: IpAddressUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateIpAddressToDomainResolutionArgs = {
  data: IpAddressToDomainResolutionUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateIpAddressToDomainResolutionBulkArgs = {
  data: IpAddressToDomainResolutionUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateIpInputOutputArgs = {
  data: IpInputOutputUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateIpInputOutputBulkArgs = {
  data: IpInputOutputUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateJsonInputOutputArgs = {
  data: JsonInputOutputUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateJsonInputOutputBulkArgs = {
  data: JsonInputOutputUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateLabelArgs = {
  data: LabelUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateLabelBulkArgs = {
  data: LabelUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateMalwareArgs = {
  data: MalwareUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateMalwareBulkArgs = {
  data: MalwareUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateMalwareProcedureArgs = {
  data: MalwareProcedureUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateMalwareProcedureBulkArgs = {
  data: MalwareProcedureUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateMitigationArgs = {
  data: MitigationUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateMitigationBulkArgs = {
  data: MitigationUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateObservableLinkArgs = {
  data: ObservableLinkUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateObservableLinkBulkArgs = {
  data: ObservableLinkUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateOutputFromBlockingTasksArgs = {
  id: Scalars['ID'];
};

export type MutationUpdateSourceSpecifierArgs = {
  data: SourceSpecifierUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateSourceSpecifierBulkArgs = {
  data: SourceSpecifierUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateStageArgs = {
  data: StageUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateStageBulkArgs = {
  data: StageUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateStorageEventArgs = {
  data: StorageEventUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateStorageEventBulkArgs = {
  data: StorageEventUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateStringInputOutputArgs = {
  data: StringInputOutputUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateStringInputOutputBulkArgs = {
  data: StringInputOutputUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateTacticArgs = {
  data: TacticUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateTacticBulkArgs = {
  data: TacticUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateTaskArgs = {
  data: TaskUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateTaskBulkArgs = {
  data: TaskUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateTaskReferenceArgs = {
  data: TaskReferenceUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateTaskReferenceBulkArgs = {
  data: TaskReferenceUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateTaskRelationshipArgs = {
  data: TaskRelationshipUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateTaskRelationshipBulkArgs = {
  data: TaskRelationshipUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateTaskTemplateArgs = {
  data: TaskTemplateUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateTaskTemplateBulkArgs = {
  data: TaskTemplateUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateTechniqueArgs = {
  data: TechniqueUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateTechniqueBulkArgs = {
  data: TechniqueUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateTechniqueMitigationRelationshipArgs = {
  data: TechniqueMitigationRelationshipUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateTechniqueMitigationRelationshipBulkArgs = {
  data: TechniqueMitigationRelationshipUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateToolArgs = {
  data: ToolUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateToolBulkArgs = {
  data: ToolUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateToolProcedureArgs = {
  data: ToolProcedureUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateToolProcedureBulkArgs = {
  data: ToolProcedureUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateTtpGroupArgs = {
  data: TtpGroupUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateTtpGroupBulkArgs = {
  data: TtpGroupUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateTtpLinkArgs = {
  data: TtpLinkUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateTtpLinkBulkArgs = {
  data: TtpLinkUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateTtpMetaArgs = {
  data: TtpMetaUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateTtpMetaBulkArgs = {
  data: TtpMetaUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateTtpPlatformArgs = {
  data: TtpPlatformUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateTtpPlatformBulkArgs = {
  data: TtpPlatformUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateUrlArgs = {
  data: UrlUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateUrlBulkArgs = {
  data: UrlUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateUrlFragmentArgs = {
  data: UrlFragmentUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateUrlFragmentBulkArgs = {
  data: UrlFragmentUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateUrlInputOutputArgs = {
  data: UrlInputOutputUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateUrlInputOutputBulkArgs = {
  data: UrlInputOutputUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateUrlPathArgs = {
  data: UrlPathUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateUrlPathBulkArgs = {
  data: UrlPathUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateUrlQueryArgs = {
  data: UrlQueryUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateUrlQueryBulkArgs = {
  data: UrlQueryUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateUrlQueryParamArgs = {
  data: UrlQueryParamUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateUrlQueryParamBulkArgs = {
  data: UrlQueryParamUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateUserIpAccountingModelArgs = {
  data: UserIpAccountingModelUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateUserIpAccountingModelBulkArgs = {
  data: UserIpAccountingModelUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateWorkflowArgs = {
  data: WorkflowUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateWorkflowBulkArgs = {
  data: WorkflowUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUpdateWorkflowTemplateArgs = {
  data: WorkflowTemplateUpdate;
  id: Scalars['ID'];
};

export type MutationUpdateWorkflowTemplateBulkArgs = {
  data: WorkflowTemplateUpdate;
  ids: Array<Scalars['ID']>;
};

export type MutationUploadTaskTemplateArgs = {
  file: Scalars['Upload'];
};

export type MutationUploadWorkflowTemplateArgs = {
  file: Scalars['Upload'];
};

export type MutationResult = {
  __typename?: 'MutationResult';
  id?: Maybe<Scalars['Int']>;
};

export type MutationResultField = {
  __typename?: 'MutationResultField';
  field?: Maybe<Scalars['String']>;
};

export type NetFieldFilter = {
  family?: InputMaybe<Scalars['Int']>;
  host?: InputMaybe<Scalars['String']>;
  isnull?: InputMaybe<Scalars['Boolean']>;
  maxPrefixlen?: InputMaybe<Scalars['Int']>;
  minPrefixlen?: InputMaybe<Scalars['Int']>;
  netContained?: InputMaybe<Scalars['String']>;
  netContainedOrEqual?: InputMaybe<Scalars['String']>;
  netContains?: InputMaybe<Scalars['String']>;
  netContainsOrEquals?: InputMaybe<Scalars['String']>;
  netOverlaps?: InputMaybe<Scalars['String']>;
};

export type NodeInput = {
  cpeMatch?: InputMaybe<Array<InputMaybe<CpeMatchInput>>>;
  negate?: InputMaybe<Scalars['Boolean']>;
  operator?: InputMaybe<NodeOperator>;
};

export enum NodeOperator {
  AND = 'AND',
  OR = 'OR',
}

export type Observable = {
  ctiEntries?: Maybe<ObservableLinkNestedList>;
  description?: Maybe<Scalars['String']>;
  id: Scalars['ID'];
  observableType?: Maybe<Scalars['String']>;
  uniqueIdentifier: Scalars['String'];
};

export type ObservableCtiEntriesArgs = {
  filter?: InputMaybe<Array<ObservableLinkFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ObservableLinkOrdEnumOrderingEntry>>;
};

export type ObservableFederationBase = {
  cases: CaseFederationResult;
  description?: Maybe<Scalars['String']>;
  id: Scalars['ID'];
  observableType?: Maybe<Scalars['String']>;
  observableTypeEnum?: Maybe<KnownObservablesEnum>;
  tasks: TaskFederationResult;
};

export type ObservableFederationBaseCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type ObservableFederationBaseTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type ObservableFederationBaseFederationResult = {
  __typename?: 'ObservableFederationBaseFederationResult';
  data: Array<ObservableFederationBase>;
  error?: Maybe<Scalars['String']>;
};

export type ObservableFederationBaseFilter = {
  caseId?: InputMaybe<StrawberryIdFilter>;
  observableId?: InputMaybe<StrawberryIdFilter>;
  observableType?: InputMaybe<KnownObservablesEnumEnumFilter>;
  taskId?: InputMaybe<StrawberryIdFilter>;
};

export type ObservableFederationBaseFilterAndFilterEntry = {
  AND: Array<ObservableFederationBaseFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type ObservableFederationBaseFilterOrFilterEntry = {
  OR: Array<ObservableFederationBaseFilter>;
  negate?: Scalars['Boolean'];
};

export type ObservableFilter1 = {
  address?: InputMaybe<NetFieldFilter>;
  attachmentOf?: InputMaybe<EmailMessagePartsRelationshipFilter1>;
  body?: InputMaybe<StrFieldFilter>;
  ctiEntries?: InputMaybe<ObservableLinkFilter1>;
  description?: InputMaybe<StrFieldFilter>;
  domainName?: InputMaybe<StrFieldFilter>;
  domainResolvedFromIps?: InputMaybe<IpAddressToDomainResolutionFilter1>;
  domainResolvesToIps?: InputMaybe<DomainToIpAddressResolutionFilter1>;
  domainToDomainFirstSeen?: InputMaybe<DateTimeFieldFilter>;
  domainToDomainLastSeen?: InputMaybe<DateTimeFieldFilter>;
  domainToIpFirstSeen?: InputMaybe<DateTimeFieldFilter>;
  domainToIpLastSeen?: InputMaybe<DateTimeFieldFilter>;
  emailAddress?: InputMaybe<EmailAddressFilter1>;
  emailAddressHost?: InputMaybe<HostFilter1>;
  emailAddresses?: InputMaybe<EmailMessageEmailAddressRelationshipFilter1>;
  emailMessage?: InputMaybe<EmailMessageFilter1>;
  emailMessages?: InputMaybe<EmailMessageEmailAddressRelationshipFilter1>;
  emails?: InputMaybe<EmailAddressFilter1>;
  file?: InputMaybe<FileReferenceFilter1>;
  fragment?: InputMaybe<UrlFragmentFilter1>;
  hashes?: InputMaybe<HashFilter1>;
  headers?: InputMaybe<EmailHeaderFilter1>;
  host?: InputMaybe<HostFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  inHeader?: InputMaybe<StrFieldFilter>;
  ipResolvedFromDomains?: InputMaybe<DomainToIpAddressResolutionFilter1>;
  ipResolvesToDomains?: InputMaybe<IpAddressToDomainResolutionFilter1>;
  ipToDomainFirstSeen?: InputMaybe<DateTimeFieldFilter>;
  ipToDomainLastSeen?: InputMaybe<DateTimeFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
  observableType?: InputMaybe<StrFieldFilter>;
  originalDomain?: InputMaybe<DomainNameFilter1>;
  partType?: InputMaybe<StrFieldFilter>;
  parts?: InputMaybe<EmailMessagePartsRelationshipFilter1>;
  path?: InputMaybe<UrlPathFilter1>;
  port?: InputMaybe<IntFieldFilter>;
  protocol?: InputMaybe<StrFieldFilter>;
  query?: InputMaybe<UrlQueryFilter1>;
  rawEmailAddress?: InputMaybe<StrFieldFilter>;
  rawReference?: InputMaybe<StrFieldFilter>;
  rawUrl?: InputMaybe<StrFieldFilter>;
  reference?: InputMaybe<StrFieldFilter>;
  resolutionDomain?: InputMaybe<DomainNameFilter1>;
  resolvedDomain?: InputMaybe<DomainNameFilter1>;
  resolvedFromDomains?: InputMaybe<DomainToDomainResolutionFilter1>;
  resolvedIpAddress?: InputMaybe<IpAddressFilter1>;
  resolvesToDomains?: InputMaybe<DomainToDomainResolutionFilter1>;
  sourceDomain?: InputMaybe<DomainNameFilter1>;
  sourceEmailMessage?: InputMaybe<EmailMessageFilter1>;
  sourceIpAddress?: InputMaybe<IpAddressFilter1>;
  subject?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
  urls?: InputMaybe<UrlFilter1>;
  username?: InputMaybe<StrFieldFilter>;
};

export type ObservableFilter1AndFilterEntry = {
  AND: Array<ObservableFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type ObservableFilter1OrFilterEntry = {
  OR: ObservableFilter1;
  negate?: Scalars['Boolean'];
};

export type ObservableInput = {
  id: Scalars['ID'];
  observableType: KnownObservablesEnum;
};

export type ObservableLink = {
  __typename?: 'ObservableLink';
  ctiEntry?: Maybe<CtiEntry>;
  id: Scalars['ID'];
  observable?: Maybe<Observable>;
  observableLinkType?: Maybe<ObservableLinkTypeEnum>;
};

export type ObservableLinkCreate = {
  ctiEntry?: InputMaybe<Scalars['ID']>;
  observable?: InputMaybe<Scalars['ID']>;
  observableLinkType?: InputMaybe<ObservableLinkTypeEnum>;
};

export type ObservableLinkFilter0 = {
  id?: InputMaybe<StrawberryIdFieldFilter>;
  observableLinkType?: InputMaybe<ObservableLinkTypeEnumEnumFieldFilter>;
};

export type ObservableLinkFilter0AndFilterEntry = {
  AND: Array<ObservableLinkFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type ObservableLinkFilter0OrFilterEntry = {
  OR: ObservableLinkFilter0;
  negate?: Scalars['Boolean'];
};

export type ObservableLinkFilter1 = {
  ctiEntry?: InputMaybe<CtiEntryFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  observable?: InputMaybe<ObservableFilter1>;
  observableLinkType?: InputMaybe<ObservableLinkTypeEnumEnumFieldFilter>;
};

export type ObservableLinkFilter1AndFilterEntry = {
  AND: Array<ObservableLinkFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type ObservableLinkFilter1OrFilterEntry = {
  OR: ObservableLinkFilter1;
  negate?: Scalars['Boolean'];
};

export type ObservableLinkNestedList = {
  __typename?: 'ObservableLinkNestedList';
  data: Array<ObservableLink>;
  totalCount: Scalars['Int'];
};

export enum ObservableLinkOrdEnum {
  ID = 'ID',
  OBSERVABLE_LINK_TYPE = 'OBSERVABLE_LINK_TYPE',
}

export type ObservableLinkOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: ObservableLinkOrdEnum;
};

export type ObservableLinkPaginated = {
  __typename?: 'ObservableLinkPaginated';
  data: Array<ObservableLink>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export enum ObservableLinkTypeEnum {
  PRIMARY = 'PRIMARY',
  SECONDARY = 'SECONDARY',
}

export type ObservableLinkTypeEnumEnumFieldFilter = {
  exact?: InputMaybe<ObservableLinkTypeEnum>;
  except_?: InputMaybe<ObservableLinkTypeEnum>;
  in_?: InputMaybe<Array<ObservableLinkTypeEnum>>;
  isnull?: InputMaybe<Scalars['Boolean']>;
};

export type ObservableLinkUpdate = {
  ctiEntry?: InputMaybe<Scalars['ID']>;
  observable?: InputMaybe<Scalars['ID']>;
  observableLinkType?: InputMaybe<ObservableLinkTypeEnum>;
};

export enum ObservableOrdEnum {
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  OBSERVABLE_TYPE = 'OBSERVABLE_TYPE',
  UNIQUE_IDENTIFIER = 'UNIQUE_IDENTIFIER',
}

export type ObservableOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: ObservableOrdEnum;
};

export type ObservablePaginated = {
  __typename?: 'ObservablePaginated';
  data: Array<Observable>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type OrVertex = {
  __typename?: 'OrVertex';
  factRef?: Maybe<FactRefVertex>;
  negate?: Maybe<Scalars['Boolean']>;
};

export type PlatformFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  deviceCount?: InputMaybe<IntFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  manufacturer?: InputMaybe<ManufacturerFilter>;
  manufacturerId?: InputMaybe<StrawberryIdFilter>;
  name?: InputMaybe<StrFilter>;
  napalmArgs?: InputMaybe<StrFilter>;
  napalmDriver?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  slug?: InputMaybe<StrFilter>;
  uuid?: InputMaybe<StrFilter>;
  virtualmachineCount?: InputMaybe<IntFilter>;
};

export type PlatformFilterAndFilterEntry = {
  AND: Array<PlatformFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type PlatformFilterOrFilterEntry = {
  OR: Array<PlatformFilter>;
  negate?: Scalars['Boolean'];
};

export type PlatformType = AssetFederationBase &
  AssetType & {
    __typename?: 'PlatformType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    deviceCount?: Maybe<Scalars['Int']>;
    devices: DeviceTypeResultSet;
    id: Scalars['ID'];
    lastUpdated?: Maybe<Scalars['DateTime']>;
    manufacturer?: Maybe<ManufacturerType>;
    manufacturerId?: Maybe<Scalars['ID']>;
    name?: Maybe<Scalars['String']>;
    napalmArgs?: Maybe<Scalars['String']>;
    napalmDriver?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    slug?: Maybe<Scalars['String']>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
    virtualMachines: VirtualMachineTypeResultSet;
    virtualmachineCount?: Maybe<Scalars['Int']>;
  };

export type PlatformTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type PlatformTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type PlatformTypeResultSet = {
  __typename?: 'PlatformTypeResultSet';
  data: Array<PlatformType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type PowerFeedFilter = {
  Name?: InputMaybe<StrFilter>;
  amperage?: InputMaybe<IntFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  cable?: InputMaybe<CableFilter>;
  cableId?: InputMaybe<StrawberryIdFilter>;
  comments?: InputMaybe<StrFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  markConnected?: InputMaybe<BoolFilter>;
  maxUtilization?: InputMaybe<IntFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  phase?: InputMaybe<DcimPowerFeedPhaseChoicesEnumFilter>;
  powerPanel?: InputMaybe<PowerPanelFilter>;
  powerPanelId?: InputMaybe<StrawberryIdFilter>;
  rack?: InputMaybe<RackFilter>;
  rackId?: InputMaybe<StrawberryIdFilter>;
  status?: InputMaybe<DcimPowerFeedStatusChoicesEnumFilter>;
  supply?: InputMaybe<DcimPowerFeedSupplyChoicesEnumFilter>;
  type?: InputMaybe<DcimPowerFeedTypeChoicesEnumFilter>;
  uuid?: InputMaybe<StrFilter>;
  voltage?: InputMaybe<IntFilter>;
};

export type PowerFeedFilterAndFilterEntry = {
  AND: Array<PowerFeedFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type PowerFeedFilterOrFilterEntry = {
  OR: Array<PowerFeedFilter>;
  negate?: Scalars['Boolean'];
};

export type PowerFeedType = AssetFederationBase &
  AssetType & {
    __typename?: 'PowerFeedType';
    Name?: Maybe<Scalars['String']>;
    amperage?: Maybe<Scalars['Int']>;
    assetType: KnownAssetsEnum;
    cable?: Maybe<CableType>;
    cableId?: Maybe<Scalars['ID']>;
    cases: CaseFederationResult;
    comments?: Maybe<Scalars['String']>;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    id: Scalars['ID'];
    lastUpdated?: Maybe<Scalars['DateTime']>;
    markConnected?: Maybe<Scalars['Boolean']>;
    maxUtilization?: Maybe<Scalars['Int']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    phase?: Maybe<DcimPowerFeedPhaseChoices>;
    powerPanel?: Maybe<PowerPanelType>;
    powerPanelId?: Maybe<Scalars['ID']>;
    rack?: Maybe<RackType>;
    rackId?: Maybe<Scalars['ID']>;
    status?: Maybe<DcimPowerFeedStatusChoices>;
    supply?: Maybe<DcimPowerFeedSupplyChoices>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    type?: Maybe<DcimPowerFeedTypeChoices>;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
    voltage?: Maybe<Scalars['Int']>;
  };

export type PowerFeedTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type PowerFeedTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type PowerFeedTypeResultSet = {
  __typename?: 'PowerFeedTypeResultSet';
  data: Array<PowerFeedType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type PowerOutletFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  cable?: InputMaybe<CableFilter>;
  cableId?: InputMaybe<StrawberryIdFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  device?: InputMaybe<DeviceFilter>;
  deviceId?: InputMaybe<StrawberryIdFilter>;
  feedLeg?: InputMaybe<DcimPowerOutletFeedLegChoicesEnumFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  label?: InputMaybe<StrFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  markConnected?: InputMaybe<BoolFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  powerPort?: InputMaybe<PowerPortFilter>;
  powerPortId?: InputMaybe<StrawberryIdFilter>;
  type?: InputMaybe<DcimPowerOutletTypeChoicesEnumFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type PowerOutletFilterAndFilterEntry = {
  AND: Array<PowerOutletFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type PowerOutletFilterOrFilterEntry = {
  OR: Array<PowerOutletFilter>;
  negate?: Scalars['Boolean'];
};

export type PowerOutletType = AssetFederationBase &
  AssetType & {
    __typename?: 'PowerOutletType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cable?: Maybe<CableType>;
    cableId?: Maybe<Scalars['ID']>;
    cases: CaseFederationResult;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    device?: Maybe<DeviceType>;
    deviceId?: Maybe<Scalars['ID']>;
    feedLeg?: Maybe<DcimPowerOutletFeedLegChoices>;
    id: Scalars['ID'];
    label?: Maybe<Scalars['String']>;
    lastUpdated?: Maybe<Scalars['DateTime']>;
    markConnected?: Maybe<Scalars['Boolean']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    powerPort?: Maybe<PowerPortType>;
    powerPortId?: Maybe<Scalars['ID']>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    type?: Maybe<DcimPowerOutletTypeChoices>;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
  };

export type PowerOutletTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type PowerOutletTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type PowerOutletTypeResultSet = {
  __typename?: 'PowerOutletTypeResultSet';
  data: Array<PowerOutletType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type PowerPanelFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  location?: InputMaybe<LocationFilter>;
  locationId?: InputMaybe<StrawberryIdFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  powerfeedCount?: InputMaybe<IntFilter>;
  site?: InputMaybe<SiteFilter>;
  siteId?: InputMaybe<StrawberryIdFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type PowerPanelFilterAndFilterEntry = {
  AND: Array<PowerPanelFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type PowerPanelFilterOrFilterEntry = {
  OR: Array<PowerPanelFilter>;
  negate?: Scalars['Boolean'];
};

export type PowerPanelType = AssetFederationBase &
  AssetType & {
    __typename?: 'PowerPanelType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    id: Scalars['ID'];
    lastUpdated?: Maybe<Scalars['DateTime']>;
    location?: Maybe<LocationType>;
    locationId?: Maybe<Scalars['ID']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    powerFeeds: PowerFeedTypeResultSet;
    powerfeedCount?: Maybe<Scalars['Int']>;
    site?: Maybe<SiteType>;
    siteId?: Maybe<Scalars['ID']>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
  };

export type PowerPanelTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type PowerPanelTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type PowerPanelTypeResultSet = {
  __typename?: 'PowerPanelTypeResultSet';
  data: Array<PowerPanelType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type PowerPortFilter = {
  Name?: InputMaybe<StrFilter>;
  allocatedDraw?: InputMaybe<IntFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  cable?: InputMaybe<CableFilter>;
  cableId?: InputMaybe<StrawberryIdFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  device?: InputMaybe<DeviceFilter>;
  deviceId?: InputMaybe<StrawberryIdFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  label?: InputMaybe<StrFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  markConnected?: InputMaybe<BoolFilter>;
  maximumDraw?: InputMaybe<IntFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  type?: InputMaybe<DcimPowerPortTypeChoicesEnumFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type PowerPortFilterAndFilterEntry = {
  AND: Array<PowerPortFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type PowerPortFilterOrFilterEntry = {
  OR: Array<PowerPortFilter>;
  negate?: Scalars['Boolean'];
};

export type PowerPortType = AssetFederationBase &
  AssetType & {
    __typename?: 'PowerPortType';
    Name?: Maybe<Scalars['String']>;
    allocatedDraw?: Maybe<Scalars['Int']>;
    assetType: KnownAssetsEnum;
    cable?: Maybe<CableType>;
    cableId?: Maybe<Scalars['ID']>;
    cases: CaseFederationResult;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    device?: Maybe<DeviceType>;
    deviceId?: Maybe<Scalars['ID']>;
    id: Scalars['ID'];
    label?: Maybe<Scalars['String']>;
    lastUpdated?: Maybe<Scalars['DateTime']>;
    markConnected?: Maybe<Scalars['Boolean']>;
    maximumDraw?: Maybe<Scalars['Int']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    powerOutlets: PowerOutletTypeResultSet;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    type?: Maybe<DcimPowerPortTypeChoices>;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
  };

export type PowerPortTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type PowerPortTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type PowerPortTypeResultSet = {
  __typename?: 'PowerPortTypeResultSet';
  data: Array<PowerPortType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type PredecessorInput = {
  predecessor: Scalars['ID'];
  predecessorCondition?: TaskRelationshipTypeEnum;
};

export type PrefixFilter = {
  Children?: InputMaybe<IntFilter>;
  Depth?: InputMaybe<IntFilter>;
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  isPool?: InputMaybe<BoolFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  markUtilized?: InputMaybe<BoolFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  prefix?: InputMaybe<StrFilter>;
  role?: InputMaybe<RoleFilter>;
  roleId?: InputMaybe<StrawberryIdFilter>;
  site?: InputMaybe<SiteFilter>;
  siteId?: InputMaybe<StrawberryIdFilter>;
  status?: InputMaybe<IpamPrefixStatusChoicesEnumFilter>;
  tenant?: InputMaybe<TenantFilter>;
  tenantId?: InputMaybe<StrawberryIdFilter>;
  uuid?: InputMaybe<StrFilter>;
  vlan?: InputMaybe<VlanFilter>;
  vlanId?: InputMaybe<StrawberryIdFilter>;
  vrf?: InputMaybe<VrfFilter>;
  vrfId?: InputMaybe<StrawberryIdFilter>;
};

export type PrefixFilterAndFilterEntry = {
  AND: Array<PrefixFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type PrefixFilterOrFilterEntry = {
  OR: Array<PrefixFilter>;
  negate?: Scalars['Boolean'];
};

export type PrefixType = AssetFederationBase &
  AssetType & {
    __typename?: 'PrefixType';
    Depth?: Maybe<Scalars['Int']>;
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    children?: Maybe<Scalars['Int']>;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    isPool?: Maybe<Scalars['Boolean']>;
    lastUpdated?: Maybe<Scalars['DateTime']>;
    markUtilized?: Maybe<Scalars['Boolean']>;
    netboxUrl?: Maybe<Scalars['String']>;
    prefix?: Maybe<Scalars['String']>;
    role?: Maybe<RoleType>;
    roleId?: Maybe<Scalars['ID']>;
    site?: Maybe<SiteType>;
    siteId?: Maybe<Scalars['ID']>;
    status?: Maybe<IpamPrefixStatusChoices>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    tenant?: Maybe<TenantType>;
    tenantId?: Maybe<Scalars['ID']>;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
    vlan?: Maybe<VlanType>;
    vlanId?: Maybe<Scalars['ID']>;
    vrf?: Maybe<VrfType>;
    vrfId?: Maybe<Scalars['ID']>;
  };

export type PrefixTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type PrefixTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type PrefixTypeResultSet = {
  __typename?: 'PrefixTypeResultSet';
  data: Array<PrefixType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type ProviderFilter = {
  Name?: InputMaybe<StrFilter>;
  account?: InputMaybe<StrFilter>;
  adminContact?: InputMaybe<StrFilter>;
  asn?: InputMaybe<IntFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  circuitCount?: InputMaybe<IntFilter>;
  comments?: InputMaybe<StrFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  nocContact?: InputMaybe<StrFilter>;
  portalUrl?: InputMaybe<StrFilter>;
  slug?: InputMaybe<StrFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type ProviderFilterAndFilterEntry = {
  AND: Array<ProviderFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type ProviderFilterOrFilterEntry = {
  OR: Array<ProviderFilter>;
  negate?: Scalars['Boolean'];
};

export type ProviderNetworkFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  comments?: InputMaybe<StrFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  provider?: InputMaybe<ProviderFilter>;
  providerId?: InputMaybe<StrawberryIdFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type ProviderNetworkFilterAndFilterEntry = {
  AND: Array<ProviderNetworkFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type ProviderNetworkFilterOrFilterEntry = {
  OR: Array<ProviderNetworkFilter>;
  negate?: Scalars['Boolean'];
};

export type ProviderNetworkType = AssetFederationBase &
  AssetType & {
    __typename?: 'ProviderNetworkType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    circuitTerminations: CircuitTerminationTypeResultSet;
    comments?: Maybe<Scalars['String']>;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    lastUpdated?: Maybe<Scalars['DateTime']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    provider?: Maybe<ProviderType>;
    providerId?: Maybe<Scalars['ID']>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
  };

export type ProviderNetworkTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type ProviderNetworkTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type ProviderNetworkTypeResultSet = {
  __typename?: 'ProviderNetworkTypeResultSet';
  data: Array<ProviderNetworkType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type ProviderType = AssetFederationBase &
  AssetType & {
    __typename?: 'ProviderType';
    Name?: Maybe<Scalars['String']>;
    account?: Maybe<Scalars['String']>;
    adminContact?: Maybe<Scalars['String']>;
    asn?: Maybe<Scalars['Int']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    circuitCount?: Maybe<Scalars['Int']>;
    circuits: CircuitTypeResultSet;
    comments?: Maybe<Scalars['String']>;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    id: Scalars['ID'];
    lastUpdated?: Maybe<Scalars['DateTime']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    networks: ProviderNetworkTypeResultSet;
    nocContact?: Maybe<Scalars['String']>;
    portalUrl?: Maybe<Scalars['String']>;
    slug?: Maybe<Scalars['String']>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
  };

export type ProviderTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type ProviderTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type ProviderTypeResultSet = {
  __typename?: 'ProviderTypeResultSet';
  data: Array<ProviderType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type Query = {
  __typename?: 'Query';
  Service?: Maybe<Scalars['String']>;
  aggregate?: Maybe<AggregateType>;
  aggregateList: AggregateTypeResultSet;
  asn?: Maybe<AsnType>;
  asnList: AsnTypeResultSet;
  asset?: Maybe<AssetType>;
  assetList: AssetTypeResultSet;
  cable?: Maybe<CableType>;
  cableList: CableTypeResultSet;
  circuit?: Maybe<CircuitType>;
  circuitList: CircuitTypeResultSet;
  circuitTermination?: Maybe<CircuitTerminationType>;
  circuitTerminationList: CircuitTerminationTypeResultSet;
  circuitType?: Maybe<CircuitTypeType>;
  circuitTypeList: CircuitTypeTypeResultSet;
  cluster?: Maybe<ClusterType>;
  clusterGroup?: Maybe<ClusterGroupType>;
  clusterGroupList: ClusterGroupTypeResultSet;
  clusterList: ClusterTypeResultSet;
  clusterType?: Maybe<ClusterTypeType>;
  clusterTypeList: ClusterTypeTypeResultSet;
  consolePort?: Maybe<ConsolePortType>;
  consolePortList: ConsolePortTypeResultSet;
  consoleServerPort?: Maybe<ConsoleServerPortType>;
  consoleServerPortList: ConsoleServerPortTypeResultSet;
  device?: Maybe<DeviceType>;
  deviceBay?: Maybe<DeviceBayType>;
  deviceBayList: DeviceBayTypeResultSet;
  deviceList: DeviceTypeResultSet;
  deviceRole?: Maybe<DeviceRoleType>;
  deviceRoleList: DeviceRoleTypeResultSet;
  deviceType?: Maybe<DeviceTypeType>;
  deviceTypeList: DeviceTypeTypeResultSet;
  exportAllCpesToJson: Scalars['JSONString'];
  exportAllCpesToService: Scalars['Boolean'];
  exportCpeToJson: Scalars['JSONString'];
  exportCpeToService: Scalars['Boolean'];
  fhrpGroup?: Maybe<FhrpGroupType>;
  fhrpGroupList: FhrpGroupTypeResultSet;
  findAll?: Maybe<Array<Maybe<MatchResult>>>;
  findByAsset?: Maybe<Array<Maybe<MatchResult>>>;
  findByCve?: Maybe<Array<Maybe<MatchResult>>>;
  frontPort?: Maybe<FrontPortType>;
  frontPortList: FrontPortTypeResultSet;
  /**
   * Retrieve one Activity instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getActivity?: Maybe<Activity>;
  /**
   * Retrieve multiple Activity instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[ActivityFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[ActivityOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getActivityList: ActivityPaginated;
  /**
   * Retrieve one Alias instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getAlias?: Maybe<Alias>;
  /**
   * Retrieve multiple Alias instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[AliasFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[AliasOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getAliasList: AliasPaginated;
  getAllAssets?: Maybe<Array<Maybe<AssetVertex>>>;
  getAllCve?: Maybe<Array<Maybe<CveVertex>>>;
  /**
   * Retrieve one BaseActivity instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getBaseActivity?: Maybe<BaseActivity>;
  /**
   * Retrieve multiple BaseActivity instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[BaseActivityFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[BaseActivityOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getBaseActivityList: BaseActivityPaginated;
  /**
   * Retrieve one BaseHashableObservable instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getBaseHashableObservable?: Maybe<BaseHashableObservable>;
  /**
   * Retrieve multiple BaseHashableObservable instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[BaseHashableObservableFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[BaseHashableObservableOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getBaseHashableObservableList: BaseHashableObservablePaginated;
  /**
   * Retrieve one BaseHost instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getBaseHost?: Maybe<BaseHost>;
  /**
   * Retrieve multiple BaseHost instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[BaseHostFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[BaseHostOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getBaseHostList: BaseHostPaginated;
  /**
   * Retrieve one BaseObservable instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getBaseObservable?: Maybe<BaseObservable>;
  /**
   * Retrieve multiple BaseObservable instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[BaseObservableFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[BaseObservableOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getBaseObservableList: BaseObservablePaginated;
  /**
   * Retrieve one BaseTaskInputOutput instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getBaseTaskInputOutput?: Maybe<BaseTaskInputOutput>;
  /**
   * Retrieve multiple BaseTaskInputOutput instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[BaseTaskInputOutputFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[BaseTaskInputOutputOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getBaseTaskInputOutputList: BaseTaskInputOutputPaginated;
  /**
   * Retrieve one BoolInputOutput instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getBoolInputOutput?: Maybe<BoolInputOutput>;
  /**
   * Retrieve multiple BoolInputOutput instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[BoolInputOutputFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[BoolInputOutputOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getBoolInputOutputList: BoolInputOutputPaginated;
  /**
   * Retrieve one Case instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getCase?: Maybe<Case>;
  getCaseByFederatedEntity: CaseFederationResult;
  /**
   * Retrieve one CaseDBRole instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getCaseDbRole?: Maybe<CaseDbRole>;
  /**
   * Retrieve multiple CaseDBRole instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[CaseDBRoleFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[CaseDBRoleOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getCaseDbRoleList: CaseDbRolePaginated;
  /**
   * Retrieve one CaseDBUser instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getCaseDbUser?: Maybe<CaseDbUser>;
  /**
   * Retrieve multiple CaseDBUser instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[CaseDBUserFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[CaseDBUserOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getCaseDbUserList: CaseDbUserPaginated;
  /**
   * Retrieve one CaseFileItem instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getCaseFileItem?: Maybe<CaseFileItem>;
  /**
   * Retrieve one CaseFileItemBase instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getCaseFileItemBase?: Maybe<CaseFileItemBase>;
  /**
   * Retrieve multiple CaseFileItemBase instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[CaseFileItemBaseFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[CaseFileItemBaseOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getCaseFileItemBaseList: CaseFileItemBasePaginated;
  /**
   * Retrieve multiple CaseFileItem instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[CaseFileItemFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[CaseFileItemOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getCaseFileItemList: CaseFileItemPaginated;
  /**
   * Retrieve multiple Case instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[CaseFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[CaseOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getCaseList: CasePaginated;
  /**
   * Retrieve one CaseManagementExternalReference instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getCaseManagementExternalReference?: Maybe<CaseManagementExternalReference>;
  /**
   * Retrieve multiple CaseManagementExternalReference instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[CaseManagementExternalReferenceFilter1]]]_): List of
   * filters in [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[CaseManagementExternalReferenceOrdEnum]]_):
   * List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getCaseManagementExternalReferenceList: CaseManagementExternalReferencePaginated;
  /**
   * Retrieve one CaseRelationship instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getCaseRelationship?: Maybe<CaseRelationship>;
  /**
   * Retrieve multiple CaseRelationship instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[CaseRelationshipFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[CaseRelationshipOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getCaseRelationshipList: CaseRelationshipPaginated;
  /**
   * Retrieve one Comment instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getComment?: Maybe<Comment>;
  /**
   * Retrieve multiple Comment instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[CommentFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[CommentOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getCommentList: CommentPaginated;
  /**
   * Retrieve one CTIEntry instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getCtiEntry?: Maybe<CtiEntry>;
  /**
   * Retrieve multiple CTIEntry instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[CTIEntryFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[CTIEntryOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getCtiEntryList: CtiEntryPaginated;
  getCurrentUser: CaseDbUser;
  /**
   * Retrieve one DataPlatformServiceIPFix instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getDataPlatformServiceIpFix?: Maybe<DataPlatformServiceIpFix>;
  /**
   * Retrieve multiple DataPlatformServiceIPFix instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[DataPlatformServiceIPFixFilter1]]]_): List of filters
   * in [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[DataPlatformServiceIPFixOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getDataPlatformServiceIpFixList: DataPlatformServiceIpFixPaginated;
  /**
   * Retrieve one DataSource instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getDataSource?: Maybe<DataSource>;
  /**
   * Retrieve multiple DataSource instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[DataSourceFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[DataSourceOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getDataSourceList: DataSourcePaginated;
  /**
   * Retrieve one DateInputOutput instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getDateInputOutput?: Maybe<DateInputOutput>;
  /**
   * Retrieve multiple DateInputOutput instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[DateInputOutputFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[DateInputOutputOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getDateInputOutputList: DateInputOutputPaginated;
  /**
   * Retrieve one DateTimeInputOutput instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getDateTimeInputOutput?: Maybe<DateTimeInputOutput>;
  /**
   * Retrieve multiple DateTimeInputOutput instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[DateTimeInputOutputFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[DateTimeInputOutputOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getDateTimeInputOutputList: DateTimeInputOutputPaginated;
  /**
   * Retrieve one Directory instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getDirectory?: Maybe<Directory>;
  /**
   * Retrieve multiple Directory instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[DirectoryFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[DirectoryOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getDirectoryList: DirectoryPaginated;
  /**
   * Retrieve one DomainInputOutput instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getDomainInputOutput?: Maybe<DomainInputOutput>;
  /**
   * Retrieve multiple DomainInputOutput instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[DomainInputOutputFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[DomainInputOutputOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getDomainInputOutputList: DomainInputOutputPaginated;
  /**
   * Retrieve one DomainName instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getDomainName?: Maybe<DomainName>;
  /**
   * Retrieve multiple DomainName instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[DomainNameFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[DomainNameOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getDomainNameList: DomainNamePaginated;
  /**
   * Retrieve one DomainToDomainResolution instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getDomainToDomainResolution?: Maybe<DomainToDomainResolution>;
  /**
   * Retrieve multiple DomainToDomainResolution instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[DomainToDomainResolutionFilter1]]]_): List of filters
   * in [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[DomainToDomainResolutionOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getDomainToDomainResolutionList: DomainToDomainResolutionPaginated;
  /**
   * Retrieve one DomainToIPAddressResolution instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getDomainToIpAddressResolution?: Maybe<DomainToIpAddressResolution>;
  /**
   * Retrieve multiple DomainToIPAddressResolution instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[DomainToIPAddressResolutionFilter1]]]_): List of
   * filters in [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[DomainToIPAddressResolutionOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getDomainToIpAddressResolutionList: DomainToIpAddressResolutionPaginated;
  /**
   * Retrieve one EmailAddress instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getEmailAddress?: Maybe<EmailAddress>;
  /**
   * Retrieve one EmailAddressInputOutput instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getEmailAddressInputOutput?: Maybe<EmailAddressInputOutput>;
  /**
   * Retrieve multiple EmailAddressInputOutput instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[EmailAddressInputOutputFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[EmailAddressInputOutputOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getEmailAddressInputOutputList: EmailAddressInputOutputPaginated;
  /**
   * Retrieve multiple EmailAddress instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[EmailAddressFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[EmailAddressOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getEmailAddressList: EmailAddressPaginated;
  /**
   * Retrieve one EmailHeader instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getEmailHeader?: Maybe<EmailHeader>;
  /**
   * Retrieve multiple EmailHeader instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[EmailHeaderFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[EmailHeaderOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getEmailHeaderList: EmailHeaderPaginated;
  /**
   * Retrieve one EmailMessage instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getEmailMessage?: Maybe<EmailMessage>;
  /**
   * Retrieve one EmailMessageEmailAddressRelationship instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getEmailMessageEmailAddressRelationship?: Maybe<EmailMessageEmailAddressRelationship>;
  /**
   * Retrieve multiple EmailMessageEmailAddressRelationship instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[EmailMessageEmailAddressRelationshipFilter1]]]_): List
   * of filters in [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[EmailMessageEmailAddressRelationshipOrdEnum]]_):
   * List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getEmailMessageEmailAddressRelationshipList: EmailMessageEmailAddressRelationshipPaginated;
  /**
   * Retrieve one EmailMessageInputOutput instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getEmailMessageInputOutput?: Maybe<EmailMessageInputOutput>;
  /**
   * Retrieve multiple EmailMessageInputOutput instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[EmailMessageInputOutputFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[EmailMessageInputOutputOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getEmailMessageInputOutputList: EmailMessageInputOutputPaginated;
  /**
   * Retrieve multiple EmailMessage instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[EmailMessageFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[EmailMessageOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getEmailMessageList: EmailMessagePaginated;
  /**
   * Retrieve one EmailMessagePartsRelationship instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getEmailMessagePartsRelationship?: Maybe<EmailMessagePartsRelationship>;
  /**
   * Retrieve multiple EmailMessagePartsRelationship instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[EmailMessagePartsRelationshipFilter1]]]_): List of
   * filters in [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[EmailMessagePartsRelationshipOrdEnum]]_): List
   * of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getEmailMessagePartsRelationshipList: EmailMessagePartsRelationshipPaginated;
  /**
   * Retrieve one EntryType instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getEntryType?: Maybe<EntryType>;
  /**
   * Retrieve multiple EntryType instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[EntryTypeFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[EntryTypeOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getEntryTypeList: EntryTypePaginated;
  /**
   * Retrieve one Event instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getEvent?: Maybe<Event>;
  /**
   * Retrieve multiple Event instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[EventFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[EventOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getEventList: EventPaginated;
  /**
   * Retrieve one ExternalReference instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getExternalReference?: Maybe<ExternalReference>;
  /**
   * Retrieve multiple ExternalReference instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[ExternalReferenceFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[ExternalReferenceOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getExternalReferenceList: ExternalReferencePaginated;
  getFederatedAsset?: Maybe<AssetFederationBase>;
  getFederatedAssetList: AssetFederationBaseFederationResult;
  getFederatedObservable?: Maybe<ObservableFederationBase>;
  getFederatedObservableList: ObservableFederationBaseFederationResult;
  getFederatedRelatedUser?: Maybe<RelatedUserFederatedType>;
  getFederatedRelatedUserList: RelatedUserFederatedTypeFederationResult;
  getFederatedTtp?: Maybe<TtpFederationBase>;
  getFederatedTtpList: TtpFederationBaseFederationResult;
  /**
   * Retrieve one File instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getFile?: Maybe<File>;
  /**
   * Retrieve one FileInputOutput instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getFileInputOutput?: Maybe<FileInputOutput>;
  /**
   * Retrieve multiple FileInputOutput instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[FileInputOutputFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[FileInputOutputOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getFileInputOutputList: FileInputOutputPaginated;
  /**
   * Retrieve multiple File instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[FileFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[FileOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getFileList: FilePaginated;
  /**
   * Retrieve one FileRefInputOutput instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getFileRefInputOutput?: Maybe<FileRefInputOutput>;
  /**
   * Retrieve multiple FileRefInputOutput instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[FileRefInputOutputFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[FileRefInputOutputOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getFileRefInputOutputList: FileRefInputOutputPaginated;
  /**
   * Retrieve one FileReference instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getFileReference?: Maybe<FileReference>;
  /**
   * Retrieve multiple FileReference instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[FileReferenceFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[FileReferenceOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getFileReferenceList: FileReferencePaginated;
  /**
   * Retrieve one FlowEvent instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getFlowEvent?: Maybe<FlowEvent>;
  /**
   * Retrieve one FlowEventData instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getFlowEventData?: Maybe<FlowEventData>;
  /**
   * Retrieve multiple FlowEventData instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[FlowEventDataFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[FlowEventDataOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getFlowEventDataList: FlowEventDataPaginated;
  /**
   * Retrieve multiple FlowEvent instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[FlowEventFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[FlowEventOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getFlowEventList: FlowEventPaginated;
  /**
   * Retrieve one GroupProcedure instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getGroupProcedure?: Maybe<GroupProcedure>;
  /**
   * Retrieve multiple GroupProcedure instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[GroupProcedureFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[GroupProcedureOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getGroupProcedureList: GroupProcedurePaginated;
  /**
   * Retrieve one Hash instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getHash?: Maybe<Hash>;
  /**
   * Retrieve one HashInputOutput instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getHashInputOutput?: Maybe<HashInputOutput>;
  /**
   * Retrieve multiple HashInputOutput instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[HashInputOutputFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[HashInputOutputOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getHashInputOutputList: HashInputOutputPaginated;
  /**
   * Retrieve multiple Hash instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[HashFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[HashOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getHashList: HashPaginated;
  /**
   * Retrieve one HashableObservable instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getHashableObservable?: Maybe<HashableObservable>;
  /**
   * Retrieve multiple HashableObservable instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[HashableObservableFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[HashableObservableOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getHashableObservableList: HashableObservablePaginated;
  /**
   * Retrieve one Host instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getHost?: Maybe<Host>;
  /**
   * Retrieve multiple Host instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[HostFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[HostOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getHostList: HostPaginated;
  /**
   * Retrieve one IPAddress instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getIpAddress?: Maybe<IpAddress>;
  /**
   * Retrieve multiple IPAddress instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[IPAddressFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[IPAddressOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getIpAddressList: IpAddressPaginated;
  /**
   * Retrieve one IPAddressToDomainResolution instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getIpAddressToDomainResolution?: Maybe<IpAddressToDomainResolution>;
  /**
   * Retrieve multiple IPAddressToDomainResolution instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[IPAddressToDomainResolutionFilter1]]]_): List of
   * filters in [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[IPAddressToDomainResolutionOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getIpAddressToDomainResolutionList: IpAddressToDomainResolutionPaginated;
  /**
   * Retrieve one IPInputOutput instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getIpInputOutput?: Maybe<IpInputOutput>;
  /**
   * Retrieve multiple IPInputOutput instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[IPInputOutputFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[IPInputOutputOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getIpInputOutputList: IpInputOutputPaginated;
  /**
   * Retrieve one ITTP instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getIttp?: Maybe<Ittp>;
  /**
   * Retrieve multiple ITTP instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[ITTPFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[ITTPOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getIttpList: IttpPaginated;
  /**
   * Retrieve one JSONInputOutput instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getJsonInputOutput?: Maybe<JsonInputOutput>;
  /**
   * Retrieve multiple JSONInputOutput instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[JSONInputOutputFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[JSONInputOutputOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getJsonInputOutputList: JsonInputOutputPaginated;
  /**
   * Retrieve one Label instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getLabel?: Maybe<Label>;
  /**
   * Retrieve multiple Label instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[LabelFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[LabelOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getLabelList: LabelPaginated;
  /**
   * Retrieve one Malware instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getMalware?: Maybe<Malware>;
  /**
   * Retrieve multiple Malware instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[MalwareFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[MalwareOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getMalwareList: MalwarePaginated;
  /**
   * Retrieve one MalwareProcedure instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getMalwareProcedure?: Maybe<MalwareProcedure>;
  /**
   * Retrieve multiple MalwareProcedure instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[MalwareProcedureFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[MalwareProcedureOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getMalwareProcedureList: MalwareProcedurePaginated;
  /**
   * Retrieve one Mitigation instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getMitigation?: Maybe<Mitigation>;
  /**
   * Retrieve multiple Mitigation instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[MitigationFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[MitigationOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getMitigationList: MitigationPaginated;
  /**
   * Retrieve one Observable instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getObservable?: Maybe<Observable>;
  /**
   * Retrieve one ObservableLink instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getObservableLink?: Maybe<ObservableLink>;
  /**
   * Retrieve multiple ObservableLink instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[ObservableLinkFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[ObservableLinkOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getObservableLinkList: ObservableLinkPaginated;
  /**
   * Retrieve multiple Observable instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[ObservableFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[ObservableOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getObservableList: ObservablePaginated;
  /**
   * Retrieve one SourceSpecifier instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getSourceSpecifier?: Maybe<SourceSpecifier>;
  /**
   * Retrieve multiple SourceSpecifier instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[SourceSpecifierFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[SourceSpecifierOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getSourceSpecifierList: SourceSpecifierPaginated;
  /**
   * Retrieve one Stage instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getStage?: Maybe<Stage>;
  /**
   * Retrieve multiple Stage instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[StageFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[StageOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getStageList: StagePaginated;
  /**
   * Retrieve one StorageEvent instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getStorageEvent?: Maybe<StorageEvent>;
  /**
   * Retrieve multiple StorageEvent instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[StorageEventFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[StorageEventOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getStorageEventList: StorageEventPaginated;
  /**
   * Retrieve one StringInputOutput instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getStringInputOutput?: Maybe<StringInputOutput>;
  /**
   * Retrieve multiple StringInputOutput instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[StringInputOutputFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[StringInputOutputOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getStringInputOutputList: StringInputOutputPaginated;
  /**
   * Retrieve one Tactic instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getTactic?: Maybe<Tactic>;
  /**
   * Retrieve multiple Tactic instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[TacticFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[TacticOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getTacticList: TacticPaginated;
  /**
   * Retrieve one Task instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getTask?: Maybe<Task>;
  /**
   * Retrieve one TaskInputOutput instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getTaskInputOutput?: Maybe<TaskInputOutput>;
  /**
   * Retrieve multiple TaskInputOutput instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[TaskInputOutputFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[TaskInputOutputOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getTaskInputOutputList: TaskInputOutputPaginated;
  /**
   * Retrieve multiple Task instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[TaskFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[TaskOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getTaskList: TaskPaginated;
  /**
   * Retrieve one TaskReference instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getTaskReference?: Maybe<TaskReference>;
  /**
   * Retrieve multiple TaskReference instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[TaskReferenceFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[TaskReferenceOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getTaskReferenceList: TaskReferencePaginated;
  /**
   * Retrieve one TaskRelationship instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getTaskRelationship?: Maybe<TaskRelationship>;
  /**
   * Retrieve multiple TaskRelationship instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[TaskRelationshipFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[TaskRelationshipOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getTaskRelationshipList: TaskRelationshipPaginated;
  /**
   * Retrieve one TaskTemplate instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getTaskTemplate?: Maybe<TaskTemplate>;
  /**
   * Retrieve multiple TaskTemplate instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[TaskTemplateFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[TaskTemplateOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getTaskTemplateList: TaskTemplatePaginated;
  /**
   * Retrieve one Technique instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getTechnique?: Maybe<Technique>;
  /**
   * Retrieve multiple Technique instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[TechniqueFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[TechniqueOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getTechniqueList: TechniquePaginated;
  /**
   * Retrieve one TechniqueMitigationRelationship instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getTechniqueMitigationRelationship?: Maybe<TechniqueMitigationRelationship>;
  /**
   * Retrieve multiple TechniqueMitigationRelationship instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[TechniqueMitigationRelationshipFilter1]]]_): List of
   * filters in [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[TechniqueMitigationRelationshipOrdEnum]]_):
   * List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getTechniqueMitigationRelationshipList: TechniqueMitigationRelationshipPaginated;
  /**
   * Retrieve one Tool instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getTool?: Maybe<Tool>;
  /**
   * Retrieve multiple Tool instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[ToolFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[ToolOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getToolList: ToolPaginated;
  /**
   * Retrieve one ToolProcedure instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getToolProcedure?: Maybe<ToolProcedure>;
  /**
   * Retrieve multiple ToolProcedure instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[ToolProcedureFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[ToolProcedureOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getToolProcedureList: ToolProcedurePaginated;
  /**
   * Retrieve one TTPGroup instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getTtpGroup?: Maybe<TtpGroup>;
  /**
   * Retrieve multiple TTPGroup instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[TTPGroupFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[TTPGroupOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getTtpGroupList: TtpGroupPaginated;
  /**
   * Retrieve one TTPLink instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getTtpLink?: Maybe<TtpLink>;
  /**
   * Retrieve multiple TTPLink instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[TTPLinkFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[TTPLinkOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getTtpLinkList: TtpLinkPaginated;
  /**
   * Retrieve one TTPMeta instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getTtpMeta?: Maybe<TtpMeta>;
  /**
   * Retrieve multiple TTPMeta instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[TTPMetaFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[TTPMetaOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getTtpMetaList: TtpMetaPaginated;
  /**
   * Retrieve one TTPPlatform instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getTtpPlatform?: Maybe<TtpPlatform>;
  /**
   * Retrieve multiple TTPPlatform instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[TTPPlatformFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[TTPPlatformOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getTtpPlatformList: TtpPlatformPaginated;
  /**
   * Retrieve one URL instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getUrl?: Maybe<Url>;
  /**
   * Retrieve one URLFragment instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getUrlFragment?: Maybe<UrlFragment>;
  /**
   * Retrieve multiple URLFragment instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[URLFragmentFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[URLFragmentOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getUrlFragmentList: UrlFragmentPaginated;
  /**
   * Retrieve one URLInputOutput instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getUrlInputOutput?: Maybe<UrlInputOutput>;
  /**
   * Retrieve multiple URLInputOutput instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[URLInputOutputFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[URLInputOutputOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getUrlInputOutputList: UrlInputOutputPaginated;
  /**
   * Retrieve multiple URL instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[URLFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[URLOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getUrlList: UrlPaginated;
  /**
   * Retrieve one URLPath instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getUrlPath?: Maybe<UrlPath>;
  /**
   * Retrieve multiple URLPath instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[URLPathFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[URLPathOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getUrlPathList: UrlPathPaginated;
  /**
   * Retrieve one URLQuery instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getUrlQuery?: Maybe<UrlQuery>;
  /**
   * Retrieve multiple URLQuery instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[URLQueryFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[URLQueryOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getUrlQueryList: UrlQueryPaginated;
  /**
   * Retrieve one URLQueryParam instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getUrlQueryParam?: Maybe<UrlQueryParam>;
  /**
   * Retrieve multiple URLQueryParam instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[URLQueryParamFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[URLQueryParamOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getUrlQueryParamList: UrlQueryParamPaginated;
  getUserFlows: Array<UserAccountingUserIpDataGroup>;
  /**
   * Retrieve one UserIPAccountingModel instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getUserIpAccountingModel?: Maybe<UserAccountingUserIpData>;
  /**
   * Retrieve multiple UserIPAccountingModel instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[UserIPAccountingModelFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[UserIPAccountingModelOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getUserIpAccountingModelList: UserAccountingUserIpDataPaginated;
  getUsersWithFlows: Array<UserGroupedAccounting>;
  /**
   * Retrieve one Workflow instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getWorkflow?: Maybe<Workflow>;
  /**
   * Retrieve multiple Workflow instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[WorkflowFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[WorkflowOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getWorkflowList: WorkflowPaginated;
  /**
   * Retrieve one WorkflowTemplate instance.
   *
   * Arguments:
   * - **id** (_ID!_): Identifier of the object to retrieve
   */
  getWorkflowTemplate?: Maybe<WorkflowTemplate>;
  /**
   * Retrieve multiple WorkflowTemplate instances based on defined rules.
   *
   * Arguments:
   * - **filter** (_[AND[OR[WorkflowTemplateFilter1]]]_): List of filters in
   * [CNF](https://en.wikipedia.org/wiki/Conjunctive_normal_form) to apply.
   * - **ordering** (_[OrderingEntry[WorkflowTemplateOrdEnum]]_): List of fields to sort the returned instances by.
   * - **limit** (_[Int]_): Limit number of returned instances.
   * - **cursor** (_[String]_): Continue from the last returned cursor (by **next**
   * and **previous** fields in the result). This is used in conjunction to limit
   * to retrieve multiple pages.
   */
  getWorkflowTemplateList: WorkflowTemplatePaginated;
  interface?: Maybe<InterfaceType>;
  interfaceList: InterfaceTypeResultSet;
  inventoryItem?: Maybe<InventoryItemType>;
  inventoryItemList: InventoryItemTypeResultSet;
  ipAddress?: Maybe<IpAddressType>;
  ipAddressList: IpAddressTypeResultSet;
  ipRange?: Maybe<IpRangeType>;
  ipRangeList: IpRangeTypeResultSet;
  location?: Maybe<LocationType>;
  locationList: LocationTypeResultSet;
  manufacturer?: Maybe<ManufacturerType>;
  manufacturerList: ManufacturerTypeResultSet;
  metadataAll: MetadataResultSet;
  metadataCategories: CategoryMetadataResultSet;
  platform?: Maybe<PlatformType>;
  platformList: PlatformTypeResultSet;
  powerFeed?: Maybe<PowerFeedType>;
  powerFeedList: PowerFeedTypeResultSet;
  powerOutlet?: Maybe<PowerOutletType>;
  powerOutletList: PowerOutletTypeResultSet;
  powerPanel?: Maybe<PowerPanelType>;
  powerPanelList: PowerPanelTypeResultSet;
  powerPort?: Maybe<PowerPortType>;
  powerPortList: PowerPortTypeResultSet;
  prefix?: Maybe<PrefixType>;
  prefixList: PrefixTypeResultSet;
  provider?: Maybe<ProviderType>;
  providerList: ProviderTypeResultSet;
  providerNetwork?: Maybe<ProviderNetworkType>;
  providerNetworkList: ProviderNetworkTypeResultSet;
  rack?: Maybe<RackType>;
  rackList: RackTypeResultSet;
  rackReservation?: Maybe<RackReservationType>;
  rackReservationList: RackReservationTypeResultSet;
  rackRole?: Maybe<RackRoleType>;
  rackRoleList: RackRoleTypeResultSet;
  rearPort?: Maybe<RearPortType>;
  rearPortList: RearPortTypeResultSet;
  region?: Maybe<RegionType>;
  regionList: RegionTypeResultSet;
  rir?: Maybe<RirType>;
  rirList: RirTypeResultSet;
  role?: Maybe<RoleType>;
  roleList: RoleTypeResultSet;
  routeTarget?: Maybe<RouteTargetType>;
  routeTargetList: RouteTargetTypeResultSet;
  serviceAsset?: Maybe<ServiceType>;
  serviceAssetList: ServiceTypeResultSet;
  site?: Maybe<SiteType>;
  siteGroup?: Maybe<SiteGroupType>;
  siteGroupList: SiteGroupTypeResultSet;
  siteList: SiteTypeResultSet;
  tenant?: Maybe<TenantType>;
  tenantGroup?: Maybe<TenantGroupType>;
  tenantGroupList: TenantGroupTypeResultSet;
  tenantList: TenantTypeResultSet;
  virtualChassis?: Maybe<VirtualChassisType>;
  virtualChassisList: VirtualChassisTypeResultSet;
  virtualMachine?: Maybe<VirtualMachineType>;
  virtualMachineList: VirtualMachineTypeResultSet;
  vlan?: Maybe<VlanType>;
  vlanGroup?: Maybe<VlanGroupType>;
  vlanGroupList: VlanGroupTypeResultSet;
  vlanList: VlanTypeResultSet;
  vmInterface?: Maybe<VmInterfaceType>;
  vmInterfaceList: VmInterfaceTypeResultSet;
  vrf?: Maybe<VrfType>;
  vrfList: VrfTypeResultSet;
  wirelessLan?: Maybe<WirelessLanType>;
  wirelessLanGroup?: Maybe<WirelessLanGroupType>;
  wirelessLanGroupList: WirelessLanGroupTypeResultSet;
  wirelessLanList: WirelessLanTypeResultSet;
  wirelessLink?: Maybe<WirelessLinkType>;
  wirelessLinkList: WirelessLinkTypeResultSet;
};

export type QueryAggregateArgs = {
  id: Scalars['ID'];
};

export type QueryAggregateListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<AggregateFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryAsnArgs = {
  id: Scalars['ID'];
};

export type QueryAsnListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<AsnFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryAssetArgs = {
  assetType: KnownAssetsEnum;
  id: Scalars['ID'];
};

export type QueryAssetListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<AssetFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryCableArgs = {
  id: Scalars['ID'];
};

export type QueryCableListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<CableFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryCircuitArgs = {
  id: Scalars['ID'];
};

export type QueryCircuitListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<CircuitFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryCircuitTerminationArgs = {
  id: Scalars['ID'];
};

export type QueryCircuitTerminationListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<CircuitTerminationFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryCircuitTypeArgs = {
  id: Scalars['ID'];
};

export type QueryCircuitTypeListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<CircuitTypeFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryClusterArgs = {
  id: Scalars['ID'];
};

export type QueryClusterGroupArgs = {
  id: Scalars['ID'];
};

export type QueryClusterGroupListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<ClusterGroupFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryClusterListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<ClusterFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryClusterTypeArgs = {
  id: Scalars['ID'];
};

export type QueryClusterTypeListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<ClusterTypeFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryConsolePortArgs = {
  id: Scalars['ID'];
};

export type QueryConsolePortListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<ConsolePortFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryConsoleServerPortArgs = {
  id: Scalars['ID'];
};

export type QueryConsoleServerPortListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<ConsoleServerPortFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryDeviceArgs = {
  id: Scalars['ID'];
};

export type QueryDeviceBayArgs = {
  id: Scalars['ID'];
};

export type QueryDeviceBayListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<DeviceBayFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryDeviceListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<DeviceFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryDeviceRoleArgs = {
  id: Scalars['ID'];
};

export type QueryDeviceRoleListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<DeviceRoleFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryDeviceTypeArgs = {
  id: Scalars['ID'];
};

export type QueryDeviceTypeListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<DeviceTypeFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryExportAllCpesToJsonArgs = {
  includeComponentCpes?: Scalars['Boolean'];
};

export type QueryExportAllCpesToServiceArgs = {
  flush?: Scalars['Boolean'];
  includeComponentCpes?: Scalars['Boolean'];
};

export type QueryExportCpeToJsonArgs = {
  includeComponentCpes?: Scalars['Boolean'];
  uuid: Scalars['String'];
};

export type QueryExportCpeToServiceArgs = {
  flush?: Scalars['Boolean'];
  includeComponentCpes?: Scalars['Boolean'];
  uuid: Scalars['String'];
};

export type QueryFhrpGroupArgs = {
  id: Scalars['ID'];
};

export type QueryFhrpGroupListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<FhrpGroupFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryFindByAssetArgs = {
  assetUid?: InputMaybe<Scalars['String']>;
};

export type QueryFindByCveArgs = {
  cveUid?: InputMaybe<Scalars['String']>;
};

export type QueryFrontPortArgs = {
  id: Scalars['ID'];
};

export type QueryFrontPortListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<FrontPortFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryGetActivityArgs = {
  id: Scalars['ID'];
};

export type QueryGetActivityListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<ActivityFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ActivityOrdEnumOrderingEntry>>;
};

export type QueryGetAliasArgs = {
  id: Scalars['ID'];
};

export type QueryGetAliasListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<AliasFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<AliasOrdEnumOrderingEntry>>;
};

export type QueryGetBaseActivityArgs = {
  id: Scalars['ID'];
};

export type QueryGetBaseActivityListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<BaseActivityFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<BaseActivityOrdEnumOrderingEntry>>;
};

export type QueryGetBaseHashableObservableArgs = {
  id: Scalars['ID'];
};

export type QueryGetBaseHashableObservableListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<BaseHashableObservableFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<BaseHashableObservableOrdEnumOrderingEntry>>;
};

export type QueryGetBaseHostArgs = {
  id: Scalars['ID'];
};

export type QueryGetBaseHostListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<BaseHostFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<BaseHostOrdEnumOrderingEntry>>;
};

export type QueryGetBaseObservableArgs = {
  id: Scalars['ID'];
};

export type QueryGetBaseObservableListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<BaseObservableFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<BaseObservableOrdEnumOrderingEntry>>;
};

export type QueryGetBaseTaskInputOutputArgs = {
  id: Scalars['ID'];
};

export type QueryGetBaseTaskInputOutputListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<BaseTaskInputOutputFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<BaseTaskInputOutputOrdEnumOrderingEntry>>;
};

export type QueryGetBoolInputOutputArgs = {
  id: Scalars['ID'];
};

export type QueryGetBoolInputOutputListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<BoolInputOutputFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<BoolInputOutputOrdEnumOrderingEntry>>;
};

export type QueryGetCaseArgs = {
  id: Scalars['ID'];
};

export type QueryGetCaseByFederatedEntityArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type QueryGetCaseDbRoleArgs = {
  id: Scalars['ID'];
};

export type QueryGetCaseDbRoleListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<CaseDbRoleFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<CaseDbRoleOrdEnumOrderingEntry>>;
};

export type QueryGetCaseDbUserArgs = {
  id: Scalars['ID'];
};

export type QueryGetCaseDbUserListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<CaseDbUserFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<CaseDbUserOrdEnumOrderingEntry>>;
};

export type QueryGetCaseFileItemArgs = {
  id: Scalars['ID'];
};

export type QueryGetCaseFileItemBaseArgs = {
  id: Scalars['ID'];
};

export type QueryGetCaseFileItemBaseListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<CaseFileItemBaseFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<CaseFileItemBaseOrdEnumOrderingEntry>>;
};

export type QueryGetCaseFileItemListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<CaseFileItemFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<CaseFileItemOrdEnumOrderingEntry>>;
};

export type QueryGetCaseListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<CaseFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<CaseOrdEnumOrderingEntry>>;
};

export type QueryGetCaseManagementExternalReferenceArgs = {
  id: Scalars['ID'];
};

export type QueryGetCaseManagementExternalReferenceListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<CaseManagementExternalReferenceFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<CaseManagementExternalReferenceOrdEnumOrderingEntry>>;
};

export type QueryGetCaseRelationshipArgs = {
  id: Scalars['ID'];
};

export type QueryGetCaseRelationshipListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<CaseRelationshipFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<CaseRelationshipOrdEnumOrderingEntry>>;
};

export type QueryGetCommentArgs = {
  id: Scalars['ID'];
};

export type QueryGetCommentListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<CommentFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<CommentOrdEnumOrderingEntry>>;
};

export type QueryGetCtiEntryArgs = {
  id: Scalars['ID'];
};

export type QueryGetCtiEntryListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<CtiEntryFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<CtiEntryOrdEnumOrderingEntry>>;
};

export type QueryGetDataPlatformServiceIpFixArgs = {
  id: Scalars['ID'];
};

export type QueryGetDataPlatformServiceIpFixListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<DataPlatformServiceIpFixFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<DataPlatformServiceIpFixOrdEnumOrderingEntry>>;
};

export type QueryGetDataSourceArgs = {
  id: Scalars['ID'];
};

export type QueryGetDataSourceListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<DataSourceFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<DataSourceOrdEnumOrderingEntry>>;
};

export type QueryGetDateInputOutputArgs = {
  id: Scalars['ID'];
};

export type QueryGetDateInputOutputListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<DateInputOutputFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<DateInputOutputOrdEnumOrderingEntry>>;
};

export type QueryGetDateTimeInputOutputArgs = {
  id: Scalars['ID'];
};

export type QueryGetDateTimeInputOutputListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<DateTimeInputOutputFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<DateTimeInputOutputOrdEnumOrderingEntry>>;
};

export type QueryGetDirectoryArgs = {
  id: Scalars['ID'];
};

export type QueryGetDirectoryListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<DirectoryFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<DirectoryOrdEnumOrderingEntry>>;
};

export type QueryGetDomainInputOutputArgs = {
  id: Scalars['ID'];
};

export type QueryGetDomainInputOutputListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<DomainInputOutputFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<DomainInputOutputOrdEnumOrderingEntry>>;
};

export type QueryGetDomainNameArgs = {
  id: Scalars['ID'];
};

export type QueryGetDomainNameListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<DomainNameFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<DomainNameOrdEnumOrderingEntry>>;
};

export type QueryGetDomainToDomainResolutionArgs = {
  id: Scalars['ID'];
};

export type QueryGetDomainToDomainResolutionListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<DomainToDomainResolutionFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<DomainToDomainResolutionOrdEnumOrderingEntry>>;
};

export type QueryGetDomainToIpAddressResolutionArgs = {
  id: Scalars['ID'];
};

export type QueryGetDomainToIpAddressResolutionListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<DomainToIpAddressResolutionFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<DomainToIpAddressResolutionOrdEnumOrderingEntry>>;
};

export type QueryGetEmailAddressArgs = {
  id: Scalars['ID'];
};

export type QueryGetEmailAddressInputOutputArgs = {
  id: Scalars['ID'];
};

export type QueryGetEmailAddressInputOutputListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<EmailAddressInputOutputFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<EmailAddressInputOutputOrdEnumOrderingEntry>>;
};

export type QueryGetEmailAddressListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<EmailAddressFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<EmailAddressOrdEnumOrderingEntry>>;
};

export type QueryGetEmailHeaderArgs = {
  id: Scalars['ID'];
};

export type QueryGetEmailHeaderListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<EmailHeaderFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<EmailHeaderOrdEnumOrderingEntry>>;
};

export type QueryGetEmailMessageArgs = {
  id: Scalars['ID'];
};

export type QueryGetEmailMessageEmailAddressRelationshipArgs = {
  id: Scalars['ID'];
};

export type QueryGetEmailMessageEmailAddressRelationshipListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<EmailMessageEmailAddressRelationshipFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<EmailMessageEmailAddressRelationshipOrdEnumOrderingEntry>>;
};

export type QueryGetEmailMessageInputOutputArgs = {
  id: Scalars['ID'];
};

export type QueryGetEmailMessageInputOutputListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<EmailMessageInputOutputFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<EmailMessageInputOutputOrdEnumOrderingEntry>>;
};

export type QueryGetEmailMessageListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<EmailMessageFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<EmailMessageOrdEnumOrderingEntry>>;
};

export type QueryGetEmailMessagePartsRelationshipArgs = {
  id: Scalars['ID'];
};

export type QueryGetEmailMessagePartsRelationshipListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<EmailMessagePartsRelationshipFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<EmailMessagePartsRelationshipOrdEnumOrderingEntry>>;
};

export type QueryGetEntryTypeArgs = {
  id: Scalars['ID'];
};

export type QueryGetEntryTypeListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<EntryTypeFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<EntryTypeOrdEnumOrderingEntry>>;
};

export type QueryGetEventArgs = {
  id: Scalars['ID'];
};

export type QueryGetEventListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<EventFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<EventOrdEnumOrderingEntry>>;
};

export type QueryGetExternalReferenceArgs = {
  id: Scalars['ID'];
};

export type QueryGetExternalReferenceListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<ExternalReferenceFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ExternalReferenceOrdEnumOrderingEntry>>;
};

export type QueryGetFederatedAssetArgs = {
  assetId: Scalars['ID'];
  assetType: KnownAssetsEnum;
};

export type QueryGetFederatedAssetListArgs = {
  filter?: InputMaybe<Array<AssetFederationBaseFilterAndFilterEntry>>;
};

export type QueryGetFederatedObservableArgs = {
  observableId: Scalars['ID'];
  observableType: KnownObservablesEnum;
};

export type QueryGetFederatedObservableListArgs = {
  filter?: InputMaybe<Array<ObservableFederationBaseFilterAndFilterEntry>>;
};

export type QueryGetFederatedRelatedUserArgs = {
  userId: Scalars['ID'];
};

export type QueryGetFederatedRelatedUserListArgs = {
  filter?: InputMaybe<Array<RelatedUserFederationBaseFilterAndFilterEntry>>;
};

export type QueryGetFederatedTtpArgs = {
  ttpId: Scalars['ID'];
  ttpType: KnownTtPsTypesEnum;
};

export type QueryGetFederatedTtpListArgs = {
  filter?: InputMaybe<Array<TtpFederationBaseFilterAndFilterEntry>>;
};

export type QueryGetFileArgs = {
  id: Scalars['ID'];
};

export type QueryGetFileInputOutputArgs = {
  id: Scalars['ID'];
};

export type QueryGetFileInputOutputListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<FileInputOutputFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<FileInputOutputOrdEnumOrderingEntry>>;
};

export type QueryGetFileListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<FileFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<FileOrdEnumOrderingEntry>>;
};

export type QueryGetFileRefInputOutputArgs = {
  id: Scalars['ID'];
};

export type QueryGetFileRefInputOutputListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<FileRefInputOutputFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<FileRefInputOutputOrdEnumOrderingEntry>>;
};

export type QueryGetFileReferenceArgs = {
  id: Scalars['ID'];
};

export type QueryGetFileReferenceListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<FileReferenceFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<FileReferenceOrdEnumOrderingEntry>>;
};

export type QueryGetFlowEventArgs = {
  id: Scalars['ID'];
};

export type QueryGetFlowEventDataArgs = {
  id: Scalars['ID'];
};

export type QueryGetFlowEventDataListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<FlowEventDataFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<FlowEventDataOrdEnumOrderingEntry>>;
};

export type QueryGetFlowEventListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<FlowEventFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<FlowEventOrdEnumOrderingEntry>>;
};

export type QueryGetGroupProcedureArgs = {
  id: Scalars['ID'];
};

export type QueryGetGroupProcedureListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<GroupProcedureFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<GroupProcedureOrdEnumOrderingEntry>>;
};

export type QueryGetHashArgs = {
  id: Scalars['ID'];
};

export type QueryGetHashInputOutputArgs = {
  id: Scalars['ID'];
};

export type QueryGetHashInputOutputListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<HashInputOutputFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<HashInputOutputOrdEnumOrderingEntry>>;
};

export type QueryGetHashListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<HashFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<HashOrdEnumOrderingEntry>>;
};

export type QueryGetHashableObservableArgs = {
  id: Scalars['ID'];
};

export type QueryGetHashableObservableListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<HashableObservableFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<HashableObservableOrdEnumOrderingEntry>>;
};

export type QueryGetHostArgs = {
  id: Scalars['ID'];
};

export type QueryGetHostListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<HostFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<HostOrdEnumOrderingEntry>>;
};

export type QueryGetIpAddressArgs = {
  id: Scalars['ID'];
};

export type QueryGetIpAddressListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<IpAddressFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<IpAddressOrdEnumOrderingEntry>>;
};

export type QueryGetIpAddressToDomainResolutionArgs = {
  id: Scalars['ID'];
};

export type QueryGetIpAddressToDomainResolutionListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<IpAddressToDomainResolutionFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<IpAddressToDomainResolutionOrdEnumOrderingEntry>>;
};

export type QueryGetIpInputOutputArgs = {
  id: Scalars['ID'];
};

export type QueryGetIpInputOutputListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<IpInputOutputFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<IpInputOutputOrdEnumOrderingEntry>>;
};

export type QueryGetIttpArgs = {
  id: Scalars['ID'];
};

export type QueryGetIttpListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<IttpFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<IttpOrdEnumOrderingEntry>>;
};

export type QueryGetJsonInputOutputArgs = {
  id: Scalars['ID'];
};

export type QueryGetJsonInputOutputListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<JsonInputOutputFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<JsonInputOutputOrdEnumOrderingEntry>>;
};

export type QueryGetLabelArgs = {
  id: Scalars['ID'];
};

export type QueryGetLabelListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<LabelFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<LabelOrdEnumOrderingEntry>>;
};

export type QueryGetMalwareArgs = {
  id: Scalars['ID'];
};

export type QueryGetMalwareListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<MalwareFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<MalwareOrdEnumOrderingEntry>>;
};

export type QueryGetMalwareProcedureArgs = {
  id: Scalars['ID'];
};

export type QueryGetMalwareProcedureListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<MalwareProcedureFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<MalwareProcedureOrdEnumOrderingEntry>>;
};

export type QueryGetMitigationArgs = {
  id: Scalars['ID'];
};

export type QueryGetMitigationListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<MitigationFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<MitigationOrdEnumOrderingEntry>>;
};

export type QueryGetObservableArgs = {
  id: Scalars['ID'];
};

export type QueryGetObservableLinkArgs = {
  id: Scalars['ID'];
};

export type QueryGetObservableLinkListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<ObservableLinkFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ObservableLinkOrdEnumOrderingEntry>>;
};

export type QueryGetObservableListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<ObservableFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ObservableOrdEnumOrderingEntry>>;
};

export type QueryGetSourceSpecifierArgs = {
  id: Scalars['ID'];
};

export type QueryGetSourceSpecifierListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<SourceSpecifierFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<SourceSpecifierOrdEnumOrderingEntry>>;
};

export type QueryGetStageArgs = {
  id: Scalars['ID'];
};

export type QueryGetStageListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<StageFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<StageOrdEnumOrderingEntry>>;
};

export type QueryGetStorageEventArgs = {
  id: Scalars['ID'];
};

export type QueryGetStorageEventListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<StorageEventFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<StorageEventOrdEnumOrderingEntry>>;
};

export type QueryGetStringInputOutputArgs = {
  id: Scalars['ID'];
};

export type QueryGetStringInputOutputListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<StringInputOutputFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<StringInputOutputOrdEnumOrderingEntry>>;
};

export type QueryGetTacticArgs = {
  id: Scalars['ID'];
};

export type QueryGetTacticListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<TacticFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TacticOrdEnumOrderingEntry>>;
};

export type QueryGetTaskArgs = {
  id: Scalars['ID'];
};

export type QueryGetTaskInputOutputArgs = {
  id: Scalars['ID'];
};

export type QueryGetTaskInputOutputListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<TaskInputOutputFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TaskInputOutputOrdEnumOrderingEntry>>;
};

export type QueryGetTaskListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<TaskFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TaskOrdEnumOrderingEntry>>;
};

export type QueryGetTaskReferenceArgs = {
  id: Scalars['ID'];
};

export type QueryGetTaskReferenceListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<TaskReferenceFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TaskReferenceOrdEnumOrderingEntry>>;
};

export type QueryGetTaskRelationshipArgs = {
  id: Scalars['ID'];
};

export type QueryGetTaskRelationshipListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<TaskRelationshipFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TaskRelationshipOrdEnumOrderingEntry>>;
};

export type QueryGetTaskTemplateArgs = {
  id: Scalars['ID'];
};

export type QueryGetTaskTemplateListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<TaskTemplateFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TaskTemplateOrdEnumOrderingEntry>>;
};

export type QueryGetTechniqueArgs = {
  id: Scalars['ID'];
};

export type QueryGetTechniqueListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<TechniqueFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TechniqueOrdEnumOrderingEntry>>;
};

export type QueryGetTechniqueMitigationRelationshipArgs = {
  id: Scalars['ID'];
};

export type QueryGetTechniqueMitigationRelationshipListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<TechniqueMitigationRelationshipFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TechniqueMitigationRelationshipOrdEnumOrderingEntry>>;
};

export type QueryGetToolArgs = {
  id: Scalars['ID'];
};

export type QueryGetToolListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<ToolFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ToolOrdEnumOrderingEntry>>;
};

export type QueryGetToolProcedureArgs = {
  id: Scalars['ID'];
};

export type QueryGetToolProcedureListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<ToolProcedureFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ToolProcedureOrdEnumOrderingEntry>>;
};

export type QueryGetTtpGroupArgs = {
  id: Scalars['ID'];
};

export type QueryGetTtpGroupListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<TtpGroupFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TtpGroupOrdEnumOrderingEntry>>;
};

export type QueryGetTtpLinkArgs = {
  id: Scalars['ID'];
};

export type QueryGetTtpLinkListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<TtpLinkFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TtpLinkOrdEnumOrderingEntry>>;
};

export type QueryGetTtpMetaArgs = {
  id: Scalars['ID'];
};

export type QueryGetTtpMetaListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<TtpMetaFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TtpMetaOrdEnumOrderingEntry>>;
};

export type QueryGetTtpPlatformArgs = {
  id: Scalars['ID'];
};

export type QueryGetTtpPlatformListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<TtpPlatformFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TtpPlatformOrdEnumOrderingEntry>>;
};

export type QueryGetUrlArgs = {
  id: Scalars['ID'];
};

export type QueryGetUrlFragmentArgs = {
  id: Scalars['ID'];
};

export type QueryGetUrlFragmentListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<UrlFragmentFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<UrlFragmentOrdEnumOrderingEntry>>;
};

export type QueryGetUrlInputOutputArgs = {
  id: Scalars['ID'];
};

export type QueryGetUrlInputOutputListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<UrlInputOutputFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<UrlInputOutputOrdEnumOrderingEntry>>;
};

export type QueryGetUrlListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<UrlFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<UrlOrdEnumOrderingEntry>>;
};

export type QueryGetUrlPathArgs = {
  id: Scalars['ID'];
};

export type QueryGetUrlPathListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<UrlPathFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<UrlPathOrdEnumOrderingEntry>>;
};

export type QueryGetUrlQueryArgs = {
  id: Scalars['ID'];
};

export type QueryGetUrlQueryListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<UrlQueryFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<UrlQueryOrdEnumOrderingEntry>>;
};

export type QueryGetUrlQueryParamArgs = {
  id: Scalars['ID'];
};

export type QueryGetUrlQueryParamListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<UrlQueryParamFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<UrlQueryParamOrdEnumOrderingEntry>>;
};

export type QueryGetUserFlowsArgs = {
  from_?: InputMaybe<Scalars['DateTime']>;
  to_?: InputMaybe<Scalars['DateTime']>;
  username: Scalars['String'];
};

export type QueryGetUserIpAccountingModelArgs = {
  id: Scalars['ID'];
};

export type QueryGetUserIpAccountingModelListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<UserIpAccountingModelFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<UserIpAccountingModelOrdEnumOrderingEntry>>;
};

export type QueryGetUsersWithFlowsArgs = {
  filters: Array<UsersWithFlowsFilter>;
};

export type QueryGetWorkflowArgs = {
  id: Scalars['ID'];
};

export type QueryGetWorkflowListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<WorkflowFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<WorkflowOrdEnumOrderingEntry>>;
};

export type QueryGetWorkflowTemplateArgs = {
  id: Scalars['ID'];
};

export type QueryGetWorkflowTemplateListArgs = {
  cursor?: InputMaybe<Scalars['String']>;
  filter?: InputMaybe<Array<WorkflowTemplateFilter1AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<WorkflowTemplateOrdEnumOrderingEntry>>;
};

export type QueryInterfaceArgs = {
  id: Scalars['ID'];
};

export type QueryInterfaceListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<InterfaceFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryInventoryItemArgs = {
  id: Scalars['ID'];
};

export type QueryInventoryItemListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<InventoryItemFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryIpAddressArgs = {
  id: Scalars['ID'];
};

export type QueryIpAddressListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<IpAddressFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryIpRangeArgs = {
  id: Scalars['ID'];
};

export type QueryIpRangeListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<IpRangeFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryLocationArgs = {
  id: Scalars['ID'];
};

export type QueryLocationListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<LocationFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryManufacturerArgs = {
  id: Scalars['ID'];
};

export type QueryManufacturerListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<ManufacturerFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryMetadataAllArgs = {
  filter?: InputMaybe<MetadataFilterAndFilterEntry>;
};

export type QueryMetadataCategoriesArgs = {
  filter?: InputMaybe<CategoryFilterAndFilterEntry>;
};

export type QueryPlatformArgs = {
  id: Scalars['ID'];
};

export type QueryPlatformListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<PlatformFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryPowerFeedArgs = {
  id: Scalars['ID'];
};

export type QueryPowerFeedListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<PowerFeedFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryPowerOutletArgs = {
  id: Scalars['ID'];
};

export type QueryPowerOutletListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<PowerOutletFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryPowerPanelArgs = {
  id: Scalars['ID'];
};

export type QueryPowerPanelListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<PowerPanelFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryPowerPortArgs = {
  id: Scalars['ID'];
};

export type QueryPowerPortListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<PowerPortFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryPrefixArgs = {
  id: Scalars['ID'];
};

export type QueryPrefixListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<PrefixFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryProviderArgs = {
  id: Scalars['ID'];
};

export type QueryProviderListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<ProviderFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryProviderNetworkArgs = {
  id: Scalars['ID'];
};

export type QueryProviderNetworkListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<ProviderNetworkFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryRackArgs = {
  id: Scalars['ID'];
};

export type QueryRackListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<RackFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryRackReservationArgs = {
  id: Scalars['ID'];
};

export type QueryRackReservationListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<RackReservationFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryRackRoleArgs = {
  id: Scalars['ID'];
};

export type QueryRackRoleListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<RackRoleFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryRearPortArgs = {
  id: Scalars['ID'];
};

export type QueryRearPortListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<RearPortFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryRegionArgs = {
  id: Scalars['ID'];
};

export type QueryRegionListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<RegionFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryRirArgs = {
  id: Scalars['ID'];
};

export type QueryRirListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<RirFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryRoleArgs = {
  id: Scalars['ID'];
};

export type QueryRoleListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<RoleFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryRouteTargetArgs = {
  id: Scalars['ID'];
};

export type QueryRouteTargetListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<RouteTargetFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryServiceAssetArgs = {
  id: Scalars['ID'];
};

export type QueryServiceAssetListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<ServiceFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QuerySiteArgs = {
  id: Scalars['ID'];
};

export type QuerySiteGroupArgs = {
  id: Scalars['ID'];
};

export type QuerySiteGroupListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<SiteGroupFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QuerySiteListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<SiteFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryTenantArgs = {
  id: Scalars['ID'];
};

export type QueryTenantGroupArgs = {
  id: Scalars['ID'];
};

export type QueryTenantGroupListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<TenantGroupFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryTenantListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<TenantFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryVirtualChassisArgs = {
  id: Scalars['ID'];
};

export type QueryVirtualChassisListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<VirtualChassisFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryVirtualMachineArgs = {
  id: Scalars['ID'];
};

export type QueryVirtualMachineListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<VirtualMachineFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryVlanArgs = {
  id: Scalars['ID'];
};

export type QueryVlanGroupArgs = {
  id: Scalars['ID'];
};

export type QueryVlanGroupListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<VlanGroupFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryVlanListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<VlanFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryVmInterfaceArgs = {
  id: Scalars['ID'];
};

export type QueryVmInterfaceListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<VmInterfaceFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryVrfArgs = {
  id: Scalars['ID'];
};

export type QueryVrfListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<VrfFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryWirelessLanArgs = {
  id: Scalars['ID'];
};

export type QueryWirelessLanGroupArgs = {
  id: Scalars['ID'];
};

export type QueryWirelessLanGroupListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<WirelessLanGroupFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryWirelessLanListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<WirelessLanFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type QueryWirelessLinkArgs = {
  id: Scalars['ID'];
};

export type QueryWirelessLinkListArgs = {
  cursor?: InputMaybe<Scalars['ID']>;
  filter?: InputMaybe<WirelessLinkFilterAndFilterEntry>;
  limit?: InputMaybe<Scalars['Int']>;
};

export type RirFilter = {
  Name?: InputMaybe<StrFilter>;
  aggregateCount?: InputMaybe<IntFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  isPrivate?: InputMaybe<BoolFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  slug?: InputMaybe<StrFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type RirFilterAndFilterEntry = {
  AND: Array<RirFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type RirFilterOrFilterEntry = {
  OR: Array<RirFilter>;
  negate?: Scalars['Boolean'];
};

export type RirType = AssetFederationBase &
  AssetType & {
    __typename?: 'RIRType';
    Name?: Maybe<Scalars['String']>;
    aggregateCount?: Maybe<Scalars['Int']>;
    aggregates: AggregateTypeResultSet;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    isPrivate?: Maybe<Scalars['Boolean']>;
    lastUpdated?: Maybe<Scalars['DateTime']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    slug?: Maybe<Scalars['String']>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
  };

export type RirTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type RirTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type RirTypeResultSet = {
  __typename?: 'RIRTypeResultSet';
  data: Array<RirType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type RackFilter = {
  Name?: InputMaybe<StrFilter>;
  assetTag?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  comments?: InputMaybe<StrFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  descUnits?: InputMaybe<BoolFilter>;
  deviceCount?: InputMaybe<IntFilter>;
  facilityId?: InputMaybe<StrFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  location?: InputMaybe<LocationFilter>;
  locationId?: InputMaybe<StrawberryIdFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  outerDepth?: InputMaybe<IntFilter>;
  outerUnit?: InputMaybe<DcimRackOuterUnitChoicesEnumFilter>;
  outerWidth?: InputMaybe<IntFilter>;
  role?: InputMaybe<RackRoleFilter>;
  roleId?: InputMaybe<StrawberryIdFilter>;
  serial?: InputMaybe<StrFilter>;
  site?: InputMaybe<SiteFilter>;
  siteId?: InputMaybe<StrawberryIdFilter>;
  status?: InputMaybe<DcimRackStatusChoicesEnumFilter>;
  tenant?: InputMaybe<TenantFilter>;
  tenantId?: InputMaybe<StrawberryIdFilter>;
  type?: InputMaybe<DcimRackTypeChoicesEnumFilter>;
  uHeight?: InputMaybe<IntFilter>;
  uuid?: InputMaybe<StrFilter>;
  width?: InputMaybe<DcimRackWidthChoicesEnumFilter>;
};

export type RackFilterAndFilterEntry = {
  AND: Array<RackFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type RackFilterOrFilterEntry = {
  OR: Array<RackFilter>;
  negate?: Scalars['Boolean'];
};

export type RackReservationFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  rack?: InputMaybe<RackFilter>;
  rackId?: InputMaybe<StrawberryIdFilter>;
  tenant?: InputMaybe<TenantFilter>;
  tenantId?: InputMaybe<StrawberryIdFilter>;
  units?: InputMaybe<IntFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type RackReservationFilterAndFilterEntry = {
  AND: Array<RackReservationFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type RackReservationFilterOrFilterEntry = {
  OR: Array<RackReservationFilter>;
  negate?: Scalars['Boolean'];
};

export type RackReservationType = AssetFederationBase &
  AssetType & {
    __typename?: 'RackReservationType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    lastUpdated?: Maybe<Scalars['DateTime']>;
    netboxUrl?: Maybe<Scalars['String']>;
    rack?: Maybe<RackType>;
    rackId?: Maybe<Scalars['ID']>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    tenant?: Maybe<TenantType>;
    tenantId?: Maybe<Scalars['ID']>;
    uniquePrefix: Scalars['String'];
    units: Array<Maybe<Scalars['Int']>>;
    uuid?: Maybe<Scalars['String']>;
  };

export type RackReservationTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type RackReservationTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type RackReservationTypeResultSet = {
  __typename?: 'RackReservationTypeResultSet';
  data: Array<RackReservationType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type RackRoleFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  color?: InputMaybe<StrFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  rackCount?: InputMaybe<IntFilter>;
  slug?: InputMaybe<StrFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type RackRoleFilterAndFilterEntry = {
  AND: Array<RackRoleFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type RackRoleFilterOrFilterEntry = {
  OR: Array<RackRoleFilter>;
  negate?: Scalars['Boolean'];
};

export type RackRoleType = AssetFederationBase &
  AssetType & {
    __typename?: 'RackRoleType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    color?: Maybe<Scalars['String']>;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    lastUpdated?: Maybe<Scalars['DateTime']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    rackCount?: Maybe<Scalars['Int']>;
    racks: RackTypeResultSet;
    slug?: Maybe<Scalars['String']>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
  };

export type RackRoleTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type RackRoleTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type RackRoleTypeResultSet = {
  __typename?: 'RackRoleTypeResultSet';
  data: Array<RackRoleType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type RackType = AssetFederationBase &
  AssetType & {
    __typename?: 'RackType';
    Name?: Maybe<Scalars['String']>;
    assetTag?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    comments?: Maybe<Scalars['String']>;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    descUnits?: Maybe<Scalars['Boolean']>;
    deviceCount?: Maybe<Scalars['Int']>;
    devices: DeviceTypeResultSet;
    facilityId?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    lastUpdated?: Maybe<Scalars['DateTime']>;
    location?: Maybe<LocationType>;
    locationId?: Maybe<Scalars['ID']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    outerDepth?: Maybe<Scalars['Int']>;
    outerUnit?: Maybe<DcimRackOuterUnitChoices>;
    outerWidth?: Maybe<Scalars['Int']>;
    powerFeedCount?: Maybe<Scalars['Int']>;
    powerFeedSet: PowerFeedTypeResultSet;
    reservations: RackReservationTypeResultSet;
    role?: Maybe<RackRoleType>;
    roleId?: Maybe<Scalars['ID']>;
    serial?: Maybe<Scalars['String']>;
    site?: Maybe<SiteType>;
    siteId?: Maybe<Scalars['ID']>;
    status?: Maybe<DcimRackStatusChoices>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    tenant?: Maybe<TenantType>;
    tenantId?: Maybe<Scalars['ID']>;
    type?: Maybe<DcimRackTypeChoices>;
    uHeight?: Maybe<Scalars['Int']>;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
    vlanGroups: VlanGroupTypeResultSet;
    width?: Maybe<DcimRackWidthChoices>;
  };

export type RackTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type RackTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type RackTypeResultSet = {
  __typename?: 'RackTypeResultSet';
  data: Array<RackType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type RearPortFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  cable?: InputMaybe<CableFilter>;
  cableId?: InputMaybe<StrawberryIdFilter>;
  color?: InputMaybe<StrFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  device?: InputMaybe<DeviceFilter>;
  deviceId?: InputMaybe<StrawberryIdFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  label?: InputMaybe<StrFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  markConnected?: InputMaybe<BoolFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  positions?: InputMaybe<IntFilter>;
  type?: InputMaybe<DcimRearPortTypeChoicesEnumFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type RearPortFilterAndFilterEntry = {
  AND: Array<RearPortFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type RearPortFilterOrFilterEntry = {
  OR: Array<RearPortFilter>;
  negate?: Scalars['Boolean'];
};

export type RearPortType = AssetFederationBase &
  AssetType & {
    __typename?: 'RearPortType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cable?: Maybe<CableType>;
    cableId?: Maybe<Scalars['ID']>;
    cases: CaseFederationResult;
    color?: Maybe<Scalars['String']>;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    device?: Maybe<DeviceType>;
    deviceId?: Maybe<Scalars['ID']>;
    frontPorts: FrontPortTypeResultSet;
    id: Scalars['ID'];
    label?: Maybe<Scalars['String']>;
    lastUpdated?: Maybe<Scalars['DateTime']>;
    markConnected?: Maybe<Scalars['Boolean']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    positions?: Maybe<Scalars['Int']>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    type?: Maybe<DcimRearPortTypeChoices>;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
  };

export type RearPortTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type RearPortTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type RearPortTypeResultSet = {
  __typename?: 'RearPortTypeResultSet';
  data: Array<RearPortType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type RegionFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  parent?: InputMaybe<RegionFilter>;
  parentId?: InputMaybe<StrawberryIdFilter>;
  siteCount?: InputMaybe<IntFilter>;
  slug?: InputMaybe<StrFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type RegionFilterAndFilterEntry = {
  AND: Array<RegionFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type RegionFilterOrFilterEntry = {
  OR: Array<RegionFilter>;
  negate?: Scalars['Boolean'];
};

export type RegionType = AssetFederationBase &
  AssetType & {
    __typename?: 'RegionType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    children: RegionTypeResultSet;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    lastUpdated?: Maybe<Scalars['DateTime']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    parent?: Maybe<RegionType>;
    parentId?: Maybe<Scalars['ID']>;
    siteCount?: Maybe<Scalars['Int']>;
    sites: SiteTypeResultSet;
    slug?: Maybe<Scalars['String']>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
  };

export type RegionTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type RegionTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type RegionTypeResultSet = {
  __typename?: 'RegionTypeResultSet';
  data: Array<RegionType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type RelatedUserFederatedType = {
  __typename?: 'RelatedUserFederatedType';
  cases: CaseFederationResult;
  email: Scalars['String'];
  firstName: Scalars['String'];
  lastName: Scalars['String'];
  tasks: TaskFederationResult;
  userId: Scalars['String'];
  username: Scalars['String'];
};

export type RelatedUserFederatedTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type RelatedUserFederatedTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type RelatedUserFederatedTypeFederationResult = {
  __typename?: 'RelatedUserFederatedTypeFederationResult';
  data: Array<RelatedUserFederatedType>;
  error?: Maybe<Scalars['String']>;
};

export type RelatedUserFederationBaseFilter = {
  caseId?: InputMaybe<StrawberryIdFilter>;
  taskId?: InputMaybe<StrawberryIdFilter>;
  userId?: InputMaybe<StrawberryIdFilter>;
};

export type RelatedUserFederationBaseFilterAndFilterEntry = {
  AND: Array<RelatedUserFederationBaseFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type RelatedUserFederationBaseFilterOrFilterEntry = {
  OR: Array<RelatedUserFederationBaseFilter>;
  negate?: Scalars['Boolean'];
};

export enum Relation {
  DISJOINT = 'DISJOINT',
  EQUAL = 'EQUAL',
  SUBSET = 'SUBSET',
  SUPERSET = 'SUPERSET',
  UNDEFINED = 'UNDEFINED',
}

export type RelationEdge = {
  __typename?: 'RelationEdge';
  relation?: Maybe<Relation>;
};

export enum RelationOperation {
  ADD = 'ADD',
  REM = 'REM',
  SET = 'SET',
}

export type RelationUpdate = {
  ids: Array<InputMaybe<Scalars['ID']>>;
  op: RelationOperation;
};

export type RoleFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  prefixCount?: InputMaybe<IntFilter>;
  slug?: InputMaybe<StrFilter>;
  uuid?: InputMaybe<StrFilter>;
  vlanCount?: InputMaybe<IntFilter>;
  weight?: InputMaybe<IntFilter>;
};

export type RoleFilterAndFilterEntry = {
  AND: Array<RoleFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type RoleFilterOrFilterEntry = {
  OR: Array<RoleFilter>;
  negate?: Scalars['Boolean'];
};

export type RoleType = AssetFederationBase &
  AssetType & {
    __typename?: 'RoleType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    ipRanges: IpRangeTypeResultSet;
    lastUpdated?: Maybe<Scalars['DateTime']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    prefixCount?: Maybe<Scalars['Int']>;
    prefixes: PrefixTypeResultSet;
    slug?: Maybe<Scalars['String']>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
    vlanCount?: Maybe<Scalars['Int']>;
    vlans: VlanTypeResultSet;
    weight?: Maybe<Scalars['Int']>;
  };

export type RoleTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type RoleTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type RoleTypeResultSet = {
  __typename?: 'RoleTypeResultSet';
  data: Array<RoleType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type RouteTargetFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  tenant?: InputMaybe<TenantFilter>;
  tenantId?: InputMaybe<StrawberryIdFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type RouteTargetFilterAndFilterEntry = {
  AND: Array<RouteTargetFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type RouteTargetFilterOrFilterEntry = {
  OR: Array<RouteTargetFilter>;
  negate?: Scalars['Boolean'];
};

export type RouteTargetType = AssetFederationBase &
  AssetType & {
    __typename?: 'RouteTargetType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    exportingVrfs: VrfTypeResultSet;
    id: Scalars['ID'];
    importingVrfs: VrfTypeResultSet;
    lastUpdated?: Maybe<Scalars['DateTime']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    tenant?: Maybe<TenantType>;
    tenantId?: Maybe<Scalars['ID']>;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
  };

export type RouteTargetTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type RouteTargetTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type RouteTargetTypeResultSet = {
  __typename?: 'RouteTargetTypeResultSet';
  data: Array<RouteTargetType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type ServiceFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  device?: InputMaybe<DeviceFilter>;
  deviceId?: InputMaybe<StrawberryIdFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  ipAddressIds?: InputMaybe<StrawberryIdFilter>;
  ipAddresses?: InputMaybe<IpAddressFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  ports?: InputMaybe<IntFilter>;
  protocol?: InputMaybe<IpamServiceProtocolChoicesEnumFilter>;
  uuid?: InputMaybe<StrFilter>;
  virtualMachine?: InputMaybe<VirtualMachineFilter>;
  virtualMachineId?: InputMaybe<StrawberryIdFilter>;
};

export type ServiceFilterAndFilterEntry = {
  AND: Array<ServiceFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type ServiceFilterOrFilterEntry = {
  OR: Array<ServiceFilter>;
  negate?: Scalars['Boolean'];
};

export type ServiceType = AssetFederationBase &
  AssetType & {
    __typename?: 'ServiceType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    device?: Maybe<DeviceType>;
    deviceId?: Maybe<Scalars['ID']>;
    id: Scalars['ID'];
    ipAddresses: Array<IpAddressType>;
    ipAddressesIds: Array<Scalars['ID']>;
    lastUpdated?: Maybe<Scalars['DateTime']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    ports: Array<Maybe<Scalars['Int']>>;
    protocol?: Maybe<IpamServiceProtocolChoices>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
    virtualMachine?: Maybe<VirtualMachineType>;
    virtualMachineId?: Maybe<Scalars['ID']>;
  };

export type ServiceTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type ServiceTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type ServiceTypeResultSet = {
  __typename?: 'ServiceTypeResultSet';
  data: Array<ServiceType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type SimpleAssetInput = {
  cpe23fs?: InputMaybe<Scalars['String']>;
  name?: InputMaybe<Scalars['String']>;
  parentUuid?: InputMaybe<Scalars['UUID']>;
  uuid?: InputMaybe<Scalars['UUID']>;
};

export type SiteFilter = {
  Name?: InputMaybe<StrFilter>;
  asn?: InputMaybe<IntFilter>;
  asnIds?: InputMaybe<StrawberryIdFilter>;
  asns?: InputMaybe<AsnFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  circuitCount?: InputMaybe<IntFilter>;
  comments?: InputMaybe<StrFilter>;
  contactEmail?: InputMaybe<StrFilter>;
  contactName?: InputMaybe<StrFilter>;
  contactPhone?: InputMaybe<StrFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  deviceCount?: InputMaybe<IntFilter>;
  facility?: InputMaybe<StrFilter>;
  group?: InputMaybe<SiteGroupFilter>;
  groupId?: InputMaybe<StrawberryIdFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  latitude?: InputMaybe<FloatFilter>;
  longitude?: InputMaybe<FloatFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  physicalAddress?: InputMaybe<StrFilter>;
  prefixCount?: InputMaybe<IntFilter>;
  rackCount?: InputMaybe<IntFilter>;
  region?: InputMaybe<RegionFilter>;
  regionId?: InputMaybe<StrawberryIdFilter>;
  shippingAddress?: InputMaybe<StrFilter>;
  slug?: InputMaybe<StrFilter>;
  status?: InputMaybe<DcimSiteStatusChoicesEnumFilter>;
  tenant?: InputMaybe<TenantFilter>;
  tenantId?: InputMaybe<StrawberryIdFilter>;
  timeZone?: InputMaybe<DcimSiteTimeZoneChoicesEnumFilter>;
  uuid?: InputMaybe<StrFilter>;
  virtualmachineCount?: InputMaybe<IntFilter>;
  vlanCount?: InputMaybe<IntFilter>;
};

export type SiteFilterAndFilterEntry = {
  AND: Array<SiteFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type SiteFilterOrFilterEntry = {
  OR: Array<SiteFilter>;
  negate?: Scalars['Boolean'];
};

export type SiteGroupFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  parent?: InputMaybe<SiteGroupFilter>;
  parentId?: InputMaybe<StrawberryIdFilter>;
  siteCount?: InputMaybe<IntFilter>;
  slug?: InputMaybe<StrFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type SiteGroupFilterAndFilterEntry = {
  AND: Array<SiteGroupFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type SiteGroupFilterOrFilterEntry = {
  OR: Array<SiteGroupFilter>;
  negate?: Scalars['Boolean'];
};

export type SiteGroupType = AssetFederationBase &
  AssetType & {
    __typename?: 'SiteGroupType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    children: SiteGroupTypeResultSet;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    lastUpdated?: Maybe<Scalars['DateTime']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    parent?: Maybe<SiteGroupType>;
    parentId?: Maybe<Scalars['ID']>;
    siteCount?: Maybe<Scalars['Int']>;
    sites: SiteTypeResultSet;
    slug?: Maybe<Scalars['String']>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
  };

export type SiteGroupTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type SiteGroupTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type SiteGroupTypeResultSet = {
  __typename?: 'SiteGroupTypeResultSet';
  data: Array<SiteGroupType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type SiteType = AssetFederationBase &
  AssetType & {
    __typename?: 'SiteType';
    Name?: Maybe<Scalars['String']>;
    asn?: Maybe<Scalars['Int']>;
    asnIds: Array<Scalars['ID']>;
    asns: Array<AsnType>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    circuitCount?: Maybe<Scalars['Int']>;
    circuitTerminations: CircuitTerminationTypeResultSet;
    clusters: ClusterTypeResultSet;
    comments?: Maybe<Scalars['String']>;
    contactEmail?: Maybe<Scalars['String']>;
    contactName?: Maybe<Scalars['String']>;
    contactPhone?: Maybe<Scalars['String']>;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    deviceCount?: Maybe<Scalars['Int']>;
    devices: DeviceTypeResultSet;
    facility?: Maybe<Scalars['String']>;
    group?: Maybe<SiteGroupType>;
    groupId?: Maybe<Scalars['ID']>;
    id: Scalars['ID'];
    lastUpdated?: Maybe<Scalars['DateTime']>;
    latitude?: Maybe<Scalars['Float']>;
    locations: LocationTypeResultSet;
    longitude?: Maybe<Scalars['Float']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    physicalAddress?: Maybe<Scalars['String']>;
    powerpanelSet: PowerPanelTypeResultSet;
    prefixCount?: Maybe<Scalars['Int']>;
    prefixes: PrefixTypeResultSet;
    rackCount?: Maybe<Scalars['Int']>;
    racks: RackTypeResultSet;
    region?: Maybe<RegionType>;
    regionId?: Maybe<Scalars['ID']>;
    shippingAddress?: Maybe<Scalars['String']>;
    slug?: Maybe<Scalars['String']>;
    status?: Maybe<DcimSiteStatusChoices>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    tenant?: Maybe<TenantType>;
    tenantId?: Maybe<Scalars['ID']>;
    timeZone?: Maybe<DcimSiteTimeZoneChoices>;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
    virtualmachineCount?: Maybe<Scalars['Int']>;
    vlanCount?: Maybe<Scalars['Int']>;
    vlans: VlanTypeResultSet;
  };

export type SiteTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type SiteTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type SiteTypeResultSet = {
  __typename?: 'SiteTypeResultSet';
  data: Array<SiteType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type SourceAvSpecVertex = {
  __typename?: 'SourceAVSpecVertex';
  aVPair?: Maybe<AvPair>;
  attribute?: Maybe<WellFormedNameAttribute>;
  relationEdges?: Maybe<Array<Maybe<RelationEdge>>>;
  stringRange?: Maybe<StringRange>;
};

export type SourceSpecifier = {
  __typename?: 'SourceSpecifier';
  ctiEntries?: Maybe<CtiEntryNestedList>;
  dataSource?: Maybe<DataSource>;
  entryType?: Maybe<EntryType>;
  globalUuid: Scalars['String'];
  id: Scalars['ID'];
};

export type SourceSpecifierCtiEntriesArgs = {
  filter?: InputMaybe<Array<CtiEntryFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<CtiEntryOrdEnumOrderingEntry>>;
};

export type SourceSpecifierCreate = {
  ctiEntries?: InputMaybe<Array<Scalars['ID']>>;
  dataSource?: InputMaybe<Scalars['ID']>;
  entryType?: InputMaybe<Scalars['ID']>;
  globalUuid: Scalars['String'];
};

export type SourceSpecifierFilter0 = {
  globalUuid?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
};

export type SourceSpecifierFilter0AndFilterEntry = {
  AND: Array<SourceSpecifierFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type SourceSpecifierFilter0OrFilterEntry = {
  OR: SourceSpecifierFilter0;
  negate?: Scalars['Boolean'];
};

export type SourceSpecifierFilter1 = {
  ctiEntries?: InputMaybe<CtiEntryFilter1>;
  dataSource?: InputMaybe<DataSourceFilter1>;
  entryType?: InputMaybe<EntryTypeFilter1>;
  globalUuid?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
};

export type SourceSpecifierFilter1AndFilterEntry = {
  AND: Array<SourceSpecifierFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type SourceSpecifierFilter1OrFilterEntry = {
  OR: SourceSpecifierFilter1;
  negate?: Scalars['Boolean'];
};

export type SourceSpecifierNestedList = {
  __typename?: 'SourceSpecifierNestedList';
  data: Array<SourceSpecifier>;
  totalCount: Scalars['Int'];
};

export type SourceSpecifierNestedListResult = {
  __typename?: 'SourceSpecifierNestedListResult';
  data?: Maybe<SourceSpecifier>;
  error?: Maybe<ValidationError>;
};

export enum SourceSpecifierOrdEnum {
  GLOBAL_UUID = 'GLOBAL_UUID',
  ID = 'ID',
}

export type SourceSpecifierOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: SourceSpecifierOrdEnum;
};

export type SourceSpecifierPaginated = {
  __typename?: 'SourceSpecifierPaginated';
  data: Array<SourceSpecifier>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type SourceSpecifierUpdate = {
  ctiEntries?: InputMaybe<RelationUpdate>;
  dataSource?: InputMaybe<Scalars['ID']>;
  entryType?: InputMaybe<Scalars['ID']>;
  globalUuid?: InputMaybe<Scalars['String']>;
};

export type Stage = {
  __typename?: 'Stage';
  assignees?: Maybe<CaseDbUserNestedList>;
  caseIdentifier?: Maybe<Scalars['String']>;
  created?: Maybe<Scalars['DateTime']>;
  createdBy?: Maybe<CaseDbUser>;
  description: Scalars['String'];
  dueDate?: Maybe<Scalars['DateTime']>;
  id: Scalars['ID'];
  lastUpdated?: Maybe<Scalars['DateTime']>;
  name: Scalars['String'];
  progress: Scalars['Float'];
  state: StageStateEnum;
  tasks?: Maybe<TaskNestedList>;
  weight?: Maybe<Scalars['Int']>;
  workflow: Workflow;
};

export type StageAssigneesArgs = {
  filter?: InputMaybe<Array<CaseDbUserFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<CaseDbUserOrdEnumOrderingEntry>>;
};

export type StageTasksArgs = {
  filter?: InputMaybe<Array<TaskFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TaskOrdEnumOrderingEntry>>;
};

export type StageCreate = {
  assignees?: InputMaybe<Array<Scalars['ID']>>;
  created?: InputMaybe<Scalars['DateTime']>;
  createdBy?: InputMaybe<Scalars['ID']>;
  description: Scalars['String'];
  dueDate?: InputMaybe<Scalars['DateTime']>;
  lastUpdated?: InputMaybe<Scalars['DateTime']>;
  name: Scalars['String'];
  tasks?: InputMaybe<Array<Scalars['ID']>>;
  weight?: InputMaybe<Scalars['Int']>;
  workflow: Scalars['ID'];
};

export type StageFilter0 = {
  caseIdentifier?: InputMaybe<StrFieldFilter>;
  created?: InputMaybe<DateTimeFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  dueDate?: InputMaybe<DateTimeFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  lastUpdated?: InputMaybe<DateTimeFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
  progress?: InputMaybe<FloatFieldFilter>;
  state?: InputMaybe<StageStateEnumEnumFieldFilter>;
  weight?: InputMaybe<IntFieldFilter>;
};

export type StageFilter0AndFilterEntry = {
  AND: Array<StageFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type StageFilter0OrFilterEntry = {
  OR: StageFilter0;
  negate?: Scalars['Boolean'];
};

export type StageFilter1 = {
  assignees?: InputMaybe<CaseDbUserFilter1>;
  caseIdentifier?: InputMaybe<StrFieldFilter>;
  created?: InputMaybe<DateTimeFieldFilter>;
  createdBy?: InputMaybe<CaseDbUserFilter1>;
  description?: InputMaybe<StrFieldFilter>;
  dueDate?: InputMaybe<DateTimeFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  lastUpdated?: InputMaybe<DateTimeFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
  progress?: InputMaybe<FloatFieldFilter>;
  state?: InputMaybe<StageStateEnumEnumFieldFilter>;
  tasks?: InputMaybe<TaskFilter1>;
  weight?: InputMaybe<IntFieldFilter>;
  workflow?: InputMaybe<WorkflowFilter1>;
};

export type StageFilter1AndFilterEntry = {
  AND: Array<StageFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type StageFilter1OrFilterEntry = {
  OR: StageFilter1;
  negate?: Scalars['Boolean'];
};

export type StageNestedList = {
  __typename?: 'StageNestedList';
  data: Array<Stage>;
  totalCount: Scalars['Int'];
};

export enum StageOrdEnum {
  CASE_IDENTIFIER = 'CASE_IDENTIFIER',
  CREATED = 'CREATED',
  DESCRIPTION = 'DESCRIPTION',
  DUE_DATE = 'DUE_DATE',
  ID = 'ID',
  LAST_UPDATED = 'LAST_UPDATED',
  NAME = 'NAME',
  PROGRESS = 'PROGRESS',
  STATE = 'STATE',
  WEIGHT = 'WEIGHT',
}

export type StageOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: StageOrdEnum;
};

export type StagePaginated = {
  __typename?: 'StagePaginated';
  data: Array<Stage>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export enum StageStateEnum {
  DONE = 'DONE',
  IN_PROGRESS = 'IN_PROGRESS',
  PENDING = 'PENDING',
  REJECTED = 'REJECTED',
}

export type StageStateEnumEnumFieldFilter = {
  exact?: InputMaybe<StageStateEnum>;
  except_?: InputMaybe<StageStateEnum>;
  in_?: InputMaybe<Array<StageStateEnum>>;
  isnull?: InputMaybe<Scalars['Boolean']>;
};

export type StageUpdate = {
  assignees?: InputMaybe<RelationUpdate>;
  created?: InputMaybe<Scalars['DateTime']>;
  createdBy?: InputMaybe<Scalars['ID']>;
  description?: InputMaybe<Scalars['String']>;
  dueDate?: InputMaybe<Scalars['DateTime']>;
  lastUpdated?: InputMaybe<Scalars['DateTime']>;
  name?: InputMaybe<Scalars['String']>;
  tasks?: InputMaybe<RelationUpdate>;
  weight?: InputMaybe<Scalars['Int']>;
  workflow?: InputMaybe<Scalars['ID']>;
};

export type StatementVertex = {
  __typename?: 'StatementVertex';
  andOperands?: Maybe<Array<Maybe<AndVertex>>>;
  defNode?: Maybe<DefNode>;
};

export type StorageEvent = Event & {
  __typename?: 'StorageEvent';
  appName: Scalars['String'];
  created?: Maybe<Scalars['DateTime']>;
  description?: Maybe<Scalars['String']>;
  eventTime?: Maybe<Scalars['DateTime']>;
  id: Scalars['ID'];
  message: Scalars['String'];
  name?: Maybe<Scalars['String']>;
  procId: Scalars['Int'];
  relatedCases?: Maybe<CaseNestedList>;
  relatedTasks?: Maybe<TaskNestedList>;
  type?: Maybe<Scalars['String']>;
  uniqueIdentifier: Scalars['String'];
};

export type StorageEventRelatedCasesArgs = {
  filter?: InputMaybe<Array<CaseFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<CaseOrdEnumOrderingEntry>>;
};

export type StorageEventRelatedTasksArgs = {
  filter?: InputMaybe<Array<TaskFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TaskOrdEnumOrderingEntry>>;
};

export type StorageEventCreate = {
  appName: Scalars['String'];
  created?: InputMaybe<Scalars['DateTime']>;
  description?: InputMaybe<Scalars['String']>;
  eventTime?: InputMaybe<Scalars['DateTime']>;
  message: Scalars['String'];
  name?: InputMaybe<Scalars['String']>;
  procId: Scalars['Int'];
  relatedCases?: InputMaybe<Array<Scalars['ID']>>;
  relatedTasks?: InputMaybe<Array<Scalars['ID']>>;
};

export type StorageEventFilter1 = {
  appName?: InputMaybe<StrFieldFilter>;
  created?: InputMaybe<DateTimeFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  eventTime?: InputMaybe<DateTimeFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  message?: InputMaybe<StrFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
  procId?: InputMaybe<IntFieldFilter>;
  relatedCases?: InputMaybe<CaseFilter1>;
  relatedTasks?: InputMaybe<TaskFilter1>;
  type?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type StorageEventFilter1AndFilterEntry = {
  AND: Array<StorageEventFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type StorageEventFilter1OrFilterEntry = {
  OR: StorageEventFilter1;
  negate?: Scalars['Boolean'];
};

export enum StorageEventOrdEnum {
  APP_NAME = 'APP_NAME',
  CREATED = 'CREATED',
  DESCRIPTION = 'DESCRIPTION',
  EVENT_TIME = 'EVENT_TIME',
  ID = 'ID',
  MESSAGE = 'MESSAGE',
  NAME = 'NAME',
  PROC_ID = 'PROC_ID',
  TYPE = 'TYPE',
  UNIQUE_IDENTIFIER = 'UNIQUE_IDENTIFIER',
}

export type StorageEventOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: StorageEventOrdEnum;
};

export type StorageEventPaginated = {
  __typename?: 'StorageEventPaginated';
  data: Array<StorageEvent>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type StorageEventUpdate = {
  appName?: InputMaybe<Scalars['String']>;
  created?: InputMaybe<Scalars['DateTime']>;
  description?: InputMaybe<Scalars['String']>;
  eventTime?: InputMaybe<Scalars['DateTime']>;
  message?: InputMaybe<Scalars['String']>;
  name?: InputMaybe<Scalars['String']>;
  procId?: InputMaybe<Scalars['Int']>;
  relatedCases?: InputMaybe<RelationUpdate>;
  relatedTasks?: InputMaybe<RelationUpdate>;
};

export type StrFieldFilter = {
  contains?: InputMaybe<Scalars['String']>;
  endswith?: InputMaybe<Scalars['String']>;
  exact?: InputMaybe<Scalars['String']>;
  except_?: InputMaybe<Scalars['String']>;
  gt?: InputMaybe<Scalars['String']>;
  gte?: InputMaybe<Scalars['String']>;
  icontains?: InputMaybe<Scalars['String']>;
  iendswith?: InputMaybe<Scalars['String']>;
  iexact?: InputMaybe<Scalars['String']>;
  in_?: InputMaybe<Array<Scalars['String']>>;
  isnull?: InputMaybe<Scalars['Boolean']>;
  istartswith?: InputMaybe<Scalars['String']>;
  lt?: InputMaybe<Scalars['String']>;
  lte?: InputMaybe<Scalars['String']>;
  startswith?: InputMaybe<Scalars['String']>;
};

export type StrFilter = {
  contains?: InputMaybe<Scalars['String']>;
  endswith?: InputMaybe<Scalars['String']>;
  exact?: InputMaybe<Scalars['String']>;
  except_?: InputMaybe<Scalars['String']>;
  gt?: InputMaybe<Scalars['String']>;
  gte?: InputMaybe<Scalars['String']>;
  iContains?: InputMaybe<Scalars['String']>;
  iEndswith?: InputMaybe<Scalars['String']>;
  iExact?: InputMaybe<Scalars['String']>;
  iExcept?: InputMaybe<Scalars['String']>;
  iStartswith?: InputMaybe<Scalars['String']>;
  in_?: InputMaybe<Array<Scalars['String']>>;
  lt?: InputMaybe<Scalars['String']>;
  lte?: InputMaybe<Scalars['String']>;
  startswith?: InputMaybe<Scalars['String']>;
};

export type StrawberryIdFieldFilter = {
  exact?: InputMaybe<Scalars['ID']>;
  except_?: InputMaybe<Scalars['ID']>;
  in_?: InputMaybe<Array<Scalars['ID']>>;
};

export type StrawberryIdFilter = {
  exact?: InputMaybe<Scalars['ID']>;
  except_?: InputMaybe<Scalars['ID']>;
  in_?: InputMaybe<Array<Scalars['ID']>>;
};

export type StringInputOutput = TaskInputOutput & {
  __typename?: 'StringInputOutput';
  description?: Maybe<Scalars['String']>;
  id: Scalars['ID'];
  inputOf?: Maybe<Task>;
  outputOf?: Maybe<Task>;
  stringRegex?: Maybe<Scalars['String']>;
  stringValue?: Maybe<Scalars['String']>;
  stringifiedValue?: Maybe<Scalars['String']>;
  type?: Maybe<Scalars['String']>;
};

export type StringInputOutputCreate = {
  description?: InputMaybe<Scalars['String']>;
  inputOf?: InputMaybe<Scalars['ID']>;
  outputOf?: InputMaybe<Scalars['ID']>;
  stringRegex?: InputMaybe<Scalars['String']>;
  stringValue?: InputMaybe<Scalars['String']>;
};

export type StringInputOutputFilter1 = {
  description?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  inputOf?: InputMaybe<TaskFilter1>;
  outputOf?: InputMaybe<TaskFilter1>;
  stringRegex?: InputMaybe<StrFieldFilter>;
  stringValue?: InputMaybe<StrFieldFilter>;
  type?: InputMaybe<StrFieldFilter>;
};

export type StringInputOutputFilter1AndFilterEntry = {
  AND: Array<StringInputOutputFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type StringInputOutputFilter1OrFilterEntry = {
  OR: StringInputOutputFilter1;
  negate?: Scalars['Boolean'];
};

export enum StringInputOutputOrdEnum {
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  STRING_REGEX = 'STRING_REGEX',
  STRING_VALUE = 'STRING_VALUE',
  TYPE = 'TYPE',
}

export type StringInputOutputOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: StringInputOutputOrdEnum;
};

export type StringInputOutputPaginated = {
  __typename?: 'StringInputOutputPaginated';
  data: Array<StringInputOutput>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type StringInputOutputUpdate = {
  description?: InputMaybe<Scalars['String']>;
  inputOf?: InputMaybe<Scalars['ID']>;
  outputOf?: InputMaybe<Scalars['ID']>;
  stringRegex?: InputMaybe<Scalars['String']>;
  stringValue?: InputMaybe<Scalars['String']>;
};

export type StringRange = {
  __typename?: 'StringRange';
  end?: Maybe<Scalars['String']>;
  start?: Maybe<Scalars['String']>;
};

export type TtpFederationBase = {
  cases: CaseFederationResult;
  created?: Maybe<Scalars['DateTime']>;
  description?: Maybe<Scalars['String']>;
  id: Scalars['ID'];
  modified?: Maybe<Scalars['DateTime']>;
  tasks: TaskFederationResult;
  ttpType?: Maybe<Scalars['String']>;
  ttpTypeEnum?: Maybe<KnownTtPsTypesEnum>;
};

export type TtpFederationBaseCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type TtpFederationBaseTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type TtpFederationBaseFederationResult = {
  __typename?: 'TTPFederationBaseFederationResult';
  data: Array<TtpFederationBase>;
  error?: Maybe<Scalars['String']>;
};

export type TtpFederationBaseFilter = {
  caseId?: InputMaybe<StrawberryIdFilter>;
  taskId?: InputMaybe<StrawberryIdFilter>;
  ttpId?: InputMaybe<StrawberryIdFilter>;
  ttpType?: InputMaybe<KnownTtPsTypesEnumEnumFilter>;
};

export type TtpFederationBaseFilterAndFilterEntry = {
  AND: Array<TtpFederationBaseFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type TtpFederationBaseFilterOrFilterEntry = {
  OR: Array<TtpFederationBaseFilter>;
  negate?: Scalars['Boolean'];
};

export type TtpGroup = {
  __typename?: 'TTPGroup';
  aliases?: Maybe<AliasNestedList>;
  created?: Maybe<Scalars['DateTime']>;
  description?: Maybe<Scalars['String']>;
  externalReferences?: Maybe<ExternalReferenceNestedList>;
  id: Scalars['ID'];
  malware?: Maybe<MalwareNestedList>;
  modified?: Maybe<Scalars['DateTime']>;
  name: Scalars['String'];
  techniquesUsed?: Maybe<GroupProcedureNestedList>;
  tools?: Maybe<ToolNestedList>;
};

export type TtpGroupAliasesArgs = {
  filter?: InputMaybe<Array<AliasFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<AliasOrdEnumOrderingEntry>>;
};

export type TtpGroupExternalReferencesArgs = {
  filter?: InputMaybe<Array<ExternalReferenceFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ExternalReferenceOrdEnumOrderingEntry>>;
};

export type TtpGroupMalwareArgs = {
  filter?: InputMaybe<Array<MalwareFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<MalwareOrdEnumOrderingEntry>>;
};

export type TtpGroupTechniquesUsedArgs = {
  filter?: InputMaybe<Array<GroupProcedureFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<GroupProcedureOrdEnumOrderingEntry>>;
};

export type TtpGroupToolsArgs = {
  filter?: InputMaybe<Array<ToolFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ToolOrdEnumOrderingEntry>>;
};

export type TtpGroupCreate = {
  aliases?: InputMaybe<Array<Scalars['ID']>>;
  description?: InputMaybe<Scalars['String']>;
  externalReferences?: InputMaybe<Array<Scalars['ID']>>;
  malware?: InputMaybe<Array<Scalars['ID']>>;
  name: Scalars['String'];
  techniquesUsed?: InputMaybe<Array<Scalars['ID']>>;
  tools?: InputMaybe<Array<Scalars['ID']>>;
};

export type TtpGroupFilter0 = {
  created?: InputMaybe<DateTimeFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  modified?: InputMaybe<DateTimeFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
};

export type TtpGroupFilter0AndFilterEntry = {
  AND: Array<TtpGroupFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type TtpGroupFilter0OrFilterEntry = {
  OR: TtpGroupFilter0;
  negate?: Scalars['Boolean'];
};

export type TtpGroupFilter1 = {
  aliases?: InputMaybe<AliasFilter1>;
  created?: InputMaybe<DateTimeFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  externalReferences?: InputMaybe<ExternalReferenceFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  malware?: InputMaybe<MalwareFilter1>;
  modified?: InputMaybe<DateTimeFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
  techniquesUsed?: InputMaybe<GroupProcedureFilter1>;
  tools?: InputMaybe<ToolFilter1>;
};

export type TtpGroupFilter1AndFilterEntry = {
  AND: Array<TtpGroupFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type TtpGroupFilter1OrFilterEntry = {
  OR: TtpGroupFilter1;
  negate?: Scalars['Boolean'];
};

export type TtpGroupNestedList = {
  __typename?: 'TTPGroupNestedList';
  data: Array<TtpGroup>;
  totalCount: Scalars['Int'];
};

export enum TtpGroupOrdEnum {
  CREATED = 'CREATED',
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  MODIFIED = 'MODIFIED',
  NAME = 'NAME',
}

export type TtpGroupOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: TtpGroupOrdEnum;
};

export type TtpGroupPaginated = {
  __typename?: 'TTPGroupPaginated';
  data: Array<TtpGroup>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type TtpGroupUpdate = {
  aliases?: InputMaybe<RelationUpdate>;
  description?: InputMaybe<Scalars['String']>;
  externalReferences?: InputMaybe<RelationUpdate>;
  malware?: InputMaybe<RelationUpdate>;
  name?: InputMaybe<Scalars['String']>;
  techniquesUsed?: InputMaybe<RelationUpdate>;
  tools?: InputMaybe<RelationUpdate>;
};

export type TtpInput = {
  id: Scalars['ID'];
  ttpType: KnownTtPsTypesEnum;
};

export type TtpLink = {
  __typename?: 'TTPLink';
  ctiEntry?: Maybe<CtiEntry>;
  id: Scalars['ID'];
  ttpMeta?: Maybe<TtpMeta>;
  ttpMetaLinkType?: Maybe<Scalars['String']>;
};

export type TtpLinkCreate = {
  ctiEntry?: InputMaybe<Scalars['ID']>;
  ttpMeta?: InputMaybe<Scalars['ID']>;
  ttpMetaLinkType?: InputMaybe<Scalars['String']>;
};

export type TtpLinkFilter0 = {
  id?: InputMaybe<StrawberryIdFieldFilter>;
  ttpMetaLinkType?: InputMaybe<StrFieldFilter>;
};

export type TtpLinkFilter0AndFilterEntry = {
  AND: Array<TtpLinkFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type TtpLinkFilter0OrFilterEntry = {
  OR: TtpLinkFilter0;
  negate?: Scalars['Boolean'];
};

export type TtpLinkFilter1 = {
  ctiEntry?: InputMaybe<CtiEntryFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  ttpMeta?: InputMaybe<TtpMetaFilter1>;
  ttpMetaLinkType?: InputMaybe<StrFieldFilter>;
};

export type TtpLinkFilter1AndFilterEntry = {
  AND: Array<TtpLinkFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type TtpLinkFilter1OrFilterEntry = {
  OR: TtpLinkFilter1;
  negate?: Scalars['Boolean'];
};

export type TtpLinkNestedList = {
  __typename?: 'TTPLinkNestedList';
  data: Array<TtpLink>;
  totalCount: Scalars['Int'];
};

export enum TtpLinkOrdEnum {
  ID = 'ID',
  TTP_META_LINK_TYPE = 'TTP_META_LINK_TYPE',
}

export type TtpLinkOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: TtpLinkOrdEnum;
};

export type TtpLinkPaginated = {
  __typename?: 'TTPLinkPaginated';
  data: Array<TtpLink>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type TtpLinkUpdate = {
  ctiEntry?: InputMaybe<Scalars['ID']>;
  ttpMeta?: InputMaybe<Scalars['ID']>;
  ttpMetaLinkType?: InputMaybe<Scalars['String']>;
};

export type TtpMeta = {
  __typename?: 'TTPMeta';
  ctiEntries?: Maybe<TtpLinkNestedList>;
  description?: Maybe<Scalars['String']>;
  id: Scalars['ID'];
  ttpId: Scalars['String'];
};

export type TtpMetaCtiEntriesArgs = {
  filter?: InputMaybe<Array<TtpLinkFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TtpLinkOrdEnumOrderingEntry>>;
};

export type TtpMetaCreate = {
  ctiEntries?: InputMaybe<Array<Scalars['ID']>>;
  description?: InputMaybe<Scalars['String']>;
  ttpId: Scalars['String'];
};

export type TtpMetaFilter1 = {
  ctiEntries?: InputMaybe<TtpLinkFilter1>;
  description?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  ttpId?: InputMaybe<StrFieldFilter>;
};

export type TtpMetaFilter1AndFilterEntry = {
  AND: Array<TtpMetaFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type TtpMetaFilter1OrFilterEntry = {
  OR: TtpMetaFilter1;
  negate?: Scalars['Boolean'];
};

export type TtpMetaNestedListResult = {
  __typename?: 'TTPMetaNestedListResult';
  data?: Maybe<TtpMeta>;
  error?: Maybe<ValidationError>;
};

export enum TtpMetaOrdEnum {
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  TTP_ID = 'TTP_ID',
}

export type TtpMetaOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: TtpMetaOrdEnum;
};

export type TtpMetaPaginated = {
  __typename?: 'TTPMetaPaginated';
  data: Array<TtpMeta>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type TtpMetaUpdate = {
  ctiEntries?: InputMaybe<RelationUpdate>;
  description?: InputMaybe<Scalars['String']>;
  ttpId?: InputMaybe<Scalars['String']>;
};

export type TtpPlatform = {
  __typename?: 'TTPPlatform';
  id: Scalars['ID'];
  malware?: Maybe<MalwareNestedList>;
  techniques?: Maybe<TechniqueNestedList>;
  tools?: Maybe<ToolNestedList>;
  value: Scalars['String'];
};

export type TtpPlatformMalwareArgs = {
  filter?: InputMaybe<Array<MalwareFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<MalwareOrdEnumOrderingEntry>>;
};

export type TtpPlatformTechniquesArgs = {
  filter?: InputMaybe<Array<TechniqueFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TechniqueOrdEnumOrderingEntry>>;
};

export type TtpPlatformToolsArgs = {
  filter?: InputMaybe<Array<ToolFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ToolOrdEnumOrderingEntry>>;
};

export type TtpPlatformCreate = {
  malware?: InputMaybe<Array<Scalars['ID']>>;
  techniques?: InputMaybe<Array<Scalars['ID']>>;
  tools?: InputMaybe<Array<Scalars['ID']>>;
  value: Scalars['String'];
};

export type TtpPlatformFilter0 = {
  id?: InputMaybe<StrawberryIdFieldFilter>;
  value?: InputMaybe<StrFieldFilter>;
};

export type TtpPlatformFilter0AndFilterEntry = {
  AND: Array<TtpPlatformFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type TtpPlatformFilter0OrFilterEntry = {
  OR: TtpPlatformFilter0;
  negate?: Scalars['Boolean'];
};

export type TtpPlatformFilter1 = {
  id?: InputMaybe<StrawberryIdFieldFilter>;
  malware?: InputMaybe<MalwareFilter1>;
  techniques?: InputMaybe<TechniqueFilter1>;
  tools?: InputMaybe<ToolFilter1>;
  value?: InputMaybe<StrFieldFilter>;
};

export type TtpPlatformFilter1AndFilterEntry = {
  AND: Array<TtpPlatformFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type TtpPlatformFilter1OrFilterEntry = {
  OR: TtpPlatformFilter1;
  negate?: Scalars['Boolean'];
};

export type TtpPlatformNestedList = {
  __typename?: 'TTPPlatformNestedList';
  data: Array<TtpPlatform>;
  totalCount: Scalars['Int'];
};

export enum TtpPlatformOrdEnum {
  ID = 'ID',
  VALUE = 'VALUE',
}

export type TtpPlatformOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: TtpPlatformOrdEnum;
};

export type TtpPlatformPaginated = {
  __typename?: 'TTPPlatformPaginated';
  data: Array<TtpPlatform>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type TtpPlatformUpdate = {
  malware?: InputMaybe<RelationUpdate>;
  techniques?: InputMaybe<RelationUpdate>;
  tools?: InputMaybe<RelationUpdate>;
  value?: InputMaybe<Scalars['String']>;
};

export type Tactic = Ittp &
  TtpFederationBase & {
    __typename?: 'Tactic';
    cases: CaseFederationResult;
    created?: Maybe<Scalars['DateTime']>;
    description?: Maybe<Scalars['String']>;
    externalReferences?: Maybe<ExternalReferenceNestedList>;
    id: Scalars['ID'];
    modified?: Maybe<Scalars['DateTime']>;
    tacticName: Scalars['String'];
    tasks: TaskFederationResult;
    techniques?: Maybe<TechniqueNestedList>;
    ttpType?: Maybe<Scalars['String']>;
    ttpTypeEnum?: Maybe<KnownTtPsTypesEnum>;
    uniqueIdentifier: Scalars['String'];
  };

export type TacticCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type TacticExternalReferencesArgs = {
  filter?: InputMaybe<Array<ExternalReferenceFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ExternalReferenceOrdEnumOrderingEntry>>;
};

export type TacticTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type TacticTechniquesArgs = {
  filter?: InputMaybe<Array<TechniqueFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TechniqueOrdEnumOrderingEntry>>;
};

export type TacticCreate = {
  description?: InputMaybe<Scalars['String']>;
  externalReferences?: InputMaybe<Array<Scalars['ID']>>;
  tacticName: Scalars['String'];
  techniques?: InputMaybe<Array<Scalars['ID']>>;
};

export type TacticFilter0 = {
  created?: InputMaybe<DateTimeFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  modified?: InputMaybe<DateTimeFieldFilter>;
  tacticName?: InputMaybe<StrFieldFilter>;
  ttpType?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type TacticFilter0AndFilterEntry = {
  AND: Array<TacticFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type TacticFilter0OrFilterEntry = {
  OR: TacticFilter0;
  negate?: Scalars['Boolean'];
};

export type TacticFilter1 = {
  created?: InputMaybe<DateTimeFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  externalReferences?: InputMaybe<ExternalReferenceFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  modified?: InputMaybe<DateTimeFieldFilter>;
  tacticName?: InputMaybe<StrFieldFilter>;
  techniques?: InputMaybe<TechniqueFilter1>;
  ttpType?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type TacticFilter1AndFilterEntry = {
  AND: Array<TacticFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type TacticFilter1OrFilterEntry = {
  OR: TacticFilter1;
  negate?: Scalars['Boolean'];
};

export type TacticNestedList = {
  __typename?: 'TacticNestedList';
  data: Array<Tactic>;
  totalCount: Scalars['Int'];
};

export enum TacticOrdEnum {
  CREATED = 'CREATED',
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  MODIFIED = 'MODIFIED',
  TACTIC_NAME = 'TACTIC_NAME',
  TTP_TYPE = 'TTP_TYPE',
  UNIQUE_IDENTIFIER = 'UNIQUE_IDENTIFIER',
}

export type TacticOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: TacticOrdEnum;
};

export type TacticPaginated = {
  __typename?: 'TacticPaginated';
  data: Array<Tactic>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type TacticUpdate = {
  description?: InputMaybe<Scalars['String']>;
  externalReferences?: InputMaybe<RelationUpdate>;
  tacticName?: InputMaybe<Scalars['String']>;
  techniques?: InputMaybe<RelationUpdate>;
};

export type TagType = {
  __typename?: 'TagType';
  assetType?: Maybe<KnownAssetsEnum>;
  color?: Maybe<Scalars['String']>;
  created?: Maybe<Scalars['String']>;
  description?: Maybe<Scalars['String']>;
  id?: Maybe<Scalars['ID']>;
  lastUpdated?: Maybe<Scalars['String']>;
  name?: Maybe<Scalars['String']>;
  slug?: Maybe<Scalars['String']>;
};

export type TagTypeResultSet = {
  __typename?: 'TagTypeResultSet';
  data: Array<TagType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type TargetAvSpecVertex = {
  __typename?: 'TargetAVSpecVertex';
  aVPair?: Maybe<AvPair>;
  attribute?: Maybe<WellFormedNameAttribute>;
  id?: Maybe<Scalars['String']>;
  relationEdges?: Maybe<Array<Maybe<RelationEdge>>>;
  uid?: Maybe<Scalars['String']>;
};

export type Task = {
  __typename?: 'Task';
  aggregatesResults?: Maybe<Scalars['Boolean']>;
  assets: AssetFederationBaseFederationResult;
  assignees?: Maybe<CaseDbUserNestedList>;
  autotrigger?: Maybe<Scalars['Boolean']>;
  caseIdentifier?: Maybe<Scalars['String']>;
  comments?: Maybe<CommentNestedList>;
  created?: Maybe<Scalars['DateTime']>;
  createdBy?: Maybe<CaseDbUser>;
  decision?: Maybe<Scalars['Boolean']>;
  description: Scalars['String'];
  dueDate?: Maybe<Scalars['DateTime']>;
  events?: Maybe<EventNestedList>;
  externalReferences?: Maybe<CaseManagementExternalReferenceNestedList>;
  id: Scalars['ID'];
  input?: Maybe<TaskInputOutput>;
  isAutomated?: Maybe<Scalars['Boolean']>;
  isDecision?: Maybe<Scalars['Boolean']>;
  labels?: Maybe<LabelNestedList>;
  lastUpdated?: Maybe<Scalars['DateTime']>;
  name: Scalars['String'];
  observables: ObservableFederationBaseFederationResult;
  output?: Maybe<TaskInputOutput>;
  outputIsJoined?: Maybe<Scalars['Boolean']>;
  processingQueue?: Maybe<Scalars['String']>;
  referencedBy?: Maybe<TaskReferenceNestedList>;
  refersTo?: Maybe<TaskReferenceNestedList>;
  relatedUsers: RelatedUserFederatedTypeFederationResult;
  sourceRelationships?: Maybe<TaskRelationshipNestedList>;
  stage: Stage;
  state?: Maybe<TaskStateEnum>;
  targetRelationships?: Maybe<TaskRelationshipNestedList>;
  ttps: TtpFederationBaseFederationResult;
  weight?: Maybe<Scalars['Int']>;
};

export type TaskAssetsArgs = {
  filter?: InputMaybe<Array<AssetFederationBaseFilterAndFilterEntry>>;
};

export type TaskAssigneesArgs = {
  filter?: InputMaybe<Array<CaseDbUserFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<CaseDbUserOrdEnumOrderingEntry>>;
};

export type TaskCommentsArgs = {
  filter?: InputMaybe<Array<CommentFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<CommentOrdEnumOrderingEntry>>;
};

export type TaskEventsArgs = {
  filter?: InputMaybe<Array<EventFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<EventOrdEnumOrderingEntry>>;
};

export type TaskExternalReferencesArgs = {
  filter?: InputMaybe<Array<CaseManagementExternalReferenceFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<CaseManagementExternalReferenceOrdEnumOrderingEntry>>;
};

export type TaskLabelsArgs = {
  filter?: InputMaybe<Array<LabelFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<LabelOrdEnumOrderingEntry>>;
};

export type TaskObservablesArgs = {
  filter?: InputMaybe<Array<ObservableFederationBaseFilterAndFilterEntry>>;
};

export type TaskReferencedByArgs = {
  filter?: InputMaybe<Array<TaskReferenceFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TaskReferenceOrdEnumOrderingEntry>>;
};

export type TaskRefersToArgs = {
  filter?: InputMaybe<Array<TaskReferenceFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TaskReferenceOrdEnumOrderingEntry>>;
};

export type TaskRelatedUsersArgs = {
  filter?: InputMaybe<Array<RelatedUserFederationBaseFilterAndFilterEntry>>;
};

export type TaskSourceRelationshipsArgs = {
  filter?: InputMaybe<Array<TaskRelationshipFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TaskRelationshipOrdEnumOrderingEntry>>;
};

export type TaskTargetRelationshipsArgs = {
  filter?: InputMaybe<Array<TaskRelationshipFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TaskRelationshipOrdEnumOrderingEntry>>;
};

export type TaskTtpsArgs = {
  filter?: InputMaybe<Array<TtpFederationBaseFilterAndFilterEntry>>;
};

export type TaskCreate = {
  aggregatesResults?: InputMaybe<Scalars['Boolean']>;
  autotrigger?: InputMaybe<Scalars['Boolean']>;
  createdBy?: InputMaybe<Scalars['ID']>;
  description: Scalars['String'];
  dueDate?: InputMaybe<Scalars['DateTime']>;
  input?: InputMaybe<Scalars['String']>;
  inputDescription?: InputMaybe<Scalars['String']>;
  inputFormat?: InputMaybe<Scalars['String']>;
  inputType?: InputMaybe<KnownInputOutputTypes>;
  isAutomated?: InputMaybe<Scalars['Boolean']>;
  isDecision?: InputMaybe<Scalars['Boolean']>;
  name: Scalars['String'];
  output?: InputMaybe<Scalars['String']>;
  outputDescription?: InputMaybe<Scalars['String']>;
  outputFormat?: InputMaybe<Scalars['String']>;
  outputType?: InputMaybe<KnownInputOutputTypes>;
  predecessors: Array<PredecessorInput>;
  processingQueue?: InputMaybe<Scalars['String']>;
  stage?: InputMaybe<Scalars['ID']>;
};

export type TaskCreateBulk = {
  inputFile?: InputMaybe<Scalars['Upload']>;
  task: TaskCreate;
};

export type TaskCreateParentless = {
  aggregatesResults?: InputMaybe<Scalars['Boolean']>;
  autotrigger?: InputMaybe<Scalars['Boolean']>;
  createdBy?: InputMaybe<Scalars['ID']>;
  description: Scalars['String'];
  dueDate?: InputMaybe<Scalars['DateTime']>;
  input?: InputMaybe<Scalars['String']>;
  inputDescription?: InputMaybe<Scalars['String']>;
  inputFormat?: InputMaybe<Scalars['String']>;
  inputType?: InputMaybe<KnownInputOutputTypes>;
  isAutomated?: InputMaybe<Scalars['Boolean']>;
  isDecision?: InputMaybe<Scalars['Boolean']>;
  name: Scalars['String'];
  output?: InputMaybe<Scalars['String']>;
  outputDescription?: InputMaybe<Scalars['String']>;
  outputFormat?: InputMaybe<Scalars['String']>;
  outputType?: InputMaybe<KnownInputOutputTypes>;
  predecessors?: InputMaybe<Array<PredecessorInput>>;
  processingQueue?: InputMaybe<Scalars['String']>;
  stage: Scalars['ID'];
};

export type TaskCreateParentlessBulk = {
  inputFile?: InputMaybe<Scalars['Upload']>;
  task: TaskCreateParentless;
};

export type TaskFederationResult = {
  __typename?: 'TaskFederationResult';
  data: Array<Task>;
  error?: Maybe<Scalars['String']>;
};

export type TaskFilter = {
  asset?: InputMaybe<AssetFederationBaseFilter>;
  ids?: InputMaybe<Array<StrawberryIdFilter>>;
  observable?: InputMaybe<ObservableFederationBaseFilter>;
  relatedUser?: InputMaybe<RelatedUserFederationBaseFilter>;
  ttp?: InputMaybe<TtpFederationBaseFilter>;
};

export type TaskFilter0 = {
  aggregatesResults?: InputMaybe<BoolFieldFilter>;
  autotrigger?: InputMaybe<BoolFieldFilter>;
  caseIdentifier?: InputMaybe<StrFieldFilter>;
  created?: InputMaybe<DateTimeFieldFilter>;
  decision?: InputMaybe<BoolFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  dueDate?: InputMaybe<DateTimeFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  isAutomated?: InputMaybe<BoolFieldFilter>;
  isDecision?: InputMaybe<BoolFieldFilter>;
  lastUpdated?: InputMaybe<DateTimeFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
  outputIsJoined?: InputMaybe<BoolFieldFilter>;
  processingQueue?: InputMaybe<StrFieldFilter>;
  state?: InputMaybe<TaskStateEnumEnumFieldFilter>;
  weight?: InputMaybe<IntFieldFilter>;
};

export type TaskFilter0AndFilterEntry = {
  AND: Array<TaskFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type TaskFilter0OrFilterEntry = {
  OR: TaskFilter0;
  negate?: Scalars['Boolean'];
};

export type TaskFilter1 = {
  aggregatesResults?: InputMaybe<BoolFieldFilter>;
  assignees?: InputMaybe<CaseDbUserFilter1>;
  autotrigger?: InputMaybe<BoolFieldFilter>;
  caseIdentifier?: InputMaybe<StrFieldFilter>;
  comments?: InputMaybe<CommentFilter1>;
  created?: InputMaybe<DateTimeFieldFilter>;
  createdBy?: InputMaybe<CaseDbUserFilter1>;
  decision?: InputMaybe<BoolFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  dueDate?: InputMaybe<DateTimeFieldFilter>;
  events?: InputMaybe<EventFilter1>;
  externalReferences?: InputMaybe<CaseManagementExternalReferenceFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  input?: InputMaybe<TaskInputOutputFilter1>;
  isAutomated?: InputMaybe<BoolFieldFilter>;
  isDecision?: InputMaybe<BoolFieldFilter>;
  labels?: InputMaybe<LabelFilter1>;
  lastUpdated?: InputMaybe<DateTimeFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
  output?: InputMaybe<TaskInputOutputFilter1>;
  outputIsJoined?: InputMaybe<BoolFieldFilter>;
  processingQueue?: InputMaybe<StrFieldFilter>;
  referencedBy?: InputMaybe<TaskReferenceFilter1>;
  refersTo?: InputMaybe<TaskReferenceFilter1>;
  sourceRelationships?: InputMaybe<TaskRelationshipFilter1>;
  stage?: InputMaybe<StageFilter1>;
  state?: InputMaybe<TaskStateEnumEnumFieldFilter>;
  targetRelationships?: InputMaybe<TaskRelationshipFilter1>;
  weight?: InputMaybe<IntFieldFilter>;
};

export type TaskFilter1AndFilterEntry = {
  AND: Array<TaskFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type TaskFilter1OrFilterEntry = {
  OR: TaskFilter1;
  negate?: Scalars['Boolean'];
};

export type TaskFilterAndFilterEntry = {
  AND: Array<TaskFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type TaskFilterOrFilterEntry = {
  OR: Array<TaskFilter>;
  negate?: Scalars['Boolean'];
};

export type TaskInput = {
  id: Scalars['ID'];
};

export type TaskInputOutput = {
  description?: Maybe<Scalars['String']>;
  id: Scalars['ID'];
  inputOf?: Maybe<Task>;
  outputOf?: Maybe<Task>;
  stringifiedValue?: Maybe<Scalars['String']>;
  type?: Maybe<Scalars['String']>;
};

export type TaskInputOutputFilter1 = {
  booleanValue?: InputMaybe<BoolFieldFilter>;
  dateValue?: InputMaybe<DateTimeFieldFilter>;
  datetimeValue?: InputMaybe<DateTimeFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  domainValue?: InputMaybe<StrFieldFilter>;
  emailAddressValue?: InputMaybe<StrFieldFilter>;
  emailMessageValue?: InputMaybe<StrFieldFilter>;
  fileRefValue?: InputMaybe<StrFieldFilter>;
  fileValue?: InputMaybe<StrFieldFilter>;
  hashValue?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  inputOf?: InputMaybe<TaskFilter1>;
  ipValue?: InputMaybe<StrFieldFilter>;
  jsonFormlySchema?: InputMaybe<StrFieldFilter>;
  jsonInitialValue?: InputMaybe<StrFieldFilter>;
  jsonSchema?: InputMaybe<StrFieldFilter>;
  jsonValue?: InputMaybe<StrFieldFilter>;
  outputOf?: InputMaybe<TaskFilter1>;
  stringRegex?: InputMaybe<StrFieldFilter>;
  stringValue?: InputMaybe<StrFieldFilter>;
  type?: InputMaybe<StrFieldFilter>;
  urlValue?: InputMaybe<StrFieldFilter>;
};

export type TaskInputOutputFilter1AndFilterEntry = {
  AND: Array<TaskInputOutputFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type TaskInputOutputFilter1OrFilterEntry = {
  OR: TaskInputOutputFilter1;
  negate?: Scalars['Boolean'];
};

export enum TaskInputOutputOrdEnum {
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  TYPE = 'TYPE',
}

export type TaskInputOutputOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: TaskInputOutputOrdEnum;
};

export type TaskInputOutputPaginated = {
  __typename?: 'TaskInputOutputPaginated';
  data: Array<TaskInputOutput>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type TaskNestedList = {
  __typename?: 'TaskNestedList';
  data: Array<Task>;
  totalCount: Scalars['Int'];
};

export enum TaskOrdEnum {
  AGGREGATES_RESULTS = 'AGGREGATES_RESULTS',
  AUTOTRIGGER = 'AUTOTRIGGER',
  CASE_IDENTIFIER = 'CASE_IDENTIFIER',
  CREATED = 'CREATED',
  DECISION = 'DECISION',
  DESCRIPTION = 'DESCRIPTION',
  DUE_DATE = 'DUE_DATE',
  ID = 'ID',
  IS_AUTOMATED = 'IS_AUTOMATED',
  IS_DECISION = 'IS_DECISION',
  LAST_UPDATED = 'LAST_UPDATED',
  NAME = 'NAME',
  OUTPUT_IS_JOINED = 'OUTPUT_IS_JOINED',
  PROCESSING_QUEUE = 'PROCESSING_QUEUE',
  STATE = 'STATE',
  WEIGHT = 'WEIGHT',
}

export type TaskOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: TaskOrdEnum;
};

export type TaskPaginated = {
  __typename?: 'TaskPaginated';
  data: Array<Task>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type TaskReference = {
  __typename?: 'TaskReference';
  id: Scalars['ID'];
  relationshipType: TaskReferenceTypeEnum;
  source: Task;
  target: Task;
};

export type TaskReferenceCreate = {
  relationshipType: TaskReferenceTypeEnum;
  source: Scalars['ID'];
  target: Scalars['ID'];
};

export type TaskReferenceFilter0 = {
  id?: InputMaybe<StrawberryIdFieldFilter>;
  relationshipType?: InputMaybe<TaskReferenceTypeEnumEnumFieldFilter>;
};

export type TaskReferenceFilter0AndFilterEntry = {
  AND: Array<TaskReferenceFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type TaskReferenceFilter0OrFilterEntry = {
  OR: TaskReferenceFilter0;
  negate?: Scalars['Boolean'];
};

export type TaskReferenceFilter1 = {
  id?: InputMaybe<StrawberryIdFieldFilter>;
  relationshipType?: InputMaybe<TaskReferenceTypeEnumEnumFieldFilter>;
  source?: InputMaybe<TaskFilter1>;
  target?: InputMaybe<TaskFilter1>;
};

export type TaskReferenceFilter1AndFilterEntry = {
  AND: Array<TaskReferenceFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type TaskReferenceFilter1OrFilterEntry = {
  OR: TaskReferenceFilter1;
  negate?: Scalars['Boolean'];
};

export type TaskReferenceNestedList = {
  __typename?: 'TaskReferenceNestedList';
  data: Array<TaskReference>;
  totalCount: Scalars['Int'];
};

export enum TaskReferenceOrdEnum {
  ID = 'ID',
  RELATIONSHIP_TYPE = 'RELATIONSHIP_TYPE',
}

export type TaskReferenceOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: TaskReferenceOrdEnum;
};

export type TaskReferencePaginated = {
  __typename?: 'TaskReferencePaginated';
  data: Array<TaskReference>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export enum TaskReferenceTypeEnum {
  REFERS_TO = 'REFERS_TO',
}

export type TaskReferenceTypeEnumEnumFieldFilter = {
  exact?: InputMaybe<TaskReferenceTypeEnum>;
  except_?: InputMaybe<TaskReferenceTypeEnum>;
  in_?: InputMaybe<Array<TaskReferenceTypeEnum>>;
  isnull?: InputMaybe<Scalars['Boolean']>;
};

export type TaskReferenceUpdate = {
  relationshipType?: InputMaybe<TaskReferenceTypeEnum>;
  source?: InputMaybe<Scalars['ID']>;
  target?: InputMaybe<Scalars['ID']>;
};

export type TaskRelationship = {
  __typename?: 'TaskRelationship';
  id: Scalars['ID'];
  relationshipType: TaskRelationshipTypeEnum;
  source: Task;
  target: Task;
};

export type TaskRelationshipCreate = {
  relationshipType: TaskRelationshipTypeEnum;
  source: Scalars['ID'];
  target: Scalars['ID'];
};

export type TaskRelationshipFilter0 = {
  id?: InputMaybe<StrawberryIdFieldFilter>;
  relationshipType?: InputMaybe<TaskRelationshipTypeEnumEnumFieldFilter>;
};

export type TaskRelationshipFilter0AndFilterEntry = {
  AND: Array<TaskRelationshipFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type TaskRelationshipFilter0OrFilterEntry = {
  OR: TaskRelationshipFilter0;
  negate?: Scalars['Boolean'];
};

export type TaskRelationshipFilter1 = {
  id?: InputMaybe<StrawberryIdFieldFilter>;
  relationshipType?: InputMaybe<TaskRelationshipTypeEnumEnumFieldFilter>;
  source?: InputMaybe<TaskFilter1>;
  target?: InputMaybe<TaskFilter1>;
};

export type TaskRelationshipFilter1AndFilterEntry = {
  AND: Array<TaskRelationshipFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type TaskRelationshipFilter1OrFilterEntry = {
  OR: TaskRelationshipFilter1;
  negate?: Scalars['Boolean'];
};

export type TaskRelationshipNestedList = {
  __typename?: 'TaskRelationshipNestedList';
  data: Array<TaskRelationship>;
  totalCount: Scalars['Int'];
};

export enum TaskRelationshipOrdEnum {
  ID = 'ID',
  RELATIONSHIP_TYPE = 'RELATIONSHIP_TYPE',
}

export type TaskRelationshipOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: TaskRelationshipOrdEnum;
};

export type TaskRelationshipPaginated = {
  __typename?: 'TaskRelationshipPaginated';
  data: Array<TaskRelationship>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export enum TaskRelationshipTypeEnum {
  BLOCKED_BY = 'BLOCKED_BY',
  ON_COMPLETION = 'ON_COMPLETION',
  ON_FALSE = 'ON_FALSE',
  ON_TRUE = 'ON_TRUE',
}

export type TaskRelationshipTypeEnumEnumFieldFilter = {
  exact?: InputMaybe<TaskRelationshipTypeEnum>;
  except_?: InputMaybe<TaskRelationshipTypeEnum>;
  in_?: InputMaybe<Array<TaskRelationshipTypeEnum>>;
  isnull?: InputMaybe<Scalars['Boolean']>;
};

export type TaskRelationshipUpdate = {
  relationshipType?: InputMaybe<TaskRelationshipTypeEnum>;
  source?: InputMaybe<Scalars['ID']>;
  target?: InputMaybe<Scalars['ID']>;
};

export enum TaskStateEnum {
  OPEN = 'OPEN',
  PENDING = 'PENDING',
  REJECTED = 'REJECTED',
  RESOLVED = 'RESOLVED',
  RUNNING = 'RUNNING',
  SKIPPED = 'SKIPPED',
}

export type TaskStateEnumEnumFieldFilter = {
  exact?: InputMaybe<TaskStateEnum>;
  except_?: InputMaybe<TaskStateEnum>;
  in_?: InputMaybe<Array<TaskStateEnum>>;
  isnull?: InputMaybe<Scalars['Boolean']>;
};

export type TaskTemplate = {
  __typename?: 'TaskTemplate';
  created?: Maybe<Scalars['DateTime']>;
  description: Scalars['String'];
  id: Scalars['ID'];
  lastUpdated?: Maybe<Scalars['DateTime']>;
  name: Scalars['String'];
  src: Scalars['String'];
  template?: Maybe<Scalars['String']>;
};

export type TaskTemplateFilter1 = {
  created?: InputMaybe<DateTimeFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  lastUpdated?: InputMaybe<DateTimeFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
  template?: InputMaybe<StrFieldFilter>;
};

export type TaskTemplateFilter1AndFilterEntry = {
  AND: Array<TaskTemplateFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type TaskTemplateFilter1OrFilterEntry = {
  OR: TaskTemplateFilter1;
  negate?: Scalars['Boolean'];
};

export enum TaskTemplateOrdEnum {
  CREATED = 'CREATED',
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  LAST_UPDATED = 'LAST_UPDATED',
  NAME = 'NAME',
  TEMPLATE = 'TEMPLATE',
}

export type TaskTemplateOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: TaskTemplateOrdEnum;
};

export type TaskTemplatePaginated = {
  __typename?: 'TaskTemplatePaginated';
  data: Array<TaskTemplate>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type TaskTemplateUpdate = {
  created?: InputMaybe<Scalars['DateTime']>;
  description?: InputMaybe<Scalars['String']>;
  lastUpdated?: InputMaybe<Scalars['DateTime']>;
  name?: InputMaybe<Scalars['String']>;
  template?: InputMaybe<Scalars['String']>;
};

export type TaskUpdate = {
  aggregatesResults?: InputMaybe<Scalars['Boolean']>;
  assignees?: InputMaybe<RelationUpdate>;
  autotrigger?: InputMaybe<Scalars['Boolean']>;
  comments?: InputMaybe<RelationUpdate>;
  created?: InputMaybe<Scalars['DateTime']>;
  createdBy?: InputMaybe<Scalars['ID']>;
  decision?: InputMaybe<Scalars['Boolean']>;
  description?: InputMaybe<Scalars['String']>;
  dueDate?: InputMaybe<Scalars['DateTime']>;
  events?: InputMaybe<RelationUpdate>;
  externalReferences?: InputMaybe<RelationUpdate>;
  input?: InputMaybe<RelationUpdate>;
  isAutomated?: InputMaybe<Scalars['Boolean']>;
  isDecision?: InputMaybe<Scalars['Boolean']>;
  labels?: InputMaybe<RelationUpdate>;
  lastUpdated?: InputMaybe<Scalars['DateTime']>;
  name?: InputMaybe<Scalars['String']>;
  output?: InputMaybe<RelationUpdate>;
  outputIsJoined?: InputMaybe<Scalars['Boolean']>;
  processingQueue?: InputMaybe<Scalars['String']>;
  referencedBy?: InputMaybe<RelationUpdate>;
  refersTo?: InputMaybe<RelationUpdate>;
  sourceRelationships?: InputMaybe<RelationUpdate>;
  stage?: InputMaybe<Scalars['ID']>;
  state?: InputMaybe<TaskStateEnum>;
  targetRelationships?: InputMaybe<RelationUpdate>;
  weight?: InputMaybe<Scalars['Int']>;
};

export type Technique = Ittp &
  TtpFederationBase & {
    __typename?: 'Technique';
    cases: CaseFederationResult;
    created?: Maybe<Scalars['DateTime']>;
    description?: Maybe<Scalars['String']>;
    externalReferences?: Maybe<ExternalReferenceNestedList>;
    groupProcedures?: Maybe<GroupProcedureNestedList>;
    id: Scalars['ID'];
    isSubtechnique?: Maybe<Scalars['Boolean']>;
    malwareProcedures?: Maybe<MalwareProcedureNestedList>;
    mitigations?: Maybe<TechniqueMitigationRelationshipNestedList>;
    modified?: Maybe<Scalars['DateTime']>;
    platforms?: Maybe<TtpPlatformNestedList>;
    subTechniqueOf?: Maybe<Technique>;
    subTechniques?: Maybe<TechniqueNestedList>;
    tactics?: Maybe<TacticNestedList>;
    tasks: TaskFederationResult;
    techniqueName: Scalars['String'];
    toolProcedures?: Maybe<ToolProcedureNestedList>;
    ttpType?: Maybe<Scalars['String']>;
    ttpTypeEnum?: Maybe<KnownTtPsTypesEnum>;
    uniqueIdentifier: Scalars['String'];
  };

export type TechniqueCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type TechniqueExternalReferencesArgs = {
  filter?: InputMaybe<Array<ExternalReferenceFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ExternalReferenceOrdEnumOrderingEntry>>;
};

export type TechniqueGroupProceduresArgs = {
  filter?: InputMaybe<Array<GroupProcedureFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<GroupProcedureOrdEnumOrderingEntry>>;
};

export type TechniqueMalwareProceduresArgs = {
  filter?: InputMaybe<Array<MalwareProcedureFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<MalwareProcedureOrdEnumOrderingEntry>>;
};

export type TechniqueMitigationsArgs = {
  filter?: InputMaybe<Array<TechniqueMitigationRelationshipFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TechniqueMitigationRelationshipOrdEnumOrderingEntry>>;
};

export type TechniquePlatformsArgs = {
  filter?: InputMaybe<Array<TtpPlatformFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TtpPlatformOrdEnumOrderingEntry>>;
};

export type TechniqueSubTechniquesArgs = {
  filter?: InputMaybe<Array<TechniqueFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TechniqueOrdEnumOrderingEntry>>;
};

export type TechniqueTacticsArgs = {
  filter?: InputMaybe<Array<TacticFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TacticOrdEnumOrderingEntry>>;
};

export type TechniqueTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type TechniqueToolProceduresArgs = {
  filter?: InputMaybe<Array<ToolProcedureFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ToolProcedureOrdEnumOrderingEntry>>;
};

export type TechniqueCreate = {
  description?: InputMaybe<Scalars['String']>;
  externalReferences?: InputMaybe<Array<Scalars['ID']>>;
  groupProcedures?: InputMaybe<Array<Scalars['ID']>>;
  malwareProcedures?: InputMaybe<Array<Scalars['ID']>>;
  mitigations?: InputMaybe<Array<Scalars['ID']>>;
  platforms?: InputMaybe<Array<Scalars['ID']>>;
  subTechniqueOf?: InputMaybe<Scalars['ID']>;
  subTechniques?: InputMaybe<Array<Scalars['ID']>>;
  tactics?: InputMaybe<Array<Scalars['ID']>>;
  techniqueName: Scalars['String'];
  toolProcedures?: InputMaybe<Array<Scalars['ID']>>;
};

export type TechniqueFilter0 = {
  created?: InputMaybe<DateTimeFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  isSubtechnique?: InputMaybe<BoolFieldFilter>;
  modified?: InputMaybe<DateTimeFieldFilter>;
  techniqueName?: InputMaybe<StrFieldFilter>;
  ttpType?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type TechniqueFilter0AndFilterEntry = {
  AND: Array<TechniqueFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type TechniqueFilter0OrFilterEntry = {
  OR: TechniqueFilter0;
  negate?: Scalars['Boolean'];
};

export type TechniqueFilter1 = {
  created?: InputMaybe<DateTimeFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  externalReferences?: InputMaybe<ExternalReferenceFilter1>;
  groupProcedures?: InputMaybe<GroupProcedureFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  isSubtechnique?: InputMaybe<BoolFieldFilter>;
  malwareProcedures?: InputMaybe<MalwareProcedureFilter1>;
  mitigations?: InputMaybe<TechniqueMitigationRelationshipFilter1>;
  modified?: InputMaybe<DateTimeFieldFilter>;
  platforms?: InputMaybe<TtpPlatformFilter1>;
  subTechniqueOf?: InputMaybe<TechniqueFilter1>;
  subTechniques?: InputMaybe<TechniqueFilter1>;
  tactics?: InputMaybe<TacticFilter1>;
  techniqueName?: InputMaybe<StrFieldFilter>;
  toolProcedures?: InputMaybe<ToolProcedureFilter1>;
  ttpType?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type TechniqueFilter1AndFilterEntry = {
  AND: Array<TechniqueFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type TechniqueFilter1OrFilterEntry = {
  OR: TechniqueFilter1;
  negate?: Scalars['Boolean'];
};

export type TechniqueMitigationRelationship = {
  __typename?: 'TechniqueMitigationRelationship';
  description?: Maybe<Scalars['String']>;
  externalReferences?: Maybe<ExternalReferenceNestedList>;
  id: Scalars['ID'];
  mitigation?: Maybe<Mitigation>;
  name?: Maybe<Scalars['String']>;
  technique?: Maybe<Technique>;
};

export type TechniqueMitigationRelationshipExternalReferencesArgs = {
  filter?: InputMaybe<Array<ExternalReferenceFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ExternalReferenceOrdEnumOrderingEntry>>;
};

export type TechniqueMitigationRelationshipCreate = {
  description?: InputMaybe<Scalars['String']>;
  externalReferences?: InputMaybe<Array<Scalars['ID']>>;
  mitigation?: InputMaybe<Scalars['ID']>;
  technique?: InputMaybe<Scalars['ID']>;
};

export type TechniqueMitigationRelationshipFilter0 = {
  description?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
};

export type TechniqueMitigationRelationshipFilter0AndFilterEntry = {
  AND: Array<TechniqueMitigationRelationshipFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type TechniqueMitigationRelationshipFilter0OrFilterEntry = {
  OR: TechniqueMitigationRelationshipFilter0;
  negate?: Scalars['Boolean'];
};

export type TechniqueMitigationRelationshipFilter1 = {
  description?: InputMaybe<StrFieldFilter>;
  externalReferences?: InputMaybe<ExternalReferenceFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  mitigation?: InputMaybe<MitigationFilter1>;
  name?: InputMaybe<StrFieldFilter>;
  technique?: InputMaybe<TechniqueFilter1>;
};

export type TechniqueMitigationRelationshipFilter1AndFilterEntry = {
  AND: Array<TechniqueMitigationRelationshipFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type TechniqueMitigationRelationshipFilter1OrFilterEntry = {
  OR: TechniqueMitigationRelationshipFilter1;
  negate?: Scalars['Boolean'];
};

export type TechniqueMitigationRelationshipNestedList = {
  __typename?: 'TechniqueMitigationRelationshipNestedList';
  data: Array<TechniqueMitigationRelationship>;
  totalCount: Scalars['Int'];
};

export enum TechniqueMitigationRelationshipOrdEnum {
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  NAME = 'NAME',
}

export type TechniqueMitigationRelationshipOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: TechniqueMitigationRelationshipOrdEnum;
};

export type TechniqueMitigationRelationshipPaginated = {
  __typename?: 'TechniqueMitigationRelationshipPaginated';
  data: Array<TechniqueMitigationRelationship>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type TechniqueMitigationRelationshipUpdate = {
  description?: InputMaybe<Scalars['String']>;
  externalReferences?: InputMaybe<RelationUpdate>;
  mitigation?: InputMaybe<Scalars['ID']>;
  technique?: InputMaybe<Scalars['ID']>;
};

export type TechniqueNestedList = {
  __typename?: 'TechniqueNestedList';
  data: Array<Technique>;
  totalCount: Scalars['Int'];
};

export enum TechniqueOrdEnum {
  CREATED = 'CREATED',
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  IS_SUBTECHNIQUE = 'IS_SUBTECHNIQUE',
  MODIFIED = 'MODIFIED',
  TECHNIQUE_NAME = 'TECHNIQUE_NAME',
  TTP_TYPE = 'TTP_TYPE',
  UNIQUE_IDENTIFIER = 'UNIQUE_IDENTIFIER',
}

export type TechniqueOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: TechniqueOrdEnum;
};

export type TechniquePaginated = {
  __typename?: 'TechniquePaginated';
  data: Array<Technique>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type TechniqueUpdate = {
  description?: InputMaybe<Scalars['String']>;
  externalReferences?: InputMaybe<RelationUpdate>;
  groupProcedures?: InputMaybe<RelationUpdate>;
  malwareProcedures?: InputMaybe<RelationUpdate>;
  mitigations?: InputMaybe<RelationUpdate>;
  platforms?: InputMaybe<RelationUpdate>;
  subTechniqueOf?: InputMaybe<Scalars['ID']>;
  subTechniques?: InputMaybe<RelationUpdate>;
  tactics?: InputMaybe<RelationUpdate>;
  techniqueName?: InputMaybe<Scalars['String']>;
  toolProcedures?: InputMaybe<RelationUpdate>;
};

export type TemplateCreate = {
  description: Scalars['String'];
  name: Scalars['String'];
  template?: InputMaybe<Scalars['String']>;
};

export type TenantFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  circuitCount?: InputMaybe<IntFilter>;
  clusterCount?: InputMaybe<IntFilter>;
  comments?: InputMaybe<StrFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  deviceCount?: InputMaybe<IntFilter>;
  group?: InputMaybe<TenantGroupFilter>;
  groupId?: InputMaybe<StrawberryIdFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  ipaddressCount?: InputMaybe<IntFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  prefixCount?: InputMaybe<IntFilter>;
  rackCount?: InputMaybe<IntFilter>;
  siteCount?: InputMaybe<IntFilter>;
  slug?: InputMaybe<StrFilter>;
  uuid?: InputMaybe<StrFilter>;
  virtualmachineCount?: InputMaybe<IntFilter>;
  vlanCount?: InputMaybe<IntFilter>;
  vrfCount?: InputMaybe<IntFilter>;
};

export type TenantFilterAndFilterEntry = {
  AND: Array<TenantFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type TenantFilterOrFilterEntry = {
  OR: Array<TenantFilter>;
  negate?: Scalars['Boolean'];
};

export type TenantGroupFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  parent?: InputMaybe<TenantGroupFilter>;
  parentId?: InputMaybe<StrawberryIdFilter>;
  slug?: InputMaybe<StrFilter>;
  tenantCount?: InputMaybe<IntFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type TenantGroupFilterAndFilterEntry = {
  AND: Array<TenantGroupFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type TenantGroupFilterOrFilterEntry = {
  OR: Array<TenantGroupFilter>;
  negate?: Scalars['Boolean'];
};

export type TenantGroupType = AssetFederationBase &
  AssetType & {
    __typename?: 'TenantGroupType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    children: TenantGroupTypeResultSet;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    lastUpdated?: Maybe<Scalars['DateTime']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    parent?: Maybe<TenantGroupType>;
    parentId?: Maybe<Scalars['ID']>;
    slug?: Maybe<Scalars['String']>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    tenantCount?: Maybe<Scalars['Int']>;
    tenants: TenantTypeResultSet;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
  };

export type TenantGroupTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type TenantGroupTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type TenantGroupTypeResultSet = {
  __typename?: 'TenantGroupTypeResultSet';
  data: Array<TenantGroupType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type TenantType = AssetFederationBase &
  AssetType & {
    __typename?: 'TenantType';
    Name?: Maybe<Scalars['String']>;
    aggregates: AggregateTypeResultSet;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    circuitCount?: Maybe<Scalars['Int']>;
    circuits: CircuitTypeResultSet;
    clusterCount?: Maybe<Scalars['Int']>;
    clusters: ClusterTypeResultSet;
    comments?: Maybe<Scalars['String']>;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    deviceCount?: Maybe<Scalars['Int']>;
    devices: DeviceTypeResultSet;
    group?: Maybe<TenantGroupType>;
    groupId?: Maybe<Scalars['ID']>;
    id: Scalars['ID'];
    ipRanges: IpRangeTypeResultSet;
    ipaddressCount?: Maybe<Scalars['Int']>;
    ipaddresses: IpAddressTypeResultSet;
    lastUpdated?: Maybe<Scalars['DateTime']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    prefixCount?: Maybe<Scalars['Int']>;
    prefixes: PrefixTypeResultSet;
    rackCount?: Maybe<Scalars['Int']>;
    rackReservations: RackReservationTypeResultSet;
    racks: RackTypeResultSet;
    routeTargets: RouteTargetTypeResultSet;
    siteCount?: Maybe<Scalars['Int']>;
    sites: SiteTypeResultSet;
    slug?: Maybe<Scalars['String']>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
    virtualMachines: VirtualMachineTypeResultSet;
    virtualmachineCount?: Maybe<Scalars['Int']>;
    vlanCount?: Maybe<Scalars['Int']>;
    vlans: VlanTypeResultSet;
    vrfCount?: Maybe<Scalars['Int']>;
    vrfs: VrfTypeResultSet;
  };

export type TenantTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type TenantTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type TenantTypeResultSet = {
  __typename?: 'TenantTypeResultSet';
  data: Array<TenantType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type Tool = {
  __typename?: 'Tool';
  aliases?: Maybe<AliasNestedList>;
  created?: Maybe<Scalars['DateTime']>;
  description?: Maybe<Scalars['String']>;
  externalReferences?: Maybe<ExternalReferenceNestedList>;
  groups?: Maybe<TtpGroupNestedList>;
  id: Scalars['ID'];
  modified?: Maybe<Scalars['DateTime']>;
  name: Scalars['String'];
  platforms?: Maybe<TtpPlatformNestedList>;
  techniquesUsed?: Maybe<ToolProcedureNestedList>;
};

export type ToolAliasesArgs = {
  filter?: InputMaybe<Array<AliasFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<AliasOrdEnumOrderingEntry>>;
};

export type ToolExternalReferencesArgs = {
  filter?: InputMaybe<Array<ExternalReferenceFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ExternalReferenceOrdEnumOrderingEntry>>;
};

export type ToolGroupsArgs = {
  filter?: InputMaybe<Array<TtpGroupFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TtpGroupOrdEnumOrderingEntry>>;
};

export type ToolPlatformsArgs = {
  filter?: InputMaybe<Array<TtpPlatformFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<TtpPlatformOrdEnumOrderingEntry>>;
};

export type ToolTechniquesUsedArgs = {
  filter?: InputMaybe<Array<ToolProcedureFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ToolProcedureOrdEnumOrderingEntry>>;
};

export type ToolCreate = {
  aliases?: InputMaybe<Array<Scalars['ID']>>;
  description?: InputMaybe<Scalars['String']>;
  externalReferences?: InputMaybe<Array<Scalars['ID']>>;
  groups?: InputMaybe<Array<Scalars['ID']>>;
  name: Scalars['String'];
  platforms?: InputMaybe<Array<Scalars['ID']>>;
  techniquesUsed?: InputMaybe<Array<Scalars['ID']>>;
};

export type ToolFilter0 = {
  created?: InputMaybe<DateTimeFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  modified?: InputMaybe<DateTimeFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
};

export type ToolFilter0AndFilterEntry = {
  AND: Array<ToolFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type ToolFilter0OrFilterEntry = {
  OR: ToolFilter0;
  negate?: Scalars['Boolean'];
};

export type ToolFilter1 = {
  aliases?: InputMaybe<AliasFilter1>;
  created?: InputMaybe<DateTimeFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  externalReferences?: InputMaybe<ExternalReferenceFilter1>;
  groups?: InputMaybe<TtpGroupFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  modified?: InputMaybe<DateTimeFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
  platforms?: InputMaybe<TtpPlatformFilter1>;
  techniquesUsed?: InputMaybe<ToolProcedureFilter1>;
};

export type ToolFilter1AndFilterEntry = {
  AND: Array<ToolFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type ToolFilter1OrFilterEntry = {
  OR: ToolFilter1;
  negate?: Scalars['Boolean'];
};

export type ToolNestedList = {
  __typename?: 'ToolNestedList';
  data: Array<Tool>;
  totalCount: Scalars['Int'];
};

export enum ToolOrdEnum {
  CREATED = 'CREATED',
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  MODIFIED = 'MODIFIED',
  NAME = 'NAME',
}

export type ToolOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: ToolOrdEnum;
};

export type ToolPaginated = {
  __typename?: 'ToolPaginated';
  data: Array<Tool>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type ToolProcedure = Ittp &
  TtpFederationBase & {
    __typename?: 'ToolProcedure';
    cases: CaseFederationResult;
    created?: Maybe<Scalars['DateTime']>;
    description?: Maybe<Scalars['String']>;
    externalReferences?: Maybe<ExternalReferenceNestedList>;
    id: Scalars['ID'];
    modified?: Maybe<Scalars['DateTime']>;
    tasks: TaskFederationResult;
    tool: Tool;
    toolProcedureName: Scalars['String'];
    toolTechnique: Technique;
    ttpType?: Maybe<Scalars['String']>;
    ttpTypeEnum?: Maybe<KnownTtPsTypesEnum>;
    uniqueIdentifier: Scalars['String'];
  };

export type ToolProcedureCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type ToolProcedureExternalReferencesArgs = {
  filter?: InputMaybe<Array<ExternalReferenceFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ExternalReferenceOrdEnumOrderingEntry>>;
};

export type ToolProcedureTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type ToolProcedureCreate = {
  description?: InputMaybe<Scalars['String']>;
  externalReferences?: InputMaybe<Array<Scalars['ID']>>;
  tool: Scalars['ID'];
  toolTechnique: Scalars['ID'];
};

export type ToolProcedureFilter0 = {
  created?: InputMaybe<DateTimeFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  modified?: InputMaybe<DateTimeFieldFilter>;
  toolProcedureName?: InputMaybe<StrFieldFilter>;
  ttpType?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type ToolProcedureFilter0AndFilterEntry = {
  AND: Array<ToolProcedureFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type ToolProcedureFilter0OrFilterEntry = {
  OR: ToolProcedureFilter0;
  negate?: Scalars['Boolean'];
};

export type ToolProcedureFilter1 = {
  created?: InputMaybe<DateTimeFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  externalReferences?: InputMaybe<ExternalReferenceFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  modified?: InputMaybe<DateTimeFieldFilter>;
  tool?: InputMaybe<ToolFilter1>;
  toolProcedureName?: InputMaybe<StrFieldFilter>;
  toolTechnique?: InputMaybe<TechniqueFilter1>;
  ttpType?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type ToolProcedureFilter1AndFilterEntry = {
  AND: Array<ToolProcedureFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type ToolProcedureFilter1OrFilterEntry = {
  OR: ToolProcedureFilter1;
  negate?: Scalars['Boolean'];
};

export type ToolProcedureNestedList = {
  __typename?: 'ToolProcedureNestedList';
  data: Array<ToolProcedure>;
  totalCount: Scalars['Int'];
};

export enum ToolProcedureOrdEnum {
  CREATED = 'CREATED',
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  MODIFIED = 'MODIFIED',
  TOOL_PROCEDURE_NAME = 'TOOL_PROCEDURE_NAME',
  TTP_TYPE = 'TTP_TYPE',
  UNIQUE_IDENTIFIER = 'UNIQUE_IDENTIFIER',
}

export type ToolProcedureOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: ToolProcedureOrdEnum;
};

export type ToolProcedurePaginated = {
  __typename?: 'ToolProcedurePaginated';
  data: Array<ToolProcedure>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type ToolProcedureUpdate = {
  description?: InputMaybe<Scalars['String']>;
  externalReferences?: InputMaybe<RelationUpdate>;
  tool?: InputMaybe<Scalars['ID']>;
  toolTechnique?: InputMaybe<Scalars['ID']>;
};

export type ToolUpdate = {
  aliases?: InputMaybe<RelationUpdate>;
  description?: InputMaybe<Scalars['String']>;
  externalReferences?: InputMaybe<RelationUpdate>;
  groups?: InputMaybe<RelationUpdate>;
  name?: InputMaybe<Scalars['String']>;
  platforms?: InputMaybe<RelationUpdate>;
  techniquesUsed?: InputMaybe<RelationUpdate>;
};

export type Url = Observable &
  ObservableFederationBase & {
    __typename?: 'URL';
    cases: CaseFederationResult;
    ctiEntries?: Maybe<ObservableLinkNestedList>;
    description?: Maybe<Scalars['String']>;
    fragment?: Maybe<UrlFragment>;
    host?: Maybe<Host>;
    id: Scalars['ID'];
    observableType?: Maybe<Scalars['String']>;
    observableTypeEnum?: Maybe<KnownObservablesEnum>;
    path?: Maybe<UrlPath>;
    port?: Maybe<Scalars['Int']>;
    protocol?: Maybe<Scalars['String']>;
    query?: Maybe<UrlQuery>;
    rawUrl: Scalars['String'];
    tasks: TaskFederationResult;
    uniqueIdentifier: Scalars['String'];
  };

export type UrlCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type UrlCtiEntriesArgs = {
  filter?: InputMaybe<Array<ObservableLinkFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<ObservableLinkOrdEnumOrderingEntry>>;
};

export type UrlTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type UrlCreate = {
  ctiEntries?: InputMaybe<Array<Scalars['ID']>>;
  description?: InputMaybe<Scalars['String']>;
  fragment?: InputMaybe<Scalars['ID']>;
  host?: InputMaybe<Scalars['ID']>;
  path?: InputMaybe<Scalars['ID']>;
  port?: InputMaybe<Scalars['Int']>;
  protocol?: InputMaybe<Scalars['String']>;
  query?: InputMaybe<Scalars['ID']>;
  rawUrl: Scalars['String'];
};

export type UrlFilter0 = {
  description?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  observableType?: InputMaybe<StrFieldFilter>;
  port?: InputMaybe<IntFieldFilter>;
  protocol?: InputMaybe<StrFieldFilter>;
  rawUrl?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type UrlFilter0AndFilterEntry = {
  AND: Array<UrlFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type UrlFilter0OrFilterEntry = {
  OR: UrlFilter0;
  negate?: Scalars['Boolean'];
};

export type UrlFilter1 = {
  ctiEntries?: InputMaybe<ObservableLinkFilter1>;
  description?: InputMaybe<StrFieldFilter>;
  fragment?: InputMaybe<UrlFragmentFilter1>;
  host?: InputMaybe<HostFilter1>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  observableType?: InputMaybe<StrFieldFilter>;
  path?: InputMaybe<UrlPathFilter1>;
  port?: InputMaybe<IntFieldFilter>;
  protocol?: InputMaybe<StrFieldFilter>;
  query?: InputMaybe<UrlQueryFilter1>;
  rawUrl?: InputMaybe<StrFieldFilter>;
  uniqueIdentifier?: InputMaybe<StrFieldFilter>;
};

export type UrlFilter1AndFilterEntry = {
  AND: Array<UrlFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type UrlFilter1OrFilterEntry = {
  OR: UrlFilter1;
  negate?: Scalars['Boolean'];
};

export type UrlFragment = {
  __typename?: 'URLFragment';
  id: Scalars['ID'];
  rawFragment: Scalars['String'];
  urls?: Maybe<UrlNestedList>;
};

export type UrlFragmentUrlsArgs = {
  filter?: InputMaybe<Array<UrlFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<UrlOrdEnumOrderingEntry>>;
};

export type UrlFragmentCreate = {
  rawFragment: Scalars['String'];
  urls?: InputMaybe<Array<Scalars['ID']>>;
};

export type UrlFragmentFilter1 = {
  id?: InputMaybe<StrawberryIdFieldFilter>;
  rawFragment?: InputMaybe<StrFieldFilter>;
  urls?: InputMaybe<UrlFilter1>;
};

export type UrlFragmentFilter1AndFilterEntry = {
  AND: Array<UrlFragmentFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type UrlFragmentFilter1OrFilterEntry = {
  OR: UrlFragmentFilter1;
  negate?: Scalars['Boolean'];
};

export enum UrlFragmentOrdEnum {
  ID = 'ID',
  RAW_FRAGMENT = 'RAW_FRAGMENT',
}

export type UrlFragmentOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: UrlFragmentOrdEnum;
};

export type UrlFragmentPaginated = {
  __typename?: 'URLFragmentPaginated';
  data: Array<UrlFragment>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type UrlFragmentUpdate = {
  rawFragment?: InputMaybe<Scalars['String']>;
  urls?: InputMaybe<RelationUpdate>;
};

export type UrlInputOutput = TaskInputOutput & {
  __typename?: 'URLInputOutput';
  description?: Maybe<Scalars['String']>;
  id: Scalars['ID'];
  inputOf?: Maybe<Task>;
  outputOf?: Maybe<Task>;
  stringifiedValue?: Maybe<Scalars['String']>;
  type?: Maybe<Scalars['String']>;
  urlValue?: Maybe<Scalars['String']>;
};

export type UrlInputOutputCreate = {
  description?: InputMaybe<Scalars['String']>;
  inputOf?: InputMaybe<Scalars['ID']>;
  outputOf?: InputMaybe<Scalars['ID']>;
  urlValue?: InputMaybe<Scalars['String']>;
};

export type UrlInputOutputFilter1 = {
  description?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  inputOf?: InputMaybe<TaskFilter1>;
  outputOf?: InputMaybe<TaskFilter1>;
  type?: InputMaybe<StrFieldFilter>;
  urlValue?: InputMaybe<StrFieldFilter>;
};

export type UrlInputOutputFilter1AndFilterEntry = {
  AND: Array<UrlInputOutputFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type UrlInputOutputFilter1OrFilterEntry = {
  OR: UrlInputOutputFilter1;
  negate?: Scalars['Boolean'];
};

export enum UrlInputOutputOrdEnum {
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  TYPE = 'TYPE',
  URL_VALUE = 'URL_VALUE',
}

export type UrlInputOutputOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: UrlInputOutputOrdEnum;
};

export type UrlInputOutputPaginated = {
  __typename?: 'URLInputOutputPaginated';
  data: Array<UrlInputOutput>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type UrlInputOutputUpdate = {
  description?: InputMaybe<Scalars['String']>;
  inputOf?: InputMaybe<Scalars['ID']>;
  outputOf?: InputMaybe<Scalars['ID']>;
  urlValue?: InputMaybe<Scalars['String']>;
};

export type UrlNestedList = {
  __typename?: 'URLNestedList';
  data: Array<Url>;
  totalCount: Scalars['Int'];
};

export type UrlNestedListResult = {
  __typename?: 'URLNestedListResult';
  data?: Maybe<Url>;
  error?: Maybe<ValidationError>;
};

export enum UrlOrdEnum {
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  OBSERVABLE_TYPE = 'OBSERVABLE_TYPE',
  PORT = 'PORT',
  PROTOCOL = 'PROTOCOL',
  RAW_URL = 'RAW_URL',
  UNIQUE_IDENTIFIER = 'UNIQUE_IDENTIFIER',
}

export type UrlOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: UrlOrdEnum;
};

export type UrlPaginated = {
  __typename?: 'URLPaginated';
  data: Array<Url>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type UrlPath = {
  __typename?: 'URLPath';
  id: Scalars['ID'];
  path?: Maybe<Scalars['String']>;
  urls?: Maybe<UrlNestedList>;
};

export type UrlPathUrlsArgs = {
  filter?: InputMaybe<Array<UrlFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<UrlOrdEnumOrderingEntry>>;
};

export type UrlPathCreate = {
  path?: InputMaybe<Scalars['String']>;
  urls?: InputMaybe<Array<Scalars['ID']>>;
};

export type UrlPathFilter1 = {
  id?: InputMaybe<StrawberryIdFieldFilter>;
  path?: InputMaybe<StrFieldFilter>;
  urls?: InputMaybe<UrlFilter1>;
};

export type UrlPathFilter1AndFilterEntry = {
  AND: Array<UrlPathFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type UrlPathFilter1OrFilterEntry = {
  OR: UrlPathFilter1;
  negate?: Scalars['Boolean'];
};

export enum UrlPathOrdEnum {
  ID = 'ID',
  PATH = 'PATH',
}

export type UrlPathOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: UrlPathOrdEnum;
};

export type UrlPathPaginated = {
  __typename?: 'URLPathPaginated';
  data: Array<UrlPath>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type UrlPathUpdate = {
  path?: InputMaybe<Scalars['String']>;
  urls?: InputMaybe<RelationUpdate>;
};

export type UrlQuery = {
  __typename?: 'URLQuery';
  id: Scalars['ID'];
  params?: Maybe<UrlQueryParamNestedList>;
  rawQuery: Scalars['String'];
  urls?: Maybe<UrlNestedList>;
};

export type UrlQueryParamsArgs = {
  filter?: InputMaybe<Array<UrlQueryParamFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<UrlQueryParamOrdEnumOrderingEntry>>;
};

export type UrlQueryUrlsArgs = {
  filter?: InputMaybe<Array<UrlFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<UrlOrdEnumOrderingEntry>>;
};

export type UrlQueryCreate = {
  params?: InputMaybe<Array<Scalars['ID']>>;
  rawQuery: Scalars['String'];
  urls?: InputMaybe<Array<Scalars['ID']>>;
};

export type UrlQueryFilter0 = {
  id?: InputMaybe<StrawberryIdFieldFilter>;
  rawQuery?: InputMaybe<StrFieldFilter>;
};

export type UrlQueryFilter0AndFilterEntry = {
  AND: Array<UrlQueryFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type UrlQueryFilter0OrFilterEntry = {
  OR: UrlQueryFilter0;
  negate?: Scalars['Boolean'];
};

export type UrlQueryFilter1 = {
  id?: InputMaybe<StrawberryIdFieldFilter>;
  params?: InputMaybe<UrlQueryParamFilter1>;
  rawQuery?: InputMaybe<StrFieldFilter>;
  urls?: InputMaybe<UrlFilter1>;
};

export type UrlQueryFilter1AndFilterEntry = {
  AND: Array<UrlQueryFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type UrlQueryFilter1OrFilterEntry = {
  OR: UrlQueryFilter1;
  negate?: Scalars['Boolean'];
};

export type UrlQueryNestedList = {
  __typename?: 'URLQueryNestedList';
  data: Array<UrlQuery>;
  totalCount: Scalars['Int'];
};

export enum UrlQueryOrdEnum {
  ID = 'ID',
  RAW_QUERY = 'RAW_QUERY',
}

export type UrlQueryOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: UrlQueryOrdEnum;
};

export type UrlQueryPaginated = {
  __typename?: 'URLQueryPaginated';
  data: Array<UrlQuery>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type UrlQueryParam = {
  __typename?: 'URLQueryParam';
  id: Scalars['ID'];
  key: Scalars['String'];
  queries?: Maybe<UrlQueryNestedList>;
  value: Scalars['String'];
};

export type UrlQueryParamQueriesArgs = {
  filter?: InputMaybe<Array<UrlQueryFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<UrlQueryOrdEnumOrderingEntry>>;
};

export type UrlQueryParamCreate = {
  key: Scalars['String'];
  queries?: InputMaybe<Array<Scalars['ID']>>;
  value: Scalars['String'];
};

export type UrlQueryParamFilter0 = {
  id?: InputMaybe<StrawberryIdFieldFilter>;
  key?: InputMaybe<StrFieldFilter>;
  value?: InputMaybe<StrFieldFilter>;
};

export type UrlQueryParamFilter0AndFilterEntry = {
  AND: Array<UrlQueryParamFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type UrlQueryParamFilter0OrFilterEntry = {
  OR: UrlQueryParamFilter0;
  negate?: Scalars['Boolean'];
};

export type UrlQueryParamFilter1 = {
  id?: InputMaybe<StrawberryIdFieldFilter>;
  key?: InputMaybe<StrFieldFilter>;
  queries?: InputMaybe<UrlQueryFilter1>;
  value?: InputMaybe<StrFieldFilter>;
};

export type UrlQueryParamFilter1AndFilterEntry = {
  AND: Array<UrlQueryParamFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type UrlQueryParamFilter1OrFilterEntry = {
  OR: UrlQueryParamFilter1;
  negate?: Scalars['Boolean'];
};

export type UrlQueryParamNestedList = {
  __typename?: 'URLQueryParamNestedList';
  data: Array<UrlQueryParam>;
  totalCount: Scalars['Int'];
};

export enum UrlQueryParamOrdEnum {
  ID = 'ID',
  KEY = 'KEY',
  VALUE = 'VALUE',
}

export type UrlQueryParamOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: UrlQueryParamOrdEnum;
};

export type UrlQueryParamPaginated = {
  __typename?: 'URLQueryParamPaginated';
  data: Array<UrlQueryParam>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type UrlQueryParamUpdate = {
  key?: InputMaybe<Scalars['String']>;
  queries?: InputMaybe<RelationUpdate>;
  value?: InputMaybe<Scalars['String']>;
};

export type UrlQueryUpdate = {
  params?: InputMaybe<RelationUpdate>;
  rawQuery?: InputMaybe<Scalars['String']>;
  urls?: InputMaybe<RelationUpdate>;
};

export type UrlUpdate = {
  ctiEntries?: InputMaybe<RelationUpdate>;
  description?: InputMaybe<Scalars['String']>;
  fragment?: InputMaybe<Scalars['ID']>;
  host?: InputMaybe<Scalars['ID']>;
  path?: InputMaybe<Scalars['ID']>;
  port?: InputMaybe<Scalars['Int']>;
  protocol?: InputMaybe<Scalars['String']>;
  query?: InputMaybe<Scalars['ID']>;
  rawUrl?: InputMaybe<Scalars['String']>;
};

export type UserAccountingIpFix = {
  __typename?: 'UserAccountingIPFix';
  applicationid?: Maybe<Scalars['String']>;
  applicationidrev?: Maybe<Scalars['String']>;
  applicationname?: Maybe<Scalars['String']>;
  applicationnamerev?: Maybe<Scalars['String']>;
  bgpdestinationasnumber?: Maybe<Scalars['LargeJsInt']>;
  bgpdestinationasnumberrev?: Maybe<Scalars['LargeJsInt']>;
  bgpsourceasnumber?: Maybe<Scalars['LargeJsInt']>;
  bgpsourceasnumberrev?: Maybe<Scalars['LargeJsInt']>;
  destinationipv4address?: Maybe<Scalars['String']>;
  destinationipv6address?: Maybe<Scalars['String']>;
  destinationtransportport?: Maybe<Scalars['Int']>;
  flowendmilliseconds?: Maybe<Scalars['LargeJsInt']>;
  flowendmillisecondsrev?: Maybe<Scalars['LargeJsInt']>;
  flowstartmilliseconds?: Maybe<Scalars['LargeJsInt']>;
  flowstartmillisecondsrev?: Maybe<Scalars['LargeJsInt']>;
  icmptypecodeipv4?: Maybe<Scalars['Int']>;
  id: Scalars['ID'];
  ingressinterface?: Maybe<Scalars['LargeJsInt']>;
  ipclassofservice?: Maybe<Scalars['Int']>;
  ipclassofservicerev?: Maybe<Scalars['Int']>;
  ipversion?: Maybe<Scalars['Int']>;
  mplslabelstacksection2?: Maybe<Scalars['String']>;
  mplslabelstacksection2rev?: Maybe<Scalars['String']>;
  mplslabelstacksection3?: Maybe<Scalars['String']>;
  mplslabelstacksection3rev?: Maybe<Scalars['String']>;
  mplslabelstacksection4?: Maybe<Scalars['String']>;
  mplslabelstacksection4rev?: Maybe<Scalars['String']>;
  mplslabelstacksection5?: Maybe<Scalars['String']>;
  mplslabelstacksection5rev?: Maybe<Scalars['String']>;
  mplslabelstacksection6?: Maybe<Scalars['String']>;
  mplslabelstacksection6rev?: Maybe<Scalars['String']>;
  mplslabelstacksection7?: Maybe<Scalars['String']>;
  mplslabelstacksection7rev?: Maybe<Scalars['String']>;
  mplslabelstacksection8?: Maybe<Scalars['String']>;
  mplslabelstacksection8rev?: Maybe<Scalars['String']>;
  mplslabelstacksection9?: Maybe<Scalars['String']>;
  mplslabelstacksection9rev?: Maybe<Scalars['String']>;
  mplslabelstacksection10?: Maybe<Scalars['String']>;
  mplslabelstacksection10rev?: Maybe<Scalars['String']>;
  mplstoplabelstacksection?: Maybe<Scalars['String']>;
  mplstoplabelstacksectionrev?: Maybe<Scalars['String']>;
  octetdeltacount?: Maybe<Scalars['LargeJsInt']>;
  octetdeltacountrev?: Maybe<Scalars['LargeJsInt']>;
  originalexporteripv6address?: Maybe<Scalars['String']>;
  packetdeltacount?: Maybe<Scalars['LargeJsInt']>;
  packetdeltacountrev?: Maybe<Scalars['LargeJsInt']>;
  protocolidentifier?: Maybe<Scalars['Int']>;
  samplingalgorithm?: Maybe<Scalars['Int']>;
  samplingalgorithmrev?: Maybe<Scalars['Int']>;
  samplinginterval?: Maybe<Scalars['LargeJsInt']>;
  samplingintervalrev?: Maybe<Scalars['LargeJsInt']>;
  sourceipv4address?: Maybe<Scalars['String']>;
  sourceipv6address?: Maybe<Scalars['String']>;
  sourcetransportport?: Maybe<Scalars['Int']>;
  tcpcontrolbits?: Maybe<Scalars['Int']>;
  tcpcontrolbitsrev?: Maybe<Scalars['Int']>;
  tcpwindowsize?: Maybe<Scalars['Int']>;
  tcpwindowsizerev?: Maybe<Scalars['Int']>;
  timestamp?: Maybe<Scalars['DatetimeTimestamp']>;
  vlanid?: Maybe<Scalars['Int']>;
  vlanidrev?: Maybe<Scalars['Int']>;
};

export type UserAccountingUserIpData = {
  __typename?: 'UserAccountingUserIPData';
  acctinputoctets?: Maybe<Scalars['Int']>;
  acctoutputoctets?: Maybe<Scalars['Int']>;
  acctstarttime?: Maybe<Scalars['LargeJsInt']>;
  acctstarttimemilliseconds?: Maybe<Scalars['LargeJsInt']>;
  acctstoptime?: Maybe<Scalars['LargeJsInt']>;
  acctstoptimemilliseconds?: Maybe<Scalars['LargeJsInt']>;
  acctterminatecause?: Maybe<Scalars['Int']>;
  calledstationid?: Maybe<Scalars['String']>;
  callingstationid?: Maybe<Scalars['String']>;
  chargeableuseridentity?: Maybe<Scalars['String']>;
  eapidentity?: Maybe<Scalars['String']>;
  flowsFrom: Array<UserAccountingIpFix>;
  flowsTo: Array<UserAccountingIpFix>;
  framedipaddress?: Maybe<Scalars['String']>;
  id?: Maybe<Scalars['Int']>;
  nasidentifier?: Maybe<Scalars['String']>;
  nasipaddress?: Maybe<Scalars['String']>;
  userId?: Maybe<Scalars['String']>;
  username?: Maybe<Scalars['String']>;
};

export type UserAccountingUserIpDataGroup = {
  __typename?: 'UserAccountingUserIPDataGroup';
  accounting: Array<UserAccountingUserIpData>;
  framedipaddress: Scalars['String'];
  userIntrospection?: Maybe<UserIntrospection>;
};

export type UserAccountingUserIpDataPaginated = {
  __typename?: 'UserAccountingUserIPDataPaginated';
  data: Array<UserAccountingUserIpData>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type UserGroupedAccounting = {
  __typename?: 'UserGroupedAccounting';
  accounting: Array<UserAccountingUserIpData>;
  userIntrospection?: Maybe<UserIntrospection>;
  username: Scalars['String'];
};

export type UserIpAccountingModelCreate = {
  acctinputoctets?: InputMaybe<Scalars['Int']>;
  acctoutputoctets?: InputMaybe<Scalars['Int']>;
  acctstarttime?: InputMaybe<Scalars['DateTime']>;
  acctstoptime?: InputMaybe<Scalars['DateTime']>;
  acctterminatecause?: InputMaybe<Scalars['Int']>;
  calledstationid?: InputMaybe<Scalars['String']>;
  callingstationid?: InputMaybe<Scalars['String']>;
  chargeableuseridentity?: InputMaybe<Scalars['String']>;
  eapidentity?: InputMaybe<Scalars['String']>;
  framedipaddress?: InputMaybe<Scalars['String']>;
  nasidentifier?: InputMaybe<Scalars['String']>;
  nasipaddress?: InputMaybe<Scalars['String']>;
  username?: InputMaybe<Scalars['String']>;
};

export type UserIpAccountingModelFilter1 = {
  acctinputoctets?: InputMaybe<IntFieldFilter>;
  acctoutputoctets?: InputMaybe<IntFieldFilter>;
  acctstarttime?: InputMaybe<DateTimeFieldFilter>;
  acctstoptime?: InputMaybe<DateTimeFieldFilter>;
  acctterminatecause?: InputMaybe<IntFieldFilter>;
  calledstationid?: InputMaybe<StrFieldFilter>;
  callingstationid?: InputMaybe<StrFieldFilter>;
  chargeableuseridentity?: InputMaybe<StrFieldFilter>;
  eapidentity?: InputMaybe<StrFieldFilter>;
  framedipaddress?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  nasidentifier?: InputMaybe<StrFieldFilter>;
  nasipaddress?: InputMaybe<StrFieldFilter>;
  username?: InputMaybe<StrFieldFilter>;
};

export type UserIpAccountingModelFilter1AndFilterEntry = {
  AND: Array<UserIpAccountingModelFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type UserIpAccountingModelFilter1OrFilterEntry = {
  OR: UserIpAccountingModelFilter1;
  negate?: Scalars['Boolean'];
};

export enum UserIpAccountingModelOrdEnum {
  ACCTINPUTOCTETS = 'ACCTINPUTOCTETS',
  ACCTOUTPUTOCTETS = 'ACCTOUTPUTOCTETS',
  ACCTSTARTTIME = 'ACCTSTARTTIME',
  ACCTSTOPTIME = 'ACCTSTOPTIME',
  ACCTTERMINATECAUSE = 'ACCTTERMINATECAUSE',
  CALLEDSTATIONID = 'CALLEDSTATIONID',
  CALLINGSTATIONID = 'CALLINGSTATIONID',
  CHARGEABLEUSERIDENTITY = 'CHARGEABLEUSERIDENTITY',
  EAPIDENTITY = 'EAPIDENTITY',
  FRAMEDIPADDRESS = 'FRAMEDIPADDRESS',
  ID = 'ID',
  NASIDENTIFIER = 'NASIDENTIFIER',
  NASIPADDRESS = 'NASIPADDRESS',
  USERNAME = 'USERNAME',
}

export type UserIpAccountingModelOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: UserIpAccountingModelOrdEnum;
};

export type UserIpAccountingModelUpdate = {
  acctinputoctets?: InputMaybe<Scalars['Int']>;
  acctoutputoctets?: InputMaybe<Scalars['Int']>;
  acctstarttime?: InputMaybe<Scalars['DateTime']>;
  acctstoptime?: InputMaybe<Scalars['DateTime']>;
  acctterminatecause?: InputMaybe<Scalars['Int']>;
  calledstationid?: InputMaybe<Scalars['String']>;
  callingstationid?: InputMaybe<Scalars['String']>;
  chargeableuseridentity?: InputMaybe<Scalars['String']>;
  eapidentity?: InputMaybe<Scalars['String']>;
  framedipaddress?: InputMaybe<Scalars['String']>;
  nasidentifier?: InputMaybe<Scalars['String']>;
  nasipaddress?: InputMaybe<Scalars['String']>;
  username?: InputMaybe<Scalars['String']>;
};

export type UserIntrospection = {
  __typename?: 'UserIntrospection';
  email: Scalars['String'];
  firstName: Scalars['String'];
  lastName: Scalars['String'];
  userId: Scalars['String'];
  username: Scalars['String'];
};

export type UsersWithFlowsFilter = {
  from_: Scalars['DateTime'];
  ipv4?: InputMaybe<Scalars['IPv4']>;
  ipv6?: InputMaybe<Scalars['IPv6']>;
  to: Scalars['DateTime'];
};

export type VlanFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  group?: InputMaybe<VlanGroupFilter>;
  groupId?: InputMaybe<StrawberryIdFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  prefixCount?: InputMaybe<IntFilter>;
  role?: InputMaybe<RoleFilter>;
  roleId?: InputMaybe<StrawberryIdFilter>;
  site?: InputMaybe<SiteFilter>;
  siteId?: InputMaybe<StrawberryIdFilter>;
  status?: InputMaybe<IpamVlanStatusChoicesEnumFilter>;
  tenant?: InputMaybe<TenantFilter>;
  tenantId?: InputMaybe<StrawberryIdFilter>;
  uuid?: InputMaybe<StrFilter>;
  vid?: InputMaybe<IntFilter>;
};

export type VlanFilterAndFilterEntry = {
  AND: Array<VlanFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type VlanFilterOrFilterEntry = {
  OR: Array<VlanFilter>;
  negate?: Scalars['Boolean'];
};

export type VlanGroupFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  scopeId?: InputMaybe<StrawberryIdFilter>;
  scopeType?: InputMaybe<StrFilter>;
  slug?: InputMaybe<StrFilter>;
  uuid?: InputMaybe<StrFilter>;
  vlanCount?: InputMaybe<IntFilter>;
};

export type VlanGroupFilterAndFilterEntry = {
  AND: Array<VlanGroupFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type VlanGroupFilterOrFilterEntry = {
  OR: Array<VlanGroupFilter>;
  negate?: Scalars['Boolean'];
};

export type VlanGroupType = AssetFederationBase &
  AssetType & {
    __typename?: 'VLANGroupType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    lastUpdated?: Maybe<Scalars['DateTime']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    scope?: Maybe<AssetType>;
    scopeId?: Maybe<Scalars['ID']>;
    scopeType?: Maybe<Scalars['String']>;
    slug?: Maybe<Scalars['String']>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
    vlanCount?: Maybe<Scalars['Int']>;
    vlans: VlanTypeResultSet;
  };

export type VlanGroupTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type VlanGroupTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type VlanGroupTypeResultSet = {
  __typename?: 'VLANGroupTypeResultSet';
  data: Array<VlanGroupType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type VlanType = AssetFederationBase &
  AssetType & {
    __typename?: 'VLANType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    group?: Maybe<VlanGroupType>;
    groupId?: Maybe<Scalars['ID']>;
    id: Scalars['ID'];
    lastUpdated?: Maybe<Scalars['DateTime']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    prefixCount?: Maybe<Scalars['Int']>;
    prefixes: PrefixTypeResultSet;
    role?: Maybe<RoleType>;
    roleId?: Maybe<Scalars['ID']>;
    site?: Maybe<SiteType>;
    siteId?: Maybe<Scalars['ID']>;
    status?: Maybe<IpamVlanStatusChoices>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    tenant?: Maybe<TenantType>;
    tenantId?: Maybe<Scalars['ID']>;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
    vid?: Maybe<Scalars['Int']>;
  };

export type VlanTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type VlanTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type VlanTypeResultSet = {
  __typename?: 'VLANTypeResultSet';
  data: Array<VlanType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type VmInterfaceFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  countFhrpGroups?: InputMaybe<IntFilter>;
  countIpaddresses?: InputMaybe<IntFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  enabled?: InputMaybe<BoolFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  macAddress?: InputMaybe<StrFilter>;
  mode?: InputMaybe<VirtualizationVmInterfaceModeChoicesEnumFilter>;
  mtu?: InputMaybe<IntFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  parent?: InputMaybe<VmInterfaceFilter>;
  parentId?: InputMaybe<StrawberryIdFilter>;
  taggedVlanIds?: InputMaybe<StrawberryIdFilter>;
  taggedVlans?: InputMaybe<VlanFilter>;
  untaggedVlan?: InputMaybe<VlanFilter>;
  untaggedVlanId?: InputMaybe<StrawberryIdFilter>;
  uuid?: InputMaybe<StrFilter>;
  virtualMachine?: InputMaybe<VirtualMachineFilter>;
  virtualMachineId?: InputMaybe<StrawberryIdFilter>;
};

export type VmInterfaceFilterAndFilterEntry = {
  AND: Array<VmInterfaceFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type VmInterfaceFilterOrFilterEntry = {
  OR: Array<VmInterfaceFilter>;
  negate?: Scalars['Boolean'];
};

export type VmInterfaceType = AssetFederationBase &
  AssetType & {
    __typename?: 'VMInterfaceType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    children: VmInterfaceTypeResultSet;
    countFhrpGroups?: Maybe<Scalars['Int']>;
    countIpaddresses?: Maybe<Scalars['Int']>;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    enabled?: Maybe<Scalars['Boolean']>;
    id: Scalars['ID'];
    lastUpdated?: Maybe<Scalars['DateTime']>;
    macAddress?: Maybe<Scalars['String']>;
    mode?: Maybe<VirtualizationVmInterfaceModeChoices>;
    mtu?: Maybe<Scalars['Int']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    parent?: Maybe<VmInterfaceType>;
    parentId?: Maybe<Scalars['ID']>;
    tagIds: Array<Scalars['ID']>;
    taggedVlanIds: Array<Scalars['ID']>;
    taggedVlans: Array<VlanType>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    uniquePrefix: Scalars['String'];
    untaggedVlan?: Maybe<VlanType>;
    untaggedVlanId?: Maybe<Scalars['ID']>;
    uuid?: Maybe<Scalars['String']>;
    virtualMachine?: Maybe<VirtualMachineType>;
    virtualMachineId?: Maybe<Scalars['ID']>;
  };

export type VmInterfaceTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type VmInterfaceTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type VmInterfaceTypeResultSet = {
  __typename?: 'VMInterfaceTypeResultSet';
  data: Array<VmInterfaceType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type VrfFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  enforceUnique?: InputMaybe<BoolFilter>;
  exportTargetIds?: InputMaybe<StrawberryIdFilter>;
  exportTargets?: InputMaybe<RouteTargetFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  importTargetIds?: InputMaybe<StrawberryIdFilter>;
  importTargets?: InputMaybe<RouteTargetFilter>;
  ipaddressCount?: InputMaybe<IntFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  prefixCount?: InputMaybe<IntFilter>;
  rd?: InputMaybe<StrFilter>;
  tenant?: InputMaybe<TenantFilter>;
  tenantId?: InputMaybe<StrawberryIdFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type VrfFilterAndFilterEntry = {
  AND: Array<VrfFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type VrfFilterOrFilterEntry = {
  OR: Array<VrfFilter>;
  negate?: Scalars['Boolean'];
};

export type VrfType = AssetFederationBase &
  AssetType & {
    __typename?: 'VRFType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    enforceUnique?: Maybe<Scalars['Boolean']>;
    exportTargetIds: Array<Scalars['ID']>;
    exportTargets: Array<RouteTargetType>;
    id: Scalars['ID'];
    importTargetIds: Array<Scalars['ID']>;
    importTargets: Array<RouteTargetType>;
    ipAddresses: IpAddressTypeResultSet;
    ipRanges: IpRangeTypeResultSet;
    ipaddressCount?: Maybe<Scalars['Int']>;
    lastUpdated?: Maybe<Scalars['DateTime']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    prefixCount?: Maybe<Scalars['Int']>;
    prefixes: PrefixTypeResultSet;
    rd?: Maybe<Scalars['String']>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    tenant?: Maybe<TenantType>;
    tenantId?: Maybe<Scalars['ID']>;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
  };

export type VrfTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type VrfTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type VrfTypeResultSet = {
  __typename?: 'VRFTypeResultSet';
  data: Array<VrfType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type ValidationError = {
  __typename?: 'ValidationError';
  message: Scalars['String'];
};

export type VirtualChassisFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  domain?: InputMaybe<StrFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  master?: InputMaybe<DeviceFilter>;
  masterId?: InputMaybe<StrawberryIdFilter>;
  memberCount?: InputMaybe<IntFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type VirtualChassisFilterAndFilterEntry = {
  AND: Array<VirtualChassisFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type VirtualChassisFilterOrFilterEntry = {
  OR: Array<VirtualChassisFilter>;
  negate?: Scalars['Boolean'];
};

export type VirtualChassisType = AssetFederationBase &
  AssetType & {
    __typename?: 'VirtualChassisType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    domain?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    lastUpdated?: Maybe<Scalars['DateTime']>;
    master?: Maybe<DeviceType>;
    masterId?: Maybe<Scalars['ID']>;
    memberCount?: Maybe<Scalars['Int']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
  };

export type VirtualChassisTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type VirtualChassisTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type VirtualChassisTypeResultSet = {
  __typename?: 'VirtualChassisTypeResultSet';
  data: Array<VirtualChassisType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type VirtualMachineFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  cluster?: InputMaybe<ClusterFilter>;
  clusterId?: InputMaybe<StrawberryIdFilter>;
  comments?: InputMaybe<StrFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  disk?: InputMaybe<IntFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  localContextData?: InputMaybe<StrFilter>;
  memory?: InputMaybe<IntFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  platform?: InputMaybe<PlatformFilter>;
  platformId?: InputMaybe<StrawberryIdFilter>;
  primaryIp?: InputMaybe<IpAddressFilter>;
  primaryIp4?: InputMaybe<IpAddressFilter>;
  primaryIp4Id?: InputMaybe<StrawberryIdFilter>;
  primaryIp6?: InputMaybe<IpAddressFilter>;
  primaryIp6Id?: InputMaybe<StrawberryIdFilter>;
  primaryIpId?: InputMaybe<StrawberryIdFilter>;
  role?: InputMaybe<RoleFilter>;
  roleId?: InputMaybe<StrawberryIdFilter>;
  site?: InputMaybe<SiteFilter>;
  siteId?: InputMaybe<StrawberryIdFilter>;
  status?: InputMaybe<VirtualizationVirtualMachineStatusChoicesEnumFilter>;
  tenant?: InputMaybe<TenantFilter>;
  tenantId?: InputMaybe<StrawberryIdFilter>;
  uuid?: InputMaybe<StrFilter>;
  vcpus?: InputMaybe<FloatFilter>;
};

export type VirtualMachineFilterAndFilterEntry = {
  AND: Array<VirtualMachineFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type VirtualMachineFilterOrFilterEntry = {
  OR: Array<VirtualMachineFilter>;
  negate?: Scalars['Boolean'];
};

export type VirtualMachineType = AssetFederationBase &
  AssetType & {
    __typename?: 'VirtualMachineType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    cluster?: Maybe<ClusterType>;
    clusterId?: Maybe<Scalars['ID']>;
    comments?: Maybe<Scalars['String']>;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    disk?: Maybe<Scalars['Int']>;
    id: Scalars['ID'];
    lastUpdated?: Maybe<Scalars['DateTime']>;
    localContextData?: Maybe<Scalars['JSONString']>;
    memory?: Maybe<Scalars['Int']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    platform?: Maybe<PlatformType>;
    platformId?: Maybe<Scalars['ID']>;
    primaryIp?: Maybe<IpAddressType>;
    primaryIp4?: Maybe<IpAddressType>;
    primaryIp4Id?: Maybe<Scalars['ID']>;
    primaryIp6?: Maybe<IpAddressType>;
    primaryIp6Id?: Maybe<Scalars['ID']>;
    primaryIpId?: Maybe<Scalars['ID']>;
    role?: Maybe<RoleType>;
    roleId?: Maybe<Scalars['ID']>;
    services: ServiceTypeResultSet;
    site?: Maybe<SiteType>;
    siteId?: Maybe<Scalars['ID']>;
    status?: Maybe<VirtualizationVirtualMachineStatusChoices>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    tenant?: Maybe<TenantType>;
    tenantId?: Maybe<Scalars['ID']>;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
    vcpus?: Maybe<Scalars['Float']>;
    vmInterfaces: VmInterfaceTypeResultSet;
  };

export type VirtualMachineTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type VirtualMachineTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type VirtualMachineTypeResultSet = {
  __typename?: 'VirtualMachineTypeResultSet';
  data: Array<VirtualMachineType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export enum VirtualizationVmInterfaceModeChoices {
  ACCESS = 'ACCESS',
  TAGGED = 'TAGGED',
  TAGGED_ALL = 'TAGGED_ALL',
  UNKNOWN = 'UNKNOWN',
}

export type VirtualizationVmInterfaceModeChoicesEnumFilter = {
  exact?: InputMaybe<VirtualizationVmInterfaceModeChoices>;
  except_?: InputMaybe<VirtualizationVmInterfaceModeChoices>;
  in_?: InputMaybe<Array<VirtualizationVmInterfaceModeChoices>>;
};

export enum VirtualizationVirtualMachineStatusChoices {
  ACTIVE = 'ACTIVE',
  DECOMMISSIONING = 'DECOMMISSIONING',
  FAILED = 'FAILED',
  OFFLINE = 'OFFLINE',
  PLANNED = 'PLANNED',
  STAGED = 'STAGED',
  UNKNOWN = 'UNKNOWN',
}

export type VirtualizationVirtualMachineStatusChoicesEnumFilter = {
  exact?: InputMaybe<VirtualizationVirtualMachineStatusChoices>;
  except_?: InputMaybe<VirtualizationVirtualMachineStatusChoices>;
  in_?: InputMaybe<Array<VirtualizationVirtualMachineStatusChoices>>;
};

export enum WellFormedNameAttribute {
  EDITION = 'EDITION',
  LANGUAGE = 'LANGUAGE',
  OTHER = 'OTHER',
  PART = 'PART',
  PRODUCT = 'PRODUCT',
  SW_EDITION = 'SW_EDITION',
  TARGET_HW = 'TARGET_HW',
  TARGET_SW = 'TARGET_SW',
  UPDATE = 'UPDATE',
  VENDOR = 'VENDOR',
  VERSION = 'VERSION',
}

export enum WirelessLanAuthCipherChoices {
  AES = 'AES',
  AUTO = 'AUTO',
  TKIP = 'TKIP',
  UNKNOWN = 'UNKNOWN',
}

export type WirelessLanAuthCipherChoicesEnumFilter = {
  exact?: InputMaybe<WirelessLanAuthCipherChoices>;
  except_?: InputMaybe<WirelessLanAuthCipherChoices>;
  in_?: InputMaybe<Array<WirelessLanAuthCipherChoices>>;
};

export enum WirelessLanAuthTypeChoices {
  OPEN = 'OPEN',
  UNKNOWN = 'UNKNOWN',
  WEP = 'WEP',
  WPA_ENTERPRISE = 'WPA_ENTERPRISE',
  WPA_PERSONAL = 'WPA_PERSONAL',
}

export type WirelessLanAuthTypeChoicesEnumFilter = {
  exact?: InputMaybe<WirelessLanAuthTypeChoices>;
  except_?: InputMaybe<WirelessLanAuthTypeChoices>;
  in_?: InputMaybe<Array<WirelessLanAuthTypeChoices>>;
};

export type WirelessLanFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  authCipher?: InputMaybe<WirelessLanAuthCipherChoicesEnumFilter>;
  authPsk?: InputMaybe<StrFilter>;
  authType?: InputMaybe<WirelessLanAuthTypeChoicesEnumFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  group?: InputMaybe<WirelessLanGroupFilter>;
  groupId?: InputMaybe<StrawberryIdFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  ssid?: InputMaybe<StrFilter>;
  uuid?: InputMaybe<StrFilter>;
  vlan?: InputMaybe<VlanFilter>;
  vlanId?: InputMaybe<StrawberryIdFilter>;
};

export type WirelessLanFilterAndFilterEntry = {
  AND: Array<WirelessLanFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type WirelessLanFilterOrFilterEntry = {
  OR: Array<WirelessLanFilter>;
  negate?: Scalars['Boolean'];
};

export type WirelessLanGroupFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  name?: InputMaybe<StrFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  parent?: InputMaybe<WirelessLanGroupFilter>;
  parentId?: InputMaybe<StrawberryIdFilter>;
  slug?: InputMaybe<StrFilter>;
  uuid?: InputMaybe<StrFilter>;
  wirelesslanCount?: InputMaybe<IntFilter>;
};

export type WirelessLanGroupFilterAndFilterEntry = {
  AND: Array<WirelessLanGroupFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type WirelessLanGroupFilterOrFilterEntry = {
  OR: Array<WirelessLanGroupFilter>;
  negate?: Scalars['Boolean'];
};

export type WirelessLanGroupType = AssetFederationBase &
  AssetType & {
    __typename?: 'WirelessLanGroupType';
    Depth?: Maybe<Scalars['Int']>;
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    cases: CaseFederationResult;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    lastUpdated?: Maybe<Scalars['DateTime']>;
    name?: Maybe<Scalars['String']>;
    netboxUrl?: Maybe<Scalars['String']>;
    parent?: Maybe<WirelessLanGroupType>;
    parentId?: Maybe<Scalars['ID']>;
    slug?: Maybe<Scalars['String']>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
    wirelessLans: WirelessLanTypeResultSet;
    wirelesslanCount?: Maybe<Scalars['Int']>;
  };

export type WirelessLanGroupTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type WirelessLanGroupTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type WirelessLanGroupTypeResultSet = {
  __typename?: 'WirelessLanGroupTypeResultSet';
  data: Array<WirelessLanGroupType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type WirelessLanType = AssetFederationBase &
  AssetType & {
    __typename?: 'WirelessLanType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    authCipher?: Maybe<WirelessLanAuthCipherChoices>;
    authPsk?: Maybe<Scalars['String']>;
    authType?: Maybe<WirelessLanAuthTypeChoices>;
    cases: CaseFederationResult;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    group?: Maybe<WirelessLanGroupType>;
    groupId?: Maybe<Scalars['ID']>;
    id: Scalars['ID'];
    lastUpdated?: Maybe<Scalars['DateTime']>;
    netboxUrl?: Maybe<Scalars['String']>;
    ssid?: Maybe<Scalars['String']>;
    tagIds: Array<Scalars['ID']>;
    tags: TagTypeResultSet;
    tasks: TaskFederationResult;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
    vlan?: Maybe<VlanType>;
    vlanId?: Maybe<Scalars['ID']>;
  };

export type WirelessLanTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type WirelessLanTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type WirelessLanTypeResultSet = {
  __typename?: 'WirelessLanTypeResultSet';
  data: Array<WirelessLanType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export enum WirelessLinkAuthCipherChoices {
  AES = 'AES',
  AUTO = 'AUTO',
  TKIP = 'TKIP',
  UNKNOWN = 'UNKNOWN',
}

export type WirelessLinkAuthCipherChoicesEnumFilter = {
  exact?: InputMaybe<WirelessLinkAuthCipherChoices>;
  except_?: InputMaybe<WirelessLinkAuthCipherChoices>;
  in_?: InputMaybe<Array<WirelessLinkAuthCipherChoices>>;
};

export enum WirelessLinkAuthTypeChoices {
  OPEN = 'OPEN',
  UNKNOWN = 'UNKNOWN',
  WEP = 'WEP',
  WPA_ENTERPRISE = 'WPA_ENTERPRISE',
  WPA_PERSONAL = 'WPA_PERSONAL',
}

export type WirelessLinkAuthTypeChoicesEnumFilter = {
  exact?: InputMaybe<WirelessLinkAuthTypeChoices>;
  except_?: InputMaybe<WirelessLinkAuthTypeChoices>;
  in_?: InputMaybe<Array<WirelessLinkAuthTypeChoices>>;
};

export type WirelessLinkFilter = {
  Name?: InputMaybe<StrFilter>;
  assetType?: InputMaybe<KnownAssetsEnumEnumFilter>;
  authCipher?: InputMaybe<WirelessLinkAuthCipherChoicesEnumFilter>;
  authPsk?: InputMaybe<StrFilter>;
  authType?: InputMaybe<WirelessLinkAuthTypeChoicesEnumFilter>;
  created?: InputMaybe<DateTimeFilter>;
  customFields?: InputMaybe<StrFilter>;
  description?: InputMaybe<StrFilter>;
  id?: InputMaybe<StrawberryIdFilter>;
  interfaceA?: InputMaybe<InterfaceFilter>;
  interfaceAId?: InputMaybe<StrawberryIdFilter>;
  interfaceB?: InputMaybe<InterfaceFilter>;
  interfaceBId?: InputMaybe<StrawberryIdFilter>;
  lastUpdated?: InputMaybe<DateTimeFilter>;
  netboxUrl?: InputMaybe<StrFilter>;
  ssid?: InputMaybe<StrFilter>;
  status?: InputMaybe<WirelessLinkStatusChoicesEnumFilter>;
  uuid?: InputMaybe<StrFilter>;
};

export type WirelessLinkFilterAndFilterEntry = {
  AND: Array<WirelessLinkFilterOrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type WirelessLinkFilterOrFilterEntry = {
  OR: Array<WirelessLinkFilter>;
  negate?: Scalars['Boolean'];
};

export enum WirelessLinkStatusChoices {
  CONNECTED = 'CONNECTED',
  DECOMMISSIONING = 'DECOMMISSIONING',
  PLANNED = 'PLANNED',
  UNKNOWN = 'UNKNOWN',
}

export type WirelessLinkStatusChoicesEnumFilter = {
  exact?: InputMaybe<WirelessLinkStatusChoices>;
  except_?: InputMaybe<WirelessLinkStatusChoices>;
  in_?: InputMaybe<Array<WirelessLinkStatusChoices>>;
};

export type WirelessLinkType = AssetFederationBase &
  AssetType & {
    __typename?: 'WirelessLinkType';
    Name?: Maybe<Scalars['String']>;
    assetType: KnownAssetsEnum;
    authCipher?: Maybe<WirelessLinkAuthCipherChoices>;
    authPsk?: Maybe<Scalars['String']>;
    authType?: Maybe<WirelessLinkAuthTypeChoices>;
    cases: CaseFederationResult;
    created?: Maybe<Scalars['DateTime']>;
    customFieldData: Scalars['JSONString'];
    customFields?: Maybe<Scalars['GenericScalar']>;
    description?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    interfaceA?: Maybe<InterfaceType>;
    interfaceAId?: Maybe<Scalars['ID']>;
    interfaceB?: Maybe<InterfaceType>;
    interfaceBId?: Maybe<Scalars['ID']>;
    lastUpdated?: Maybe<Scalars['DateTime']>;
    netboxUrl?: Maybe<Scalars['String']>;
    ssid?: Maybe<Scalars['String']>;
    status?: Maybe<WirelessLinkStatusChoices>;
    tasks: TaskFederationResult;
    uniquePrefix: Scalars['String'];
    uuid?: Maybe<Scalars['String']>;
  };

export type WirelessLinkTypeCasesArgs = {
  filter?: InputMaybe<Array<CaseFilterAndFilterEntry>>;
};

export type WirelessLinkTypeTasksArgs = {
  filter?: InputMaybe<TaskFilterAndFilterEntry>;
};

export type WirelessLinkTypeResultSet = {
  __typename?: 'WirelessLinkTypeResultSet';
  data: Array<WirelessLinkType>;
  error?: Maybe<Scalars['String']>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type Workflow = {
  __typename?: 'Workflow';
  assignees?: Maybe<CaseDbUserNestedList>;
  case: Case;
  caseIdentifier?: Maybe<Scalars['String']>;
  created?: Maybe<Scalars['DateTime']>;
  createdBy?: Maybe<CaseDbUser>;
  description: Scalars['String'];
  dueDate?: Maybe<Scalars['DateTime']>;
  id: Scalars['ID'];
  lastUpdated?: Maybe<Scalars['DateTime']>;
  name: Scalars['String'];
  progress: Scalars['Float'];
  stages?: Maybe<StageNestedList>;
  state: WorkflowStateEnum;
  weight?: Maybe<Scalars['Int']>;
};

export type WorkflowAssigneesArgs = {
  filter?: InputMaybe<Array<CaseDbUserFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<CaseDbUserOrdEnumOrderingEntry>>;
};

export type WorkflowStagesArgs = {
  filter?: InputMaybe<Array<StageFilter0AndFilterEntry>>;
  limit?: InputMaybe<Scalars['Int']>;
  ordering?: InputMaybe<Array<StageOrdEnumOrderingEntry>>;
};

export type WorkflowCreate = {
  assignees?: InputMaybe<Array<Scalars['ID']>>;
  case: Scalars['ID'];
  created?: InputMaybe<Scalars['DateTime']>;
  createdBy?: InputMaybe<Scalars['ID']>;
  description: Scalars['String'];
  dueDate?: InputMaybe<Scalars['DateTime']>;
  lastUpdated?: InputMaybe<Scalars['DateTime']>;
  name: Scalars['String'];
  stages?: InputMaybe<Array<Scalars['ID']>>;
  weight?: InputMaybe<Scalars['Int']>;
};

export type WorkflowFilter0 = {
  caseIdentifier?: InputMaybe<StrFieldFilter>;
  created?: InputMaybe<DateTimeFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  dueDate?: InputMaybe<DateTimeFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  lastUpdated?: InputMaybe<DateTimeFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
  progress?: InputMaybe<FloatFieldFilter>;
  state?: InputMaybe<WorkflowStateEnumEnumFieldFilter>;
  weight?: InputMaybe<IntFieldFilter>;
};

export type WorkflowFilter0AndFilterEntry = {
  AND: Array<WorkflowFilter0OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type WorkflowFilter0OrFilterEntry = {
  OR: WorkflowFilter0;
  negate?: Scalars['Boolean'];
};

export type WorkflowFilter1 = {
  assignees?: InputMaybe<CaseDbUserFilter1>;
  case?: InputMaybe<CaseFilter1>;
  caseIdentifier?: InputMaybe<StrFieldFilter>;
  created?: InputMaybe<DateTimeFieldFilter>;
  createdBy?: InputMaybe<CaseDbUserFilter1>;
  description?: InputMaybe<StrFieldFilter>;
  dueDate?: InputMaybe<DateTimeFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  lastUpdated?: InputMaybe<DateTimeFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
  progress?: InputMaybe<FloatFieldFilter>;
  stages?: InputMaybe<StageFilter1>;
  state?: InputMaybe<WorkflowStateEnumEnumFieldFilter>;
  weight?: InputMaybe<IntFieldFilter>;
};

export type WorkflowFilter1AndFilterEntry = {
  AND: Array<WorkflowFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type WorkflowFilter1OrFilterEntry = {
  OR: WorkflowFilter1;
  negate?: Scalars['Boolean'];
};

export type WorkflowNestedList = {
  __typename?: 'WorkflowNestedList';
  data: Array<Workflow>;
  totalCount: Scalars['Int'];
};

export enum WorkflowOrdEnum {
  CASE_IDENTIFIER = 'CASE_IDENTIFIER',
  CREATED = 'CREATED',
  DESCRIPTION = 'DESCRIPTION',
  DUE_DATE = 'DUE_DATE',
  ID = 'ID',
  LAST_UPDATED = 'LAST_UPDATED',
  NAME = 'NAME',
  PROGRESS = 'PROGRESS',
  STATE = 'STATE',
  WEIGHT = 'WEIGHT',
}

export type WorkflowOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: WorkflowOrdEnum;
};

export type WorkflowPaginated = {
  __typename?: 'WorkflowPaginated';
  data: Array<Workflow>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export enum WorkflowStateEnum {
  DONE = 'DONE',
  IN_PROGRESS = 'IN_PROGRESS',
  REJECTED = 'REJECTED',
}

export type WorkflowStateEnumEnumFieldFilter = {
  exact?: InputMaybe<WorkflowStateEnum>;
  except_?: InputMaybe<WorkflowStateEnum>;
  in_?: InputMaybe<Array<WorkflowStateEnum>>;
  isnull?: InputMaybe<Scalars['Boolean']>;
};

export type WorkflowTemplate = {
  __typename?: 'WorkflowTemplate';
  created?: Maybe<Scalars['DateTime']>;
  description: Scalars['String'];
  id: Scalars['ID'];
  lastUpdated?: Maybe<Scalars['DateTime']>;
  name: Scalars['String'];
  src: Scalars['String'];
  template?: Maybe<Scalars['String']>;
};

export type WorkflowTemplateFilter1 = {
  created?: InputMaybe<DateTimeFieldFilter>;
  description?: InputMaybe<StrFieldFilter>;
  id?: InputMaybe<StrawberryIdFieldFilter>;
  lastUpdated?: InputMaybe<DateTimeFieldFilter>;
  name?: InputMaybe<StrFieldFilter>;
  template?: InputMaybe<StrFieldFilter>;
};

export type WorkflowTemplateFilter1AndFilterEntry = {
  AND: Array<WorkflowTemplateFilter1OrFilterEntry>;
  negate?: Scalars['Boolean'];
};

export type WorkflowTemplateFilter1OrFilterEntry = {
  OR: WorkflowTemplateFilter1;
  negate?: Scalars['Boolean'];
};

export type WorkflowTemplateInput = {
  id: Scalars['ID'];
  name?: InputMaybe<Scalars['String']>;
};

export enum WorkflowTemplateOrdEnum {
  CREATED = 'CREATED',
  DESCRIPTION = 'DESCRIPTION',
  ID = 'ID',
  LAST_UPDATED = 'LAST_UPDATED',
  NAME = 'NAME',
  TEMPLATE = 'TEMPLATE',
}

export type WorkflowTemplateOrdEnumOrderingEntry = {
  desc?: Scalars['Boolean'];
  o: WorkflowTemplateOrdEnum;
};

export type WorkflowTemplatePaginated = {
  __typename?: 'WorkflowTemplatePaginated';
  data: Array<WorkflowTemplate>;
  next?: Maybe<Scalars['String']>;
  previous?: Maybe<Scalars['String']>;
  totalCount: Scalars['Int'];
};

export type WorkflowTemplateUpdate = {
  created?: InputMaybe<Scalars['DateTime']>;
  description?: InputMaybe<Scalars['String']>;
  lastUpdated?: InputMaybe<Scalars['DateTime']>;
  name?: InputMaybe<Scalars['String']>;
  template?: InputMaybe<Scalars['String']>;
};

export type WorkflowUpdate = {
  assignees?: InputMaybe<RelationUpdate>;
  case?: InputMaybe<Scalars['ID']>;
  created?: InputMaybe<Scalars['DateTime']>;
  createdBy?: InputMaybe<Scalars['ID']>;
  description?: InputMaybe<Scalars['String']>;
  dueDate?: InputMaybe<Scalars['DateTime']>;
  lastUpdated?: InputMaybe<Scalars['DateTime']>;
  name?: InputMaybe<Scalars['String']>;
  stages?: InputMaybe<RelationUpdate>;
  weight?: InputMaybe<Scalars['Int']>;
};
