import { ChangeDetectionStrategy, Component } from '@angular/core';
import { MalwareProcedureOrdEnum } from '@orion/graphql-types';
import {
  MalwareProcedureFilterChipsService,
  MalwareProcedureFilterService,
} from '@orion/ttps-components/filters-malware-procedure';
import { MalwareProcedureClientFilter } from '@orion/ttps-types';
import { FilterService } from '@csirtmu-orion/microframework/filter-services';
import {
  INIT_PAGINATION_EVENT_BASE_TOKEN,
  PaginationBaseInit,
  PaginationService,
  QueryParamPaginationService,
} from '@csirtmu-orion/microframework/pagination-services';
import { EntityPaginableFilterableSmartOverviewDirective } from '@csirtmu-orion/microframework/entity-smart-directives';
import { MalwareProcedureOverviewElementFragment } from './graphql';
import { MalwareProcedureOverviewService } from './malware-procedure-overview.service';

@Component({
  selector: 'orion-malware-procedure-overview-page',
  templateUrl: './malware-procedure-overview-page.component.html',
  styleUrls: ['./malware-procedure-overview-page.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [
    MalwareProcedureOverviewService,
    MalwareProcedureFilterChipsService,
    {
      provide: FilterService,
      useClass: MalwareProcedureFilterService,
    },
    { provide: PaginationService, useClass: QueryParamPaginationService },
    {
      provide: INIT_PAGINATION_EVENT_BASE_TOKEN,
      useValue: new PaginationBaseInit(10, MalwareProcedureOrdEnum.MALWARE_PROCEDURE_NAME, 'asc'),
    },
  ],
})
export class MalwareProcedureOverviewPageComponent extends EntityPaginableFilterableSmartOverviewDirective<
  MalwareProcedureOverviewElementFragment,
  MalwareProcedureClientFilter
> {
  constructor(
    protected paginationService: PaginationService,
    protected malwareService: MalwareProcedureOverviewService,
    protected filterService: FilterService<MalwareProcedureClientFilter>,
    protected filterChipsService: MalwareProcedureFilterChipsService
  ) {
    super(malwareService, filterService, paginationService, filterChipsService);
  }
}
