import { Injectable } from '@angular/core';
import { MalwareProcedureFilter1AndFilterEntry, MalwareProcedureOrdEnum } from '@orion/graphql-types';
import { MalwareProcedureClientFilter, MalwareProcedureFilterConverter } from '@orion/ttps-types';
import { FilterConverter } from '@csirtmu-orion/microframework/filter';
import { CursorPaginatedResponse } from '@csirtmu-orion/microframework/graphql';
import { IPaginationEvent } from '@sentinel/common/pagination';
import { enumFromValue, Optional } from '@sentinel/common/utils';
import {
  MalwareProcedureOverviewElementFragment,
  MalwareProcedureOverviewQuery,
  MalwareProcedureOverviewQueryService,
  MalwareProcedureOverviewQueryVariables,
} from './graphql';
import { ApolloPaginatedFilterablePollingService } from '@orion/shared-services';

@Injectable()
export class MalwareProcedureOverviewService extends ApolloPaginatedFilterablePollingService<
  MalwareProcedureOverviewQuery,
  MalwareProcedureOverviewQueryVariables,
  MalwareProcedureOverviewElementFragment,
  MalwareProcedureOrdEnum,
  MalwareProcedureClientFilter,
  MalwareProcedureFilter1AndFilterEntry
> {
  constructor(public getQuery: MalwareProcedureOverviewQueryService) {
    super(getQuery, 'Fetching malware procedures');
  }

  protected createFilterConverter(): FilterConverter<
    MalwareProcedureClientFilter,
    MalwareProcedureFilter1AndFilterEntry[]
  > {
    return new MalwareProcedureFilterConverter();
  }

  protected createVariables(
    paginationEvent: IPaginationEvent,
    clientFilter: MalwareProcedureClientFilter,
    args: unknown
  ): MalwareProcedureOverviewQueryVariables {
    return {
      ...this.createPaginationVariables(paginationEvent),
      ...this.createOrderVariables(paginationEvent.sort, paginationEvent.sortDir),
      ...this.createFilterVariables(clientFilter),
    };
  }

  protected getQueryResponse(
    query: MalwareProcedureOverviewQuery
  ): CursorPaginatedResponse<MalwareProcedureOverviewElementFragment> {
    return query?.getMalwareProcedureList;
  }

  protected strToOrderable(sort: string): Optional<MalwareProcedureOrdEnum> {
    return enumFromValue(MalwareProcedureOrdEnum, sort);
  }
}
